# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlTObjDrivers module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmltobjdrivers.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlTObjDrivers
else:
    import _XmlTObjDrivers

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlTObjDrivers.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlTObjDrivers.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlTObjDrivers.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlTObjDrivers.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlTObjDrivers.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlTObjDrivers.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlTObjDrivers.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlTObjDrivers.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlTObjDrivers.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlTObjDrivers.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlTObjDrivers.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlTObjDrivers.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlTObjDrivers.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlTObjDrivers.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlTObjDrivers.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlTObjDrivers.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlTObjDrivers.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlTObjDrivers:
_XmlTObjDrivers.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlTObjDrivers.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.XmlMDF
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TDF
import OCC.Core.XmlObjMgt
import OCC.Core.LDOM
import OCC.Core.gp
import OCC.Core.Storage
import OCC.Core.TDocStd
import OCC.Core.CDF
import OCC.Core.CDM
import OCC.Core.Resource
import OCC.Core.PCDM
import OCC.Core.XmlLDrivers

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XmlTObjDrivers_DocumentRetrievalDriver_Create() -> "opencascade::handle< XmlTObjDrivers_DocumentRetrievalDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_DocumentRetrievalDriver_Create()

def Handle_XmlTObjDrivers_DocumentRetrievalDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlTObjDrivers_DocumentRetrievalDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_DocumentRetrievalDriver_DownCast(t)

def Handle_XmlTObjDrivers_DocumentRetrievalDriver_IsNull(t: "opencascade::handle< XmlTObjDrivers_DocumentRetrievalDriver > const &") -> "bool":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_DocumentRetrievalDriver_IsNull(t)

def Handle_XmlTObjDrivers_DocumentStorageDriver_Create() -> "opencascade::handle< XmlTObjDrivers_DocumentStorageDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_DocumentStorageDriver_Create()

def Handle_XmlTObjDrivers_DocumentStorageDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlTObjDrivers_DocumentStorageDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_DocumentStorageDriver_DownCast(t)

def Handle_XmlTObjDrivers_DocumentStorageDriver_IsNull(t: "opencascade::handle< XmlTObjDrivers_DocumentStorageDriver > const &") -> "bool":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_DocumentStorageDriver_IsNull(t)

def Handle_XmlTObjDrivers_IntSparseArrayDriver_Create() -> "opencascade::handle< XmlTObjDrivers_IntSparseArrayDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_IntSparseArrayDriver_Create()

def Handle_XmlTObjDrivers_IntSparseArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlTObjDrivers_IntSparseArrayDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_IntSparseArrayDriver_DownCast(t)

def Handle_XmlTObjDrivers_IntSparseArrayDriver_IsNull(t: "opencascade::handle< XmlTObjDrivers_IntSparseArrayDriver > const &") -> "bool":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_IntSparseArrayDriver_IsNull(t)

def Handle_XmlTObjDrivers_ModelDriver_Create() -> "opencascade::handle< XmlTObjDrivers_ModelDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_ModelDriver_Create()

def Handle_XmlTObjDrivers_ModelDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlTObjDrivers_ModelDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_ModelDriver_DownCast(t)

def Handle_XmlTObjDrivers_ModelDriver_IsNull(t: "opencascade::handle< XmlTObjDrivers_ModelDriver > const &") -> "bool":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_ModelDriver_IsNull(t)

def Handle_XmlTObjDrivers_ObjectDriver_Create() -> "opencascade::handle< XmlTObjDrivers_ObjectDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_ObjectDriver_Create()

def Handle_XmlTObjDrivers_ObjectDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlTObjDrivers_ObjectDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_ObjectDriver_DownCast(t)

def Handle_XmlTObjDrivers_ObjectDriver_IsNull(t: "opencascade::handle< XmlTObjDrivers_ObjectDriver > const &") -> "bool":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_ObjectDriver_IsNull(t)

def Handle_XmlTObjDrivers_ReferenceDriver_Create() -> "opencascade::handle< XmlTObjDrivers_ReferenceDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_ReferenceDriver_Create()

def Handle_XmlTObjDrivers_ReferenceDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlTObjDrivers_ReferenceDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_ReferenceDriver_DownCast(t)

def Handle_XmlTObjDrivers_ReferenceDriver_IsNull(t: "opencascade::handle< XmlTObjDrivers_ReferenceDriver > const &") -> "bool":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_ReferenceDriver_IsNull(t)

def Handle_XmlTObjDrivers_XYZDriver_Create() -> "opencascade::handle< XmlTObjDrivers_XYZDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_XYZDriver_Create()

def Handle_XmlTObjDrivers_XYZDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlTObjDrivers_XYZDriver >":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_XYZDriver_DownCast(t)

def Handle_XmlTObjDrivers_XYZDriver_IsNull(t: "opencascade::handle< XmlTObjDrivers_XYZDriver > const &") -> "bool":
    return _XmlTObjDrivers.Handle_XmlTObjDrivers_XYZDriver_IsNull(t)
class xmltobjdrivers(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDriverTable: XmlMDF_ADriverTable
        anMsgDrv: Message_Messenger

        Returns
        -------
        None

        """
        return _XmlTObjDrivers.xmltobjdrivers_AddDrivers(*args)

    @staticmethod
    def DefineFormat(*args) -> "void":
        r"""
        Defines format 'tobjxml' and registers its read and write drivers in the specified application.

        Parameters
        ----------
        theApp: TDocStd_Application

        Returns
        -------
        None

        """
        return _XmlTObjDrivers.xmltobjdrivers_DefineFormat(*args)

    @staticmethod
    def Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
        r"""
        Returns a driver corresponding to <aguid>. used for plugin.

        Parameters
        ----------
        aGUID: Standard_GUID

        Returns
        -------
        opencascade::handle<Standard_Transient>

        """
        return _XmlTObjDrivers.xmltobjdrivers_Factory(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlTObjDrivers.xmltobjdrivers_swiginit(self, _XmlTObjDrivers.new_xmltobjdrivers())
    __swig_destroy__ = _XmlTObjDrivers.delete_xmltobjdrivers

# Register xmltobjdrivers in _XmlTObjDrivers:
_XmlTObjDrivers.xmltobjdrivers_swigregister(xmltobjdrivers)

def xmltobjdrivers_AddDrivers(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aDriverTable: XmlMDF_ADriverTable
    anMsgDrv: Message_Messenger

    Returns
    -------
    None

    """
    return _XmlTObjDrivers.xmltobjdrivers_AddDrivers(*args)

def xmltobjdrivers_DefineFormat(*args) -> "void":
    r"""
    Defines format 'tobjxml' and registers its read and write drivers in the specified application.

    Parameters
    ----------
    theApp: TDocStd_Application

    Returns
    -------
    None

    """
    return _XmlTObjDrivers.xmltobjdrivers_DefineFormat(*args)

def xmltobjdrivers_Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
    r"""
    Returns a driver corresponding to <aguid>. used for plugin.

    Parameters
    ----------
    aGUID: Standard_GUID

    Returns
    -------
    opencascade::handle<Standard_Transient>

    """
    return _XmlTObjDrivers.xmltobjdrivers_Factory(*args)

class XmlTObjDrivers_DocumentRetrievalDriver(OCC.Core.XmlLDrivers.XmlLDrivers_DocumentRetrievalDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _XmlTObjDrivers.XmlTObjDrivers_DocumentRetrievalDriver_swiginit(self, _XmlTObjDrivers.new_XmlTObjDrivers_DocumentRetrievalDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_XmlTObjDrivers_DocumentRetrievalDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlTObjDrivers.delete_XmlTObjDrivers_DocumentRetrievalDriver

# Register XmlTObjDrivers_DocumentRetrievalDriver in _XmlTObjDrivers:
_XmlTObjDrivers.XmlTObjDrivers_DocumentRetrievalDriver_swigregister(XmlTObjDrivers_DocumentRetrievalDriver)

class XmlTObjDrivers_DocumentStorageDriver(OCC.Core.XmlLDrivers.XmlLDrivers_DocumentStorageDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theCopyright: TCollection_ExtendedString

        Returns
        -------
        None

        """
        _XmlTObjDrivers.XmlTObjDrivers_DocumentStorageDriver_swiginit(self, _XmlTObjDrivers.new_XmlTObjDrivers_DocumentStorageDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_XmlTObjDrivers_DocumentStorageDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlTObjDrivers.delete_XmlTObjDrivers_DocumentStorageDriver

# Register XmlTObjDrivers_DocumentStorageDriver in _XmlTObjDrivers:
_XmlTObjDrivers.XmlTObjDrivers_DocumentStorageDriver_swigregister(XmlTObjDrivers_DocumentStorageDriver)

class XmlTObjDrivers_IntSparseArrayDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlTObjDrivers.XmlTObjDrivers_IntSparseArrayDriver_swiginit(self, _XmlTObjDrivers.new_XmlTObjDrivers_IntSparseArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: XmlObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: XmlObjMgt_Persistent
        theRelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlTObjDrivers.XmlTObjDrivers_IntSparseArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlTObjDrivers_IntSparseArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlTObjDrivers.delete_XmlTObjDrivers_IntSparseArrayDriver

# Register XmlTObjDrivers_IntSparseArrayDriver in _XmlTObjDrivers:
_XmlTObjDrivers.XmlTObjDrivers_IntSparseArrayDriver_swigregister(XmlTObjDrivers_IntSparseArrayDriver)

class XmlTObjDrivers_ModelDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlTObjDrivers.XmlTObjDrivers_ModelDriver_swiginit(self, _XmlTObjDrivers.new_XmlTObjDrivers_ModelDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlTObjDrivers.XmlTObjDrivers_ModelDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlTObjDrivers_ModelDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlTObjDrivers.delete_XmlTObjDrivers_ModelDriver

# Register XmlTObjDrivers_ModelDriver in _XmlTObjDrivers:
_XmlTObjDrivers.XmlTObjDrivers_ModelDriver_swigregister(XmlTObjDrivers_ModelDriver)

class XmlTObjDrivers_ObjectDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlTObjDrivers.XmlTObjDrivers_ObjectDriver_swiginit(self, _XmlTObjDrivers.new_XmlTObjDrivers_ObjectDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlTObjDrivers.XmlTObjDrivers_ObjectDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlTObjDrivers_ObjectDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlTObjDrivers.delete_XmlTObjDrivers_ObjectDriver

# Register XmlTObjDrivers_ObjectDriver in _XmlTObjDrivers:
_XmlTObjDrivers.XmlTObjDrivers_ObjectDriver_swigregister(XmlTObjDrivers_ObjectDriver)

class XmlTObjDrivers_ReferenceDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlTObjDrivers.XmlTObjDrivers_ReferenceDriver_swiginit(self, _XmlTObjDrivers.new_XmlTObjDrivers_ReferenceDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlTObjDrivers.XmlTObjDrivers_ReferenceDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlTObjDrivers_ReferenceDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlTObjDrivers.delete_XmlTObjDrivers_ReferenceDriver

# Register XmlTObjDrivers_ReferenceDriver in _XmlTObjDrivers:
_XmlTObjDrivers.XmlTObjDrivers_ReferenceDriver_swigregister(XmlTObjDrivers_ReferenceDriver)

class XmlTObjDrivers_XYZDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlTObjDrivers.XmlTObjDrivers_XYZDriver_swiginit(self, _XmlTObjDrivers.new_XmlTObjDrivers_XYZDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlTObjDrivers.XmlTObjDrivers_XYZDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlTObjDrivers_XYZDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlTObjDrivers.delete_XmlTObjDrivers_XYZDriver

# Register XmlTObjDrivers_XYZDriver in _XmlTObjDrivers:
_XmlTObjDrivers.XmlTObjDrivers_XYZDriver_swigregister(XmlTObjDrivers_XYZDriver)





