# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
IMeshTools module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_imeshtools.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _IMeshTools
else:
    import _IMeshTools

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _IMeshTools.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _IMeshTools.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IMeshTools.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IMeshTools.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _IMeshTools.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _IMeshTools.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _IMeshTools.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _IMeshTools.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _IMeshTools.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _IMeshTools.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IMeshTools.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _IMeshTools.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _IMeshTools.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IMeshTools.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IMeshTools.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IMeshTools.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _IMeshTools.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _IMeshTools:
_IMeshTools.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _IMeshTools.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.IMeshData
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.BRepAdaptor
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor

from enum import IntEnum
from OCC.Core.Exception import *

IMeshTools_MeshAlgoType_DEFAULT = _IMeshTools.IMeshTools_MeshAlgoType_DEFAULT
IMeshTools_MeshAlgoType_Watson = _IMeshTools.IMeshTools_MeshAlgoType_Watson
IMeshTools_MeshAlgoType_Delabella = _IMeshTools.IMeshTools_MeshAlgoType_Delabella


class IMeshTools_MeshAlgoType(IntEnum):
	IMeshTools_MeshAlgoType_DEFAULT = - 1
	IMeshTools_MeshAlgoType_Watson = 0
	IMeshTools_MeshAlgoType_Delabella = 1
IMeshTools_MeshAlgoType_DEFAULT = IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_DEFAULT
IMeshTools_MeshAlgoType_Watson = IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_Watson
IMeshTools_MeshAlgoType_Delabella = IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_Delabella


def Handle_IMeshTools_Context_Create() -> "opencascade::handle< IMeshTools_Context >":
    return _IMeshTools.Handle_IMeshTools_Context_Create()

def Handle_IMeshTools_Context_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_Context >":
    return _IMeshTools.Handle_IMeshTools_Context_DownCast(t)

def Handle_IMeshTools_Context_IsNull(t: "opencascade::handle< IMeshTools_Context > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_Context_IsNull(t)

def Handle_IMeshTools_CurveTessellator_Create() -> "opencascade::handle< IMeshTools_CurveTessellator >":
    return _IMeshTools.Handle_IMeshTools_CurveTessellator_Create()

def Handle_IMeshTools_CurveTessellator_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_CurveTessellator >":
    return _IMeshTools.Handle_IMeshTools_CurveTessellator_DownCast(t)

def Handle_IMeshTools_CurveTessellator_IsNull(t: "opencascade::handle< IMeshTools_CurveTessellator > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_CurveTessellator_IsNull(t)

def Handle_IMeshTools_MeshAlgo_Create() -> "opencascade::handle< IMeshTools_MeshAlgo >":
    return _IMeshTools.Handle_IMeshTools_MeshAlgo_Create()

def Handle_IMeshTools_MeshAlgo_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_MeshAlgo >":
    return _IMeshTools.Handle_IMeshTools_MeshAlgo_DownCast(t)

def Handle_IMeshTools_MeshAlgo_IsNull(t: "opencascade::handle< IMeshTools_MeshAlgo > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_MeshAlgo_IsNull(t)

def Handle_IMeshTools_MeshAlgoFactory_Create() -> "opencascade::handle< IMeshTools_MeshAlgoFactory >":
    return _IMeshTools.Handle_IMeshTools_MeshAlgoFactory_Create()

def Handle_IMeshTools_MeshAlgoFactory_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_MeshAlgoFactory >":
    return _IMeshTools.Handle_IMeshTools_MeshAlgoFactory_DownCast(t)

def Handle_IMeshTools_MeshAlgoFactory_IsNull(t: "opencascade::handle< IMeshTools_MeshAlgoFactory > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_MeshAlgoFactory_IsNull(t)

def Handle_IMeshTools_ModelAlgo_Create() -> "opencascade::handle< IMeshTools_ModelAlgo >":
    return _IMeshTools.Handle_IMeshTools_ModelAlgo_Create()

def Handle_IMeshTools_ModelAlgo_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_ModelAlgo >":
    return _IMeshTools.Handle_IMeshTools_ModelAlgo_DownCast(t)

def Handle_IMeshTools_ModelAlgo_IsNull(t: "opencascade::handle< IMeshTools_ModelAlgo > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_ModelAlgo_IsNull(t)

def Handle_IMeshTools_ShapeExplorer_Create() -> "opencascade::handle< IMeshTools_ShapeExplorer >":
    return _IMeshTools.Handle_IMeshTools_ShapeExplorer_Create()

def Handle_IMeshTools_ShapeExplorer_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_ShapeExplorer >":
    return _IMeshTools.Handle_IMeshTools_ShapeExplorer_DownCast(t)

def Handle_IMeshTools_ShapeExplorer_IsNull(t: "opencascade::handle< IMeshTools_ShapeExplorer > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_ShapeExplorer_IsNull(t)

def Handle_IMeshTools_ShapeVisitor_Create() -> "opencascade::handle< IMeshTools_ShapeVisitor >":
    return _IMeshTools.Handle_IMeshTools_ShapeVisitor_Create()

def Handle_IMeshTools_ShapeVisitor_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_ShapeVisitor >":
    return _IMeshTools.Handle_IMeshTools_ShapeVisitor_DownCast(t)

def Handle_IMeshTools_ShapeVisitor_IsNull(t: "opencascade::handle< IMeshTools_ShapeVisitor > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_ShapeVisitor_IsNull(t)
class IMeshTools_Context(OCC.Core.IMeshData.IMeshData_Shape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructor.

        Returns
        -------
        None

        """
        _IMeshTools.IMeshTools_Context_swiginit(self, _IMeshTools.new_IMeshTools_Context(*args))

    def BuildModel(self, *args) -> "Standard_Boolean":
        r"""
        Builds model using assined model builder. returns true on success, false elsewhere.

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_Context_BuildModel(self, *args)

    def ChangeParameters(self, *args) -> "IMeshTools_Parameters &":
        r"""
        Gets reference to parameters to be used for meshing.

        Returns
        -------
        IMeshTools_Parameters

        """
        return _IMeshTools.IMeshTools_Context_ChangeParameters(self, *args)

    def Clean(self, *args) -> "void":
        r"""
        Cleans temporary context data.

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_Clean(self, *args)

    def DiscretizeEdges(self, *args) -> "Standard_Boolean":
        r"""
        Performs discretization of model edges using assigned edge discret algorithm. returns true on success, false elsewhere.

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_Context_DiscretizeEdges(self, *args)

    def DiscretizeFaces(self, *args) -> "Standard_Boolean":
        r"""
        Performs meshing of faces of discrete model using assigned meshing algorithm. returns true on success, false elsewhere.

        Parameters
        ----------
        theRange: Message_ProgressRange

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_Context_DiscretizeFaces(self, *args)

    def GetFaceDiscret(self, *args) -> "opencascade::handle< IMeshTools_ModelAlgo > const &":
        r"""
        Gets instance of meshing algorithm.

        Returns
        -------
        opencascade::handle<IMeshTools_ModelAlgo>

        """
        return _IMeshTools.IMeshTools_Context_GetFaceDiscret(self, *args)

    def GetModelHealer(self, *args) -> "opencascade::handle< IMeshTools_ModelAlgo > const &":
        r"""
        Gets instance of a tool to be used to heal discrete model.

        Returns
        -------
        opencascade::handle<IMeshTools_ModelAlgo>

        """
        return _IMeshTools.IMeshTools_Context_GetModelHealer(self, *args)

    def GetParameters(self, *args) -> "IMeshTools_Parameters const &":
        r"""
        Gets parameters to be used for meshing.

        Returns
        -------
        IMeshTools_Parameters

        """
        return _IMeshTools.IMeshTools_Context_GetParameters(self, *args)

    def GetPostProcessor(self, *args) -> "opencascade::handle< IMeshTools_ModelAlgo > const &":
        r"""
        Gets instance of post-processing algorithm.

        Returns
        -------
        opencascade::handle<IMeshTools_ModelAlgo>

        """
        return _IMeshTools.IMeshTools_Context_GetPostProcessor(self, *args)

    def GetPreProcessor(self, *args) -> "opencascade::handle< IMeshTools_ModelAlgo > const &":
        r"""
        Gets instance of pre-processing algorithm.

        Returns
        -------
        opencascade::handle<IMeshTools_ModelAlgo>

        """
        return _IMeshTools.IMeshTools_Context_GetPreProcessor(self, *args)

    def HealModel(self, *args) -> "Standard_Boolean":
        r"""
        Performs healing of discrete model built by discretizeedges() method using assigned healing algorithm. returns true on success, false elsewhere.

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_Context_HealModel(self, *args)

    def PostProcessModel(self, *args) -> "Standard_Boolean":
        r"""
        Performs post-processing of discrete model using assigned algorithm. returns true on success, false elsewhere.

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_Context_PostProcessModel(self, *args)

    def PreProcessModel(self, *args) -> "Standard_Boolean":
        r"""
        Performs pre-processing of discrete model using assigned algorithm. performs auxiliary actions such as cleaning shape from old triangulation. returns true on success, false elsewhere.

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_Context_PreProcessModel(self, *args)

    def SetEdgeDiscret(self, *args) -> "void":
        r"""
        Sets instance of a tool to be used to discretize edges of a model.

        Parameters
        ----------
        theEdgeDiscret: Handle ( IMeshTools_ModelAlgo )

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_SetEdgeDiscret(self, *args)

    def SetFaceDiscret(self, *args) -> "void":
        r"""
        Sets instance of meshing algorithm.

        Parameters
        ----------
        theFaceDiscret: IMeshTools_ModelAlgo

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_SetFaceDiscret(self, *args)

    def SetModelBuilder(self, *args) -> "void":
        r"""
        Sets instance of a tool to be used to build discrete model.

        Parameters
        ----------
        theBuilder: Handle ( IMeshTools_ModelBuilder )

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_SetModelBuilder(self, *args)

    def SetModelHealer(self, *args) -> "void":
        r"""
        Sets instance of a tool to be used to heal discrete model.

        Parameters
        ----------
        theModelHealer: IMeshTools_ModelAlgo

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_SetModelHealer(self, *args)

    def SetPostProcessor(self, *args) -> "void":
        r"""
        Sets instance of post-processing algorithm.

        Parameters
        ----------
        thePostProcessor: IMeshTools_ModelAlgo

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_SetPostProcessor(self, *args)

    def SetPreProcessor(self, *args) -> "void":
        r"""
        Sets instance of pre-processing algorithm.

        Parameters
        ----------
        thePreProcessor: IMeshTools_ModelAlgo

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_SetPreProcessor(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_Context_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_Context

# Register IMeshTools_Context in _IMeshTools:
_IMeshTools.IMeshTools_Context_swigregister(IMeshTools_Context)

class IMeshTools_CurveTessellator(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def PointsNb(self, *args) -> "Standard_Integer":
        r"""
        Returns number of tessellation points.

        Returns
        -------
        int

        """
        return _IMeshTools.IMeshTools_CurveTessellator_PointsNb(self, *args)

    def Value(self, *args) -> "Standard_Boolean":
        r"""
        Returns parameters of solution with the given index. @param theindex index of tessellation point. @param thepoint tessellation point. @param theparameter parameters on pcurve corresponded to the solution. returns true in case of valid result, false elewhere.

        Parameters
        ----------
        theIndex: int
        thePoint: gp_Pnt

        Returns
        -------
        theParameter: float

        """
        return _IMeshTools.IMeshTools_CurveTessellator_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_CurveTessellator_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_CurveTessellator

# Register IMeshTools_CurveTessellator in _IMeshTools:
_IMeshTools.IMeshTools_CurveTessellator_swigregister(IMeshTools_CurveTessellator)

class IMeshTools_MeshAlgo(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Perform(self, *args) -> "void":
        r"""
        Performs processing of the given face.

        Parameters
        ----------
        theDFace: IMeshData::IFaceHandle
        theParameters: IMeshTools_Parameters
        theRange: Message_ProgressRange

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_MeshAlgo_Perform(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_MeshAlgo_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_MeshAlgo

# Register IMeshTools_MeshAlgo in _IMeshTools:
_IMeshTools.IMeshTools_MeshAlgo_swigregister(IMeshTools_MeshAlgo)

class IMeshTools_MeshAlgoFactory(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetAlgo(self, *args) -> "opencascade::handle< IMeshTools_MeshAlgo >":
        r"""
        Creates instance of meshing algorithm for the given type of surface.

        Parameters
        ----------
        theSurfaceType: GeomAbs_SurfaceType
        theParameters: IMeshTools_Parameters

        Returns
        -------
        opencascade::handle<IMeshTools_MeshAlgo>

        """
        return _IMeshTools.IMeshTools_MeshAlgoFactory_GetAlgo(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_MeshAlgoFactory_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_MeshAlgoFactory

# Register IMeshTools_MeshAlgoFactory in _IMeshTools:
_IMeshTools.IMeshTools_MeshAlgoFactory_swigregister(IMeshTools_MeshAlgoFactory)

class IMeshTools_MeshBuilder(OCC.Core.Message.Message_Algorithm):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructor.

        Returns
        -------
        None
        Constructor.

        Parameters
        ----------
        theContext: Handle ( IMeshTools_Context )

        Returns
        -------
        None

        """
        _IMeshTools.IMeshTools_MeshBuilder_swiginit(self, _IMeshTools.new_IMeshTools_MeshBuilder(*args))

    def Perform(self, *args) -> "void":
        r"""
        Performs meshing ot the shape using current context.

        Parameters
        ----------
        theRange: Message_ProgressRange

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_MeshBuilder_Perform(self, *args)

    def SetContext(self, *args) -> "void":
        r"""
        Sets context for algorithm.

        Parameters
        ----------
        theContext: Handle ( IMeshTools_Context )

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_MeshBuilder_SetContext(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_MeshBuilder

# Register IMeshTools_MeshBuilder in _IMeshTools:
_IMeshTools.IMeshTools_MeshBuilder_swigregister(IMeshTools_MeshBuilder)

class IMeshTools_ModelAlgo(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Perform(self, *args) -> "Standard_Boolean":
        r"""
        Exceptions protected processing of the given model.

        Parameters
        ----------
        theModel: Handle ( IMeshData_Model )
        theParameters: IMeshTools_Parameters
        theRange: Message_ProgressRange

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_ModelAlgo_Perform(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_ModelAlgo_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_ModelAlgo

# Register IMeshTools_ModelAlgo in _IMeshTools:
_IMeshTools.IMeshTools_ModelAlgo_swigregister(IMeshTools_ModelAlgo)

class IMeshTools_ModelBuilder(OCC.Core.Message.Message_Algorithm):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_ModelBuilder

# Register IMeshTools_ModelBuilder in _IMeshTools:
_IMeshTools.IMeshTools_ModelBuilder_swigregister(IMeshTools_ModelBuilder)

class IMeshTools_Parameters(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    MeshAlgo = property(_IMeshTools.IMeshTools_Parameters_MeshAlgo_get, _IMeshTools.IMeshTools_Parameters_MeshAlgo_set)
    Angle = property(_IMeshTools.IMeshTools_Parameters_Angle_get, _IMeshTools.IMeshTools_Parameters_Angle_set)
    Deflection = property(_IMeshTools.IMeshTools_Parameters_Deflection_get, _IMeshTools.IMeshTools_Parameters_Deflection_set)
    AngleInterior = property(_IMeshTools.IMeshTools_Parameters_AngleInterior_get, _IMeshTools.IMeshTools_Parameters_AngleInterior_set)
    DeflectionInterior = property(_IMeshTools.IMeshTools_Parameters_DeflectionInterior_get, _IMeshTools.IMeshTools_Parameters_DeflectionInterior_set)
    MinSize = property(_IMeshTools.IMeshTools_Parameters_MinSize_get, _IMeshTools.IMeshTools_Parameters_MinSize_set)
    InParallel = property(_IMeshTools.IMeshTools_Parameters_InParallel_get, _IMeshTools.IMeshTools_Parameters_InParallel_set)
    Relative = property(_IMeshTools.IMeshTools_Parameters_Relative_get, _IMeshTools.IMeshTools_Parameters_Relative_set)
    InternalVerticesMode = property(_IMeshTools.IMeshTools_Parameters_InternalVerticesMode_get, _IMeshTools.IMeshTools_Parameters_InternalVerticesMode_set)
    ControlSurfaceDeflection = property(_IMeshTools.IMeshTools_Parameters_ControlSurfaceDeflection_get, _IMeshTools.IMeshTools_Parameters_ControlSurfaceDeflection_set)
    CleanModel = property(_IMeshTools.IMeshTools_Parameters_CleanModel_get, _IMeshTools.IMeshTools_Parameters_CleanModel_set)
    AdjustMinSize = property(_IMeshTools.IMeshTools_Parameters_AdjustMinSize_get, _IMeshTools.IMeshTools_Parameters_AdjustMinSize_set)
    ForceFaceDeflection = property(_IMeshTools.IMeshTools_Parameters_ForceFaceDeflection_get, _IMeshTools.IMeshTools_Parameters_ForceFaceDeflection_set)
    AllowQualityDecrease = property(_IMeshTools.IMeshTools_Parameters_AllowQualityDecrease_get, _IMeshTools.IMeshTools_Parameters_AllowQualityDecrease_set)

    def __init__(self, *args):
        r"""
        Default constructor.

        Returns
        -------
        None

        """
        _IMeshTools.IMeshTools_Parameters_swiginit(self, _IMeshTools.new_IMeshTools_Parameters(*args))

    @staticmethod
    def RelMinSize(*args) -> "Standard_Real":
        r"""
        Returns factor used to compute default value of minsize (minimum mesh edge length) from deflection.

        Returns
        -------
        float

        """
        return _IMeshTools.IMeshTools_Parameters_RelMinSize(*args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_Parameters

# Register IMeshTools_Parameters in _IMeshTools:
_IMeshTools.IMeshTools_Parameters_swigregister(IMeshTools_Parameters)

def IMeshTools_Parameters_RelMinSize(*args) -> "Standard_Real":
    r"""
    Returns factor used to compute default value of minsize (minimum mesh edge length) from deflection.

    Returns
    -------
    float

    """
    return _IMeshTools.IMeshTools_Parameters_RelMinSize(*args)

class IMeshTools_ShapeExplorer(OCC.Core.IMeshData.IMeshData_Shape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructor.

        Parameters
        ----------
        theShape: TopoDS_Shape

        Returns
        -------
        None

        """
        _IMeshTools.IMeshTools_ShapeExplorer_swiginit(self, _IMeshTools.new_IMeshTools_ShapeExplorer(*args))

    def Accept(self, *args) -> "void":
        r"""
        Starts exploring of a shape.

        Parameters
        ----------
        theVisitor: Handle ( IMeshTools_ShapeVisitor )

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_ShapeExplorer_Accept(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_ShapeExplorer_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_ShapeExplorer

# Register IMeshTools_ShapeExplorer in _IMeshTools:
_IMeshTools.IMeshTools_ShapeExplorer_swigregister(IMeshTools_ShapeExplorer)

class IMeshTools_ShapeVisitor(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Visit(self, *args) -> "void":
        r"""
        Handles topods_face object.

        Parameters
        ----------
        theFace: TopoDS_Face

        Returns
        -------
        None
        Handles topods_edge object.

        Parameters
        ----------
        theEdge: TopoDS_Edge

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_ShapeVisitor_Visit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_ShapeVisitor_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_ShapeVisitor

# Register IMeshTools_ShapeVisitor in _IMeshTools:
_IMeshTools.IMeshTools_ShapeVisitor_swigregister(IMeshTools_ShapeVisitor)





