# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
RWStepAP214 module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_rwstepap214.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _RWStepAP214
else:
    import _RWStepAP214

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _RWStepAP214.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _RWStepAP214.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepAP214.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepAP214.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _RWStepAP214.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _RWStepAP214.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _RWStepAP214.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _RWStepAP214.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _RWStepAP214.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _RWStepAP214.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepAP214.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepAP214.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepAP214.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepAP214.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepAP214.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepAP214.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _RWStepAP214.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _RWStepAP214:
_RWStepAP214.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _RWStepAP214.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepAP214
import OCC.Core.StepBasic
import OCC.Core.StepVisual
import OCC.Core.StepShape
import OCC.Core.StepGeom
import OCC.Core.StepRepr
import OCC.Core.TColgp

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_RWStepAP214_GeneralModule_Create() -> "opencascade::handle< RWStepAP214_GeneralModule >":
    return _RWStepAP214.Handle_RWStepAP214_GeneralModule_Create()

def Handle_RWStepAP214_GeneralModule_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< RWStepAP214_GeneralModule >":
    return _RWStepAP214.Handle_RWStepAP214_GeneralModule_DownCast(t)

def Handle_RWStepAP214_GeneralModule_IsNull(t: "opencascade::handle< RWStepAP214_GeneralModule > const &") -> "bool":
    return _RWStepAP214.Handle_RWStepAP214_GeneralModule_IsNull(t)

def Handle_RWStepAP214_ReadWriteModule_Create() -> "opencascade::handle< RWStepAP214_ReadWriteModule >":
    return _RWStepAP214.Handle_RWStepAP214_ReadWriteModule_Create()

def Handle_RWStepAP214_ReadWriteModule_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< RWStepAP214_ReadWriteModule >":
    return _RWStepAP214.Handle_RWStepAP214_ReadWriteModule_DownCast(t)

def Handle_RWStepAP214_ReadWriteModule_IsNull(t: "opencascade::handle< RWStepAP214_ReadWriteModule > const &") -> "bool":
    return _RWStepAP214.Handle_RWStepAP214_ReadWriteModule_IsNull(t)
class rwstepap214(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Init(*args) -> "void":
        r"""
        Enforced the initialisation of the libraries.

        Returns
        -------
        None

        """
        return _RWStepAP214.rwstepap214_Init(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _RWStepAP214.rwstepap214_swiginit(self, _RWStepAP214.new_rwstepap214())
    __swig_destroy__ = _RWStepAP214.delete_rwstepap214

# Register rwstepap214 in _RWStepAP214:
_RWStepAP214.rwstepap214_swigregister(rwstepap214)

def rwstepap214_Init(*args) -> "void":
    r"""
    Enforced the initialisation of the libraries.

    Returns
    -------
    None

    """
    return _RWStepAP214.rwstepap214_Init(*args)

class RWStepAP214_GeneralModule(OCC.Core.StepData.StepData_GeneralModule):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a generalmodule.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_GeneralModule_swiginit(self, _RWStepAP214.new_RWStepAP214_GeneralModule(*args))


    @staticmethod
    def DownCast(t):
      return Handle_RWStepAP214_GeneralModule_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_GeneralModule

# Register RWStepAP214_GeneralModule in _RWStepAP214:
_RWStepAP214.RWStepAP214_GeneralModule_swigregister(RWStepAP214_GeneralModule)

class RWStepAP214_RWAppliedApprovalAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedApprovalAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedApprovalAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedApprovalAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedApprovalAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedApprovalAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedApprovalAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedApprovalAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedApprovalAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedApprovalAssignment

# Register RWStepAP214_RWAppliedApprovalAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedApprovalAssignment_swigregister(RWStepAP214_RWAppliedApprovalAssignment)

class RWStepAP214_RWAppliedDateAndTimeAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedDateAndTimeAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedDateAndTimeAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDateAndTimeAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedDateAndTimeAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDateAndTimeAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDateAndTimeAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedDateAndTimeAssignment

# Register RWStepAP214_RWAppliedDateAndTimeAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedDateAndTimeAssignment_swigregister(RWStepAP214_RWAppliedDateAndTimeAssignment)

class RWStepAP214_RWAppliedDateAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedDateAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedDateAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedDateAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDateAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedDateAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDateAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedDateAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDateAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedDateAssignment

# Register RWStepAP214_RWAppliedDateAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedDateAssignment_swigregister(RWStepAP214_RWAppliedDateAssignment)

class RWStepAP214_RWAppliedDocumentReference(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedDocumentReference_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedDocumentReference(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedDocumentReference

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDocumentReference_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedDocumentReference
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDocumentReference_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedDocumentReference

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDocumentReference_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedDocumentReference

# Register RWStepAP214_RWAppliedDocumentReference in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedDocumentReference_swigregister(RWStepAP214_RWAppliedDocumentReference)

class RWStepAP214_RWAppliedExternalIdentificationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedExternalIdentificationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedExternalIdentificationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads appliedexternalidentificationassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedExternalIdentificationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedExternalIdentificationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP214_AppliedExternalIdentificationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedExternalIdentificationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes appliedexternalidentificationassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedExternalIdentificationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedExternalIdentificationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedExternalIdentificationAssignment

# Register RWStepAP214_RWAppliedExternalIdentificationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedExternalIdentificationAssignment_swigregister(RWStepAP214_RWAppliedExternalIdentificationAssignment)

class RWStepAP214_RWAppliedGroupAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedGroupAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedGroupAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads appliedgroupassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedGroupAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedGroupAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP214_AppliedGroupAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedGroupAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes appliedgroupassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedGroupAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedGroupAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedGroupAssignment

# Register RWStepAP214_RWAppliedGroupAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedGroupAssignment_swigregister(RWStepAP214_RWAppliedGroupAssignment)

class RWStepAP214_RWAppliedOrganizationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedOrganizationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedOrganizationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedOrganizationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedOrganizationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedOrganizationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedOrganizationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedOrganizationAssignment

# Register RWStepAP214_RWAppliedOrganizationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedOrganizationAssignment_swigregister(RWStepAP214_RWAppliedOrganizationAssignment)

class RWStepAP214_RWAppliedPersonAndOrganizationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedPersonAndOrganizationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedPersonAndOrganizationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedPersonAndOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedPersonAndOrganizationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedPersonAndOrganizationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedPersonAndOrganizationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedPersonAndOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedPersonAndOrganizationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedPersonAndOrganizationAssignment

# Register RWStepAP214_RWAppliedPersonAndOrganizationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedPersonAndOrganizationAssignment_swigregister(RWStepAP214_RWAppliedPersonAndOrganizationAssignment)

class RWStepAP214_RWAppliedPresentedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedPresentedItem_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedPresentedItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedPresentedItem

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedPresentedItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedPresentedItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedPresentedItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedPresentedItem

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedPresentedItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedPresentedItem

# Register RWStepAP214_RWAppliedPresentedItem in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedPresentedItem_swigregister(RWStepAP214_RWAppliedPresentedItem)

class RWStepAP214_RWAppliedSecurityClassificationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedSecurityClassificationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedSecurityClassificationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedSecurityClassificationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedSecurityClassificationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedSecurityClassificationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedSecurityClassificationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedSecurityClassificationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedSecurityClassificationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedSecurityClassificationAssignment

# Register RWStepAP214_RWAppliedSecurityClassificationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedSecurityClassificationAssignment_swigregister(RWStepAP214_RWAppliedSecurityClassificationAssignment)

class RWStepAP214_RWAutoDesignActualDateAndTimeAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAndTimeAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignActualDateAndTimeAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignActualDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAndTimeAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignActualDateAndTimeAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAndTimeAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignActualDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAndTimeAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignActualDateAndTimeAssignment

# Register RWStepAP214_RWAutoDesignActualDateAndTimeAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignActualDateAndTimeAssignment_swigregister(RWStepAP214_RWAutoDesignActualDateAndTimeAssignment)

class RWStepAP214_RWAutoDesignActualDateAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignActualDateAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignActualDateAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignActualDateAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignActualDateAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignActualDateAssignment

# Register RWStepAP214_RWAutoDesignActualDateAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignActualDateAssignment_swigregister(RWStepAP214_RWAutoDesignActualDateAssignment)

class RWStepAP214_RWAutoDesignApprovalAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignApprovalAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignApprovalAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignApprovalAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignApprovalAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignApprovalAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignApprovalAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignApprovalAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignApprovalAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignApprovalAssignment

# Register RWStepAP214_RWAutoDesignApprovalAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignApprovalAssignment_swigregister(RWStepAP214_RWAutoDesignApprovalAssignment)

class RWStepAP214_RWAutoDesignDateAndPersonAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignDateAndPersonAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignDateAndPersonAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignDateAndPersonAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignDateAndPersonAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignDateAndPersonAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignDateAndPersonAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignDateAndPersonAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignDateAndPersonAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignDateAndPersonAssignment

# Register RWStepAP214_RWAutoDesignDateAndPersonAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignDateAndPersonAssignment_swigregister(RWStepAP214_RWAutoDesignDateAndPersonAssignment)

class RWStepAP214_RWAutoDesignDocumentReference(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignDocumentReference_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignDocumentReference(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignDocumentReference

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignDocumentReference_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignDocumentReference
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignDocumentReference_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignDocumentReference

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignDocumentReference_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignDocumentReference

# Register RWStepAP214_RWAutoDesignDocumentReference in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignDocumentReference_swigregister(RWStepAP214_RWAutoDesignDocumentReference)

class RWStepAP214_RWAutoDesignGroupAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignGroupAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignGroupAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignGroupAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignGroupAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignGroupAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignGroupAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignGroupAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignGroupAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignGroupAssignment

# Register RWStepAP214_RWAutoDesignGroupAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignGroupAssignment_swigregister(RWStepAP214_RWAutoDesignGroupAssignment)

class RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignNominalDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignNominalDateAndTimeAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignNominalDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment

# Register RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment_swigregister(RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment)

class RWStepAP214_RWAutoDesignNominalDateAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignNominalDateAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignNominalDateAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignNominalDateAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignNominalDateAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignNominalDateAssignment

# Register RWStepAP214_RWAutoDesignNominalDateAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAssignment_swigregister(RWStepAP214_RWAutoDesignNominalDateAssignment)

class RWStepAP214_RWAutoDesignOrganizationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignOrganizationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignOrganizationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignOrganizationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignOrganizationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignOrganizationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignOrganizationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignOrganizationAssignment

# Register RWStepAP214_RWAutoDesignOrganizationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignOrganizationAssignment_swigregister(RWStepAP214_RWAutoDesignOrganizationAssignment)

class RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignPersonAndOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignPersonAndOrganizationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignPersonAndOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment

# Register RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment_swigregister(RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment)

class RWStepAP214_RWAutoDesignPresentedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignPresentedItem_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignPresentedItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignPresentedItem

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignPresentedItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignPresentedItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignPresentedItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignPresentedItem

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignPresentedItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignPresentedItem

# Register RWStepAP214_RWAutoDesignPresentedItem in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignPresentedItem_swigregister(RWStepAP214_RWAutoDesignPresentedItem)

class RWStepAP214_RWAutoDesignSecurityClassificationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignSecurityClassificationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignSecurityClassificationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignSecurityClassificationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignSecurityClassificationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignSecurityClassificationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignSecurityClassificationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignSecurityClassificationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignSecurityClassificationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignSecurityClassificationAssignment

# Register RWStepAP214_RWAutoDesignSecurityClassificationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignSecurityClassificationAssignment_swigregister(RWStepAP214_RWAutoDesignSecurityClassificationAssignment)

class RWStepAP214_RWClass(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWClass_swiginit(self, _RWStepAP214.new_RWStepAP214_RWClass(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads class.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_Class

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWClass_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP214_Class
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWClass_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes class.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_Class

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWClass_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWClass

# Register RWStepAP214_RWClass in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWClass_swigregister(RWStepAP214_RWClass)

class RWStepAP214_RWExternallyDefinedClass(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWExternallyDefinedClass_swiginit(self, _RWStepAP214.new_RWStepAP214_RWExternallyDefinedClass(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads externallydefinedclass.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_ExternallyDefinedClass

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWExternallyDefinedClass_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP214_ExternallyDefinedClass
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWExternallyDefinedClass_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes externallydefinedclass.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_ExternallyDefinedClass

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWExternallyDefinedClass_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWExternallyDefinedClass

# Register RWStepAP214_RWExternallyDefinedClass in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWExternallyDefinedClass_swigregister(RWStepAP214_RWExternallyDefinedClass)

class RWStepAP214_RWExternallyDefinedGeneralProperty(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWExternallyDefinedGeneralProperty_swiginit(self, _RWStepAP214.new_RWStepAP214_RWExternallyDefinedGeneralProperty(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads externallydefinedgeneralproperty.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_ExternallyDefinedGeneralProperty

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWExternallyDefinedGeneralProperty_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP214_ExternallyDefinedGeneralProperty
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWExternallyDefinedGeneralProperty_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes externallydefinedgeneralproperty.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_ExternallyDefinedGeneralProperty

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWExternallyDefinedGeneralProperty_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWExternallyDefinedGeneralProperty

# Register RWStepAP214_RWExternallyDefinedGeneralProperty in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWExternallyDefinedGeneralProperty_swigregister(RWStepAP214_RWExternallyDefinedGeneralProperty)

class RWStepAP214_RWRepItemGroup(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWRepItemGroup_swiginit(self, _RWStepAP214.new_RWStepAP214_RWRepItemGroup(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads repitemgroup.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_RepItemGroup

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWRepItemGroup_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP214_RepItemGroup
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWRepItemGroup_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes repitemgroup.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_RepItemGroup

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWRepItemGroup_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWRepItemGroup

# Register RWStepAP214_RWRepItemGroup in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWRepItemGroup_swigregister(RWStepAP214_RWRepItemGroup)

class RWStepAP214_ReadWriteModule(OCC.Core.StepData.StepData_ReadWriteModule):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_ReadWriteModule_swiginit(self, _RWStepAP214.new_RWStepAP214_ReadWriteModule(*args))

    def CaseStep(self, *args) -> "Standard_Integer":
        r"""
        Associates a positive case number to each type of stepap214 entity, given as a string defined in the express form.

        Parameters
        ----------
        atype: TCollection_AsciiString

        Returns
        -------
        int
        Associates a positive case number to each type of stepap214 complex entity, given as a string defined in the express form.

        Parameters
        ----------
        types: TColStd_SequenceOfAsciiString

        Returns
        -------
        int

        """
        return _RWStepAP214.RWStepAP214_ReadWriteModule_CaseStep(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_RWStepAP214_ReadWriteModule_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_ReadWriteModule

# Register RWStepAP214_ReadWriteModule in _RWStepAP214:
_RWStepAP214.RWStepAP214_ReadWriteModule_swigregister(RWStepAP214_ReadWriteModule)





