# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
GccAna module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_gccana.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _GccAna
else:
    import _GccAna

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _GccAna.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _GccAna.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GccAna.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GccAna.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _GccAna.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _GccAna.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _GccAna.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _GccAna.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _GccAna.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _GccAna.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GccAna.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _GccAna.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _GccAna.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GccAna.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GccAna.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GccAna.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _GccAna.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _GccAna:
_GccAna.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _GccAna.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.GccEnt
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GccInt

from enum import IntEnum
from OCC.Core.Exception import *



class GccAna_Circ2d2TanOn(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This method implements the algorithms used to create 2d circles tangent to two 2d circles and having the center on a 2d line.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        OnLine: gp_Lin2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a 2d circle and a 2d line having the center on a 2d line.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedLin
        OnLine: gp_Lin2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to two 2d lines having the center on a 2d line.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Qualified2: GccEnt_QualifiedLin
        OnLine: gp_Lin2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a 2d circle and a point having the center on a 2d line.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Point2: gp_Pnt2d
        OnLine: gp_Lin2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a 2d line and a point having the center on a 2d line.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Point2: gp_Pnt2d
        OnLine: gp_Lin2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to two points having the center on a 2d line.

        Parameters
        ----------
        Point1: gp_Pnt2d
        Point2: gp_Pnt2d
        OnLine: gp_Lin2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to two 2d circles and having the center on a 2d circle.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        OnCirc: gp_Circ2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a circle and a line having the center on a 2d circle.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedLin
        OnCirc: gp_Circ2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a circle and a point having the center on a 2d circle.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Point2: gp_Pnt2d
        OnCirc: gp_Circ2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to two 2d lines having the center on a 2d circle.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Qualified2: GccEnt_QualifiedLin
        OnCirc: gp_Circ2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a line and a point having the center on a 2d circle.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Point2: gp_Pnt2d
        OnCirc: gp_Circ2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to two points having the center on a 2d circle.

        Parameters
        ----------
        Point1: gp_Pnt2d
        Point2: gp_Pnt2d
        OnCirc: gp_Circ2d
        Tolerance: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_Circ2d2TanOn_swiginit(self, _GccAna.new_GccAna_Circ2d2TanOn(*args))

    def CenterOn3(self, *args) -> "void":
        r"""
        Returns the informations about the center (on the curv) of the result number index and the third argument. pararg is the intrinsic parameter of the point pntarg on the third argument. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int
        PntArg: gp_Pnt2d

        Returns
        -------
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d2TanOn_CenterOn3(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the construction algorithm does not fail (even if it finds no solution). note: isdone protects against a failure arising from a more internal intersection algorithm, which has reached its numeric limits.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d2TanOn_IsDone(self, *args)

    def IsTheSame1(self, *args) -> "Standard_Boolean":
        r"""
        True if the solution and the first argument are the same (2 circles). if r1 is the radius of the first argument and rsol the radius of the solution and dist the distance between the two centers, we concider the two circles are identical if r1+dist-rsol is less than tolerance. false in the other cases. raises outofrange if index is greater than the number of solutions and notdone if isdone returns false.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d2TanOn_IsTheSame1(self, *args)

    def IsTheSame2(self, *args) -> "Standard_Boolean":
        r"""
        True if the solution and the second argument are the same (2 circles). if r2 is the radius of the second argument and rsol the radius of the solution and dist the distance between the two centers, we concider the two circles are identical if r2+dist-rsol is less than tolerance. false in the other cases. raises outofrange if index is greater than the number of solutions and notdone if isdone returns false.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d2TanOn_IsTheSame2(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of circles, representing solutions computed by this algorithm. exceptions stdfail_notdone if the construction fails.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Circ2d2TanOn_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns the informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution pararg is the intrinsic parameter of the point pntsol on the first argument. raises outofrange if index is greater than the number of solutions and notdone if isdone returns false.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d2TanOn_Tangency1(self, *args)

    def Tangency2(self, *args) -> "void":
        r"""
        Returns the informations about the tangency point between the result number index and the second argument. parsol is the intrinsic parameter of the point pntsol on the solution. pararg is the intrinsic parameter of the point pntsol on the second argument. raises outofrange if index is greater than the number of solutions and notdone if isdone returns false.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d2TanOn_Tangency2(self, *args)

    def ThisSolution(self, *args) -> "gp_Circ2d":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. be careful: the index is only a way to get all the solutions, but is not associated to those outside the context of the algorithm-object. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Circ2d

        """
        return _GccAna.GccAna_Circ2d2TanOn_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the qualifiers qualif1 and qualif2 of the tangency arguments for the solution of index index computed by this algorithm. the returned qualifiers are: - those specified at the start of construction when the solutions are defined as enclosed, enclosing or outside with respect to the arguments, or - those computed during construction (i.e. enclosed, enclosing or outside) when the solutions are defined as unqualified with respect to the arguments, or - gccent_noqualifier if the tangency argument is a point. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position
        Qualif2: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Circ2d2TanOn_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Circ2d2TanOn

# Register GccAna_Circ2d2TanOn in _GccAna:
_GccAna.GccAna_Circ2d2TanOn_swigregister(GccAna_Circ2d2TanOn)

class GccAna_Circ2d2TanRad(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This method implements the algorithms used to create 2d circles tangent to two 2d circle with a radius of radius. it raises negativevalue if radius is lower than zero.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a 2d circle and a 2d line with a radius of radius. it raises negativevalue if radius is lower than zero.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedLin
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a 2d circle and a point with a radius of radius. it raises negativevalue if radius is lower than zero.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Point2: gp_Pnt2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a 2d line and a point with a radius of radius. it raises negativevalue if radius is lower than zero.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Point2: gp_Pnt2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to two 2d lines with a radius of radius. it raises negativevalue if radius is lower than zero.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Qualified2: GccEnt_QualifiedLin
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles passing through two points with a radius of radius. it raises negativevalue if radius is lower than zero.

        Parameters
        ----------
        Point1: gp_Pnt2d
        Point2: gp_Pnt2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_Circ2d2TanRad_swiginit(self, _GccAna.new_GccAna_Circ2d2TanRad(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        This method returns true if the algorithm succeeded. note: isdone protects against a failure arising from a more internal intersection algorithm, which has reached its numeric limits.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d2TanRad_IsDone(self, *args)

    def IsTheSame1(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the first argument. raises outofrange if index is greater than the number of solutions. it raises notdone if the construction algorithm did not succeed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d2TanRad_IsTheSame1(self, *args)

    def IsTheSame2(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the second argument. raises outofrange if index is greater than the number of solutions. it raises notdone if the construction algorithm did not succeed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d2TanRad_IsTheSame2(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        This method returns the number of circles, representing solutions computed by this algorithm. exceptions stdfail_notdone if the construction fails. of solutions.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Circ2d2TanRad_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns information about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution. pararg is the intrinsic parameter of the point pntsol on the first argument. raises outofrange if index is greater than the number of solutions. it raises notdone if the construction algorithm did not succeed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d2TanRad_Tangency1(self, *args)

    def Tangency2(self, *args) -> "void":
        r"""
        Returns information about the tangency point between the result number index and the second argument. parsol is the intrinsic parameter of the point pntsol on the solution. pararg is the intrinsic parameter of the point pntarg on the second argument. raises outofrange if index is greater than the number of solutions. it raises notdone if the construction algorithm did not succeed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d2TanRad_Tangency2(self, *args)

    def ThisSolution(self, *args) -> "gp_Circ2d":
        r"""
        Returns the solution number index. be careful: the index is only a way to get all the solutions, but is not associated to those outside the context of the algorithm-object. raises outofrange exception if index is greater than the number of solutions. it raises notdone if the construction algorithm did not succeed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Circ2d

        """
        return _GccAna.GccAna_Circ2d2TanRad_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the information about the qualifiers of the tangency arguments concerning the solution number index. it returns the real qualifiers (the qualifiers given to the constructor method in case of enclosed, enclosing and outside and the qualifiers computedin case of unqualified).

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position
        Qualif2: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Circ2d2TanRad_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Circ2d2TanRad

# Register GccAna_Circ2d2TanRad in _GccAna:
_GccAna.GccAna_Circ2d2TanRad_swigregister(GccAna_Circ2d2TanRad)

class GccAna_Circ2d3Tan(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This method implements the algorithms used to create 2d circles tangent to 3 circles. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        Qualified3: GccEnt_QualifiedCirc
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to 2 circles and 1 line. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        Qualified3: GccEnt_QualifiedLin
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to 1 circle and 2 lines. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedLin
        Qualified3: GccEnt_QualifiedLin
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to 3 lines. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Qualified2: GccEnt_QualifiedLin
        Qualified3: GccEnt_QualifiedLin
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to 2 circles and 1 point. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        Point3: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a circle and a line and 1 point. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedLin
        Point3: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to 2 lines and 1 point. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Qualified2: GccEnt_QualifiedLin
        Point3: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a circle and passing thrue 2 points. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Point2: gp_Pnt2d
        Point3: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a line and passing thrue 2 points. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Point2: gp_Pnt2d
        Point3: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles passing thrue 3 points. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Point1: gp_Pnt2d
        Point2: gp_Pnt2d
        Point3: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_Circ2d3Tan_swiginit(self, _GccAna.new_GccAna_Circ2d3Tan(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        This method returns true if the construction algorithm succeeded. note: isdone protects against a failure arising from a more internal intersection algorithm, which has reached its numeric limits.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d3Tan_IsDone(self, *args)

    def IsTheSame1(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the first argument. raises outofrange if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d3Tan_IsTheSame1(self, *args)

    def IsTheSame2(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the second argument. raises outofrange index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d3Tan_IsTheSame2(self, *args)

    def IsTheSame3(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the third argument. raises outofrange if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d3Tan_IsTheSame3(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        This method returns the number of solutions. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Circ2d3Tan_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution curv. pararg is the intrinsic parameter of the point pntarg on the argument curv. raises outofrange if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d3Tan_Tangency1(self, *args)

    def Tangency2(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution curv. pararg is the intrinsic parameter of the point pntsol on the argument curv. raises outofrange if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d3Tan_Tangency2(self, *args)

    def Tangency3(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution curv. pararg is the intrinsic parameter of the point pntsol on the argument curv. raises outofrange if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d3Tan_Tangency3(self, *args)

    def ThisSolution(self, *args) -> "gp_Circ2d":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. be careful: the index is only a way to get all the solutions, but is not associated to those outside the context of the algorithm-object. raises outofrange if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Circ2d

        """
        return _GccAna.GccAna_Circ2d3Tan_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the informations about the qualifiers of the tangency arguments concerning the solution number index. it returns the real qualifiers (the qualifiers given to the constructor method in case of enclosed, enclosing and outside and the qualifiers computedin case of unqualified).

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position
        Qualif2: GccEnt_Position
        Qualif3: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Circ2d3Tan_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Circ2d3Tan

# Register GccAna_Circ2d3Tan in _GccAna:
_GccAna.GccAna_Circ2d3Tan_swigregister(GccAna_Circ2d3Tan)

class GccAna_Circ2dBisec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs bisecting curves between the two circles circ1 and circ2.

        Parameters
        ----------
        Circ1: gp_Circ2d
        Circ2: gp_Circ2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_Circ2dBisec_swiginit(self, _GccAna.new_GccAna_Circ2dBisec(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        This method returns true if the construction algorithm succeeded.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2dBisec_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        This method returns the number of solutions. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Circ2dBisec_NbSolutions(self, *args)

    def ThisSolution(self, *args) -> "opencascade::handle< GccInt_Bisec >":
        r"""
        Returns the solution number index raises outofrange exception if index is greater than the number of solutions. it raises notdone if the construction algorithm didn't succeed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<GccInt_Bisec>

        """
        return _GccAna.GccAna_Circ2dBisec_ThisSolution(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Circ2dBisec

# Register GccAna_Circ2dBisec in _GccAna:
_GccAna.GccAna_Circ2dBisec_swigregister(GccAna_Circ2dBisec)

class GccAna_Circ2dTanCen(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This method implements the algorithms used to create 2d circles tangent to a circle and centered on a point.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Pcenter: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a line and centered on a point.

        Parameters
        ----------
        Linetan: gp_Lin2d
        Pcenter: gp_Pnt2d

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles passing thrue a point and centered on a point. tolerance is a tolerance criterion used by the algorithm to find a solution when, mathematically, the problem posed does not have a solution, but where there is numeric uncertainty attached to the arguments. in these algorithms tolerance is only used in very specific cases where the center of the solution is very close to the circle to which it is tangential, and where the solution is therefore a very small circle. exceptions gccent_badqualifier if a qualifier is inconsistent with the argument it qualifies (for example, enclosing for a line).

        Parameters
        ----------
        Point1: gp_Pnt2d
        Pcenter: gp_Pnt2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_Circ2dTanCen_swiginit(self, _GccAna.new_GccAna_Circ2dTanCen(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        This method returns true if the construction algorithm succeeded. note: isdone protects against a failure arising from a more internal intersection algorithm, which has reached its numeric limits.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2dTanCen_IsDone(self, *args)

    def IsTheSame1(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the first argument. it raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions or less than zero.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2dTanCen_IsTheSame1(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of circles, representing solutions computed by this algorithm and raises notdone exception if the algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Circ2dTanCen_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution curv. pararg is the intrinsic parameter of the point pntarg on the argument curv. it raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions or less than zero.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2dTanCen_Tangency1(self, *args)

    def ThisSolution(self, *args) -> "gp_Circ2d":
        r"""
        Returns the circle, representing the solution number index and raises outofrange exception if index is greater than the number of solutions. be carefull: the index is only a way to get all the solutions, but is not associated to theses outside the context of the algorithm-object. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions or less than zer.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Circ2d

        """
        return _GccAna.GccAna_Circ2dTanCen_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the qualifier qualif1 of the tangency argument for the solution of index index computed by this algorithm. the returned qualifier is: - that specified at the start of construction when the solutions are defined as enclosed, enclosing or it returns the real qualifiers (the qualifiers given to the constructor method in case of enclosed, enclosing and outside and the qualifiers computedin case of unqualified).

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Circ2dTanCen_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Circ2dTanCen

# Register GccAna_Circ2dTanCen in _GccAna:
_GccAna.GccAna_Circ2dTanCen_swigregister(GccAna_Circ2dTanCen)

class GccAna_Circ2dTanOnRad(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This methods implements the algorithms used to create 2d circles tangent to a circle and centered on a 2d line with a given radius. tolerance is used to find solution in every limit cases. for example tolerance is used in the case of enclosedcirc when radius-r1+dist is greater tolerance (dist is the distance between the line and the location of the circ, r1 is the radius of the circ) because there is no solution. raises negativevalue in case of negativeradius.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        OnLine: gp_Lin2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d circles tangent to a 2d line and centered on a 2d line with a given radius. tolerance is used to find solution in every limit cases. raises negativevalue in case of negativeradius.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        OnLine: gp_Lin2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d circles passing through a 2d point and centered on a 2d line with a given radius. tolerance is used to find solution in every limit cases.

        Parameters
        ----------
        Point1: gp_Pnt2d
        OnLine: gp_Lin2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d circles tangent to a circle and centered on a 2d circle with a given radius. tolerance is used to find solution in every limit cases. raises negativevalue in case of negativeradius.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        OnCirc: gp_Circ2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d circles tangent to a 2d line and centered on a 2d line with a given radius. tolerance is used to find solution in every limit cases. raises negativevalue in case of negativeradius.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        OnCirc: gp_Circ2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d circles passing through a 2d point and centered on a 2d line with a given radius. tolerance is used to find solution in every limit cases. raises negativevalue in case of negativeradius.

        Parameters
        ----------
        Point1: gp_Pnt2d
        OnCirc: gp_Circ2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_Circ2dTanOnRad_swiginit(self, _GccAna.new_GccAna_Circ2dTanOnRad(*args))

    def CenterOn3(self, *args) -> "void":
        r"""
        Returns informations about the center (on the curv) of the result. pararg is the intrinsic parameter of the point on the argument curv. pntsol is the center point of the solution curv. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParArg: float

        """
        return _GccAna.GccAna_Circ2dTanOnRad_CenterOn3(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the construction algorithm does not fail (even if it finds no solution). note: isdone protects against a failure arising from a more internal intersection algorithm, which has reached its numeric limits.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2dTanOnRad_IsDone(self, *args)

    def IsTheSame1(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the first argument and false in the other cases. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2dTanOnRad_IsTheSame1(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        This method returns the number of circles, representing solutions. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Circ2dTanOnRad_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point on the solution curv. pararg is the intrinsic parameter of the point on the argument curv. pntsol is the tangency point on the solution curv. pntarg is the tangency point on the argument curv. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2dTanOnRad_Tangency1(self, *args)

    def ThisSolution(self, *args) -> "gp_Circ2d":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. be careful: the index is only a way to get all the solutions, but is not associated to theses outside the context of the algorithm-object. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Circ2d

        """
        return _GccAna.GccAna_Circ2dTanOnRad_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the qualifier qualif1 of the tangency argument for the solution of index index computed by this algorithm. the returned qualifier is: - that specified at the start of construction when the solutions are defined as enclosed, enclosing or outside with respect to the argument, or - that computed during construction (i.e. enclosed, enclosing or outside) when the solutions are defined as unqualified with respect to the argument, or - gccent_noqualifier if the tangency argument is a point. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Circ2dTanOnRad_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Circ2dTanOnRad

# Register GccAna_Circ2dTanOnRad in _GccAna:
_GccAna.GccAna_Circ2dTanOnRad_swigregister(GccAna_Circ2dTanOnRad)

class GccAna_CircLin2dBisec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs bisecting curves between the circle circle and the line line.

        Parameters
        ----------
        Circle: gp_Circ2d
        Line: gp_Lin2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_CircLin2dBisec_swiginit(self, _GccAna.new_GccAna_CircLin2dBisec(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true (this construction algorithm never fails).

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_CircLin2dBisec_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of curves, representing solutions computed by this algorithm.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_CircLin2dBisec_NbSolutions(self, *args)

    def ThisSolution(self, *args) -> "opencascade::handle< GccInt_Bisec >":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<GccInt_Bisec>

        """
        return _GccAna.GccAna_CircLin2dBisec_ThisSolution(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_CircLin2dBisec

# Register GccAna_CircLin2dBisec in _GccAna:
_GccAna.GccAna_CircLin2dBisec_swigregister(GccAna_CircLin2dBisec)

class GccAna_CircPnt2dBisec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs bisecting curves between the circle circle1 and the point point2.

        Parameters
        ----------
        Circle1: gp_Circ2d
        Point2: gp_Pnt2d

        Returns
        -------
        None
        Constructs bisecting curves between the circle circle1 and the point point2. tolerance is used.

        Parameters
        ----------
        Circle1: gp_Circ2d
        Point2: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_CircPnt2dBisec_swiginit(self, _GccAna.new_GccAna_CircPnt2dBisec(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true (this construction algorithm never fails).

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_CircPnt2dBisec_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of curves, representing solutions computed by this algorithm.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_CircPnt2dBisec_NbSolutions(self, *args)

    def ThisSolution(self, *args) -> "opencascade::handle< GccInt_Bisec >":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<GccInt_Bisec>

        """
        return _GccAna.GccAna_CircPnt2dBisec_ThisSolution(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_CircPnt2dBisec

# Register GccAna_CircPnt2dBisec in _GccAna:
_GccAna.GccAna_CircPnt2dBisec_swigregister(GccAna_CircPnt2dBisec)

class GccAna_Lin2d2Tan(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This methods implements the algorithms used to create 2d lines passing thrue 2 points. tolerance is used because we can't create a line when the distance between the two points is too small.

        Parameters
        ----------
        ThePoint1: gp_Pnt2d
        ThePoint2: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d lines tangent to one circle and passing thrue a point. exception badqualifier is raised in the case of enclosedcirc tolerance is used because there is no solution when the point is inside the solution according to the tolerance.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        ThePoint: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d lines tangent to 2 circles. exception badqualifier is raised in the case of enclosedcirc.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        Tolerance: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_Lin2d2Tan_swiginit(self, _GccAna.new_GccAna_Lin2d2Tan(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        This method returns true when there is a solution and false in the other cases.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Lin2d2Tan_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        This method returns the number of solutions. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Lin2d2Tan_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution curv. pararg is the intrinsic parameter of the point pntsol on the argument curv. raises outofrange is raised if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2d2Tan_Tangency1(self, *args)

    def Tangency2(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the second argument. parsol is the intrinsic parameter of the point parsol on the solution curv. pararg is the intrinsic parameter of the point pntsol on the argument curv. raises outofrange is raised if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2d2Tan_Tangency2(self, *args)

    def ThisSolution(self, *args) -> "gp_Lin2d":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. be carefull: the index is only a way to get all the solutions, but is not associated to theses outside the context of the algorithm-object. raises outofrange is raised if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Lin2d

        """
        return _GccAna.GccAna_Lin2d2Tan_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the qualifiers qualif1 and qualif2 of the tangency arguments for the solution of index index computed by this algorithm. the returned qualifiers are: - those specified at the start of construction when the solutions are defined as enclosing or outside with respect to the arguments, or - those computed during construction (i.e. enclosing or outside) when the solutions are defined as unqualified with respect to the arguments, or - gccent_noqualifier if the tangency argument is a point. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position
        Qualif2: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Lin2d2Tan_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Lin2d2Tan

# Register GccAna_Lin2d2Tan in _GccAna:
_GccAna.GccAna_Lin2d2Tan_swigregister(GccAna_Lin2d2Tan)

class GccAna_Lin2dBisec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs bisecting lines between the two lines lin1 and lin2.

        Parameters
        ----------
        Lin1: gp_Lin2d
        Lin2: gp_Lin2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_Lin2dBisec_swiginit(self, _GccAna.new_GccAna_Lin2dBisec(*args))

    def Intersection1(self, *args) -> "void":
        r"""
        Returns informations about the intersection point between the result number index and the first argument. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dBisec_Intersection1(self, *args)

    def Intersection2(self, *args) -> "void":
        r"""
        Returns informations about the intersection point between the result number index and the second argument. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dBisec_Intersection2(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true when the algorithm succeded.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Lin2dBisec_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of solutions and raise notdone if the constructor wasn't called before.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Lin2dBisec_NbSolutions(self, *args)

    def ThisSolution(self, *args) -> "gp_Lin2d":
        r"""
        Returns the solution number index . the first solution is the inside one and the second is the outside one. for the first solution the direction is d1+d2 (d1 is the direction of the first argument and d2 the direction of the second argument). for the second solution the direction is d1-d2. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Lin2d

        """
        return _GccAna.GccAna_Lin2dBisec_ThisSolution(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Lin2dBisec

# Register GccAna_Lin2dBisec in _GccAna:
_GccAna.GccAna_Lin2dBisec_swigregister(GccAna_Lin2dBisec)

class GccAna_Lin2dTanObl(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This class implements the algorithms used to create 2d line passing through a point and making an angle with a line.

        Parameters
        ----------
        ThePoint: gp_Pnt2d
        TheLine: gp_Lin2d
        TheAngle: float

        Returns
        -------
        None
        This class implements the algorithms used to create 2d line tangent to a circle and making an angle with a line. exceptions gccent_badqualifier if a qualifier is inconsistent with the argument it qualifies (for example, enclosed for a circle).

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        TheLine: gp_Lin2d
        TheAngle: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_Lin2dTanObl_swiginit(self, _GccAna.new_GccAna_Lin2dTanObl(*args))

    def Intersection2(self, *args) -> "void":
        r"""
        Returns informations about the intersection between the result number index and the third argument. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dTanObl_Intersection2(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the algorithm succeeded. note: isdone protects against a failure arising from a more internal intersection algorithm, which has reached its numeric limits.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Lin2dTanObl_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of of lines, representing solutions computed by this algorithm. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Lin2dTanObl_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point parsol on the solution curv. pararg is the intrinsic parameter of the point pararg on the argument curv. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dTanObl_Tangency1(self, *args)

    def ThisSolution(self, *args) -> "gp_Lin2d":
        r"""
        Returns the solution number index. be careful: the index is only a way to get all the solutions, but is not associated to theses outside the context of the algorithm-object. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Lin2d

        """
        return _GccAna.GccAna_Lin2dTanObl_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the qualifier qualif1 of the tangency argument for the solution of index index computed by this algorithm. the returned qualifier is: - that specified at the start of construction when the solutions are defined as enclosing or outside with respect to the argument, or - that computed during construction (i.e. enclosing or outside) when the solutions are defined as unqualified with respect to the argument, or - gccent_noqualifier if the tangency argument is a point. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Lin2dTanObl_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Lin2dTanObl

# Register GccAna_Lin2dTanObl in _GccAna:
_GccAna.GccAna_Lin2dTanObl_swigregister(GccAna_Lin2dTanObl)

class GccAna_Lin2dTanPar(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This method implements the algorithms used to create a 2d line passing through a point and parallel to another line.

        Parameters
        ----------
        ThePoint: gp_Pnt2d
        Lin1: gp_Lin2d

        Returns
        -------
        None
        This method implements the algorithms used to create a 2d line tangent to a circle and parallel to another line. it raises badqualifier in case of enclosedcirc. exceptions gccent_badqualifier if a qualifier is inconsistent with the argument it qualifies (for example, enclosed for a circle).

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Lin1: gp_Lin2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_Lin2dTanPar_swiginit(self, _GccAna.new_GccAna_Lin2dTanPar(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the algorithm succeeded.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Lin2dTanPar_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of solutions. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Lin2dTanPar_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point on the solution curv. pararg is the intrinsic parameter of the point on the argument curv. pararg is equal 0 when the solution is passing thrue a point. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        Pnt: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dTanPar_Tangency1(self, *args)

    def ThisSolution(self, *args) -> "gp_Lin2d":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. be careful: the index is only a way to get all the solutions, but is not associated to those outside the context of the algorithm-object. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Lin2d

        """
        return _GccAna.GccAna_Lin2dTanPar_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the informations about the qualifiers of the tangency arguments concerning the solution number index. it returns the real qualifiers (the qualifiers given to the constructor method in case of enclosed, enclosing and outside and the qualifiers computed in case of unqualified). raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Lin2dTanPar_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Lin2dTanPar

# Register GccAna_Lin2dTanPar in _GccAna:
_GccAna.GccAna_Lin2dTanPar_swigregister(GccAna_Lin2dTanPar)

class GccAna_Lin2dTanPer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This method implements the algorithms used to create 2d lines passing through a point and perpendicular to a line.

        Parameters
        ----------
        ThePnt: gp_Pnt2d
        TheLin: gp_Lin2d

        Returns
        -------
        None
        This method implements the algorithms used to create 2d lines passing through a point and perpendicular to a circle.

        Parameters
        ----------
        ThePnt: gp_Pnt2d
        TheCircle: gp_Circ2d

        Returns
        -------
        None
        This method implements the algorithms used to create 2d lines tangent to a circle and perpendicular to a line.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        TheLin: gp_Lin2d

        Returns
        -------
        None
        This method implements the algorithms used to create 2d lines tangent to a circle and perpendicular to a circle.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        TheCircle: gp_Circ2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_Lin2dTanPer_swiginit(self, _GccAna.new_GccAna_Lin2dTanPer(*args))

    def Intersection2(self, *args) -> "void":
        r"""
        Returns informations about the intersection between the solution number index and the second argument. it returns the first intersection in a case of lin2dtanper which is perpendicular to a circle . parsol is the intrinsic parameter of the point on the solution curv. pararg is the intrinsic parameter of the point on the argument curv. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dTanPer_Intersection2(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the algorithm succeeded.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Lin2dTanPer_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of solutions. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Lin2dTanPer_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point on the solution curv. pararg is the intrinsic parameter of the point on the argument curv. if the first argument is a point pararg is equal zero. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        Pnt: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dTanPer_Tangency1(self, *args)

    def ThisSolution(self, *args) -> "gp_Lin2d":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. be careful: the index is only a way to get all the solutions, but is not associated to those outside the context of the algorithm-object. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Lin2d

        """
        return _GccAna.GccAna_Lin2dTanPer_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the qualifier qualif1 of the tangency argument for the solution of index index computed by this algorithm. the returned qualifier is: - that specified at the start of construction when the solutions are defined as enclosing or outside with respect to the argument, or - that computed during construction (i.e. enclosing or outside) when the solutions are defined as unqualified with respect to the argument, or - gccent_noqualifier if the tangency argument is a point. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Lin2dTanPer_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Lin2dTanPer

# Register GccAna_Lin2dTanPer in _GccAna:
_GccAna.GccAna_Lin2dTanPer_swigregister(GccAna_Lin2dTanPer)

class GccAna_LinPnt2dBisec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs a bisecting curve between the line line1 and the point point2.

        Parameters
        ----------
        Line1: gp_Lin2d
        Point2: gp_Pnt2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_LinPnt2dBisec_swiginit(self, _GccAna.new_GccAna_LinPnt2dBisec(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the algorithm succeeded.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_LinPnt2dBisec_IsDone(self, *args)

    def ThisSolution(self, *args) -> "opencascade::handle< GccInt_Bisec >":
        r"""
        Returns the number of solutions. it raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        opencascade::handle<GccInt_Bisec>

        """
        return _GccAna.GccAna_LinPnt2dBisec_ThisSolution(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_LinPnt2dBisec

# Register GccAna_LinPnt2dBisec in _GccAna:
_GccAna.GccAna_LinPnt2dBisec_swigregister(GccAna_LinPnt2dBisec)

class GccAna_Pnt2dBisec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs a bisecting line between the points point1 and point2.

        Parameters
        ----------
        Point1: gp_Pnt2d
        Point2: gp_Pnt2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_Pnt2dBisec_swiginit(self, _GccAna.new_GccAna_Pnt2dBisec(*args))

    def HasSolution(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if this algorithm has a solution, i.e. if the two points are not coincident.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Pnt2dBisec_HasSolution(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true (this construction algorithm never fails).

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Pnt2dBisec_IsDone(self, *args)

    def ThisSolution(self, *args) -> "gp_Lin2d":
        r"""
        Returns a line, representing the solution computed by this algorithm.

        Returns
        -------
        gp_Lin2d

        """
        return _GccAna.GccAna_Pnt2dBisec_ThisSolution(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Pnt2dBisec

# Register GccAna_Pnt2dBisec in _GccAna:
_GccAna.GccAna_Pnt2dBisec_swigregister(GccAna_Pnt2dBisec)





