# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BRepSweep module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_brepsweep.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BRepSweep
else:
    import _BRepSweep

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BRepSweep.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BRepSweep.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepSweep.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepSweep.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BRepSweep.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BRepSweep.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BRepSweep.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BRepSweep.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BRepSweep.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BRepSweep.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepSweep.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BRepSweep.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BRepSweep.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepSweep.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepSweep.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepSweep.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BRepSweep.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BRepSweep:
_BRepSweep.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BRepSweep.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.BRep
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.GeomAbs
import OCC.Core.Geom
import OCC.Core.TColgp
import OCC.Core.Poly
import OCC.Core.TShort
import OCC.Core.Geom2d
import OCC.Core.Sweep

from enum import IntEnum
from OCC.Core.Exception import *



class BRepSweep_Builder(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a builder.

        Parameters
        ----------
        aBuilder: BRep_Builder

        Returns
        -------
        None

        """
        _BRepSweep.BRepSweep_Builder_swiginit(self, _BRepSweep.new_BRepSweep_Builder(*args))

    def Add(self, *args) -> "void":
        r"""
        Adds the shape 1 in the shape 2, set to <orient> orientation.

        Parameters
        ----------
        aShape1: TopoDS_Shape
        aShape2: TopoDS_Shape
        Orient: TopAbs_Orientation

        Returns
        -------
        None
        Adds the shape 1 in the shape 2.

        Parameters
        ----------
        aShape1: TopoDS_Shape
        aShape2: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_Builder_Add(self, *args)

    def Builder(self, *args) -> "BRep_Builder const &":
        r"""
        No available documentation.

        Returns
        -------
        BRep_Builder

        """
        return _BRepSweep.BRepSweep_Builder_Builder(self, *args)

    def MakeCompSolid(self, *args) -> "void":
        r"""
        Returns an empty compsolid.

        Parameters
        ----------
        aCompSolid: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_Builder_MakeCompSolid(self, *args)

    def MakeCompound(self, *args) -> "void":
        r"""
        Returns an empty compound.

        Parameters
        ----------
        aCompound: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_Builder_MakeCompound(self, *args)

    def MakeShell(self, *args) -> "void":
        r"""
        Returns an empty shell.

        Parameters
        ----------
        aShell: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_Builder_MakeShell(self, *args)

    def MakeSolid(self, *args) -> "void":
        r"""
        Returns an empty solid.

        Parameters
        ----------
        aSolid: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_Builder_MakeSolid(self, *args)

    def MakeWire(self, *args) -> "void":
        r"""
        Returns an empty wire.

        Parameters
        ----------
        aWire: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_Builder_MakeWire(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepSweep.delete_BRepSweep_Builder

# Register BRepSweep_Builder in _BRepSweep:
_BRepSweep.BRepSweep_Builder_swigregister(BRepSweep_Builder)

class BRepSweep_Iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _BRepSweep.BRepSweep_Iterator_swiginit(self, _BRepSweep.new_BRepSweep_Iterator(*args))

    def Init(self, *args) -> "void":
        r"""
        Resest the iterator on sub-shapes of <ashape>.

        Parameters
        ----------
        aShape: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_Iterator_Init(self, *args)

    def More(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if there is a current sub-shape.

        Returns
        -------
        bool

        """
        return _BRepSweep.BRepSweep_Iterator_More(self, *args)

    def Next(self, *args) -> "void":
        r"""
        Moves to the next sub-shape.

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_Iterator_Next(self, *args)

    def Orientation(self, *args) -> "TopAbs_Orientation":
        r"""
        Returns the orientation of the current sub-shape.

        Returns
        -------
        TopAbs_Orientation

        """
        return _BRepSweep.BRepSweep_Iterator_Orientation(self, *args)

    def Value(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns the current sub-shape.

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_Iterator_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepSweep.delete_BRepSweep_Iterator

# Register BRepSweep_Iterator in _BRepSweep:
_BRepSweep.BRepSweep_Iterator_swigregister(BRepSweep_Iterator)

class BRepSweep_NumLinearRegularSweep(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Closed(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_Closed(self, *args)

    def DirectSolid(self, *args) -> "TopAbs_Orientation":
        r"""
        Returns the orientation of the shell in the solid generated by the face agens with the edge adirs. it is reversed if the surface is swept in the direction of the normal.

        Parameters
        ----------
        aGenS: TopoDS_Shape
        aDirS: Sweep_NumShape

        Returns
        -------
        TopAbs_Orientation

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_DirectSolid(self, *args)

    def FirstShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the resulting shape indexed by the first vertex of mydirwire and mygenshape.

        Returns
        -------
        TopoDS_Shape
        Returns the resulting shape indexed by the first vertex of mydirwire and agens.

        Parameters
        ----------
        aGenS: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_FirstShape(self, *args)

    def GDDShapeIsToAdd(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if anewsubshape (addressed by agens and asubdirs) must be added in anewshape (addressed by agens and adirs).

        Parameters
        ----------
        aNewShape: TopoDS_Shape
        aNewSubShape: TopoDS_Shape
        aGenS: TopoDS_Shape
        aDirS: Sweep_NumShape
        aSubDirS: Sweep_NumShape

        Returns
        -------
        bool

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_GDDShapeIsToAdd(self, *args)

    def GGDShapeIsToAdd(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if anewsubshape (addressed by asubgens and adirs) must be added in anewshape (addressed by agens and adirs).

        Parameters
        ----------
        aNewShape: TopoDS_Shape
        aNewSubShape: TopoDS_Shape
        aGenS: TopoDS_Shape
        aSubGenS: TopoDS_Shape
        aDirS: Sweep_NumShape

        Returns
        -------
        bool

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_GGDShapeIsToAdd(self, *args)

    def GenIsUsed(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the shape, generated from thes is used in result shape.

        Parameters
        ----------
        theS: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_GenIsUsed(self, *args)

    def HasShape(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if adirs and agens addresses a resulting shape. in some specific cases the shape can be geometrically inexsistant, then this function returns false.

        Parameters
        ----------
        aGenS: TopoDS_Shape
        aDirS: Sweep_NumShape

        Returns
        -------
        bool

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_HasShape(self, *args)

    def IsInvariant(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if agens cannot be transformed.

        Parameters
        ----------
        aGenS: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_IsInvariant(self, *args)

    def IsUsed(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the initial shape agens is used in result shape.

        Parameters
        ----------
        aGenS: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_IsUsed(self, *args)

    def LastShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the resulting shape indexed by the last vertex of mydirwire and mygenshape.

        Returns
        -------
        TopoDS_Shape
        Returns the resulting shape indexed by the last vertex of mydirwire and agens.

        Parameters
        ----------
        aGenS: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_LastShape(self, *args)

    def MakeEmptyDirectingEdge(self, *args) -> "TopoDS_Shape":
        r"""
        Builds the edge addressed by [agenv,adire], with its geometric part, but without subcomponents.

        Parameters
        ----------
        aGenV: TopoDS_Shape
        aDirE: Sweep_NumShape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_MakeEmptyDirectingEdge(self, *args)

    def MakeEmptyFace(self, *args) -> "TopoDS_Shape":
        r"""
        Builds the face addressed by [agens,adirs], with its geometric part, but without subcomponents. the couple agens, adirs can be a 'generating face and a directing vertex' or 'a generating edge and a directing edge'.

        Parameters
        ----------
        aGenS: TopoDS_Shape
        aDirS: Sweep_NumShape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_MakeEmptyFace(self, *args)

    def MakeEmptyGeneratingEdge(self, *args) -> "TopoDS_Shape":
        r"""
        Builds the edge addressed by [agene,adirv], with its geometric part, but without subcomponents.

        Parameters
        ----------
        aGenE: TopoDS_Shape
        aDirV: Sweep_NumShape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_MakeEmptyGeneratingEdge(self, *args)

    def MakeEmptyVertex(self, *args) -> "TopoDS_Shape":
        r"""
        Builds the vertex addressed by [agenv,adirv], with its geometric part, but without subcomponents.

        Parameters
        ----------
        aGenV: TopoDS_Shape
        aDirV: Sweep_NumShape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_MakeEmptyVertex(self, *args)

    def SeparatedWires(self, *args) -> "Standard_Boolean":
        r"""
        In some particular cases the topology of a generated face must be composed of independant closed wires, in this case this function returns true.

        Parameters
        ----------
        aNewShape: TopoDS_Shape
        aNewSubShape: TopoDS_Shape
        aGenS: TopoDS_Shape
        aSubGenS: TopoDS_Shape
        aDirS: Sweep_NumShape

        Returns
        -------
        bool

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_SeparatedWires(self, *args)

    def SetContinuity(self, *args) -> "void":
        r"""
        Called to propagate the continuity of every vertex between two edges of the generating wire agens on the generated edge and faces.

        Parameters
        ----------
        aGenS: TopoDS_Shape
        aDirS: Sweep_NumShape

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_SetContinuity(self, *args)

    def SetDirectingPCurve(self, *args) -> "void":
        r"""
        Sets the pcurve for a new edge on a new face. the new edge and the new face were generated using agene, adire and agenv.

        Parameters
        ----------
        aNewFace: TopoDS_Shape
        aNewEdge: TopoDS_Shape
        aGenE: TopoDS_Shape
        aGenV: TopoDS_Shape
        aDirE: Sweep_NumShape
        orien: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_SetDirectingPCurve(self, *args)

    def SetDirectingParameter(self, *args) -> "void":
        r"""
        Sets the parameter of the new vertex on the new edge. the new edge and new vertex where generated from agenv adire, and adirv.

        Parameters
        ----------
        aNewEdge: TopoDS_Shape
        aNewVertex: TopoDS_Shape
        aGenV: TopoDS_Shape
        aDirE: Sweep_NumShape
        aDirV: Sweep_NumShape

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_SetDirectingParameter(self, *args)

    def SetGeneratingPCurve(self, *args) -> "void":
        r"""
        Sets the pcurve for a new edge on a new face. the new edge and the new face were generated using agene, adire and adirv.

        Parameters
        ----------
        aNewFace: TopoDS_Shape
        aNewEdge: TopoDS_Shape
        aGenE: TopoDS_Shape
        aDirE: Sweep_NumShape
        aDirV: Sweep_NumShape
        orien: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_SetGeneratingPCurve(self, *args)

    def SetGeneratingParameter(self, *args) -> "void":
        r"""
        Sets the parameter of the new vertex on the new edge. the new edge and new vertex where generated from agene, agenv and adirv .

        Parameters
        ----------
        aNewEdge: TopoDS_Shape
        aNewVertex: TopoDS_Shape
        aGenE: TopoDS_Shape
        aGenV: TopoDS_Shape
        aDirV: Sweep_NumShape

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_SetGeneratingParameter(self, *args)

    def SetPCurve(self, *args) -> "void":
        r"""
        Sets the pcurve for a new edge on a new face. the new edge and the new face were generated using agenf, agene and adirv.

        Parameters
        ----------
        aNewFace: TopoDS_Shape
        aNewEdge: TopoDS_Shape
        aGenF: TopoDS_Shape
        aGenE: TopoDS_Shape
        aDirV: Sweep_NumShape
        orien: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_SetPCurve(self, *args)

    def SetParameters(self, *args) -> "void":
        r"""
        Sets the parameters of the new vertex on the new face. the new face and new vertex where generated from agenf, agenv and adirv .

        Parameters
        ----------
        aNewFace: TopoDS_Shape
        aNewVertex: TopoDS_Shape
        aGenF: TopoDS_Shape
        aGenV: TopoDS_Shape
        aDirV: Sweep_NumShape

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_SetParameters(self, *args)

    def Shape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the resulting shape indexed by adirs and agens.

        Parameters
        ----------
        aGenS: TopoDS_Shape
        aDirS: Sweep_NumShape

        Returns
        -------
        TopoDS_Shape
        Returns the resulting shape indexed by mydirwire and agens.

        Parameters
        ----------
        aGenS: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape
        Returns the resulting shape indexed by mydirwire and mygenshape.

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_Shape(self, *args)

    def SplitShell(self, *args) -> "TopoDS_Shape":
        r"""
        In some particular cases the topology of a generated shell must be composed of independant closed shells, in this case this function returns a compound of independant shells.

        Parameters
        ----------
        aNewShape: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_NumLinearRegularSweep_SplitShell(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepSweep.delete_BRepSweep_NumLinearRegularSweep

# Register BRepSweep_NumLinearRegularSweep in _BRepSweep:
_BRepSweep.BRepSweep_NumLinearRegularSweep_swigregister(BRepSweep_NumLinearRegularSweep)

class BRepSweep_Prism(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Builds the prism of base s and vector v. if c is true, s is copied. if canonize is true then generated surfaces are attempted to be canonized in simple types.

        Parameters
        ----------
        S: TopoDS_Shape
        V: gp_Vec
        Copy: bool,optional
        	default value is Standard_False
        Canonize: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Builds a semi-infinite or an infinite prism of base s. if copy is true s is copied. if inf is true the prism is infinite, if inf is false the prism is infinite in the direction d. if canonize is true then generated surfaces are attempted to be canonized in simple types.

        Parameters
        ----------
        S: TopoDS_Shape
        D: gp_Dir
        Inf: bool,optional
        	default value is Standard_True
        Copy: bool,optional
        	default value is Standard_False
        Canonize: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _BRepSweep.BRepSweep_Prism_swiginit(self, _BRepSweep.new_BRepSweep_Prism(*args))

    def FirstShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the topods shape of the bottom of the prism.

        Returns
        -------
        TopoDS_Shape
        Returns the topods shape of the bottom of the prism. generated with agens (subshape of the generating shape).

        Parameters
        ----------
        aGenS: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_Prism_FirstShape(self, *args)

    def GenIsUsed(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the shape, generated from thes is used in result shape.

        Parameters
        ----------
        theS: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _BRepSweep.BRepSweep_Prism_GenIsUsed(self, *args)

    def IsUsed(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the agens is used in resulting shape.

        Parameters
        ----------
        aGenS: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _BRepSweep.BRepSweep_Prism_IsUsed(self, *args)

    def LastShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the topods shape of the top of the prism.

        Returns
        -------
        TopoDS_Shape
        Returns the topods shape of the top of the prism. generated with agens (subshape of the generating shape).

        Parameters
        ----------
        aGenS: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_Prism_LastShape(self, *args)

    def Shape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the topods shape attached to the prism.

        Returns
        -------
        TopoDS_Shape
        Returns the topods shape generated with agens (subshape of the generating shape).

        Parameters
        ----------
        aGenS: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_Prism_Shape(self, *args)

    def Vec(self, *args) -> "gp_Vec":
        r"""
        Returns the vector of the prism, if it is an infinite prism the vec is unitar.

        Returns
        -------
        gp_Vec

        """
        return _BRepSweep.BRepSweep_Prism_Vec(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepSweep.delete_BRepSweep_Prism

# Register BRepSweep_Prism in _BRepSweep:
_BRepSweep.BRepSweep_Prism_swigregister(BRepSweep_Prism)

class BRepSweep_Revol(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Builds the revol of meridian s axis a and angle d. if c is true s is copied.

        Parameters
        ----------
        S: TopoDS_Shape
        A: gp_Ax1
        D: float
        C: bool,optional
        	default value is Standard_False

        Returns
        -------
        None
        Builds the revol of meridian s axis a and angle 2*pi. if c is true s is copied.

        Parameters
        ----------
        S: TopoDS_Shape
        A: gp_Ax1
        C: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        _BRepSweep.BRepSweep_Revol_swiginit(self, _BRepSweep.new_BRepSweep_Revol(*args))

    def Angle(self, *args) -> "Standard_Real":
        r"""
        Returns the angle.

        Returns
        -------
        float

        """
        return _BRepSweep.BRepSweep_Revol_Angle(self, *args)

    def Axe(self, *args) -> "gp_Ax1":
        r"""
        Returns the axis.

        Returns
        -------
        gp_Ax1

        """
        return _BRepSweep.BRepSweep_Revol_Axe(self, *args)

    def FirstShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the first shape of the revol (coinciding with the generating shape).

        Returns
        -------
        TopoDS_Shape
        Returns the first shape of the revol (coinciding with the generating shape).

        Parameters
        ----------
        aGenS: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_Revol_FirstShape(self, *args)

    def IsUsed(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the agens is used in resulting shape .

        Parameters
        ----------
        aGenS: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _BRepSweep.BRepSweep_Revol_IsUsed(self, *args)

    def LastShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the topods shape of the top of the prism.

        Returns
        -------
        TopoDS_Shape
        Returns the topods shape of the top of the prism. generated with agens (subshape of the generating shape).

        Parameters
        ----------
        aGenS: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_Revol_LastShape(self, *args)

    def Shape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the topods shape attached to the revol.

        Returns
        -------
        TopoDS_Shape
        Returns the topods shape generated with agens (subshape of the generating shape).

        Parameters
        ----------
        aGenS: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_Revol_Shape(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepSweep.delete_BRepSweep_Revol

# Register BRepSweep_Revol in _BRepSweep:
_BRepSweep.BRepSweep_Revol_swigregister(BRepSweep_Revol)

class BRepSweep_Tool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initialize the tool with <ashape>. the indextool must prepare an indexation for all the subshapes of this shape.

        Parameters
        ----------
        aShape: TopoDS_Shape

        Returns
        -------
        None

        """
        _BRepSweep.BRepSweep_Tool_swiginit(self, _BRepSweep.new_BRepSweep_Tool(*args))

    def Index(self, *args) -> "Standard_Integer":
        r"""
        Returns the index of <ashape>.

        Parameters
        ----------
        aShape: TopoDS_Shape

        Returns
        -------
        int

        """
        return _BRepSweep.BRepSweep_Tool_Index(self, *args)

    def NbShapes(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of subshapes in the shape.

        Returns
        -------
        int

        """
        return _BRepSweep.BRepSweep_Tool_NbShapes(self, *args)

    def Orientation(self, *args) -> "TopAbs_Orientation":
        r"""
        Returns the orientation of <ashape>.

        Parameters
        ----------
        aShape: TopoDS_Shape

        Returns
        -------
        TopAbs_Orientation

        """
        return _BRepSweep.BRepSweep_Tool_Orientation(self, *args)

    def SetOrientation(self, *args) -> "void":
        r"""
        Set the orientation of <ashape> with or.

        Parameters
        ----------
        aShape: TopoDS_Shape
        Or: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_Tool_SetOrientation(self, *args)

    def Shape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the shape at index anidex.

        Parameters
        ----------
        anIndex: int

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepSweep.BRepSweep_Tool_Shape(self, *args)

    def Type(self, *args) -> "TopAbs_ShapeEnum":
        r"""
        Returns the type of <ashape>.

        Parameters
        ----------
        aShape: TopoDS_Shape

        Returns
        -------
        TopAbs_ShapeEnum

        """
        return _BRepSweep.BRepSweep_Tool_Type(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepSweep.delete_BRepSweep_Tool

# Register BRepSweep_Tool in _BRepSweep:
_BRepSweep.BRepSweep_Tool_swigregister(BRepSweep_Tool)

class BRepSweep_Trsf(BRepSweep_NumLinearRegularSweep):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Init(self, *args) -> "void":
        r"""
        Ends the construction of the swept primitive calling the virtual geometric functions that can't be called in the initialize.

        Returns
        -------
        None

        """
        return _BRepSweep.BRepSweep_Trsf_Init(self, *args)

    def Process(self, *args) -> "Standard_Boolean":
        r"""
        Function called to analize the way of construction of the shapes generated by agens and adirv.

        Parameters
        ----------
        aGenS: TopoDS_Shape
        aDirV: Sweep_NumShape

        Returns
        -------
        bool

        """
        return _BRepSweep.BRepSweep_Trsf_Process(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepSweep.delete_BRepSweep_Trsf

# Register BRepSweep_Trsf in _BRepSweep:
_BRepSweep.BRepSweep_Trsf_swigregister(BRepSweep_Trsf)

class BRepSweep_Rotation(BRepSweep_Trsf):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a topology by rotating <s> around a with the angle d.

        Parameters
        ----------
        S: TopoDS_Shape
        N: Sweep_NumShape
        L: TopLoc_Location
        A: gp_Ax1
        D: float
        C: bool

        Returns
        -------
        None

        """
        _BRepSweep.BRepSweep_Rotation_swiginit(self, _BRepSweep.new_BRepSweep_Rotation(*args))

    def Angle(self, *args) -> "Standard_Real":
        r"""
        Returns the angle.

        Returns
        -------
        float

        """
        return _BRepSweep.BRepSweep_Rotation_Angle(self, *args)

    def Axe(self, *args) -> "gp_Ax1":
        r"""
        Returns the axis.

        Returns
        -------
        gp_Ax1

        """
        return _BRepSweep.BRepSweep_Rotation_Axe(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepSweep.delete_BRepSweep_Rotation

# Register BRepSweep_Rotation in _BRepSweep:
_BRepSweep.BRepSweep_Rotation_swigregister(BRepSweep_Rotation)

class BRepSweep_Translation(BRepSweep_Trsf):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a topology by translating <s> with the vector <v>. if c is true s sucomponents are copied. if canonize is true then generated surfaces are attempted to be canonized in simple types.

        Parameters
        ----------
        S: TopoDS_Shape
        N: Sweep_NumShape
        L: TopLoc_Location
        V: gp_Vec
        C: bool
        Canonize: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _BRepSweep.BRepSweep_Translation_swiginit(self, _BRepSweep.new_BRepSweep_Translation(*args))

    def Vec(self, *args) -> "gp_Vec":
        r"""
        Returns the vector of the prism, if it is an infinite prism the vec is unitar.

        Returns
        -------
        gp_Vec

        """
        return _BRepSweep.BRepSweep_Translation_Vec(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepSweep.delete_BRepSweep_Translation

# Register BRepSweep_Translation in _BRepSweep:
_BRepSweep.BRepSweep_Translation_swigregister(BRepSweep_Translation)





