# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
TopAbs module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_topabs.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _TopAbs
else:
    import _TopAbs

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _TopAbs.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _TopAbs.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TopAbs.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TopAbs.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _TopAbs.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _TopAbs.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _TopAbs.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _TopAbs.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _TopAbs.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _TopAbs.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TopAbs.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _TopAbs.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _TopAbs.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TopAbs.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TopAbs.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TopAbs.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _TopAbs.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _TopAbs:
_TopAbs.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _TopAbs.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection

from enum import IntEnum
from OCC.Core.Exception import *

TopAbs_FORWARD = _TopAbs.TopAbs_FORWARD
TopAbs_REVERSED = _TopAbs.TopAbs_REVERSED
TopAbs_INTERNAL = _TopAbs.TopAbs_INTERNAL
TopAbs_EXTERNAL = _TopAbs.TopAbs_EXTERNAL
TopAbs_COMPOUND = _TopAbs.TopAbs_COMPOUND
TopAbs_COMPSOLID = _TopAbs.TopAbs_COMPSOLID
TopAbs_SOLID = _TopAbs.TopAbs_SOLID
TopAbs_SHELL = _TopAbs.TopAbs_SHELL
TopAbs_FACE = _TopAbs.TopAbs_FACE
TopAbs_WIRE = _TopAbs.TopAbs_WIRE
TopAbs_EDGE = _TopAbs.TopAbs_EDGE
TopAbs_VERTEX = _TopAbs.TopAbs_VERTEX
TopAbs_SHAPE = _TopAbs.TopAbs_SHAPE
TopAbs_IN = _TopAbs.TopAbs_IN
TopAbs_OUT = _TopAbs.TopAbs_OUT
TopAbs_ON = _TopAbs.TopAbs_ON
TopAbs_UNKNOWN = _TopAbs.TopAbs_UNKNOWN


class TopAbs_Orientation(IntEnum):
	TopAbs_FORWARD = 0
	TopAbs_REVERSED = 1
	TopAbs_INTERNAL = 2
	TopAbs_EXTERNAL = 3
TopAbs_FORWARD = TopAbs_Orientation.TopAbs_FORWARD
TopAbs_REVERSED = TopAbs_Orientation.TopAbs_REVERSED
TopAbs_INTERNAL = TopAbs_Orientation.TopAbs_INTERNAL
TopAbs_EXTERNAL = TopAbs_Orientation.TopAbs_EXTERNAL

class TopAbs_ShapeEnum(IntEnum):
	TopAbs_COMPOUND = 0
	TopAbs_COMPSOLID = 1
	TopAbs_SOLID = 2
	TopAbs_SHELL = 3
	TopAbs_FACE = 4
	TopAbs_WIRE = 5
	TopAbs_EDGE = 6
	TopAbs_VERTEX = 7
	TopAbs_SHAPE = 8
TopAbs_COMPOUND = TopAbs_ShapeEnum.TopAbs_COMPOUND
TopAbs_COMPSOLID = TopAbs_ShapeEnum.TopAbs_COMPSOLID
TopAbs_SOLID = TopAbs_ShapeEnum.TopAbs_SOLID
TopAbs_SHELL = TopAbs_ShapeEnum.TopAbs_SHELL
TopAbs_FACE = TopAbs_ShapeEnum.TopAbs_FACE
TopAbs_WIRE = TopAbs_ShapeEnum.TopAbs_WIRE
TopAbs_EDGE = TopAbs_ShapeEnum.TopAbs_EDGE
TopAbs_VERTEX = TopAbs_ShapeEnum.TopAbs_VERTEX
TopAbs_SHAPE = TopAbs_ShapeEnum.TopAbs_SHAPE

class TopAbs_State(IntEnum):
	TopAbs_IN = 0
	TopAbs_OUT = 1
	TopAbs_ON = 2
	TopAbs_UNKNOWN = 3
TopAbs_IN = TopAbs_State.TopAbs_IN
TopAbs_OUT = TopAbs_State.TopAbs_OUT
TopAbs_ON = TopAbs_State.TopAbs_ON
TopAbs_UNKNOWN = TopAbs_State.TopAbs_UNKNOWN

class topabs(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Complement(*args) -> "TopAbs_Orientation":
        r"""
        Reverses the interior/exterior status of each side of the object. so, to take the complement of an object means to reverse the interior/exterior status of its boundary, i.e. inside becomes outside. the method returns the complementary orientation, following the rules in the table below: forward reversed reversed forward internal external external internal //! complement complements the material side. inside becomes outside.

        Parameters
        ----------
        Or: TopAbs_Orientation

        Returns
        -------
        TopAbs_Orientation

        """
        return _TopAbs.topabs_Complement(*args)

    @staticmethod
    def Compose(*args) -> "TopAbs_Orientation":
        r"""
        Compose the orientation <or1> and <or2>. this composition is not symmetric (if you switch <or1> and <or2> the result is different). it assumes that <or1> is the orientation of a shape s1 containing a shape s2 of orientation or2. the result is the cumulated orientation of s2 in s1. the composition law is : //! \ or2 forward reversed internal external or1 ------------------------------------- forward | forward reversed internal external | reversed | reversed forward internal external | internal | internal internal internal internal | external | external external external external note: the top corner in the table is the most important for the purposes of open cascade topology and shape sharing.

        Parameters
        ----------
        Or1: TopAbs_Orientation
        Or2: TopAbs_Orientation

        Returns
        -------
        TopAbs_Orientation

        """
        return _TopAbs.topabs_Compose(*args)

    @staticmethod
    def Reverse(*args) -> "TopAbs_Orientation":
        r"""
        Xchanges the interior/exterior status of the two sides. this is what happens when the sense of direction is reversed. the following rules apply: //! forward reversed reversed forward internal internal external external //! reverse exchange the material sides.

        Parameters
        ----------
        Or: TopAbs_Orientation

        Returns
        -------
        TopAbs_Orientation

        """
        return _TopAbs.topabs_Reverse(*args)

    @staticmethod
    def ShapeOrientationFromString(*args) -> "Standard_Boolean":
        r"""
        Returns the shape orientation from the given string identifier (using case-insensitive comparison). @param theorientationstring string identifier returns shape orientation or topabs_forward if string identifier is invalid.

        Parameters
        ----------
        theOrientationString: char *

        Returns
        -------
        TopAbs_Orientation
        Determines the shape orientation from the given string identifier (using case-insensitive comparison). @param theorientationstring string identifier @param theorientation detected shape orientation returns true if string identifier is known.

        Parameters
        ----------
        theOrientationString: char *
        theOrientation: TopAbs_Orientation

        Returns
        -------
        bool

        """
        return _TopAbs.topabs_ShapeOrientationFromString(*args)

    @staticmethod
    def ShapeOrientationToString(*args) -> "char const *":
        r"""
        Returns the string name for a given shape orientation. @param theorientation shape orientation returns string identifier from the list forward, reversed, internal, external.

        Parameters
        ----------
        theOrientation: TopAbs_Orientation

        Returns
        -------
        char *

        """
        return _TopAbs.topabs_ShapeOrientationToString(*args)

    @staticmethod
    def ShapeTypeFromString(*args) -> "Standard_Boolean":
        r"""
        Returns the shape type from the given string identifier (using case-insensitive comparison). @param thetypestring string identifier returns shape type or topabs_shape if string identifier is invalid.

        Parameters
        ----------
        theTypeString: char *

        Returns
        -------
        TopAbs_ShapeEnum
        Determines the shape type from the given string identifier (using case-insensitive comparison). @param thetypestring string identifier @param thetype detected shape type returns true if string identifier is known.

        Parameters
        ----------
        theTypeString: char *
        theType: TopAbs_ShapeEnum

        Returns
        -------
        bool

        """
        return _TopAbs.topabs_ShapeTypeFromString(*args)

    @staticmethod
    def ShapeTypeToString(*args) -> "char const *":
        r"""
        Returns the string name for a given shape type. @param thetype shape type returns string identifier from the list compound, compsolid, solid, shell, face, wire, edge, vertex, shape.

        Parameters
        ----------
        theType: TopAbs_ShapeEnum

        Returns
        -------
        char *

        """
        return _TopAbs.topabs_ShapeTypeToString(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _TopAbs.topabs_swiginit(self, _TopAbs.new_topabs())
    __swig_destroy__ = _TopAbs.delete_topabs

# Register topabs in _TopAbs:
_TopAbs.topabs_swigregister(topabs)

def topabs_Complement(*args) -> "TopAbs_Orientation":
    r"""
    Reverses the interior/exterior status of each side of the object. so, to take the complement of an object means to reverse the interior/exterior status of its boundary, i.e. inside becomes outside. the method returns the complementary orientation, following the rules in the table below: forward reversed reversed forward internal external external internal //! complement complements the material side. inside becomes outside.

    Parameters
    ----------
    Or: TopAbs_Orientation

    Returns
    -------
    TopAbs_Orientation

    """
    return _TopAbs.topabs_Complement(*args)

def topabs_Compose(*args) -> "TopAbs_Orientation":
    r"""
    Compose the orientation <or1> and <or2>. this composition is not symmetric (if you switch <or1> and <or2> the result is different). it assumes that <or1> is the orientation of a shape s1 containing a shape s2 of orientation or2. the result is the cumulated orientation of s2 in s1. the composition law is : //! \ or2 forward reversed internal external or1 ------------------------------------- forward | forward reversed internal external | reversed | reversed forward internal external | internal | internal internal internal internal | external | external external external external note: the top corner in the table is the most important for the purposes of open cascade topology and shape sharing.

    Parameters
    ----------
    Or1: TopAbs_Orientation
    Or2: TopAbs_Orientation

    Returns
    -------
    TopAbs_Orientation

    """
    return _TopAbs.topabs_Compose(*args)

def topabs_Reverse(*args) -> "TopAbs_Orientation":
    r"""
    Xchanges the interior/exterior status of the two sides. this is what happens when the sense of direction is reversed. the following rules apply: //! forward reversed reversed forward internal internal external external //! reverse exchange the material sides.

    Parameters
    ----------
    Or: TopAbs_Orientation

    Returns
    -------
    TopAbs_Orientation

    """
    return _TopAbs.topabs_Reverse(*args)

def topabs_ShapeOrientationFromString(*args) -> "Standard_Boolean":
    r"""
    Returns the shape orientation from the given string identifier (using case-insensitive comparison). @param theorientationstring string identifier returns shape orientation or topabs_forward if string identifier is invalid.

    Parameters
    ----------
    theOrientationString: char *

    Returns
    -------
    TopAbs_Orientation
    Determines the shape orientation from the given string identifier (using case-insensitive comparison). @param theorientationstring string identifier @param theorientation detected shape orientation returns true if string identifier is known.

    Parameters
    ----------
    theOrientationString: char *
    theOrientation: TopAbs_Orientation

    Returns
    -------
    bool

    """
    return _TopAbs.topabs_ShapeOrientationFromString(*args)

def topabs_ShapeOrientationToString(*args) -> "char const *":
    r"""
    Returns the string name for a given shape orientation. @param theorientation shape orientation returns string identifier from the list forward, reversed, internal, external.

    Parameters
    ----------
    theOrientation: TopAbs_Orientation

    Returns
    -------
    char *

    """
    return _TopAbs.topabs_ShapeOrientationToString(*args)

def topabs_ShapeTypeFromString(*args) -> "Standard_Boolean":
    r"""
    Returns the shape type from the given string identifier (using case-insensitive comparison). @param thetypestring string identifier returns shape type or topabs_shape if string identifier is invalid.

    Parameters
    ----------
    theTypeString: char *

    Returns
    -------
    TopAbs_ShapeEnum
    Determines the shape type from the given string identifier (using case-insensitive comparison). @param thetypestring string identifier @param thetype detected shape type returns true if string identifier is known.

    Parameters
    ----------
    theTypeString: char *
    theType: TopAbs_ShapeEnum

    Returns
    -------
    bool

    """
    return _TopAbs.topabs_ShapeTypeFromString(*args)

def topabs_ShapeTypeToString(*args) -> "char const *":
    r"""
    Returns the string name for a given shape type. @param thetype shape type returns string identifier from the list compound, compsolid, solid, shell, face, wire, edge, vertex, shape.

    Parameters
    ----------
    theType: TopAbs_ShapeEnum

    Returns
    -------
    char *

    """
    return _TopAbs.topabs_ShapeTypeToString(*args)





