# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
GeomProjLib module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_geomprojlib.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _GeomProjLib
else:
    import _GeomProjLib

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _GeomProjLib.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _GeomProjLib.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GeomProjLib.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GeomProjLib.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _GeomProjLib.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _GeomProjLib.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _GeomProjLib.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _GeomProjLib.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _GeomProjLib.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _GeomProjLib.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GeomProjLib.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _GeomProjLib.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _GeomProjLib.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GeomProjLib.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GeomProjLib.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GeomProjLib.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _GeomProjLib.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _GeomProjLib:
_GeomProjLib.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _GeomProjLib.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Geom
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Geom2d

from enum import IntEnum
from OCC.Core.Exception import *



class geomprojlib(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Curve2d(*args) -> "Standard_Real &":
        r"""
        Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ) the 3dcurve is taken between the parametrization range [first, last] <tolerance> is used as input if the projection needs an approximation. in this case, the reached tolerance is set in <tolerance> as output. warning : if the projection has failed, this method returns a null handle.

        Parameters
        ----------
        C: Geom_Curve
        First: float
        Last: float
        S: Geom_Surface
        UFirst: float
        ULast: float
        VFirst: float
        VLast: float

        Returns
        -------
        Tolerance: float
        Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ) the 3dcurve is taken between the parametrization range [first, last] <tolerance> is used as input if the projection needs an approximation. in this case, the reached tolerance is set in <tolerance> as output. warning : if the projection has failed, this method returns a null handle.

        Parameters
        ----------
        C: Geom_Curve
        First: float
        Last: float
        S: Geom_Surface

        Returns
        -------
        Tolerance: float
        Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ) the 3dcurve is taken between the parametrization range [first, last] if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle.

        Parameters
        ----------
        C: Geom_Curve
        First: float
        Last: float
        S: Geom_Surface

        Returns
        -------
        opencascade::handle<Geom2d_Curve>
        Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ). if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle.

        Parameters
        ----------
        C: Geom_Curve
        S: Geom_Surface

        Returns
        -------
        opencascade::handle<Geom2d_Curve>
        Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ). if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle. can expand a little the bounds of surface.

        Parameters
        ----------
        C: Geom_Curve
        S: Geom_Surface
        UDeb: float
        UFin: float
        VDeb: float
        VFin: float

        Returns
        -------
        opencascade::handle<Geom2d_Curve>
        Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ). if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle. can expand a little the bounds of surface.

        Parameters
        ----------
        C: Geom_Curve
        S: Geom_Surface
        UDeb: float
        UFin: float
        VDeb: float
        VFin: float

        Returns
        -------
        Tolerance: float

        """
        return _GeomProjLib.geomprojlib_Curve2d(*args)

    @staticmethod
    def Project(*args) -> "opencascade::handle< Geom_Curve >":
        r"""
        Constructs the 3d-curve from the normal projection of the curve <c> on the surface <s>. warning : if the projection has failes returns a null handle.

        Parameters
        ----------
        C: Geom_Curve
        S: Geom_Surface

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _GeomProjLib.geomprojlib_Project(*args)

    @staticmethod
    def ProjectOnPlane(*args) -> "opencascade::handle< Geom_Curve >":
        r"""
        Constructs the 3d-curves from the projection of the curve <curve> on the plane <plane> along the direction <dir>. if <keepparametrization> is true, the parametrization of the projected curve <pc> will be the same as the parametrization of the initial curve <c>. it meens: proj(c(u)) = pc(u) for each u. otherwize, the parametrization may change.

        Parameters
        ----------
        Curve: Geom_Curve
        Plane: Geom_Plane
        Dir: gp_Dir
        KeepParametrization: bool

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _GeomProjLib.geomprojlib_ProjectOnPlane(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _GeomProjLib.geomprojlib_swiginit(self, _GeomProjLib.new_geomprojlib())
    __swig_destroy__ = _GeomProjLib.delete_geomprojlib

# Register geomprojlib in _GeomProjLib:
_GeomProjLib.geomprojlib_swigregister(geomprojlib)

def geomprojlib_Curve2d(*args) -> "Standard_Real &":
    r"""
    Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ) the 3dcurve is taken between the parametrization range [first, last] <tolerance> is used as input if the projection needs an approximation. in this case, the reached tolerance is set in <tolerance> as output. warning : if the projection has failed, this method returns a null handle.

    Parameters
    ----------
    C: Geom_Curve
    First: float
    Last: float
    S: Geom_Surface
    UFirst: float
    ULast: float
    VFirst: float
    VLast: float

    Returns
    -------
    Tolerance: float
    Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ) the 3dcurve is taken between the parametrization range [first, last] <tolerance> is used as input if the projection needs an approximation. in this case, the reached tolerance is set in <tolerance> as output. warning : if the projection has failed, this method returns a null handle.

    Parameters
    ----------
    C: Geom_Curve
    First: float
    Last: float
    S: Geom_Surface

    Returns
    -------
    Tolerance: float
    Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ) the 3dcurve is taken between the parametrization range [first, last] if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle.

    Parameters
    ----------
    C: Geom_Curve
    First: float
    Last: float
    S: Geom_Surface

    Returns
    -------
    opencascade::handle<Geom2d_Curve>
    Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ). if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle.

    Parameters
    ----------
    C: Geom_Curve
    S: Geom_Surface

    Returns
    -------
    opencascade::handle<Geom2d_Curve>
    Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ). if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle. can expand a little the bounds of surface.

    Parameters
    ----------
    C: Geom_Curve
    S: Geom_Surface
    UDeb: float
    UFin: float
    VDeb: float
    VFin: float

    Returns
    -------
    opencascade::handle<Geom2d_Curve>
    Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ). if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle. can expand a little the bounds of surface.

    Parameters
    ----------
    C: Geom_Curve
    S: Geom_Surface
    UDeb: float
    UFin: float
    VDeb: float
    VFin: float

    Returns
    -------
    Tolerance: float

    """
    return _GeomProjLib.geomprojlib_Curve2d(*args)

def geomprojlib_Project(*args) -> "opencascade::handle< Geom_Curve >":
    r"""
    Constructs the 3d-curve from the normal projection of the curve <c> on the surface <s>. warning : if the projection has failes returns a null handle.

    Parameters
    ----------
    C: Geom_Curve
    S: Geom_Surface

    Returns
    -------
    opencascade::handle<Geom_Curve>

    """
    return _GeomProjLib.geomprojlib_Project(*args)

def geomprojlib_ProjectOnPlane(*args) -> "opencascade::handle< Geom_Curve >":
    r"""
    Constructs the 3d-curves from the projection of the curve <curve> on the plane <plane> along the direction <dir>. if <keepparametrization> is true, the parametrization of the projected curve <pc> will be the same as the parametrization of the initial curve <c>. it meens: proj(c(u)) = pc(u) for each u. otherwize, the parametrization may change.

    Parameters
    ----------
    Curve: Geom_Curve
    Plane: Geom_Plane
    Dir: gp_Dir
    KeepParametrization: bool

    Returns
    -------
    opencascade::handle<Geom_Curve>

    """
    return _GeomProjLib.geomprojlib_ProjectOnPlane(*args)





