# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlMFunction module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmlmfunction.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlMFunction
else:
    import _XmlMFunction

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlMFunction.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlMFunction.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMFunction.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMFunction.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlMFunction.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlMFunction.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlMFunction.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlMFunction.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlMFunction.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlMFunction.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMFunction.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMFunction.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMFunction.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMFunction.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMFunction.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMFunction.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlMFunction.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlMFunction:
_XmlMFunction.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlMFunction.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.XmlMDF
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TDF
import OCC.Core.XmlObjMgt
import OCC.Core.LDOM
import OCC.Core.gp
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XmlMFunction_FunctionDriver_Create() -> "opencascade::handle< XmlMFunction_FunctionDriver >":
    return _XmlMFunction.Handle_XmlMFunction_FunctionDriver_Create()

def Handle_XmlMFunction_FunctionDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMFunction_FunctionDriver >":
    return _XmlMFunction.Handle_XmlMFunction_FunctionDriver_DownCast(t)

def Handle_XmlMFunction_FunctionDriver_IsNull(t: "opencascade::handle< XmlMFunction_FunctionDriver > const &") -> "bool":
    return _XmlMFunction.Handle_XmlMFunction_FunctionDriver_IsNull(t)

def Handle_XmlMFunction_GraphNodeDriver_Create() -> "opencascade::handle< XmlMFunction_GraphNodeDriver >":
    return _XmlMFunction.Handle_XmlMFunction_GraphNodeDriver_Create()

def Handle_XmlMFunction_GraphNodeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMFunction_GraphNodeDriver >":
    return _XmlMFunction.Handle_XmlMFunction_GraphNodeDriver_DownCast(t)

def Handle_XmlMFunction_GraphNodeDriver_IsNull(t: "opencascade::handle< XmlMFunction_GraphNodeDriver > const &") -> "bool":
    return _XmlMFunction.Handle_XmlMFunction_GraphNodeDriver_IsNull(t)

def Handle_XmlMFunction_ScopeDriver_Create() -> "opencascade::handle< XmlMFunction_ScopeDriver >":
    return _XmlMFunction.Handle_XmlMFunction_ScopeDriver_Create()

def Handle_XmlMFunction_ScopeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMFunction_ScopeDriver >":
    return _XmlMFunction.Handle_XmlMFunction_ScopeDriver_DownCast(t)

def Handle_XmlMFunction_ScopeDriver_IsNull(t: "opencascade::handle< XmlMFunction_ScopeDriver > const &") -> "bool":
    return _XmlMFunction.Handle_XmlMFunction_ScopeDriver_IsNull(t)
class xmlmfunction(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        Adds the attribute storage drivers to <adrivertable>.

        Parameters
        ----------
        aDriverTable: XmlMDF_ADriverTable
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        return _XmlMFunction.xmlmfunction_AddDrivers(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlMFunction.xmlmfunction_swiginit(self, _XmlMFunction.new_xmlmfunction())
    __swig_destroy__ = _XmlMFunction.delete_xmlmfunction

# Register xmlmfunction in _XmlMFunction:
_XmlMFunction.xmlmfunction_swigregister(xmlmfunction)

def xmlmfunction_AddDrivers(*args) -> "void":
    r"""
    Adds the attribute storage drivers to <adrivertable>.

    Parameters
    ----------
    aDriverTable: XmlMDF_ADriverTable
    theMessageDriver: Message_Messenger

    Returns
    -------
    None

    """
    return _XmlMFunction.xmlmfunction_AddDrivers(*args)

class XmlMFunction_FunctionDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMFunction.XmlMFunction_FunctionDriver_swiginit(self, _XmlMFunction.new_XmlMFunction_FunctionDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMFunction.XmlMFunction_FunctionDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMFunction_FunctionDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMFunction.delete_XmlMFunction_FunctionDriver

# Register XmlMFunction_FunctionDriver in _XmlMFunction:
_XmlMFunction.XmlMFunction_FunctionDriver_swigregister(XmlMFunction_FunctionDriver)

class XmlMFunction_GraphNodeDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMFunction.XmlMFunction_GraphNodeDriver_swiginit(self, _XmlMFunction.new_XmlMFunction_GraphNodeDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMFunction.XmlMFunction_GraphNodeDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMFunction_GraphNodeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMFunction.delete_XmlMFunction_GraphNodeDriver

# Register XmlMFunction_GraphNodeDriver in _XmlMFunction:
_XmlMFunction.XmlMFunction_GraphNodeDriver_swigregister(XmlMFunction_GraphNodeDriver)

class XmlMFunction_ScopeDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMFunction.XmlMFunction_ScopeDriver_swiginit(self, _XmlMFunction.new_XmlMFunction_ScopeDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMFunction.XmlMFunction_ScopeDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMFunction_ScopeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMFunction.delete_XmlMFunction_ScopeDriver

# Register XmlMFunction_ScopeDriver in _XmlMFunction:
_XmlMFunction.XmlMFunction_ScopeDriver_swigregister(XmlMFunction_ScopeDriver)





