# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlDrivers module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmldrivers.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlDrivers
else:
    import _XmlDrivers

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlDrivers.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlDrivers.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlDrivers.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlDrivers.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlDrivers.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlDrivers.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlDrivers.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlDrivers.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlDrivers.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlDrivers.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlDrivers.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlDrivers.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlDrivers.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlDrivers.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlDrivers.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlDrivers.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlDrivers.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlDrivers:
_XmlDrivers.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlDrivers.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.XmlMDF
import OCC.Core.TDF
import OCC.Core.XmlObjMgt
import OCC.Core.LDOM
import OCC.Core.gp
import OCC.Core.Storage
import OCC.Core.TDocStd
import OCC.Core.CDF
import OCC.Core.CDM
import OCC.Core.Resource
import OCC.Core.PCDM
import OCC.Core.XmlLDrivers

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XmlDrivers_DocumentRetrievalDriver_Create() -> "opencascade::handle< XmlDrivers_DocumentRetrievalDriver >":
    return _XmlDrivers.Handle_XmlDrivers_DocumentRetrievalDriver_Create()

def Handle_XmlDrivers_DocumentRetrievalDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlDrivers_DocumentRetrievalDriver >":
    return _XmlDrivers.Handle_XmlDrivers_DocumentRetrievalDriver_DownCast(t)

def Handle_XmlDrivers_DocumentRetrievalDriver_IsNull(t: "opencascade::handle< XmlDrivers_DocumentRetrievalDriver > const &") -> "bool":
    return _XmlDrivers.Handle_XmlDrivers_DocumentRetrievalDriver_IsNull(t)

def Handle_XmlDrivers_DocumentStorageDriver_Create() -> "opencascade::handle< XmlDrivers_DocumentStorageDriver >":
    return _XmlDrivers.Handle_XmlDrivers_DocumentStorageDriver_Create()

def Handle_XmlDrivers_DocumentStorageDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlDrivers_DocumentStorageDriver >":
    return _XmlDrivers.Handle_XmlDrivers_DocumentStorageDriver_DownCast(t)

def Handle_XmlDrivers_DocumentStorageDriver_IsNull(t: "opencascade::handle< XmlDrivers_DocumentStorageDriver > const &") -> "bool":
    return _XmlDrivers.Handle_XmlDrivers_DocumentStorageDriver_IsNull(t)
class xmldrivers(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AttributeDrivers(*args) -> "opencascade::handle< XmlMDF_ADriverTable >":
        r"""
        No available documentation.

        Parameters
        ----------
        theMsgDriver: Message_Messenger

        Returns
        -------
        opencascade::handle<XmlMDF_ADriverTable>

        """
        return _XmlDrivers.xmldrivers_AttributeDrivers(*args)

    @staticmethod
    def DefineFormat(*args) -> "void":
        r"""
        Defines format 'xmlocaf' and registers its read and write drivers in the specified application.

        Parameters
        ----------
        theApp: TDocStd_Application

        Returns
        -------
        None

        """
        return _XmlDrivers.xmldrivers_DefineFormat(*args)

    @staticmethod
    def Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
        r"""
        No available documentation.

        Parameters
        ----------
        theGUID: Standard_GUID

        Returns
        -------
        opencascade::handle<Standard_Transient>

        """
        return _XmlDrivers.xmldrivers_Factory(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlDrivers.xmldrivers_swiginit(self, _XmlDrivers.new_xmldrivers())
    __swig_destroy__ = _XmlDrivers.delete_xmldrivers

# Register xmldrivers in _XmlDrivers:
_XmlDrivers.xmldrivers_swigregister(xmldrivers)

def xmldrivers_AttributeDrivers(*args) -> "opencascade::handle< XmlMDF_ADriverTable >":
    r"""
    No available documentation.

    Parameters
    ----------
    theMsgDriver: Message_Messenger

    Returns
    -------
    opencascade::handle<XmlMDF_ADriverTable>

    """
    return _XmlDrivers.xmldrivers_AttributeDrivers(*args)

def xmldrivers_DefineFormat(*args) -> "void":
    r"""
    Defines format 'xmlocaf' and registers its read and write drivers in the specified application.

    Parameters
    ----------
    theApp: TDocStd_Application

    Returns
    -------
    None

    """
    return _XmlDrivers.xmldrivers_DefineFormat(*args)

def xmldrivers_Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
    r"""
    No available documentation.

    Parameters
    ----------
    theGUID: Standard_GUID

    Returns
    -------
    opencascade::handle<Standard_Transient>

    """
    return _XmlDrivers.xmldrivers_Factory(*args)

class XmlDrivers_DocumentRetrievalDriver(OCC.Core.XmlLDrivers.XmlLDrivers_DocumentRetrievalDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _XmlDrivers.XmlDrivers_DocumentRetrievalDriver_swiginit(self, _XmlDrivers.new_XmlDrivers_DocumentRetrievalDriver(*args))

    def ReadShapeSection(self, *args) -> "opencascade::handle< XmlMDF_ADriver >":
        r"""
        No available documentation.

        Parameters
        ----------
        thePDoc: XmlObjMgt_Element
        theMsgDriver: Message_Messenger
        theRange: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        opencascade::handle<XmlMDF_ADriver>

        """
        return _XmlDrivers.XmlDrivers_DocumentRetrievalDriver_ReadShapeSection(self, *args)

    def ShapeSetCleaning(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theDriver: XmlMDF_ADriver

        Returns
        -------
        None

        """
        return _XmlDrivers.XmlDrivers_DocumentRetrievalDriver_ShapeSetCleaning(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlDrivers_DocumentRetrievalDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlDrivers.delete_XmlDrivers_DocumentRetrievalDriver

# Register XmlDrivers_DocumentRetrievalDriver in _XmlDrivers:
_XmlDrivers.XmlDrivers_DocumentRetrievalDriver_swigregister(XmlDrivers_DocumentRetrievalDriver)

class XmlDrivers_DocumentStorageDriver(OCC.Core.XmlLDrivers.XmlLDrivers_DocumentStorageDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theCopyright: TCollection_ExtendedString

        Returns
        -------
        None

        """
        _XmlDrivers.XmlDrivers_DocumentStorageDriver_swiginit(self, _XmlDrivers.new_XmlDrivers_DocumentStorageDriver(*args))

    def WriteShapeSection(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        thePDoc: XmlObjMgt_Element
        theRange: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _XmlDrivers.XmlDrivers_DocumentStorageDriver_WriteShapeSection(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlDrivers_DocumentStorageDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlDrivers.delete_XmlDrivers_DocumentStorageDriver

# Register XmlDrivers_DocumentStorageDriver in _XmlDrivers:
_XmlDrivers.XmlDrivers_DocumentStorageDriver_swigregister(XmlDrivers_DocumentStorageDriver)





