# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
GeomEvaluator module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_geomevaluator.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _GeomEvaluator
else:
    import _GeomEvaluator

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _GeomEvaluator.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _GeomEvaluator.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GeomEvaluator.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GeomEvaluator.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _GeomEvaluator.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _GeomEvaluator.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _GeomEvaluator.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _GeomEvaluator.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _GeomEvaluator.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _GeomEvaluator.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GeomEvaluator.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _GeomEvaluator.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _GeomEvaluator.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GeomEvaluator.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GeomEvaluator.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GeomEvaluator.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _GeomEvaluator.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _GeomEvaluator:
_GeomEvaluator.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _GeomEvaluator.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.GeomAdaptor
import OCC.Core.Adaptor3d
import OCC.Core.TopAbs
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_GeomEvaluator_Curve_Create() -> "opencascade::handle< GeomEvaluator_Curve >":
    return _GeomEvaluator.Handle_GeomEvaluator_Curve_Create()

def Handle_GeomEvaluator_Curve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< GeomEvaluator_Curve >":
    return _GeomEvaluator.Handle_GeomEvaluator_Curve_DownCast(t)

def Handle_GeomEvaluator_Curve_IsNull(t: "opencascade::handle< GeomEvaluator_Curve > const &") -> "bool":
    return _GeomEvaluator.Handle_GeomEvaluator_Curve_IsNull(t)

def Handle_GeomEvaluator_Surface_Create() -> "opencascade::handle< GeomEvaluator_Surface >":
    return _GeomEvaluator.Handle_GeomEvaluator_Surface_Create()

def Handle_GeomEvaluator_Surface_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< GeomEvaluator_Surface >":
    return _GeomEvaluator.Handle_GeomEvaluator_Surface_DownCast(t)

def Handle_GeomEvaluator_Surface_IsNull(t: "opencascade::handle< GeomEvaluator_Surface > const &") -> "bool":
    return _GeomEvaluator.Handle_GeomEvaluator_Surface_IsNull(t)

def Handle_GeomEvaluator_OffsetCurve_Create() -> "opencascade::handle< GeomEvaluator_OffsetCurve >":
    return _GeomEvaluator.Handle_GeomEvaluator_OffsetCurve_Create()

def Handle_GeomEvaluator_OffsetCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< GeomEvaluator_OffsetCurve >":
    return _GeomEvaluator.Handle_GeomEvaluator_OffsetCurve_DownCast(t)

def Handle_GeomEvaluator_OffsetCurve_IsNull(t: "opencascade::handle< GeomEvaluator_OffsetCurve > const &") -> "bool":
    return _GeomEvaluator.Handle_GeomEvaluator_OffsetCurve_IsNull(t)

def Handle_GeomEvaluator_OffsetSurface_Create() -> "opencascade::handle< GeomEvaluator_OffsetSurface >":
    return _GeomEvaluator.Handle_GeomEvaluator_OffsetSurface_Create()

def Handle_GeomEvaluator_OffsetSurface_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< GeomEvaluator_OffsetSurface >":
    return _GeomEvaluator.Handle_GeomEvaluator_OffsetSurface_DownCast(t)

def Handle_GeomEvaluator_OffsetSurface_IsNull(t: "opencascade::handle< GeomEvaluator_OffsetSurface > const &") -> "bool":
    return _GeomEvaluator.Handle_GeomEvaluator_OffsetSurface_IsNull(t)

def Handle_GeomEvaluator_SurfaceOfExtrusion_Create() -> "opencascade::handle< GeomEvaluator_SurfaceOfExtrusion >":
    return _GeomEvaluator.Handle_GeomEvaluator_SurfaceOfExtrusion_Create()

def Handle_GeomEvaluator_SurfaceOfExtrusion_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< GeomEvaluator_SurfaceOfExtrusion >":
    return _GeomEvaluator.Handle_GeomEvaluator_SurfaceOfExtrusion_DownCast(t)

def Handle_GeomEvaluator_SurfaceOfExtrusion_IsNull(t: "opencascade::handle< GeomEvaluator_SurfaceOfExtrusion > const &") -> "bool":
    return _GeomEvaluator.Handle_GeomEvaluator_SurfaceOfExtrusion_IsNull(t)

def Handle_GeomEvaluator_SurfaceOfRevolution_Create() -> "opencascade::handle< GeomEvaluator_SurfaceOfRevolution >":
    return _GeomEvaluator.Handle_GeomEvaluator_SurfaceOfRevolution_Create()

def Handle_GeomEvaluator_SurfaceOfRevolution_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< GeomEvaluator_SurfaceOfRevolution >":
    return _GeomEvaluator.Handle_GeomEvaluator_SurfaceOfRevolution_DownCast(t)

def Handle_GeomEvaluator_SurfaceOfRevolution_IsNull(t: "opencascade::handle< GeomEvaluator_SurfaceOfRevolution > const &") -> "bool":
    return _GeomEvaluator.Handle_GeomEvaluator_SurfaceOfRevolution_IsNull(t)
class GeomEvaluator_Curve(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def D0(self, *args) -> "void":
        r"""
        Value of 3d curve.

        Parameters
        ----------
        theU: float
        theValue: gp_Pnt

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Curve_D0(self, *args)

    def D1(self, *args) -> "void":
        r"""
        Value and first derivatives of curve.

        Parameters
        ----------
        theU: float
        theValue: gp_Pnt
        theD1: gp_Vec

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Curve_D1(self, *args)

    def D2(self, *args) -> "void":
        r"""
        Value, first and second derivatives of curve.

        Parameters
        ----------
        theU: float
        theValue: gp_Pnt
        theD1: gp_Vec
        theD2: gp_Vec

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Curve_D2(self, *args)

    def D3(self, *args) -> "void":
        r"""
        Value, first, second and third derivatives of curve.

        Parameters
        ----------
        theU: float
        theValue: gp_Pnt
        theD1: gp_Vec
        theD2: gp_Vec
        theD3: gp_Vec

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Curve_D3(self, *args)

    def DN(self, *args) -> "gp_Vec":
        r"""
        Calculates n-th derivatives of curve, where n = thederu. raises if n < 1.

        Parameters
        ----------
        theU: float
        theDerU: int

        Returns
        -------
        gp_Vec

        """
        return _GeomEvaluator.GeomEvaluator_Curve_DN(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_GeomEvaluator_Curve_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _GeomEvaluator.delete_GeomEvaluator_Curve

# Register GeomEvaluator_Curve in _GeomEvaluator:
_GeomEvaluator.GeomEvaluator_Curve_swigregister(GeomEvaluator_Curve)

class GeomEvaluator_Surface(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def D0(self, *args) -> "void":
        r"""
        Value of surface.

        Parameters
        ----------
        theU: float
        theV: float
        theValue: gp_Pnt

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Surface_D0(self, *args)

    def D1(self, *args) -> "void":
        r"""
        Value and first derivatives of surface.

        Parameters
        ----------
        theU: float
        theV: float
        theValue: gp_Pnt
        theD1U: gp_Vec
        theD1V: gp_Vec

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Surface_D1(self, *args)

    def D2(self, *args) -> "void":
        r"""
        Value, first and second derivatives of surface.

        Parameters
        ----------
        theU: float
        theV: float
        theValue: gp_Pnt
        theD1U: gp_Vec
        theD1V: gp_Vec
        theD2U: gp_Vec
        theD2V: gp_Vec
        theD2UV: gp_Vec

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Surface_D2(self, *args)

    def D3(self, *args) -> "void":
        r"""
        Value, first, second and third derivatives of surface.

        Parameters
        ----------
        theU: float
        theV: float
        theValue: gp_Pnt
        theD1U: gp_Vec
        theD1V: gp_Vec
        theD2U: gp_Vec
        theD2V: gp_Vec
        theD2UV: gp_Vec
        theD3U: gp_Vec
        theD3V: gp_Vec
        theD3UUV: gp_Vec
        theD3UVV: gp_Vec

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Surface_D3(self, *args)

    def DN(self, *args) -> "gp_Vec":
        r"""
        Calculates n-th derivatives of surface, where n = thederu + thederv. //! raises if n < 1 or thederu < 0 or thederv < 0.

        Parameters
        ----------
        theU: float
        theV: float
        theDerU: int
        theDerV: int

        Returns
        -------
        gp_Vec

        """
        return _GeomEvaluator.GeomEvaluator_Surface_DN(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_GeomEvaluator_Surface_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _GeomEvaluator.delete_GeomEvaluator_Surface

# Register GeomEvaluator_Surface in _GeomEvaluator:
_GeomEvaluator.GeomEvaluator_Surface_swigregister(GeomEvaluator_Surface)

class GeomEvaluator_OffsetCurve(GeomEvaluator_Curve):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initialize evaluator by curve.

        Parameters
        ----------
        theBase: Geom_Curve
        theOffset: float
        theDirection: gp_Dir

        Returns
        -------
        None
        Initialize evaluator by curve adaptor.

        Parameters
        ----------
        theBase: GeomAdaptor_HCurve
        theOffset: float
        theDirection: gp_Dir

        Returns
        -------
        None

        """
        _GeomEvaluator.GeomEvaluator_OffsetCurve_swiginit(self, _GeomEvaluator.new_GeomEvaluator_OffsetCurve(*args))

    def SetOffsetDirection(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theDirection: gp_Dir

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_OffsetCurve_SetOffsetDirection(self, *args)

    def SetOffsetValue(self, *args) -> "void":
        r"""
        Change the offset value.

        Parameters
        ----------
        theOffset: float

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_OffsetCurve_SetOffsetValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_GeomEvaluator_OffsetCurve_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _GeomEvaluator.delete_GeomEvaluator_OffsetCurve

# Register GeomEvaluator_OffsetCurve in _GeomEvaluator:
_GeomEvaluator.GeomEvaluator_OffsetCurve_swigregister(GeomEvaluator_OffsetCurve)

class GeomEvaluator_OffsetSurface(GeomEvaluator_Surface):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initialize evaluator by surface.

        Parameters
        ----------
        theBase: Geom_Surface
        theOffset: float
        theOscSurf: Geom_OsculatingSurface,optional
        	default value is opencascade::handle<Geom_OsculatingSurface>()

        Returns
        -------
        None
        Initialize evaluator by surface adaptor.

        Parameters
        ----------
        theBase: GeomAdaptor_HSurface
        theOffset: float
        theOscSurf: Geom_OsculatingSurface,optional
        	default value is opencascade::handle<Geom_OsculatingSurface>()

        Returns
        -------
        None

        """
        _GeomEvaluator.GeomEvaluator_OffsetSurface_swiginit(self, _GeomEvaluator.new_GeomEvaluator_OffsetSurface(*args))

    def SetOffsetValue(self, *args) -> "void":
        r"""
        Change the offset value.

        Parameters
        ----------
        theOffset: float

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_OffsetSurface_SetOffsetValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_GeomEvaluator_OffsetSurface_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _GeomEvaluator.delete_GeomEvaluator_OffsetSurface

# Register GeomEvaluator_OffsetSurface in _GeomEvaluator:
_GeomEvaluator.GeomEvaluator_OffsetSurface_swigregister(GeomEvaluator_OffsetSurface)

class GeomEvaluator_SurfaceOfExtrusion(GeomEvaluator_Surface):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initialize evaluator by surface.

        Parameters
        ----------
        theBase: Geom_Curve
        theExtrusionDir: gp_Dir

        Returns
        -------
        None
        Initialize evaluator by surface adaptor.

        Parameters
        ----------
        theBase: Adaptor3d_HCurve
        theExtrusionDir: gp_Dir

        Returns
        -------
        None

        """
        _GeomEvaluator.GeomEvaluator_SurfaceOfExtrusion_swiginit(self, _GeomEvaluator.new_GeomEvaluator_SurfaceOfExtrusion(*args))

    def SetDirection(self, *args) -> "void":
        r"""
        /changes the direction of extrusion.

        Parameters
        ----------
        theDirection: gp_Dir

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_SurfaceOfExtrusion_SetDirection(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_GeomEvaluator_SurfaceOfExtrusion_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _GeomEvaluator.delete_GeomEvaluator_SurfaceOfExtrusion

# Register GeomEvaluator_SurfaceOfExtrusion in _GeomEvaluator:
_GeomEvaluator.GeomEvaluator_SurfaceOfExtrusion_swigregister(GeomEvaluator_SurfaceOfExtrusion)

class GeomEvaluator_SurfaceOfRevolution(GeomEvaluator_Surface):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initialize evaluator by revolved curve, the axis of revolution and the location.

        Parameters
        ----------
        theBase: Geom_Curve
        theRevolDir: gp_Dir
        theRevolLoc: gp_Pnt

        Returns
        -------
        None
        Initialize evaluator by adaptor of the revolved curve, the axis of revolution and the location.

        Parameters
        ----------
        theBase: Adaptor3d_HCurve
        theRevolDir: gp_Dir
        theRevolLoc: gp_Pnt

        Returns
        -------
        None

        """
        _GeomEvaluator.GeomEvaluator_SurfaceOfRevolution_swiginit(self, _GeomEvaluator.new_GeomEvaluator_SurfaceOfRevolution(*args))

    def SetAxis(self, *args) -> "void":
        r"""
        Change the axis of revolution.

        Parameters
        ----------
        theAxis: gp_Ax1

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_SurfaceOfRevolution_SetAxis(self, *args)

    def SetDirection(self, *args) -> "void":
        r"""
        Change direction of the axis of revolution.

        Parameters
        ----------
        theDirection: gp_Dir

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_SurfaceOfRevolution_SetDirection(self, *args)

    def SetLocation(self, *args) -> "void":
        r"""
        Change location of the axis of revolution.

        Parameters
        ----------
        theLocation: gp_Pnt

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_SurfaceOfRevolution_SetLocation(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_GeomEvaluator_SurfaceOfRevolution_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _GeomEvaluator.delete_GeomEvaluator_SurfaceOfRevolution

# Register GeomEvaluator_SurfaceOfRevolution in _GeomEvaluator:
_GeomEvaluator.GeomEvaluator_SurfaceOfRevolution_swigregister(GeomEvaluator_SurfaceOfRevolution)





