# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
IGESControl module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_igescontrol.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _IGESControl
else:
    import _IGESControl

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _IGESControl.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _IGESControl.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IGESControl.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IGESControl.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _IGESControl.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _IGESControl.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _IGESControl.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _IGESControl.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _IGESControl.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _IGESControl.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IGESControl.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _IGESControl.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _IGESControl.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IGESControl.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IGESControl.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IGESControl.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _IGESControl.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _IGESControl:
_IGESControl.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _IGESControl.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Transfer
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.Interface
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.IGESToBRep
import OCC.Core.IGESData
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.ShapeExtend
import OCC.Core.TColGeom
import OCC.Core.TopTools
import OCC.Core.Geom2d
import OCC.Core.XSControl
import OCC.Core.IFSelect

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_IGESControl_ActorWrite_Create() -> "opencascade::handle< IGESControl_ActorWrite >":
    return _IGESControl.Handle_IGESControl_ActorWrite_Create()

def Handle_IGESControl_ActorWrite_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IGESControl_ActorWrite >":
    return _IGESControl.Handle_IGESControl_ActorWrite_DownCast(t)

def Handle_IGESControl_ActorWrite_IsNull(t: "opencascade::handle< IGESControl_ActorWrite > const &") -> "bool":
    return _IGESControl.Handle_IGESControl_ActorWrite_IsNull(t)

def Handle_IGESControl_AlgoContainer_Create() -> "opencascade::handle< IGESControl_AlgoContainer >":
    return _IGESControl.Handle_IGESControl_AlgoContainer_Create()

def Handle_IGESControl_AlgoContainer_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IGESControl_AlgoContainer >":
    return _IGESControl.Handle_IGESControl_AlgoContainer_DownCast(t)

def Handle_IGESControl_AlgoContainer_IsNull(t: "opencascade::handle< IGESControl_AlgoContainer > const &") -> "bool":
    return _IGESControl.Handle_IGESControl_AlgoContainer_IsNull(t)

def Handle_IGESControl_Controller_Create() -> "opencascade::handle< IGESControl_Controller >":
    return _IGESControl.Handle_IGESControl_Controller_Create()

def Handle_IGESControl_Controller_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IGESControl_Controller >":
    return _IGESControl.Handle_IGESControl_Controller_DownCast(t)

def Handle_IGESControl_Controller_IsNull(t: "opencascade::handle< IGESControl_Controller > const &") -> "bool":
    return _IGESControl.Handle_IGESControl_Controller_IsNull(t)

def Handle_IGESControl_IGESBoundary_Create() -> "opencascade::handle< IGESControl_IGESBoundary >":
    return _IGESControl.Handle_IGESControl_IGESBoundary_Create()

def Handle_IGESControl_IGESBoundary_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IGESControl_IGESBoundary >":
    return _IGESControl.Handle_IGESControl_IGESBoundary_DownCast(t)

def Handle_IGESControl_IGESBoundary_IsNull(t: "opencascade::handle< IGESControl_IGESBoundary > const &") -> "bool":
    return _IGESControl.Handle_IGESControl_IGESBoundary_IsNull(t)

def Handle_IGESControl_ToolContainer_Create() -> "opencascade::handle< IGESControl_ToolContainer >":
    return _IGESControl.Handle_IGESControl_ToolContainer_Create()

def Handle_IGESControl_ToolContainer_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IGESControl_ToolContainer >":
    return _IGESControl.Handle_IGESControl_ToolContainer_DownCast(t)

def Handle_IGESControl_ToolContainer_IsNull(t: "opencascade::handle< IGESControl_ToolContainer > const &") -> "bool":
    return _IGESControl.Handle_IGESControl_ToolContainer_IsNull(t)
class IGESControl_ActorWrite(OCC.Core.Transfer.Transfer_ActorOfFinderProcess):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _IGESControl.IGESControl_ActorWrite_swiginit(self, _IGESControl.new_IGESControl_ActorWrite(*args))


    @staticmethod
    def DownCast(t):
      return Handle_IGESControl_ActorWrite_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IGESControl.delete_IGESControl_ActorWrite

# Register IGESControl_ActorWrite in _IGESControl:
_IGESControl.IGESControl_ActorWrite_swigregister(IGESControl_ActorWrite)

class IGESControl_AlgoContainer(OCC.Core.IGESToBRep.IGESToBRep_AlgoContainer):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _IGESControl.IGESControl_AlgoContainer_swiginit(self, _IGESControl.new_IGESControl_AlgoContainer(*args))


    @staticmethod
    def DownCast(t):
      return Handle_IGESControl_AlgoContainer_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IGESControl.delete_IGESControl_AlgoContainer

# Register IGESControl_AlgoContainer in _IGESControl:
_IGESControl.IGESControl_AlgoContainer_swigregister(IGESControl_AlgoContainer)

class IGESControl_Controller(OCC.Core.XSControl.XSControl_Controller):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the use of iges norm (the first time) and returns a controller for iges-5.1 if <modefnes> is true, sets it to internal fnes format.

        Parameters
        ----------
        modefnes: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        _IGESControl.IGESControl_Controller_swiginit(self, _IGESControl.new_IGESControl_Controller(*args))

    @staticmethod
    def Init(*args) -> "Standard_Boolean":
        r"""
        Standard initialisation. it creates a controller for iges and records it to various names, available to select it later returns true when done, false if could not be done also, it creates and records an adaptor for fnes.

        Returns
        -------
        bool

        """
        return _IGESControl.IGESControl_Controller_Init(*args)


    @staticmethod
    def DownCast(t):
      return Handle_IGESControl_Controller_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IGESControl.delete_IGESControl_Controller

# Register IGESControl_Controller in _IGESControl:
_IGESControl.IGESControl_Controller_swigregister(IGESControl_Controller)

def IGESControl_Controller_Init(*args) -> "Standard_Boolean":
    r"""
    Standard initialisation. it creates a controller for iges and records it to various names, available to select it later returns true when done, false if could not be done also, it creates and records an adaptor for fnes.

    Returns
    -------
    bool

    """
    return _IGESControl.IGESControl_Controller_Init(*args)

class IGESControl_IGESBoundary(OCC.Core.IGESToBRep.IGESToBRep_IGESBoundary):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an object and calls inherited constuctor.

        Returns
        -------
        None
        Creates an object and calls inherited constuctor.

        Parameters
        ----------
        CS: IGESToBRep_CurveAndSurface

        Returns
        -------
        None

        """
        _IGESControl.IGESControl_IGESBoundary_swiginit(self, _IGESControl.new_IGESControl_IGESBoundary(*args))


    @staticmethod
    def DownCast(t):
      return Handle_IGESControl_IGESBoundary_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IGESControl.delete_IGESControl_IGESBoundary

# Register IGESControl_IGESBoundary in _IGESControl:
_IGESControl.IGESControl_IGESBoundary_swigregister(IGESControl_IGESBoundary)

class IGESControl_Reader(OCC.Core.XSControl.XSControl_Reader):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a reader from scratch.

        Returns
        -------
        None
        Creates a reader from an already existing session.

        Parameters
        ----------
        WS: XSControl_WorkSession
        scratch: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _IGESControl.IGESControl_Reader_swiginit(self, _IGESControl.new_IGESControl_Reader(*args))

    def GetReadVisible(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IGESControl.IGESControl_Reader_GetReadVisible(self, *args)

    def IGESModel(self, *args) -> "opencascade::handle< IGESData_IGESModel >":
        r"""
        Returns the model as a igesmodel. it can then be consulted (header, product).

        Returns
        -------
        opencascade::handle<IGESData_IGESModel>

        """
        return _IGESControl.IGESControl_Reader_IGESModel(self, *args)

    def PrintTransferInfo(self, *args) -> "void":
        r"""
        Prints statistics and check list for transfer.

        Parameters
        ----------
        failwarn: IFSelect_PrintFail
        mode: IFSelect_PrintCount

        Returns
        -------
        None

        """
        return _IGESControl.IGESControl_Reader_PrintTransferInfo(self, *args)

    def SetReadVisible(self, *args) -> "void":
        r"""
        Set the transion of all roots (if thereadonlyvisible is false) or of visible roots (if thereadonlyvisible is true).

        Parameters
        ----------
        ReadRoot: bool

        Returns
        -------
        None

        """
        return _IGESControl.IGESControl_Reader_SetReadVisible(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IGESControl.delete_IGESControl_Reader

# Register IGESControl_Reader in _IGESControl:
_IGESControl.IGESControl_Reader_swigregister(IGESControl_Reader)

class IGESControl_ToolContainer(OCC.Core.IGESToBRep.IGESToBRep_ToolContainer):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _IGESControl.IGESControl_ToolContainer_swiginit(self, _IGESControl.new_IGESControl_ToolContainer(*args))


    @staticmethod
    def DownCast(t):
      return Handle_IGESControl_ToolContainer_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IGESControl.delete_IGESControl_ToolContainer

# Register IGESControl_ToolContainer in _IGESControl:
_IGESControl.IGESControl_ToolContainer_swigregister(IGESControl_ToolContainer)

class IGESControl_Writer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a writer object with the default unit (millimeters) and write mode (face). igescontrol_writer (const standard_cstring unit, const standard_integer modecr = 0);.

        Returns
        -------
        None
        Creates a writer with given values for units and for write mode. unit may be any unit that is accepted by the iges standard. by default, it is the millimeter. modecr defines the write mode and may be: - 0: faces (default) - 1: brep.

        Parameters
        ----------
        unit: char *
        modecr: int,optional
        	default value is 0

        Returns
        -------
        None
        Creates a writer object with the prepared iges model model in write mode. modecr defines the write mode and may be: - 0: faces (default) - 1: brep.

        Parameters
        ----------
        model: IGESData_IGESModel
        modecr: int,optional
        	default value is 0

        Returns
        -------
        None

        """
        _IGESControl.IGESControl_Writer_swiginit(self, _IGESControl.new_IGESControl_Writer(*args))

    def AddEntity(self, *args) -> "Standard_Boolean":
        r"""
        Adds an iges entity (and the ones it references) to the model.

        Parameters
        ----------
        ent: IGESData_IGESEntity

        Returns
        -------
        bool

        """
        return _IGESControl.IGESControl_Writer_AddEntity(self, *args)

    def AddGeom(self, *args) -> "Standard_Boolean":
        r"""
        Translates a geometry (surface or curve) to iges entities and adds them to the model returns true if done, false if geom is neither a surface or a curve suitable for iges or is null.

        Parameters
        ----------
        geom: Standard_Transient

        Returns
        -------
        bool

        """
        return _IGESControl.IGESControl_Writer_AddGeom(self, *args)

    def AddShape(self, *args) -> "Standard_Boolean":
        r"""
        Translates a shape to iges entities and adds them to the model returns true if done, false if shape not suitable for iges or null.

        Parameters
        ----------
        sh: TopoDS_Shape
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _IGESControl.IGESControl_Writer_AddShape(self, *args)

    def ComputeModel(self, *args) -> "void":
        r"""
        Computes the entities found in the model, which is ready to be written. this contrasts with the default computation of headers only.

        Returns
        -------
        None

        """
        return _IGESControl.IGESControl_Writer_ComputeModel(self, *args)

    def Model(self, *args) -> "opencascade::handle< IGESData_IGESModel > const &":
        r"""
        Returns the iges model to be written in output.

        Returns
        -------
        opencascade::handle<IGESData_IGESModel>

        """
        return _IGESControl.IGESControl_Writer_Model(self, *args)

    def SetTransferProcess(self, *args) -> "void":
        r"""
        Returns/sets the transferprocess : it contains final results and if some, check messages.

        Parameters
        ----------
        TP: Transfer_FinderProcess

        Returns
        -------
        None

        """
        return _IGESControl.IGESControl_Writer_SetTransferProcess(self, *args)

    def TransferProcess(self, *args) -> "opencascade::handle< Transfer_FinderProcess > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Transfer_FinderProcess>

        """
        return _IGESControl.IGESControl_Writer_TransferProcess(self, *args)

    def Write(self, *args) -> "Standard_Boolean":
        r"""
        Prepares and writes an iges model either to an ostream, s or to a file name,cstring. returns true if the operation was performed correctly and false if an error occurred (for instance, if the processor could not create the file).

        Parameters
        ----------
        file: char *
        fnes: bool,optional
        	default value is Standard_False

        Returns
        -------
        bool

        """
        return _IGESControl.IGESControl_Writer_Write(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IGESControl.delete_IGESControl_Writer

# Register IGESControl_Writer in _IGESControl:
_IGESControl.IGESControl_Writer_swigregister(IGESControl_Writer)





