from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *


#classnotwrapped
class LDOM_LDOMImplementation: ...

#classnotwrapped
class LDOM_CharacterData: ...

#classnotwrapped
class LDOM_CDATASection: ...

#classnotwrapped
class LDOM_Node: ...

#classnotwrapped
class LDOM_Element: ...

#classnotwrapped
class LDOM_Text: ...

#classnotwrapped
class LDOM_NodeList: ...

#classnotwrapped
class LDOM_SBuffer: ...

#classnotwrapped
class LDOM_OSStream: ...

#classnotwrapped
class LDOM_CharReference: ...

#classnotwrapped
class LDOM_XmlWriter: ...

#classnotwrapped
class LDOM_BasicElement: ...

#classnotwrapped
class LDOM_Comment: ...

#classnotwrapped
class LDOM_BasicAttribute: ...

#classnotwrapped
class LDOM_BasicText: ...

#classnotwrapped
class LDOM_Document: ...

#classnotwrapped
class LDOM_Attr: ...

#classnotwrapped
class LDOM_DocumentType: ...

#classnotwrapped
class LDOM_XmlReader: ...

#classnotwrapped
class LDOM_BasicNode: ...

#classnotwrapped
class LDOM_MemManager: ...

# harray1 classes
# harray2 classes
# hsequence classes

