# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BinTObjDrivers module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_bintobjdrivers.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BinTObjDrivers
else:
    import _BinTObjDrivers

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BinTObjDrivers.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BinTObjDrivers.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BinTObjDrivers.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BinTObjDrivers.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BinTObjDrivers.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BinTObjDrivers.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BinTObjDrivers.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BinTObjDrivers.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BinTObjDrivers.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BinTObjDrivers.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BinTObjDrivers.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BinTObjDrivers.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BinTObjDrivers.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BinTObjDrivers.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BinTObjDrivers.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BinTObjDrivers.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BinTObjDrivers.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BinTObjDrivers:
_BinTObjDrivers.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BinTObjDrivers.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.BinMDF
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TDF
import OCC.Core.BinObjMgt
import OCC.Core.Storage
import OCC.Core.TDocStd
import OCC.Core.CDF
import OCC.Core.CDM
import OCC.Core.Resource
import OCC.Core.PCDM
import OCC.Core.BinLDrivers

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_BinTObjDrivers_DocumentRetrievalDriver_Create() -> "opencascade::handle< BinTObjDrivers_DocumentRetrievalDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_DocumentRetrievalDriver_Create()

def Handle_BinTObjDrivers_DocumentRetrievalDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_DocumentRetrievalDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_DocumentRetrievalDriver_DownCast(t)

def Handle_BinTObjDrivers_DocumentRetrievalDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_DocumentRetrievalDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_DocumentRetrievalDriver_IsNull(t)

def Handle_BinTObjDrivers_DocumentStorageDriver_Create() -> "opencascade::handle< BinTObjDrivers_DocumentStorageDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_DocumentStorageDriver_Create()

def Handle_BinTObjDrivers_DocumentStorageDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_DocumentStorageDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_DocumentStorageDriver_DownCast(t)

def Handle_BinTObjDrivers_DocumentStorageDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_DocumentStorageDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_DocumentStorageDriver_IsNull(t)

def Handle_BinTObjDrivers_IntSparseArrayDriver_Create() -> "opencascade::handle< BinTObjDrivers_IntSparseArrayDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_IntSparseArrayDriver_Create()

def Handle_BinTObjDrivers_IntSparseArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_IntSparseArrayDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_IntSparseArrayDriver_DownCast(t)

def Handle_BinTObjDrivers_IntSparseArrayDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_IntSparseArrayDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_IntSparseArrayDriver_IsNull(t)

def Handle_BinTObjDrivers_ModelDriver_Create() -> "opencascade::handle< BinTObjDrivers_ModelDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ModelDriver_Create()

def Handle_BinTObjDrivers_ModelDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_ModelDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ModelDriver_DownCast(t)

def Handle_BinTObjDrivers_ModelDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_ModelDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ModelDriver_IsNull(t)

def Handle_BinTObjDrivers_ObjectDriver_Create() -> "opencascade::handle< BinTObjDrivers_ObjectDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ObjectDriver_Create()

def Handle_BinTObjDrivers_ObjectDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_ObjectDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ObjectDriver_DownCast(t)

def Handle_BinTObjDrivers_ObjectDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_ObjectDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ObjectDriver_IsNull(t)

def Handle_BinTObjDrivers_ReferenceDriver_Create() -> "opencascade::handle< BinTObjDrivers_ReferenceDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ReferenceDriver_Create()

def Handle_BinTObjDrivers_ReferenceDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_ReferenceDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ReferenceDriver_DownCast(t)

def Handle_BinTObjDrivers_ReferenceDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_ReferenceDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ReferenceDriver_IsNull(t)

def Handle_BinTObjDrivers_XYZDriver_Create() -> "opencascade::handle< BinTObjDrivers_XYZDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_XYZDriver_Create()

def Handle_BinTObjDrivers_XYZDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_XYZDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_XYZDriver_DownCast(t)

def Handle_BinTObjDrivers_XYZDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_XYZDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_XYZDriver_IsNull(t)
class bintobjdrivers(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDriverTable: BinMDF_ADriverTable
        aMsgDrv: Message_Messenger

        Returns
        -------
        None

        """
        return _BinTObjDrivers.bintobjdrivers_AddDrivers(*args)

    @staticmethod
    def DefineFormat(*args) -> "void":
        r"""
        Defines format 'tobjbin' and registers its read and write drivers in the specified application.

        Parameters
        ----------
        theApp: TDocStd_Application

        Returns
        -------
        None

        """
        return _BinTObjDrivers.bintobjdrivers_DefineFormat(*args)

    @staticmethod
    def Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
        r"""
        No available documentation.

        Parameters
        ----------
        aGUID: Standard_GUID

        Returns
        -------
        opencascade::handle<Standard_Transient>

        """
        return _BinTObjDrivers.bintobjdrivers_Factory(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _BinTObjDrivers.bintobjdrivers_swiginit(self, _BinTObjDrivers.new_bintobjdrivers())
    __swig_destroy__ = _BinTObjDrivers.delete_bintobjdrivers

# Register bintobjdrivers in _BinTObjDrivers:
_BinTObjDrivers.bintobjdrivers_swigregister(bintobjdrivers)

def bintobjdrivers_AddDrivers(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aDriverTable: BinMDF_ADriverTable
    aMsgDrv: Message_Messenger

    Returns
    -------
    None

    """
    return _BinTObjDrivers.bintobjdrivers_AddDrivers(*args)

def bintobjdrivers_DefineFormat(*args) -> "void":
    r"""
    Defines format 'tobjbin' and registers its read and write drivers in the specified application.

    Parameters
    ----------
    theApp: TDocStd_Application

    Returns
    -------
    None

    """
    return _BinTObjDrivers.bintobjdrivers_DefineFormat(*args)

def bintobjdrivers_Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
    r"""
    No available documentation.

    Parameters
    ----------
    aGUID: Standard_GUID

    Returns
    -------
    opencascade::handle<Standard_Transient>

    """
    return _BinTObjDrivers.bintobjdrivers_Factory(*args)

class BinTObjDrivers_DocumentRetrievalDriver(OCC.Core.BinLDrivers.BinLDrivers_DocumentRetrievalDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_DocumentRetrievalDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_DocumentRetrievalDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_DocumentRetrievalDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_DocumentRetrievalDriver

# Register BinTObjDrivers_DocumentRetrievalDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_DocumentRetrievalDriver_swigregister(BinTObjDrivers_DocumentRetrievalDriver)

class BinTObjDrivers_DocumentStorageDriver(OCC.Core.BinLDrivers.BinLDrivers_DocumentStorageDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_DocumentStorageDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_DocumentStorageDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_DocumentStorageDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_DocumentStorageDriver

# Register BinTObjDrivers_DocumentStorageDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_DocumentStorageDriver_swigregister(BinTObjDrivers_DocumentStorageDriver)

class BinTObjDrivers_IntSparseArrayDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_IntSparseArrayDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_IntSparseArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: BinObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: BinObjMgt_Persistent
        theRelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinTObjDrivers.BinTObjDrivers_IntSparseArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_IntSparseArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_IntSparseArrayDriver

# Register BinTObjDrivers_IntSparseArrayDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_IntSparseArrayDriver_swigregister(BinTObjDrivers_IntSparseArrayDriver)

class BinTObjDrivers_ModelDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_ModelDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_ModelDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinTObjDrivers.BinTObjDrivers_ModelDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_ModelDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_ModelDriver

# Register BinTObjDrivers_ModelDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_ModelDriver_swigregister(BinTObjDrivers_ModelDriver)

class BinTObjDrivers_ObjectDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_ObjectDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_ObjectDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinTObjDrivers.BinTObjDrivers_ObjectDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_ObjectDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_ObjectDriver

# Register BinTObjDrivers_ObjectDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_ObjectDriver_swigregister(BinTObjDrivers_ObjectDriver)

class BinTObjDrivers_ReferenceDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_ReferenceDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_ReferenceDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinTObjDrivers.BinTObjDrivers_ReferenceDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_ReferenceDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_ReferenceDriver

# Register BinTObjDrivers_ReferenceDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_ReferenceDriver_swigregister(BinTObjDrivers_ReferenceDriver)

class BinTObjDrivers_XYZDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_XYZDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_XYZDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: BinObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: BinObjMgt_Persistent
        theRelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinTObjDrivers.BinTObjDrivers_XYZDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_XYZDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_XYZDriver

# Register BinTObjDrivers_XYZDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_XYZDriver_swigregister(BinTObjDrivers_XYZDriver)





