# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
StepBasic module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_stepbasic.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _StepBasic
else:
    import _StepBasic

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _StepBasic.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _StepBasic.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepBasic.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepBasic.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _StepBasic.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _StepBasic.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _StepBasic.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _StepBasic.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _StepBasic.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _StepBasic.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepBasic.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _StepBasic.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _StepBasic.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepBasic.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepBasic.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepBasic.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _StepBasic.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _StepBasic:
_StepBasic.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _StepBasic.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource

from enum import IntEnum
from OCC.Core.Exception import *

StepBasic_sMade = _StepBasic.StepBasic_sMade
StepBasic_sBought = _StepBasic.StepBasic_sBought
StepBasic_sNotKnown = _StepBasic.StepBasic_sNotKnown
StepBasic_aobAhead = _StepBasic.StepBasic_aobAhead
StepBasic_aobExact = _StepBasic.StepBasic_aobExact
StepBasic_aobBehind = _StepBasic.StepBasic_aobBehind
StepBasic_sunMetre = _StepBasic.StepBasic_sunMetre
StepBasic_sunGram = _StepBasic.StepBasic_sunGram
StepBasic_sunSecond = _StepBasic.StepBasic_sunSecond
StepBasic_sunAmpere = _StepBasic.StepBasic_sunAmpere
StepBasic_sunKelvin = _StepBasic.StepBasic_sunKelvin
StepBasic_sunMole = _StepBasic.StepBasic_sunMole
StepBasic_sunCandela = _StepBasic.StepBasic_sunCandela
StepBasic_sunRadian = _StepBasic.StepBasic_sunRadian
StepBasic_sunSteradian = _StepBasic.StepBasic_sunSteradian
StepBasic_sunHertz = _StepBasic.StepBasic_sunHertz
StepBasic_sunNewton = _StepBasic.StepBasic_sunNewton
StepBasic_sunPascal = _StepBasic.StepBasic_sunPascal
StepBasic_sunJoule = _StepBasic.StepBasic_sunJoule
StepBasic_sunWatt = _StepBasic.StepBasic_sunWatt
StepBasic_sunCoulomb = _StepBasic.StepBasic_sunCoulomb
StepBasic_sunVolt = _StepBasic.StepBasic_sunVolt
StepBasic_sunFarad = _StepBasic.StepBasic_sunFarad
StepBasic_sunOhm = _StepBasic.StepBasic_sunOhm
StepBasic_sunSiemens = _StepBasic.StepBasic_sunSiemens
StepBasic_sunWeber = _StepBasic.StepBasic_sunWeber
StepBasic_sunTesla = _StepBasic.StepBasic_sunTesla
StepBasic_sunHenry = _StepBasic.StepBasic_sunHenry
StepBasic_sunDegreeCelsius = _StepBasic.StepBasic_sunDegreeCelsius
StepBasic_sunLumen = _StepBasic.StepBasic_sunLumen
StepBasic_sunLux = _StepBasic.StepBasic_sunLux
StepBasic_sunBecquerel = _StepBasic.StepBasic_sunBecquerel
StepBasic_sunGray = _StepBasic.StepBasic_sunGray
StepBasic_sunSievert = _StepBasic.StepBasic_sunSievert
StepBasic_spExa = _StepBasic.StepBasic_spExa
StepBasic_spPeta = _StepBasic.StepBasic_spPeta
StepBasic_spTera = _StepBasic.StepBasic_spTera
StepBasic_spGiga = _StepBasic.StepBasic_spGiga
StepBasic_spMega = _StepBasic.StepBasic_spMega
StepBasic_spKilo = _StepBasic.StepBasic_spKilo
StepBasic_spHecto = _StepBasic.StepBasic_spHecto
StepBasic_spDeca = _StepBasic.StepBasic_spDeca
StepBasic_spDeci = _StepBasic.StepBasic_spDeci
StepBasic_spCenti = _StepBasic.StepBasic_spCenti
StepBasic_spMilli = _StepBasic.StepBasic_spMilli
StepBasic_spMicro = _StepBasic.StepBasic_spMicro
StepBasic_spNano = _StepBasic.StepBasic_spNano
StepBasic_spPico = _StepBasic.StepBasic_spPico
StepBasic_spFemto = _StepBasic.StepBasic_spFemto
StepBasic_spAtto = _StepBasic.StepBasic_spAtto


class StepBasic_Source(IntEnum):
	StepBasic_sMade = 0
	StepBasic_sBought = 1
	StepBasic_sNotKnown = 2
StepBasic_sMade = StepBasic_Source.StepBasic_sMade
StepBasic_sBought = StepBasic_Source.StepBasic_sBought
StepBasic_sNotKnown = StepBasic_Source.StepBasic_sNotKnown

class StepBasic_AheadOrBehind(IntEnum):
	StepBasic_aobAhead = 0
	StepBasic_aobExact = 1
	StepBasic_aobBehind = 2
StepBasic_aobAhead = StepBasic_AheadOrBehind.StepBasic_aobAhead
StepBasic_aobExact = StepBasic_AheadOrBehind.StepBasic_aobExact
StepBasic_aobBehind = StepBasic_AheadOrBehind.StepBasic_aobBehind

class StepBasic_SiUnitName(IntEnum):
	StepBasic_sunMetre = 0
	StepBasic_sunGram = 1
	StepBasic_sunSecond = 2
	StepBasic_sunAmpere = 3
	StepBasic_sunKelvin = 4
	StepBasic_sunMole = 5
	StepBasic_sunCandela = 6
	StepBasic_sunRadian = 7
	StepBasic_sunSteradian = 8
	StepBasic_sunHertz = 9
	StepBasic_sunNewton = 10
	StepBasic_sunPascal = 11
	StepBasic_sunJoule = 12
	StepBasic_sunWatt = 13
	StepBasic_sunCoulomb = 14
	StepBasic_sunVolt = 15
	StepBasic_sunFarad = 16
	StepBasic_sunOhm = 17
	StepBasic_sunSiemens = 18
	StepBasic_sunWeber = 19
	StepBasic_sunTesla = 20
	StepBasic_sunHenry = 21
	StepBasic_sunDegreeCelsius = 22
	StepBasic_sunLumen = 23
	StepBasic_sunLux = 24
	StepBasic_sunBecquerel = 25
	StepBasic_sunGray = 26
	StepBasic_sunSievert = 27
StepBasic_sunMetre = StepBasic_SiUnitName.StepBasic_sunMetre
StepBasic_sunGram = StepBasic_SiUnitName.StepBasic_sunGram
StepBasic_sunSecond = StepBasic_SiUnitName.StepBasic_sunSecond
StepBasic_sunAmpere = StepBasic_SiUnitName.StepBasic_sunAmpere
StepBasic_sunKelvin = StepBasic_SiUnitName.StepBasic_sunKelvin
StepBasic_sunMole = StepBasic_SiUnitName.StepBasic_sunMole
StepBasic_sunCandela = StepBasic_SiUnitName.StepBasic_sunCandela
StepBasic_sunRadian = StepBasic_SiUnitName.StepBasic_sunRadian
StepBasic_sunSteradian = StepBasic_SiUnitName.StepBasic_sunSteradian
StepBasic_sunHertz = StepBasic_SiUnitName.StepBasic_sunHertz
StepBasic_sunNewton = StepBasic_SiUnitName.StepBasic_sunNewton
StepBasic_sunPascal = StepBasic_SiUnitName.StepBasic_sunPascal
StepBasic_sunJoule = StepBasic_SiUnitName.StepBasic_sunJoule
StepBasic_sunWatt = StepBasic_SiUnitName.StepBasic_sunWatt
StepBasic_sunCoulomb = StepBasic_SiUnitName.StepBasic_sunCoulomb
StepBasic_sunVolt = StepBasic_SiUnitName.StepBasic_sunVolt
StepBasic_sunFarad = StepBasic_SiUnitName.StepBasic_sunFarad
StepBasic_sunOhm = StepBasic_SiUnitName.StepBasic_sunOhm
StepBasic_sunSiemens = StepBasic_SiUnitName.StepBasic_sunSiemens
StepBasic_sunWeber = StepBasic_SiUnitName.StepBasic_sunWeber
StepBasic_sunTesla = StepBasic_SiUnitName.StepBasic_sunTesla
StepBasic_sunHenry = StepBasic_SiUnitName.StepBasic_sunHenry
StepBasic_sunDegreeCelsius = StepBasic_SiUnitName.StepBasic_sunDegreeCelsius
StepBasic_sunLumen = StepBasic_SiUnitName.StepBasic_sunLumen
StepBasic_sunLux = StepBasic_SiUnitName.StepBasic_sunLux
StepBasic_sunBecquerel = StepBasic_SiUnitName.StepBasic_sunBecquerel
StepBasic_sunGray = StepBasic_SiUnitName.StepBasic_sunGray
StepBasic_sunSievert = StepBasic_SiUnitName.StepBasic_sunSievert

class StepBasic_SiPrefix(IntEnum):
	StepBasic_spExa = 0
	StepBasic_spPeta = 1
	StepBasic_spTera = 2
	StepBasic_spGiga = 3
	StepBasic_spMega = 4
	StepBasic_spKilo = 5
	StepBasic_spHecto = 6
	StepBasic_spDeca = 7
	StepBasic_spDeci = 8
	StepBasic_spCenti = 9
	StepBasic_spMilli = 10
	StepBasic_spMicro = 11
	StepBasic_spNano = 12
	StepBasic_spPico = 13
	StepBasic_spFemto = 14
	StepBasic_spAtto = 15
StepBasic_spExa = StepBasic_SiPrefix.StepBasic_spExa
StepBasic_spPeta = StepBasic_SiPrefix.StepBasic_spPeta
StepBasic_spTera = StepBasic_SiPrefix.StepBasic_spTera
StepBasic_spGiga = StepBasic_SiPrefix.StepBasic_spGiga
StepBasic_spMega = StepBasic_SiPrefix.StepBasic_spMega
StepBasic_spKilo = StepBasic_SiPrefix.StepBasic_spKilo
StepBasic_spHecto = StepBasic_SiPrefix.StepBasic_spHecto
StepBasic_spDeca = StepBasic_SiPrefix.StepBasic_spDeca
StepBasic_spDeci = StepBasic_SiPrefix.StepBasic_spDeci
StepBasic_spCenti = StepBasic_SiPrefix.StepBasic_spCenti
StepBasic_spMilli = StepBasic_SiPrefix.StepBasic_spMilli
StepBasic_spMicro = StepBasic_SiPrefix.StepBasic_spMicro
StepBasic_spNano = StepBasic_SiPrefix.StepBasic_spNano
StepBasic_spPico = StepBasic_SiPrefix.StepBasic_spPico
StepBasic_spFemto = StepBasic_SiPrefix.StepBasic_spFemto
StepBasic_spAtto = StepBasic_SiPrefix.StepBasic_spAtto


def Handle_StepBasic_Action_Create() -> "opencascade::handle< StepBasic_Action >":
    return _StepBasic.Handle_StepBasic_Action_Create()

def Handle_StepBasic_Action_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_Action >":
    return _StepBasic.Handle_StepBasic_Action_DownCast(t)

def Handle_StepBasic_Action_IsNull(t: "opencascade::handle< StepBasic_Action > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_Action_IsNull(t)

def Handle_StepBasic_ActionAssignment_Create() -> "opencascade::handle< StepBasic_ActionAssignment >":
    return _StepBasic.Handle_StepBasic_ActionAssignment_Create()

def Handle_StepBasic_ActionAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ActionAssignment >":
    return _StepBasic.Handle_StepBasic_ActionAssignment_DownCast(t)

def Handle_StepBasic_ActionAssignment_IsNull(t: "opencascade::handle< StepBasic_ActionAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ActionAssignment_IsNull(t)

def Handle_StepBasic_ActionMethod_Create() -> "opencascade::handle< StepBasic_ActionMethod >":
    return _StepBasic.Handle_StepBasic_ActionMethod_Create()

def Handle_StepBasic_ActionMethod_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ActionMethod >":
    return _StepBasic.Handle_StepBasic_ActionMethod_DownCast(t)

def Handle_StepBasic_ActionMethod_IsNull(t: "opencascade::handle< StepBasic_ActionMethod > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ActionMethod_IsNull(t)

def Handle_StepBasic_ActionRequestAssignment_Create() -> "opencascade::handle< StepBasic_ActionRequestAssignment >":
    return _StepBasic.Handle_StepBasic_ActionRequestAssignment_Create()

def Handle_StepBasic_ActionRequestAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ActionRequestAssignment >":
    return _StepBasic.Handle_StepBasic_ActionRequestAssignment_DownCast(t)

def Handle_StepBasic_ActionRequestAssignment_IsNull(t: "opencascade::handle< StepBasic_ActionRequestAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ActionRequestAssignment_IsNull(t)

def Handle_StepBasic_ActionRequestSolution_Create() -> "opencascade::handle< StepBasic_ActionRequestSolution >":
    return _StepBasic.Handle_StepBasic_ActionRequestSolution_Create()

def Handle_StepBasic_ActionRequestSolution_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ActionRequestSolution >":
    return _StepBasic.Handle_StepBasic_ActionRequestSolution_DownCast(t)

def Handle_StepBasic_ActionRequestSolution_IsNull(t: "opencascade::handle< StepBasic_ActionRequestSolution > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ActionRequestSolution_IsNull(t)

def Handle_StepBasic_Address_Create() -> "opencascade::handle< StepBasic_Address >":
    return _StepBasic.Handle_StepBasic_Address_Create()

def Handle_StepBasic_Address_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_Address >":
    return _StepBasic.Handle_StepBasic_Address_DownCast(t)

def Handle_StepBasic_Address_IsNull(t: "opencascade::handle< StepBasic_Address > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_Address_IsNull(t)

def Handle_StepBasic_ApplicationContext_Create() -> "opencascade::handle< StepBasic_ApplicationContext >":
    return _StepBasic.Handle_StepBasic_ApplicationContext_Create()

def Handle_StepBasic_ApplicationContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ApplicationContext >":
    return _StepBasic.Handle_StepBasic_ApplicationContext_DownCast(t)

def Handle_StepBasic_ApplicationContext_IsNull(t: "opencascade::handle< StepBasic_ApplicationContext > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ApplicationContext_IsNull(t)

def Handle_StepBasic_ApplicationContextElement_Create() -> "opencascade::handle< StepBasic_ApplicationContextElement >":
    return _StepBasic.Handle_StepBasic_ApplicationContextElement_Create()

def Handle_StepBasic_ApplicationContextElement_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ApplicationContextElement >":
    return _StepBasic.Handle_StepBasic_ApplicationContextElement_DownCast(t)

def Handle_StepBasic_ApplicationContextElement_IsNull(t: "opencascade::handle< StepBasic_ApplicationContextElement > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ApplicationContextElement_IsNull(t)

def Handle_StepBasic_ApplicationProtocolDefinition_Create() -> "opencascade::handle< StepBasic_ApplicationProtocolDefinition >":
    return _StepBasic.Handle_StepBasic_ApplicationProtocolDefinition_Create()

def Handle_StepBasic_ApplicationProtocolDefinition_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ApplicationProtocolDefinition >":
    return _StepBasic.Handle_StepBasic_ApplicationProtocolDefinition_DownCast(t)

def Handle_StepBasic_ApplicationProtocolDefinition_IsNull(t: "opencascade::handle< StepBasic_ApplicationProtocolDefinition > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ApplicationProtocolDefinition_IsNull(t)

def Handle_StepBasic_Approval_Create() -> "opencascade::handle< StepBasic_Approval >":
    return _StepBasic.Handle_StepBasic_Approval_Create()

def Handle_StepBasic_Approval_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_Approval >":
    return _StepBasic.Handle_StepBasic_Approval_DownCast(t)

def Handle_StepBasic_Approval_IsNull(t: "opencascade::handle< StepBasic_Approval > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_Approval_IsNull(t)

def Handle_StepBasic_ApprovalAssignment_Create() -> "opencascade::handle< StepBasic_ApprovalAssignment >":
    return _StepBasic.Handle_StepBasic_ApprovalAssignment_Create()

def Handle_StepBasic_ApprovalAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ApprovalAssignment >":
    return _StepBasic.Handle_StepBasic_ApprovalAssignment_DownCast(t)

def Handle_StepBasic_ApprovalAssignment_IsNull(t: "opencascade::handle< StepBasic_ApprovalAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ApprovalAssignment_IsNull(t)

def Handle_StepBasic_ApprovalDateTime_Create() -> "opencascade::handle< StepBasic_ApprovalDateTime >":
    return _StepBasic.Handle_StepBasic_ApprovalDateTime_Create()

def Handle_StepBasic_ApprovalDateTime_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ApprovalDateTime >":
    return _StepBasic.Handle_StepBasic_ApprovalDateTime_DownCast(t)

def Handle_StepBasic_ApprovalDateTime_IsNull(t: "opencascade::handle< StepBasic_ApprovalDateTime > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ApprovalDateTime_IsNull(t)

def Handle_StepBasic_ApprovalPersonOrganization_Create() -> "opencascade::handle< StepBasic_ApprovalPersonOrganization >":
    return _StepBasic.Handle_StepBasic_ApprovalPersonOrganization_Create()

def Handle_StepBasic_ApprovalPersonOrganization_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ApprovalPersonOrganization >":
    return _StepBasic.Handle_StepBasic_ApprovalPersonOrganization_DownCast(t)

def Handle_StepBasic_ApprovalPersonOrganization_IsNull(t: "opencascade::handle< StepBasic_ApprovalPersonOrganization > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ApprovalPersonOrganization_IsNull(t)

def Handle_StepBasic_ApprovalRelationship_Create() -> "opencascade::handle< StepBasic_ApprovalRelationship >":
    return _StepBasic.Handle_StepBasic_ApprovalRelationship_Create()

def Handle_StepBasic_ApprovalRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ApprovalRelationship >":
    return _StepBasic.Handle_StepBasic_ApprovalRelationship_DownCast(t)

def Handle_StepBasic_ApprovalRelationship_IsNull(t: "opencascade::handle< StepBasic_ApprovalRelationship > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ApprovalRelationship_IsNull(t)

def Handle_StepBasic_ApprovalRole_Create() -> "opencascade::handle< StepBasic_ApprovalRole >":
    return _StepBasic.Handle_StepBasic_ApprovalRole_Create()

def Handle_StepBasic_ApprovalRole_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ApprovalRole >":
    return _StepBasic.Handle_StepBasic_ApprovalRole_DownCast(t)

def Handle_StepBasic_ApprovalRole_IsNull(t: "opencascade::handle< StepBasic_ApprovalRole > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ApprovalRole_IsNull(t)

def Handle_StepBasic_ApprovalStatus_Create() -> "opencascade::handle< StepBasic_ApprovalStatus >":
    return _StepBasic.Handle_StepBasic_ApprovalStatus_Create()

def Handle_StepBasic_ApprovalStatus_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ApprovalStatus >":
    return _StepBasic.Handle_StepBasic_ApprovalStatus_DownCast(t)

def Handle_StepBasic_ApprovalStatus_IsNull(t: "opencascade::handle< StepBasic_ApprovalStatus > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ApprovalStatus_IsNull(t)

def Handle_StepBasic_Certification_Create() -> "opencascade::handle< StepBasic_Certification >":
    return _StepBasic.Handle_StepBasic_Certification_Create()

def Handle_StepBasic_Certification_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_Certification >":
    return _StepBasic.Handle_StepBasic_Certification_DownCast(t)

def Handle_StepBasic_Certification_IsNull(t: "opencascade::handle< StepBasic_Certification > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_Certification_IsNull(t)

def Handle_StepBasic_CertificationAssignment_Create() -> "opencascade::handle< StepBasic_CertificationAssignment >":
    return _StepBasic.Handle_StepBasic_CertificationAssignment_Create()

def Handle_StepBasic_CertificationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_CertificationAssignment >":
    return _StepBasic.Handle_StepBasic_CertificationAssignment_DownCast(t)

def Handle_StepBasic_CertificationAssignment_IsNull(t: "opencascade::handle< StepBasic_CertificationAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_CertificationAssignment_IsNull(t)

def Handle_StepBasic_CertificationType_Create() -> "opencascade::handle< StepBasic_CertificationType >":
    return _StepBasic.Handle_StepBasic_CertificationType_Create()

def Handle_StepBasic_CertificationType_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_CertificationType >":
    return _StepBasic.Handle_StepBasic_CertificationType_DownCast(t)

def Handle_StepBasic_CertificationType_IsNull(t: "opencascade::handle< StepBasic_CertificationType > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_CertificationType_IsNull(t)

def Handle_StepBasic_CharacterizedObject_Create() -> "opencascade::handle< StepBasic_CharacterizedObject >":
    return _StepBasic.Handle_StepBasic_CharacterizedObject_Create()

def Handle_StepBasic_CharacterizedObject_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_CharacterizedObject >":
    return _StepBasic.Handle_StepBasic_CharacterizedObject_DownCast(t)

def Handle_StepBasic_CharacterizedObject_IsNull(t: "opencascade::handle< StepBasic_CharacterizedObject > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_CharacterizedObject_IsNull(t)

def Handle_StepBasic_Contract_Create() -> "opencascade::handle< StepBasic_Contract >":
    return _StepBasic.Handle_StepBasic_Contract_Create()

def Handle_StepBasic_Contract_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_Contract >":
    return _StepBasic.Handle_StepBasic_Contract_DownCast(t)

def Handle_StepBasic_Contract_IsNull(t: "opencascade::handle< StepBasic_Contract > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_Contract_IsNull(t)

def Handle_StepBasic_ContractAssignment_Create() -> "opencascade::handle< StepBasic_ContractAssignment >":
    return _StepBasic.Handle_StepBasic_ContractAssignment_Create()

def Handle_StepBasic_ContractAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ContractAssignment >":
    return _StepBasic.Handle_StepBasic_ContractAssignment_DownCast(t)

def Handle_StepBasic_ContractAssignment_IsNull(t: "opencascade::handle< StepBasic_ContractAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ContractAssignment_IsNull(t)

def Handle_StepBasic_ContractType_Create() -> "opencascade::handle< StepBasic_ContractType >":
    return _StepBasic.Handle_StepBasic_ContractType_Create()

def Handle_StepBasic_ContractType_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ContractType >":
    return _StepBasic.Handle_StepBasic_ContractType_DownCast(t)

def Handle_StepBasic_ContractType_IsNull(t: "opencascade::handle< StepBasic_ContractType > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ContractType_IsNull(t)

def Handle_StepBasic_CoordinatedUniversalTimeOffset_Create() -> "opencascade::handle< StepBasic_CoordinatedUniversalTimeOffset >":
    return _StepBasic.Handle_StepBasic_CoordinatedUniversalTimeOffset_Create()

def Handle_StepBasic_CoordinatedUniversalTimeOffset_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_CoordinatedUniversalTimeOffset >":
    return _StepBasic.Handle_StepBasic_CoordinatedUniversalTimeOffset_DownCast(t)

def Handle_StepBasic_CoordinatedUniversalTimeOffset_IsNull(t: "opencascade::handle< StepBasic_CoordinatedUniversalTimeOffset > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_CoordinatedUniversalTimeOffset_IsNull(t)

def Handle_StepBasic_Date_Create() -> "opencascade::handle< StepBasic_Date >":
    return _StepBasic.Handle_StepBasic_Date_Create()

def Handle_StepBasic_Date_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_Date >":
    return _StepBasic.Handle_StepBasic_Date_DownCast(t)

def Handle_StepBasic_Date_IsNull(t: "opencascade::handle< StepBasic_Date > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_Date_IsNull(t)

def Handle_StepBasic_DateAndTime_Create() -> "opencascade::handle< StepBasic_DateAndTime >":
    return _StepBasic.Handle_StepBasic_DateAndTime_Create()

def Handle_StepBasic_DateAndTime_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DateAndTime >":
    return _StepBasic.Handle_StepBasic_DateAndTime_DownCast(t)

def Handle_StepBasic_DateAndTime_IsNull(t: "opencascade::handle< StepBasic_DateAndTime > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DateAndTime_IsNull(t)

def Handle_StepBasic_DateAndTimeAssignment_Create() -> "opencascade::handle< StepBasic_DateAndTimeAssignment >":
    return _StepBasic.Handle_StepBasic_DateAndTimeAssignment_Create()

def Handle_StepBasic_DateAndTimeAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DateAndTimeAssignment >":
    return _StepBasic.Handle_StepBasic_DateAndTimeAssignment_DownCast(t)

def Handle_StepBasic_DateAndTimeAssignment_IsNull(t: "opencascade::handle< StepBasic_DateAndTimeAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DateAndTimeAssignment_IsNull(t)

def Handle_StepBasic_DateAssignment_Create() -> "opencascade::handle< StepBasic_DateAssignment >":
    return _StepBasic.Handle_StepBasic_DateAssignment_Create()

def Handle_StepBasic_DateAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DateAssignment >":
    return _StepBasic.Handle_StepBasic_DateAssignment_DownCast(t)

def Handle_StepBasic_DateAssignment_IsNull(t: "opencascade::handle< StepBasic_DateAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DateAssignment_IsNull(t)

def Handle_StepBasic_DateRole_Create() -> "opencascade::handle< StepBasic_DateRole >":
    return _StepBasic.Handle_StepBasic_DateRole_Create()

def Handle_StepBasic_DateRole_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DateRole >":
    return _StepBasic.Handle_StepBasic_DateRole_DownCast(t)

def Handle_StepBasic_DateRole_IsNull(t: "opencascade::handle< StepBasic_DateRole > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DateRole_IsNull(t)

def Handle_StepBasic_DateTimeRole_Create() -> "opencascade::handle< StepBasic_DateTimeRole >":
    return _StepBasic.Handle_StepBasic_DateTimeRole_Create()

def Handle_StepBasic_DateTimeRole_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DateTimeRole >":
    return _StepBasic.Handle_StepBasic_DateTimeRole_DownCast(t)

def Handle_StepBasic_DateTimeRole_IsNull(t: "opencascade::handle< StepBasic_DateTimeRole > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DateTimeRole_IsNull(t)

def Handle_StepBasic_DerivedUnit_Create() -> "opencascade::handle< StepBasic_DerivedUnit >":
    return _StepBasic.Handle_StepBasic_DerivedUnit_Create()

def Handle_StepBasic_DerivedUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DerivedUnit >":
    return _StepBasic.Handle_StepBasic_DerivedUnit_DownCast(t)

def Handle_StepBasic_DerivedUnit_IsNull(t: "opencascade::handle< StepBasic_DerivedUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DerivedUnit_IsNull(t)

def Handle_StepBasic_DerivedUnitElement_Create() -> "opencascade::handle< StepBasic_DerivedUnitElement >":
    return _StepBasic.Handle_StepBasic_DerivedUnitElement_Create()

def Handle_StepBasic_DerivedUnitElement_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DerivedUnitElement >":
    return _StepBasic.Handle_StepBasic_DerivedUnitElement_DownCast(t)

def Handle_StepBasic_DerivedUnitElement_IsNull(t: "opencascade::handle< StepBasic_DerivedUnitElement > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DerivedUnitElement_IsNull(t)

def Handle_StepBasic_DimensionalExponents_Create() -> "opencascade::handle< StepBasic_DimensionalExponents >":
    return _StepBasic.Handle_StepBasic_DimensionalExponents_Create()

def Handle_StepBasic_DimensionalExponents_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DimensionalExponents >":
    return _StepBasic.Handle_StepBasic_DimensionalExponents_DownCast(t)

def Handle_StepBasic_DimensionalExponents_IsNull(t: "opencascade::handle< StepBasic_DimensionalExponents > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DimensionalExponents_IsNull(t)

def Handle_StepBasic_Document_Create() -> "opencascade::handle< StepBasic_Document >":
    return _StepBasic.Handle_StepBasic_Document_Create()

def Handle_StepBasic_Document_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_Document >":
    return _StepBasic.Handle_StepBasic_Document_DownCast(t)

def Handle_StepBasic_Document_IsNull(t: "opencascade::handle< StepBasic_Document > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_Document_IsNull(t)

def Handle_StepBasic_DocumentProductAssociation_Create() -> "opencascade::handle< StepBasic_DocumentProductAssociation >":
    return _StepBasic.Handle_StepBasic_DocumentProductAssociation_Create()

def Handle_StepBasic_DocumentProductAssociation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DocumentProductAssociation >":
    return _StepBasic.Handle_StepBasic_DocumentProductAssociation_DownCast(t)

def Handle_StepBasic_DocumentProductAssociation_IsNull(t: "opencascade::handle< StepBasic_DocumentProductAssociation > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DocumentProductAssociation_IsNull(t)

def Handle_StepBasic_DocumentReference_Create() -> "opencascade::handle< StepBasic_DocumentReference >":
    return _StepBasic.Handle_StepBasic_DocumentReference_Create()

def Handle_StepBasic_DocumentReference_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DocumentReference >":
    return _StepBasic.Handle_StepBasic_DocumentReference_DownCast(t)

def Handle_StepBasic_DocumentReference_IsNull(t: "opencascade::handle< StepBasic_DocumentReference > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DocumentReference_IsNull(t)

def Handle_StepBasic_DocumentRelationship_Create() -> "opencascade::handle< StepBasic_DocumentRelationship >":
    return _StepBasic.Handle_StepBasic_DocumentRelationship_Create()

def Handle_StepBasic_DocumentRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DocumentRelationship >":
    return _StepBasic.Handle_StepBasic_DocumentRelationship_DownCast(t)

def Handle_StepBasic_DocumentRelationship_IsNull(t: "opencascade::handle< StepBasic_DocumentRelationship > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DocumentRelationship_IsNull(t)

def Handle_StepBasic_DocumentRepresentationType_Create() -> "opencascade::handle< StepBasic_DocumentRepresentationType >":
    return _StepBasic.Handle_StepBasic_DocumentRepresentationType_Create()

def Handle_StepBasic_DocumentRepresentationType_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DocumentRepresentationType >":
    return _StepBasic.Handle_StepBasic_DocumentRepresentationType_DownCast(t)

def Handle_StepBasic_DocumentRepresentationType_IsNull(t: "opencascade::handle< StepBasic_DocumentRepresentationType > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DocumentRepresentationType_IsNull(t)

def Handle_StepBasic_DocumentType_Create() -> "opencascade::handle< StepBasic_DocumentType >":
    return _StepBasic.Handle_StepBasic_DocumentType_Create()

def Handle_StepBasic_DocumentType_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DocumentType >":
    return _StepBasic.Handle_StepBasic_DocumentType_DownCast(t)

def Handle_StepBasic_DocumentType_IsNull(t: "opencascade::handle< StepBasic_DocumentType > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DocumentType_IsNull(t)

def Handle_StepBasic_DocumentUsageConstraint_Create() -> "opencascade::handle< StepBasic_DocumentUsageConstraint >":
    return _StepBasic.Handle_StepBasic_DocumentUsageConstraint_Create()

def Handle_StepBasic_DocumentUsageConstraint_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DocumentUsageConstraint >":
    return _StepBasic.Handle_StepBasic_DocumentUsageConstraint_DownCast(t)

def Handle_StepBasic_DocumentUsageConstraint_IsNull(t: "opencascade::handle< StepBasic_DocumentUsageConstraint > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DocumentUsageConstraint_IsNull(t)

def Handle_StepBasic_Effectivity_Create() -> "opencascade::handle< StepBasic_Effectivity >":
    return _StepBasic.Handle_StepBasic_Effectivity_Create()

def Handle_StepBasic_Effectivity_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_Effectivity >":
    return _StepBasic.Handle_StepBasic_Effectivity_DownCast(t)

def Handle_StepBasic_Effectivity_IsNull(t: "opencascade::handle< StepBasic_Effectivity > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_Effectivity_IsNull(t)

def Handle_StepBasic_EffectivityAssignment_Create() -> "opencascade::handle< StepBasic_EffectivityAssignment >":
    return _StepBasic.Handle_StepBasic_EffectivityAssignment_Create()

def Handle_StepBasic_EffectivityAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_EffectivityAssignment >":
    return _StepBasic.Handle_StepBasic_EffectivityAssignment_DownCast(t)

def Handle_StepBasic_EffectivityAssignment_IsNull(t: "opencascade::handle< StepBasic_EffectivityAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_EffectivityAssignment_IsNull(t)

def Handle_StepBasic_EulerAngles_Create() -> "opencascade::handle< StepBasic_EulerAngles >":
    return _StepBasic.Handle_StepBasic_EulerAngles_Create()

def Handle_StepBasic_EulerAngles_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_EulerAngles >":
    return _StepBasic.Handle_StepBasic_EulerAngles_DownCast(t)

def Handle_StepBasic_EulerAngles_IsNull(t: "opencascade::handle< StepBasic_EulerAngles > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_EulerAngles_IsNull(t)

def Handle_StepBasic_ExternalSource_Create() -> "opencascade::handle< StepBasic_ExternalSource >":
    return _StepBasic.Handle_StepBasic_ExternalSource_Create()

def Handle_StepBasic_ExternalSource_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ExternalSource >":
    return _StepBasic.Handle_StepBasic_ExternalSource_DownCast(t)

def Handle_StepBasic_ExternalSource_IsNull(t: "opencascade::handle< StepBasic_ExternalSource > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ExternalSource_IsNull(t)

def Handle_StepBasic_ExternallyDefinedItem_Create() -> "opencascade::handle< StepBasic_ExternallyDefinedItem >":
    return _StepBasic.Handle_StepBasic_ExternallyDefinedItem_Create()

def Handle_StepBasic_ExternallyDefinedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ExternallyDefinedItem >":
    return _StepBasic.Handle_StepBasic_ExternallyDefinedItem_DownCast(t)

def Handle_StepBasic_ExternallyDefinedItem_IsNull(t: "opencascade::handle< StepBasic_ExternallyDefinedItem > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ExternallyDefinedItem_IsNull(t)

def Handle_StepBasic_GeneralProperty_Create() -> "opencascade::handle< StepBasic_GeneralProperty >":
    return _StepBasic.Handle_StepBasic_GeneralProperty_Create()

def Handle_StepBasic_GeneralProperty_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_GeneralProperty >":
    return _StepBasic.Handle_StepBasic_GeneralProperty_DownCast(t)

def Handle_StepBasic_GeneralProperty_IsNull(t: "opencascade::handle< StepBasic_GeneralProperty > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_GeneralProperty_IsNull(t)

def Handle_StepBasic_Group_Create() -> "opencascade::handle< StepBasic_Group >":
    return _StepBasic.Handle_StepBasic_Group_Create()

def Handle_StepBasic_Group_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_Group >":
    return _StepBasic.Handle_StepBasic_Group_DownCast(t)

def Handle_StepBasic_Group_IsNull(t: "opencascade::handle< StepBasic_Group > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_Group_IsNull(t)

def Handle_StepBasic_GroupAssignment_Create() -> "opencascade::handle< StepBasic_GroupAssignment >":
    return _StepBasic.Handle_StepBasic_GroupAssignment_Create()

def Handle_StepBasic_GroupAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_GroupAssignment >":
    return _StepBasic.Handle_StepBasic_GroupAssignment_DownCast(t)

def Handle_StepBasic_GroupAssignment_IsNull(t: "opencascade::handle< StepBasic_GroupAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_GroupAssignment_IsNull(t)

def Handle_StepBasic_GroupRelationship_Create() -> "opencascade::handle< StepBasic_GroupRelationship >":
    return _StepBasic.Handle_StepBasic_GroupRelationship_Create()

def Handle_StepBasic_GroupRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_GroupRelationship >":
    return _StepBasic.Handle_StepBasic_GroupRelationship_DownCast(t)

def Handle_StepBasic_GroupRelationship_IsNull(t: "opencascade::handle< StepBasic_GroupRelationship > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_GroupRelationship_IsNull(t)

def Handle_StepBasic_IdentificationAssignment_Create() -> "opencascade::handle< StepBasic_IdentificationAssignment >":
    return _StepBasic.Handle_StepBasic_IdentificationAssignment_Create()

def Handle_StepBasic_IdentificationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_IdentificationAssignment >":
    return _StepBasic.Handle_StepBasic_IdentificationAssignment_DownCast(t)

def Handle_StepBasic_IdentificationAssignment_IsNull(t: "opencascade::handle< StepBasic_IdentificationAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_IdentificationAssignment_IsNull(t)

def Handle_StepBasic_IdentificationRole_Create() -> "opencascade::handle< StepBasic_IdentificationRole >":
    return _StepBasic.Handle_StepBasic_IdentificationRole_Create()

def Handle_StepBasic_IdentificationRole_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_IdentificationRole >":
    return _StepBasic.Handle_StepBasic_IdentificationRole_DownCast(t)

def Handle_StepBasic_IdentificationRole_IsNull(t: "opencascade::handle< StepBasic_IdentificationRole > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_IdentificationRole_IsNull(t)

def Handle_StepBasic_LocalTime_Create() -> "opencascade::handle< StepBasic_LocalTime >":
    return _StepBasic.Handle_StepBasic_LocalTime_Create()

def Handle_StepBasic_LocalTime_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_LocalTime >":
    return _StepBasic.Handle_StepBasic_LocalTime_DownCast(t)

def Handle_StepBasic_LocalTime_IsNull(t: "opencascade::handle< StepBasic_LocalTime > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_LocalTime_IsNull(t)

def Handle_StepBasic_MeasureValueMember_Create() -> "opencascade::handle< StepBasic_MeasureValueMember >":
    return _StepBasic.Handle_StepBasic_MeasureValueMember_Create()

def Handle_StepBasic_MeasureValueMember_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_MeasureValueMember >":
    return _StepBasic.Handle_StepBasic_MeasureValueMember_DownCast(t)

def Handle_StepBasic_MeasureValueMember_IsNull(t: "opencascade::handle< StepBasic_MeasureValueMember > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_MeasureValueMember_IsNull(t)

def Handle_StepBasic_MeasureWithUnit_Create() -> "opencascade::handle< StepBasic_MeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_MeasureWithUnit_Create()

def Handle_StepBasic_MeasureWithUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_MeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_MeasureWithUnit_DownCast(t)

def Handle_StepBasic_MeasureWithUnit_IsNull(t: "opencascade::handle< StepBasic_MeasureWithUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_MeasureWithUnit_IsNull(t)

def Handle_StepBasic_NameAssignment_Create() -> "opencascade::handle< StepBasic_NameAssignment >":
    return _StepBasic.Handle_StepBasic_NameAssignment_Create()

def Handle_StepBasic_NameAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_NameAssignment >":
    return _StepBasic.Handle_StepBasic_NameAssignment_DownCast(t)

def Handle_StepBasic_NameAssignment_IsNull(t: "opencascade::handle< StepBasic_NameAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_NameAssignment_IsNull(t)

def Handle_StepBasic_NamedUnit_Create() -> "opencascade::handle< StepBasic_NamedUnit >":
    return _StepBasic.Handle_StepBasic_NamedUnit_Create()

def Handle_StepBasic_NamedUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_NamedUnit >":
    return _StepBasic.Handle_StepBasic_NamedUnit_DownCast(t)

def Handle_StepBasic_NamedUnit_IsNull(t: "opencascade::handle< StepBasic_NamedUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_NamedUnit_IsNull(t)

def Handle_StepBasic_ObjectRole_Create() -> "opencascade::handle< StepBasic_ObjectRole >":
    return _StepBasic.Handle_StepBasic_ObjectRole_Create()

def Handle_StepBasic_ObjectRole_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ObjectRole >":
    return _StepBasic.Handle_StepBasic_ObjectRole_DownCast(t)

def Handle_StepBasic_ObjectRole_IsNull(t: "opencascade::handle< StepBasic_ObjectRole > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ObjectRole_IsNull(t)

def Handle_StepBasic_Organization_Create() -> "opencascade::handle< StepBasic_Organization >":
    return _StepBasic.Handle_StepBasic_Organization_Create()

def Handle_StepBasic_Organization_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_Organization >":
    return _StepBasic.Handle_StepBasic_Organization_DownCast(t)

def Handle_StepBasic_Organization_IsNull(t: "opencascade::handle< StepBasic_Organization > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_Organization_IsNull(t)

def Handle_StepBasic_OrganizationAssignment_Create() -> "opencascade::handle< StepBasic_OrganizationAssignment >":
    return _StepBasic.Handle_StepBasic_OrganizationAssignment_Create()

def Handle_StepBasic_OrganizationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_OrganizationAssignment >":
    return _StepBasic.Handle_StepBasic_OrganizationAssignment_DownCast(t)

def Handle_StepBasic_OrganizationAssignment_IsNull(t: "opencascade::handle< StepBasic_OrganizationAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_OrganizationAssignment_IsNull(t)

def Handle_StepBasic_OrganizationRole_Create() -> "opencascade::handle< StepBasic_OrganizationRole >":
    return _StepBasic.Handle_StepBasic_OrganizationRole_Create()

def Handle_StepBasic_OrganizationRole_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_OrganizationRole >":
    return _StepBasic.Handle_StepBasic_OrganizationRole_DownCast(t)

def Handle_StepBasic_OrganizationRole_IsNull(t: "opencascade::handle< StepBasic_OrganizationRole > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_OrganizationRole_IsNull(t)

def Handle_StepBasic_Person_Create() -> "opencascade::handle< StepBasic_Person >":
    return _StepBasic.Handle_StepBasic_Person_Create()

def Handle_StepBasic_Person_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_Person >":
    return _StepBasic.Handle_StepBasic_Person_DownCast(t)

def Handle_StepBasic_Person_IsNull(t: "opencascade::handle< StepBasic_Person > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_Person_IsNull(t)

def Handle_StepBasic_PersonAndOrganization_Create() -> "opencascade::handle< StepBasic_PersonAndOrganization >":
    return _StepBasic.Handle_StepBasic_PersonAndOrganization_Create()

def Handle_StepBasic_PersonAndOrganization_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_PersonAndOrganization >":
    return _StepBasic.Handle_StepBasic_PersonAndOrganization_DownCast(t)

def Handle_StepBasic_PersonAndOrganization_IsNull(t: "opencascade::handle< StepBasic_PersonAndOrganization > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_PersonAndOrganization_IsNull(t)

def Handle_StepBasic_PersonAndOrganizationAssignment_Create() -> "opencascade::handle< StepBasic_PersonAndOrganizationAssignment >":
    return _StepBasic.Handle_StepBasic_PersonAndOrganizationAssignment_Create()

def Handle_StepBasic_PersonAndOrganizationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_PersonAndOrganizationAssignment >":
    return _StepBasic.Handle_StepBasic_PersonAndOrganizationAssignment_DownCast(t)

def Handle_StepBasic_PersonAndOrganizationAssignment_IsNull(t: "opencascade::handle< StepBasic_PersonAndOrganizationAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_PersonAndOrganizationAssignment_IsNull(t)

def Handle_StepBasic_PersonAndOrganizationRole_Create() -> "opencascade::handle< StepBasic_PersonAndOrganizationRole >":
    return _StepBasic.Handle_StepBasic_PersonAndOrganizationRole_Create()

def Handle_StepBasic_PersonAndOrganizationRole_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_PersonAndOrganizationRole >":
    return _StepBasic.Handle_StepBasic_PersonAndOrganizationRole_DownCast(t)

def Handle_StepBasic_PersonAndOrganizationRole_IsNull(t: "opencascade::handle< StepBasic_PersonAndOrganizationRole > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_PersonAndOrganizationRole_IsNull(t)

def Handle_StepBasic_Product_Create() -> "opencascade::handle< StepBasic_Product >":
    return _StepBasic.Handle_StepBasic_Product_Create()

def Handle_StepBasic_Product_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_Product >":
    return _StepBasic.Handle_StepBasic_Product_DownCast(t)

def Handle_StepBasic_Product_IsNull(t: "opencascade::handle< StepBasic_Product > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_Product_IsNull(t)

def Handle_StepBasic_ProductCategory_Create() -> "opencascade::handle< StepBasic_ProductCategory >":
    return _StepBasic.Handle_StepBasic_ProductCategory_Create()

def Handle_StepBasic_ProductCategory_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductCategory >":
    return _StepBasic.Handle_StepBasic_ProductCategory_DownCast(t)

def Handle_StepBasic_ProductCategory_IsNull(t: "opencascade::handle< StepBasic_ProductCategory > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductCategory_IsNull(t)

def Handle_StepBasic_ProductCategoryRelationship_Create() -> "opencascade::handle< StepBasic_ProductCategoryRelationship >":
    return _StepBasic.Handle_StepBasic_ProductCategoryRelationship_Create()

def Handle_StepBasic_ProductCategoryRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductCategoryRelationship >":
    return _StepBasic.Handle_StepBasic_ProductCategoryRelationship_DownCast(t)

def Handle_StepBasic_ProductCategoryRelationship_IsNull(t: "opencascade::handle< StepBasic_ProductCategoryRelationship > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductCategoryRelationship_IsNull(t)

def Handle_StepBasic_ProductDefinition_Create() -> "opencascade::handle< StepBasic_ProductDefinition >":
    return _StepBasic.Handle_StepBasic_ProductDefinition_Create()

def Handle_StepBasic_ProductDefinition_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductDefinition >":
    return _StepBasic.Handle_StepBasic_ProductDefinition_DownCast(t)

def Handle_StepBasic_ProductDefinition_IsNull(t: "opencascade::handle< StepBasic_ProductDefinition > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductDefinition_IsNull(t)

def Handle_StepBasic_ProductDefinitionFormation_Create() -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionFormation_Create()

def Handle_StepBasic_ProductDefinitionFormation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionFormation_DownCast(t)

def Handle_StepBasic_ProductDefinitionFormation_IsNull(t: "opencascade::handle< StepBasic_ProductDefinitionFormation > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductDefinitionFormation_IsNull(t)

def Handle_StepBasic_ProductDefinitionFormationRelationship_Create() -> "opencascade::handle< StepBasic_ProductDefinitionFormationRelationship >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionFormationRelationship_Create()

def Handle_StepBasic_ProductDefinitionFormationRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductDefinitionFormationRelationship >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionFormationRelationship_DownCast(t)

def Handle_StepBasic_ProductDefinitionFormationRelationship_IsNull(t: "opencascade::handle< StepBasic_ProductDefinitionFormationRelationship > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductDefinitionFormationRelationship_IsNull(t)

def Handle_StepBasic_ProductDefinitionReference_Create() -> "opencascade::handle< StepBasic_ProductDefinitionReference >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionReference_Create()

def Handle_StepBasic_ProductDefinitionReference_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductDefinitionReference >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionReference_DownCast(t)

def Handle_StepBasic_ProductDefinitionReference_IsNull(t: "opencascade::handle< StepBasic_ProductDefinitionReference > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductDefinitionReference_IsNull(t)

def Handle_StepBasic_ProductDefinitionRelationship_Create() -> "opencascade::handle< StepBasic_ProductDefinitionRelationship >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionRelationship_Create()

def Handle_StepBasic_ProductDefinitionRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductDefinitionRelationship >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionRelationship_DownCast(t)

def Handle_StepBasic_ProductDefinitionRelationship_IsNull(t: "opencascade::handle< StepBasic_ProductDefinitionRelationship > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductDefinitionRelationship_IsNull(t)

def Handle_StepBasic_RoleAssociation_Create() -> "opencascade::handle< StepBasic_RoleAssociation >":
    return _StepBasic.Handle_StepBasic_RoleAssociation_Create()

def Handle_StepBasic_RoleAssociation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_RoleAssociation >":
    return _StepBasic.Handle_StepBasic_RoleAssociation_DownCast(t)

def Handle_StepBasic_RoleAssociation_IsNull(t: "opencascade::handle< StepBasic_RoleAssociation > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_RoleAssociation_IsNull(t)

def Handle_StepBasic_SecurityClassification_Create() -> "opencascade::handle< StepBasic_SecurityClassification >":
    return _StepBasic.Handle_StepBasic_SecurityClassification_Create()

def Handle_StepBasic_SecurityClassification_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SecurityClassification >":
    return _StepBasic.Handle_StepBasic_SecurityClassification_DownCast(t)

def Handle_StepBasic_SecurityClassification_IsNull(t: "opencascade::handle< StepBasic_SecurityClassification > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SecurityClassification_IsNull(t)

def Handle_StepBasic_SecurityClassificationAssignment_Create() -> "opencascade::handle< StepBasic_SecurityClassificationAssignment >":
    return _StepBasic.Handle_StepBasic_SecurityClassificationAssignment_Create()

def Handle_StepBasic_SecurityClassificationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SecurityClassificationAssignment >":
    return _StepBasic.Handle_StepBasic_SecurityClassificationAssignment_DownCast(t)

def Handle_StepBasic_SecurityClassificationAssignment_IsNull(t: "opencascade::handle< StepBasic_SecurityClassificationAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SecurityClassificationAssignment_IsNull(t)

def Handle_StepBasic_SecurityClassificationLevel_Create() -> "opencascade::handle< StepBasic_SecurityClassificationLevel >":
    return _StepBasic.Handle_StepBasic_SecurityClassificationLevel_Create()

def Handle_StepBasic_SecurityClassificationLevel_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SecurityClassificationLevel >":
    return _StepBasic.Handle_StepBasic_SecurityClassificationLevel_DownCast(t)

def Handle_StepBasic_SecurityClassificationLevel_IsNull(t: "opencascade::handle< StepBasic_SecurityClassificationLevel > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SecurityClassificationLevel_IsNull(t)

def Handle_StepBasic_SizeMember_Create() -> "opencascade::handle< StepBasic_SizeMember >":
    return _StepBasic.Handle_StepBasic_SizeMember_Create()

def Handle_StepBasic_SizeMember_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SizeMember >":
    return _StepBasic.Handle_StepBasic_SizeMember_DownCast(t)

def Handle_StepBasic_SizeMember_IsNull(t: "opencascade::handle< StepBasic_SizeMember > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SizeMember_IsNull(t)

def Handle_StepBasic_VersionedActionRequest_Create() -> "opencascade::handle< StepBasic_VersionedActionRequest >":
    return _StepBasic.Handle_StepBasic_VersionedActionRequest_Create()

def Handle_StepBasic_VersionedActionRequest_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_VersionedActionRequest >":
    return _StepBasic.Handle_StepBasic_VersionedActionRequest_DownCast(t)

def Handle_StepBasic_VersionedActionRequest_IsNull(t: "opencascade::handle< StepBasic_VersionedActionRequest > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_VersionedActionRequest_IsNull(t)

def Handle_StepBasic_AreaUnit_Create() -> "opencascade::handle< StepBasic_AreaUnit >":
    return _StepBasic.Handle_StepBasic_AreaUnit_Create()

def Handle_StepBasic_AreaUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_AreaUnit >":
    return _StepBasic.Handle_StepBasic_AreaUnit_DownCast(t)

def Handle_StepBasic_AreaUnit_IsNull(t: "opencascade::handle< StepBasic_AreaUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_AreaUnit_IsNull(t)

def Handle_StepBasic_CalendarDate_Create() -> "opencascade::handle< StepBasic_CalendarDate >":
    return _StepBasic.Handle_StepBasic_CalendarDate_Create()

def Handle_StepBasic_CalendarDate_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_CalendarDate >":
    return _StepBasic.Handle_StepBasic_CalendarDate_DownCast(t)

def Handle_StepBasic_CalendarDate_IsNull(t: "opencascade::handle< StepBasic_CalendarDate > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_CalendarDate_IsNull(t)

def Handle_StepBasic_ConversionBasedUnit_Create() -> "opencascade::handle< StepBasic_ConversionBasedUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnit_Create()

def Handle_StepBasic_ConversionBasedUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ConversionBasedUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnit_DownCast(t)

def Handle_StepBasic_ConversionBasedUnit_IsNull(t: "opencascade::handle< StepBasic_ConversionBasedUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnit_IsNull(t)

def Handle_StepBasic_DigitalDocument_Create() -> "opencascade::handle< StepBasic_DigitalDocument >":
    return _StepBasic.Handle_StepBasic_DigitalDocument_Create()

def Handle_StepBasic_DigitalDocument_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DigitalDocument >":
    return _StepBasic.Handle_StepBasic_DigitalDocument_DownCast(t)

def Handle_StepBasic_DigitalDocument_IsNull(t: "opencascade::handle< StepBasic_DigitalDocument > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DigitalDocument_IsNull(t)

def Handle_StepBasic_DocumentFile_Create() -> "opencascade::handle< StepBasic_DocumentFile >":
    return _StepBasic.Handle_StepBasic_DocumentFile_Create()

def Handle_StepBasic_DocumentFile_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DocumentFile >":
    return _StepBasic.Handle_StepBasic_DocumentFile_DownCast(t)

def Handle_StepBasic_DocumentFile_IsNull(t: "opencascade::handle< StepBasic_DocumentFile > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DocumentFile_IsNull(t)

def Handle_StepBasic_DocumentProductEquivalence_Create() -> "opencascade::handle< StepBasic_DocumentProductEquivalence >":
    return _StepBasic.Handle_StepBasic_DocumentProductEquivalence_Create()

def Handle_StepBasic_DocumentProductEquivalence_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DocumentProductEquivalence >":
    return _StepBasic.Handle_StepBasic_DocumentProductEquivalence_DownCast(t)

def Handle_StepBasic_DocumentProductEquivalence_IsNull(t: "opencascade::handle< StepBasic_DocumentProductEquivalence > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DocumentProductEquivalence_IsNull(t)

def Handle_StepBasic_ExternalIdentificationAssignment_Create() -> "opencascade::handle< StepBasic_ExternalIdentificationAssignment >":
    return _StepBasic.Handle_StepBasic_ExternalIdentificationAssignment_Create()

def Handle_StepBasic_ExternalIdentificationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ExternalIdentificationAssignment >":
    return _StepBasic.Handle_StepBasic_ExternalIdentificationAssignment_DownCast(t)

def Handle_StepBasic_ExternalIdentificationAssignment_IsNull(t: "opencascade::handle< StepBasic_ExternalIdentificationAssignment > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ExternalIdentificationAssignment_IsNull(t)

def Handle_StepBasic_LengthMeasureWithUnit_Create() -> "opencascade::handle< StepBasic_LengthMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_LengthMeasureWithUnit_Create()

def Handle_StepBasic_LengthMeasureWithUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_LengthMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_LengthMeasureWithUnit_DownCast(t)

def Handle_StepBasic_LengthMeasureWithUnit_IsNull(t: "opencascade::handle< StepBasic_LengthMeasureWithUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_LengthMeasureWithUnit_IsNull(t)

def Handle_StepBasic_LengthUnit_Create() -> "opencascade::handle< StepBasic_LengthUnit >":
    return _StepBasic.Handle_StepBasic_LengthUnit_Create()

def Handle_StepBasic_LengthUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_LengthUnit >":
    return _StepBasic.Handle_StepBasic_LengthUnit_DownCast(t)

def Handle_StepBasic_LengthUnit_IsNull(t: "opencascade::handle< StepBasic_LengthUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_LengthUnit_IsNull(t)

def Handle_StepBasic_MassMeasureWithUnit_Create() -> "opencascade::handle< StepBasic_MassMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_MassMeasureWithUnit_Create()

def Handle_StepBasic_MassMeasureWithUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_MassMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_MassMeasureWithUnit_DownCast(t)

def Handle_StepBasic_MassMeasureWithUnit_IsNull(t: "opencascade::handle< StepBasic_MassMeasureWithUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_MassMeasureWithUnit_IsNull(t)

def Handle_StepBasic_MassUnit_Create() -> "opencascade::handle< StepBasic_MassUnit >":
    return _StepBasic.Handle_StepBasic_MassUnit_Create()

def Handle_StepBasic_MassUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_MassUnit >":
    return _StepBasic.Handle_StepBasic_MassUnit_DownCast(t)

def Handle_StepBasic_MassUnit_IsNull(t: "opencascade::handle< StepBasic_MassUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_MassUnit_IsNull(t)

def Handle_StepBasic_OrdinalDate_Create() -> "opencascade::handle< StepBasic_OrdinalDate >":
    return _StepBasic.Handle_StepBasic_OrdinalDate_Create()

def Handle_StepBasic_OrdinalDate_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_OrdinalDate >":
    return _StepBasic.Handle_StepBasic_OrdinalDate_DownCast(t)

def Handle_StepBasic_OrdinalDate_IsNull(t: "opencascade::handle< StepBasic_OrdinalDate > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_OrdinalDate_IsNull(t)

def Handle_StepBasic_OrganizationalAddress_Create() -> "opencascade::handle< StepBasic_OrganizationalAddress >":
    return _StepBasic.Handle_StepBasic_OrganizationalAddress_Create()

def Handle_StepBasic_OrganizationalAddress_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_OrganizationalAddress >":
    return _StepBasic.Handle_StepBasic_OrganizationalAddress_DownCast(t)

def Handle_StepBasic_OrganizationalAddress_IsNull(t: "opencascade::handle< StepBasic_OrganizationalAddress > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_OrganizationalAddress_IsNull(t)

def Handle_StepBasic_PersonalAddress_Create() -> "opencascade::handle< StepBasic_PersonalAddress >":
    return _StepBasic.Handle_StepBasic_PersonalAddress_Create()

def Handle_StepBasic_PersonalAddress_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_PersonalAddress >":
    return _StepBasic.Handle_StepBasic_PersonalAddress_DownCast(t)

def Handle_StepBasic_PersonalAddress_IsNull(t: "opencascade::handle< StepBasic_PersonalAddress > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_PersonalAddress_IsNull(t)

def Handle_StepBasic_PhysicallyModeledProductDefinition_Create() -> "opencascade::handle< StepBasic_PhysicallyModeledProductDefinition >":
    return _StepBasic.Handle_StepBasic_PhysicallyModeledProductDefinition_Create()

def Handle_StepBasic_PhysicallyModeledProductDefinition_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_PhysicallyModeledProductDefinition >":
    return _StepBasic.Handle_StepBasic_PhysicallyModeledProductDefinition_DownCast(t)

def Handle_StepBasic_PhysicallyModeledProductDefinition_IsNull(t: "opencascade::handle< StepBasic_PhysicallyModeledProductDefinition > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_PhysicallyModeledProductDefinition_IsNull(t)

def Handle_StepBasic_PlaneAngleMeasureWithUnit_Create() -> "opencascade::handle< StepBasic_PlaneAngleMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_PlaneAngleMeasureWithUnit_Create()

def Handle_StepBasic_PlaneAngleMeasureWithUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_PlaneAngleMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_PlaneAngleMeasureWithUnit_DownCast(t)

def Handle_StepBasic_PlaneAngleMeasureWithUnit_IsNull(t: "opencascade::handle< StepBasic_PlaneAngleMeasureWithUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_PlaneAngleMeasureWithUnit_IsNull(t)

def Handle_StepBasic_PlaneAngleUnit_Create() -> "opencascade::handle< StepBasic_PlaneAngleUnit >":
    return _StepBasic.Handle_StepBasic_PlaneAngleUnit_Create()

def Handle_StepBasic_PlaneAngleUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_PlaneAngleUnit >":
    return _StepBasic.Handle_StepBasic_PlaneAngleUnit_DownCast(t)

def Handle_StepBasic_PlaneAngleUnit_IsNull(t: "opencascade::handle< StepBasic_PlaneAngleUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_PlaneAngleUnit_IsNull(t)

def Handle_StepBasic_ProductConceptContext_Create() -> "opencascade::handle< StepBasic_ProductConceptContext >":
    return _StepBasic.Handle_StepBasic_ProductConceptContext_Create()

def Handle_StepBasic_ProductConceptContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductConceptContext >":
    return _StepBasic.Handle_StepBasic_ProductConceptContext_DownCast(t)

def Handle_StepBasic_ProductConceptContext_IsNull(t: "opencascade::handle< StepBasic_ProductConceptContext > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductConceptContext_IsNull(t)

def Handle_StepBasic_ProductContext_Create() -> "opencascade::handle< StepBasic_ProductContext >":
    return _StepBasic.Handle_StepBasic_ProductContext_Create()

def Handle_StepBasic_ProductContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductContext >":
    return _StepBasic.Handle_StepBasic_ProductContext_DownCast(t)

def Handle_StepBasic_ProductContext_IsNull(t: "opencascade::handle< StepBasic_ProductContext > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductContext_IsNull(t)

def Handle_StepBasic_ProductDefinitionContext_Create() -> "opencascade::handle< StepBasic_ProductDefinitionContext >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionContext_Create()

def Handle_StepBasic_ProductDefinitionContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductDefinitionContext >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionContext_DownCast(t)

def Handle_StepBasic_ProductDefinitionContext_IsNull(t: "opencascade::handle< StepBasic_ProductDefinitionContext > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductDefinitionContext_IsNull(t)

def Handle_StepBasic_ProductDefinitionEffectivity_Create() -> "opencascade::handle< StepBasic_ProductDefinitionEffectivity >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionEffectivity_Create()

def Handle_StepBasic_ProductDefinitionEffectivity_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductDefinitionEffectivity >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionEffectivity_DownCast(t)

def Handle_StepBasic_ProductDefinitionEffectivity_IsNull(t: "opencascade::handle< StepBasic_ProductDefinitionEffectivity > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductDefinitionEffectivity_IsNull(t)

def Handle_StepBasic_ProductDefinitionFormationWithSpecifiedSource_Create() -> "opencascade::handle< StepBasic_ProductDefinitionFormationWithSpecifiedSource >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionFormationWithSpecifiedSource_Create()

def Handle_StepBasic_ProductDefinitionFormationWithSpecifiedSource_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductDefinitionFormationWithSpecifiedSource >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionFormationWithSpecifiedSource_DownCast(t)

def Handle_StepBasic_ProductDefinitionFormationWithSpecifiedSource_IsNull(t: "opencascade::handle< StepBasic_ProductDefinitionFormationWithSpecifiedSource > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductDefinitionFormationWithSpecifiedSource_IsNull(t)

def Handle_StepBasic_ProductDefinitionReferenceWithLocalRepresentation_Create() -> "opencascade::handle< StepBasic_ProductDefinitionReferenceWithLocalRepresentation >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionReferenceWithLocalRepresentation_Create()

def Handle_StepBasic_ProductDefinitionReferenceWithLocalRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductDefinitionReferenceWithLocalRepresentation >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionReferenceWithLocalRepresentation_DownCast(t)

def Handle_StepBasic_ProductDefinitionReferenceWithLocalRepresentation_IsNull(t: "opencascade::handle< StepBasic_ProductDefinitionReferenceWithLocalRepresentation > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductDefinitionReferenceWithLocalRepresentation_IsNull(t)

def Handle_StepBasic_ProductDefinitionWithAssociatedDocuments_Create() -> "opencascade::handle< StepBasic_ProductDefinitionWithAssociatedDocuments >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionWithAssociatedDocuments_Create()

def Handle_StepBasic_ProductDefinitionWithAssociatedDocuments_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductDefinitionWithAssociatedDocuments >":
    return _StepBasic.Handle_StepBasic_ProductDefinitionWithAssociatedDocuments_DownCast(t)

def Handle_StepBasic_ProductDefinitionWithAssociatedDocuments_IsNull(t: "opencascade::handle< StepBasic_ProductDefinitionWithAssociatedDocuments > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductDefinitionWithAssociatedDocuments_IsNull(t)

def Handle_StepBasic_ProductRelatedProductCategory_Create() -> "opencascade::handle< StepBasic_ProductRelatedProductCategory >":
    return _StepBasic.Handle_StepBasic_ProductRelatedProductCategory_Create()

def Handle_StepBasic_ProductRelatedProductCategory_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductRelatedProductCategory >":
    return _StepBasic.Handle_StepBasic_ProductRelatedProductCategory_DownCast(t)

def Handle_StepBasic_ProductRelatedProductCategory_IsNull(t: "opencascade::handle< StepBasic_ProductRelatedProductCategory > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductRelatedProductCategory_IsNull(t)

def Handle_StepBasic_RatioMeasureWithUnit_Create() -> "opencascade::handle< StepBasic_RatioMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_RatioMeasureWithUnit_Create()

def Handle_StepBasic_RatioMeasureWithUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_RatioMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_RatioMeasureWithUnit_DownCast(t)

def Handle_StepBasic_RatioMeasureWithUnit_IsNull(t: "opencascade::handle< StepBasic_RatioMeasureWithUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_RatioMeasureWithUnit_IsNull(t)

def Handle_StepBasic_RatioUnit_Create() -> "opencascade::handle< StepBasic_RatioUnit >":
    return _StepBasic.Handle_StepBasic_RatioUnit_Create()

def Handle_StepBasic_RatioUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_RatioUnit >":
    return _StepBasic.Handle_StepBasic_RatioUnit_DownCast(t)

def Handle_StepBasic_RatioUnit_IsNull(t: "opencascade::handle< StepBasic_RatioUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_RatioUnit_IsNull(t)

def Handle_StepBasic_SiUnit_Create() -> "opencascade::handle< StepBasic_SiUnit >":
    return _StepBasic.Handle_StepBasic_SiUnit_Create()

def Handle_StepBasic_SiUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SiUnit >":
    return _StepBasic.Handle_StepBasic_SiUnit_DownCast(t)

def Handle_StepBasic_SiUnit_IsNull(t: "opencascade::handle< StepBasic_SiUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SiUnit_IsNull(t)

def Handle_StepBasic_SolidAngleMeasureWithUnit_Create() -> "opencascade::handle< StepBasic_SolidAngleMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_SolidAngleMeasureWithUnit_Create()

def Handle_StepBasic_SolidAngleMeasureWithUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SolidAngleMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_SolidAngleMeasureWithUnit_DownCast(t)

def Handle_StepBasic_SolidAngleMeasureWithUnit_IsNull(t: "opencascade::handle< StepBasic_SolidAngleMeasureWithUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SolidAngleMeasureWithUnit_IsNull(t)

def Handle_StepBasic_SolidAngleUnit_Create() -> "opencascade::handle< StepBasic_SolidAngleUnit >":
    return _StepBasic.Handle_StepBasic_SolidAngleUnit_Create()

def Handle_StepBasic_SolidAngleUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SolidAngleUnit >":
    return _StepBasic.Handle_StepBasic_SolidAngleUnit_DownCast(t)

def Handle_StepBasic_SolidAngleUnit_IsNull(t: "opencascade::handle< StepBasic_SolidAngleUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SolidAngleUnit_IsNull(t)

def Handle_StepBasic_ThermodynamicTemperatureUnit_Create() -> "opencascade::handle< StepBasic_ThermodynamicTemperatureUnit >":
    return _StepBasic.Handle_StepBasic_ThermodynamicTemperatureUnit_Create()

def Handle_StepBasic_ThermodynamicTemperatureUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ThermodynamicTemperatureUnit >":
    return _StepBasic.Handle_StepBasic_ThermodynamicTemperatureUnit_DownCast(t)

def Handle_StepBasic_ThermodynamicTemperatureUnit_IsNull(t: "opencascade::handle< StepBasic_ThermodynamicTemperatureUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ThermodynamicTemperatureUnit_IsNull(t)

def Handle_StepBasic_TimeMeasureWithUnit_Create() -> "opencascade::handle< StepBasic_TimeMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_TimeMeasureWithUnit_Create()

def Handle_StepBasic_TimeMeasureWithUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_TimeMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_TimeMeasureWithUnit_DownCast(t)

def Handle_StepBasic_TimeMeasureWithUnit_IsNull(t: "opencascade::handle< StepBasic_TimeMeasureWithUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_TimeMeasureWithUnit_IsNull(t)

def Handle_StepBasic_TimeUnit_Create() -> "opencascade::handle< StepBasic_TimeUnit >":
    return _StepBasic.Handle_StepBasic_TimeUnit_Create()

def Handle_StepBasic_TimeUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_TimeUnit >":
    return _StepBasic.Handle_StepBasic_TimeUnit_DownCast(t)

def Handle_StepBasic_TimeUnit_IsNull(t: "opencascade::handle< StepBasic_TimeUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_TimeUnit_IsNull(t)

def Handle_StepBasic_UncertaintyMeasureWithUnit_Create() -> "opencascade::handle< StepBasic_UncertaintyMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_UncertaintyMeasureWithUnit_Create()

def Handle_StepBasic_UncertaintyMeasureWithUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_UncertaintyMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_UncertaintyMeasureWithUnit_DownCast(t)

def Handle_StepBasic_UncertaintyMeasureWithUnit_IsNull(t: "opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_UncertaintyMeasureWithUnit_IsNull(t)

def Handle_StepBasic_VolumeUnit_Create() -> "opencascade::handle< StepBasic_VolumeUnit >":
    return _StepBasic.Handle_StepBasic_VolumeUnit_Create()

def Handle_StepBasic_VolumeUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_VolumeUnit >":
    return _StepBasic.Handle_StepBasic_VolumeUnit_DownCast(t)

def Handle_StepBasic_VolumeUnit_IsNull(t: "opencascade::handle< StepBasic_VolumeUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_VolumeUnit_IsNull(t)

def Handle_StepBasic_WeekOfYearAndDayDate_Create() -> "opencascade::handle< StepBasic_WeekOfYearAndDayDate >":
    return _StepBasic.Handle_StepBasic_WeekOfYearAndDayDate_Create()

def Handle_StepBasic_WeekOfYearAndDayDate_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_WeekOfYearAndDayDate >":
    return _StepBasic.Handle_StepBasic_WeekOfYearAndDayDate_DownCast(t)

def Handle_StepBasic_WeekOfYearAndDayDate_IsNull(t: "opencascade::handle< StepBasic_WeekOfYearAndDayDate > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_WeekOfYearAndDayDate_IsNull(t)

def Handle_StepBasic_ConversionBasedUnitAndAreaUnit_Create() -> "opencascade::handle< StepBasic_ConversionBasedUnitAndAreaUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndAreaUnit_Create()

def Handle_StepBasic_ConversionBasedUnitAndAreaUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ConversionBasedUnitAndAreaUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndAreaUnit_DownCast(t)

def Handle_StepBasic_ConversionBasedUnitAndAreaUnit_IsNull(t: "opencascade::handle< StepBasic_ConversionBasedUnitAndAreaUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndAreaUnit_IsNull(t)

def Handle_StepBasic_ConversionBasedUnitAndLengthUnit_Create() -> "opencascade::handle< StepBasic_ConversionBasedUnitAndLengthUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndLengthUnit_Create()

def Handle_StepBasic_ConversionBasedUnitAndLengthUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ConversionBasedUnitAndLengthUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndLengthUnit_DownCast(t)

def Handle_StepBasic_ConversionBasedUnitAndLengthUnit_IsNull(t: "opencascade::handle< StepBasic_ConversionBasedUnitAndLengthUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndLengthUnit_IsNull(t)

def Handle_StepBasic_ConversionBasedUnitAndMassUnit_Create() -> "opencascade::handle< StepBasic_ConversionBasedUnitAndMassUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndMassUnit_Create()

def Handle_StepBasic_ConversionBasedUnitAndMassUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ConversionBasedUnitAndMassUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndMassUnit_DownCast(t)

def Handle_StepBasic_ConversionBasedUnitAndMassUnit_IsNull(t: "opencascade::handle< StepBasic_ConversionBasedUnitAndMassUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndMassUnit_IsNull(t)

def Handle_StepBasic_ConversionBasedUnitAndPlaneAngleUnit_Create() -> "opencascade::handle< StepBasic_ConversionBasedUnitAndPlaneAngleUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndPlaneAngleUnit_Create()

def Handle_StepBasic_ConversionBasedUnitAndPlaneAngleUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ConversionBasedUnitAndPlaneAngleUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndPlaneAngleUnit_DownCast(t)

def Handle_StepBasic_ConversionBasedUnitAndPlaneAngleUnit_IsNull(t: "opencascade::handle< StepBasic_ConversionBasedUnitAndPlaneAngleUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndPlaneAngleUnit_IsNull(t)

def Handle_StepBasic_ConversionBasedUnitAndRatioUnit_Create() -> "opencascade::handle< StepBasic_ConversionBasedUnitAndRatioUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndRatioUnit_Create()

def Handle_StepBasic_ConversionBasedUnitAndRatioUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ConversionBasedUnitAndRatioUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndRatioUnit_DownCast(t)

def Handle_StepBasic_ConversionBasedUnitAndRatioUnit_IsNull(t: "opencascade::handle< StepBasic_ConversionBasedUnitAndRatioUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndRatioUnit_IsNull(t)

def Handle_StepBasic_ConversionBasedUnitAndSolidAngleUnit_Create() -> "opencascade::handle< StepBasic_ConversionBasedUnitAndSolidAngleUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndSolidAngleUnit_Create()

def Handle_StepBasic_ConversionBasedUnitAndSolidAngleUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ConversionBasedUnitAndSolidAngleUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndSolidAngleUnit_DownCast(t)

def Handle_StepBasic_ConversionBasedUnitAndSolidAngleUnit_IsNull(t: "opencascade::handle< StepBasic_ConversionBasedUnitAndSolidAngleUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndSolidAngleUnit_IsNull(t)

def Handle_StepBasic_ConversionBasedUnitAndTimeUnit_Create() -> "opencascade::handle< StepBasic_ConversionBasedUnitAndTimeUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndTimeUnit_Create()

def Handle_StepBasic_ConversionBasedUnitAndTimeUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ConversionBasedUnitAndTimeUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndTimeUnit_DownCast(t)

def Handle_StepBasic_ConversionBasedUnitAndTimeUnit_IsNull(t: "opencascade::handle< StepBasic_ConversionBasedUnitAndTimeUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndTimeUnit_IsNull(t)

def Handle_StepBasic_ConversionBasedUnitAndVolumeUnit_Create() -> "opencascade::handle< StepBasic_ConversionBasedUnitAndVolumeUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndVolumeUnit_Create()

def Handle_StepBasic_ConversionBasedUnitAndVolumeUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ConversionBasedUnitAndVolumeUnit >":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndVolumeUnit_DownCast(t)

def Handle_StepBasic_ConversionBasedUnitAndVolumeUnit_IsNull(t: "opencascade::handle< StepBasic_ConversionBasedUnitAndVolumeUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ConversionBasedUnitAndVolumeUnit_IsNull(t)

def Handle_StepBasic_DesignContext_Create() -> "opencascade::handle< StepBasic_DesignContext >":
    return _StepBasic.Handle_StepBasic_DesignContext_Create()

def Handle_StepBasic_DesignContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_DesignContext >":
    return _StepBasic.Handle_StepBasic_DesignContext_DownCast(t)

def Handle_StepBasic_DesignContext_IsNull(t: "opencascade::handle< StepBasic_DesignContext > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_DesignContext_IsNull(t)

def Handle_StepBasic_MechanicalContext_Create() -> "opencascade::handle< StepBasic_MechanicalContext >":
    return _StepBasic.Handle_StepBasic_MechanicalContext_Create()

def Handle_StepBasic_MechanicalContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_MechanicalContext >":
    return _StepBasic.Handle_StepBasic_MechanicalContext_DownCast(t)

def Handle_StepBasic_MechanicalContext_IsNull(t: "opencascade::handle< StepBasic_MechanicalContext > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_MechanicalContext_IsNull(t)

def Handle_StepBasic_ProductType_Create() -> "opencascade::handle< StepBasic_ProductType >":
    return _StepBasic.Handle_StepBasic_ProductType_Create()

def Handle_StepBasic_ProductType_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_ProductType >":
    return _StepBasic.Handle_StepBasic_ProductType_DownCast(t)

def Handle_StepBasic_ProductType_IsNull(t: "opencascade::handle< StepBasic_ProductType > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_ProductType_IsNull(t)

def Handle_StepBasic_SiUnitAndAreaUnit_Create() -> "opencascade::handle< StepBasic_SiUnitAndAreaUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndAreaUnit_Create()

def Handle_StepBasic_SiUnitAndAreaUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SiUnitAndAreaUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndAreaUnit_DownCast(t)

def Handle_StepBasic_SiUnitAndAreaUnit_IsNull(t: "opencascade::handle< StepBasic_SiUnitAndAreaUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SiUnitAndAreaUnit_IsNull(t)

def Handle_StepBasic_SiUnitAndLengthUnit_Create() -> "opencascade::handle< StepBasic_SiUnitAndLengthUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndLengthUnit_Create()

def Handle_StepBasic_SiUnitAndLengthUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SiUnitAndLengthUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndLengthUnit_DownCast(t)

def Handle_StepBasic_SiUnitAndLengthUnit_IsNull(t: "opencascade::handle< StepBasic_SiUnitAndLengthUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SiUnitAndLengthUnit_IsNull(t)

def Handle_StepBasic_SiUnitAndMassUnit_Create() -> "opencascade::handle< StepBasic_SiUnitAndMassUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndMassUnit_Create()

def Handle_StepBasic_SiUnitAndMassUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SiUnitAndMassUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndMassUnit_DownCast(t)

def Handle_StepBasic_SiUnitAndMassUnit_IsNull(t: "opencascade::handle< StepBasic_SiUnitAndMassUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SiUnitAndMassUnit_IsNull(t)

def Handle_StepBasic_SiUnitAndPlaneAngleUnit_Create() -> "opencascade::handle< StepBasic_SiUnitAndPlaneAngleUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndPlaneAngleUnit_Create()

def Handle_StepBasic_SiUnitAndPlaneAngleUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SiUnitAndPlaneAngleUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndPlaneAngleUnit_DownCast(t)

def Handle_StepBasic_SiUnitAndPlaneAngleUnit_IsNull(t: "opencascade::handle< StepBasic_SiUnitAndPlaneAngleUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SiUnitAndPlaneAngleUnit_IsNull(t)

def Handle_StepBasic_SiUnitAndRatioUnit_Create() -> "opencascade::handle< StepBasic_SiUnitAndRatioUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndRatioUnit_Create()

def Handle_StepBasic_SiUnitAndRatioUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SiUnitAndRatioUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndRatioUnit_DownCast(t)

def Handle_StepBasic_SiUnitAndRatioUnit_IsNull(t: "opencascade::handle< StepBasic_SiUnitAndRatioUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SiUnitAndRatioUnit_IsNull(t)

def Handle_StepBasic_SiUnitAndSolidAngleUnit_Create() -> "opencascade::handle< StepBasic_SiUnitAndSolidAngleUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndSolidAngleUnit_Create()

def Handle_StepBasic_SiUnitAndSolidAngleUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SiUnitAndSolidAngleUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndSolidAngleUnit_DownCast(t)

def Handle_StepBasic_SiUnitAndSolidAngleUnit_IsNull(t: "opencascade::handle< StepBasic_SiUnitAndSolidAngleUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SiUnitAndSolidAngleUnit_IsNull(t)

def Handle_StepBasic_SiUnitAndThermodynamicTemperatureUnit_Create() -> "opencascade::handle< StepBasic_SiUnitAndThermodynamicTemperatureUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndThermodynamicTemperatureUnit_Create()

def Handle_StepBasic_SiUnitAndThermodynamicTemperatureUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SiUnitAndThermodynamicTemperatureUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndThermodynamicTemperatureUnit_DownCast(t)

def Handle_StepBasic_SiUnitAndThermodynamicTemperatureUnit_IsNull(t: "opencascade::handle< StepBasic_SiUnitAndThermodynamicTemperatureUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SiUnitAndThermodynamicTemperatureUnit_IsNull(t)

def Handle_StepBasic_SiUnitAndTimeUnit_Create() -> "opencascade::handle< StepBasic_SiUnitAndTimeUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndTimeUnit_Create()

def Handle_StepBasic_SiUnitAndTimeUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SiUnitAndTimeUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndTimeUnit_DownCast(t)

def Handle_StepBasic_SiUnitAndTimeUnit_IsNull(t: "opencascade::handle< StepBasic_SiUnitAndTimeUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SiUnitAndTimeUnit_IsNull(t)

def Handle_StepBasic_SiUnitAndVolumeUnit_Create() -> "opencascade::handle< StepBasic_SiUnitAndVolumeUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndVolumeUnit_Create()

def Handle_StepBasic_SiUnitAndVolumeUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_SiUnitAndVolumeUnit >":
    return _StepBasic.Handle_StepBasic_SiUnitAndVolumeUnit_DownCast(t)

def Handle_StepBasic_SiUnitAndVolumeUnit_IsNull(t: "opencascade::handle< StepBasic_SiUnitAndVolumeUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_SiUnitAndVolumeUnit_IsNull(t)

def Handle_StepBasic_HArray1OfOrganization_Create() -> "opencascade::handle< StepBasic_HArray1OfOrganization >":
    return _StepBasic.Handle_StepBasic_HArray1OfOrganization_Create()

def Handle_StepBasic_HArray1OfOrganization_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_HArray1OfOrganization >":
    return _StepBasic.Handle_StepBasic_HArray1OfOrganization_DownCast(t)

def Handle_StepBasic_HArray1OfOrganization_IsNull(t: "opencascade::handle< StepBasic_HArray1OfOrganization > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_HArray1OfOrganization_IsNull(t)

def Handle_StepBasic_HArray1OfProductDefinition_Create() -> "opencascade::handle< StepBasic_HArray1OfProductDefinition >":
    return _StepBasic.Handle_StepBasic_HArray1OfProductDefinition_Create()

def Handle_StepBasic_HArray1OfProductDefinition_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_HArray1OfProductDefinition >":
    return _StepBasic.Handle_StepBasic_HArray1OfProductDefinition_DownCast(t)

def Handle_StepBasic_HArray1OfProductDefinition_IsNull(t: "opencascade::handle< StepBasic_HArray1OfProductDefinition > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_HArray1OfProductDefinition_IsNull(t)

def Handle_StepBasic_HArray1OfDerivedUnitElement_Create() -> "opencascade::handle< StepBasic_HArray1OfDerivedUnitElement >":
    return _StepBasic.Handle_StepBasic_HArray1OfDerivedUnitElement_Create()

def Handle_StepBasic_HArray1OfDerivedUnitElement_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_HArray1OfDerivedUnitElement >":
    return _StepBasic.Handle_StepBasic_HArray1OfDerivedUnitElement_DownCast(t)

def Handle_StepBasic_HArray1OfDerivedUnitElement_IsNull(t: "opencascade::handle< StepBasic_HArray1OfDerivedUnitElement > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_HArray1OfDerivedUnitElement_IsNull(t)

def Handle_StepBasic_HArray1OfPerson_Create() -> "opencascade::handle< StepBasic_HArray1OfPerson >":
    return _StepBasic.Handle_StepBasic_HArray1OfPerson_Create()

def Handle_StepBasic_HArray1OfPerson_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_HArray1OfPerson >":
    return _StepBasic.Handle_StepBasic_HArray1OfPerson_DownCast(t)

def Handle_StepBasic_HArray1OfPerson_IsNull(t: "opencascade::handle< StepBasic_HArray1OfPerson > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_HArray1OfPerson_IsNull(t)

def Handle_StepBasic_HArray1OfUncertaintyMeasureWithUnit_Create() -> "opencascade::handle< StepBasic_HArray1OfUncertaintyMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_HArray1OfUncertaintyMeasureWithUnit_Create()

def Handle_StepBasic_HArray1OfUncertaintyMeasureWithUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_HArray1OfUncertaintyMeasureWithUnit >":
    return _StepBasic.Handle_StepBasic_HArray1OfUncertaintyMeasureWithUnit_DownCast(t)

def Handle_StepBasic_HArray1OfUncertaintyMeasureWithUnit_IsNull(t: "opencascade::handle< StepBasic_HArray1OfUncertaintyMeasureWithUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_HArray1OfUncertaintyMeasureWithUnit_IsNull(t)

def Handle_StepBasic_HArray1OfApproval_Create() -> "opencascade::handle< StepBasic_HArray1OfApproval >":
    return _StepBasic.Handle_StepBasic_HArray1OfApproval_Create()

def Handle_StepBasic_HArray1OfApproval_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_HArray1OfApproval >":
    return _StepBasic.Handle_StepBasic_HArray1OfApproval_DownCast(t)

def Handle_StepBasic_HArray1OfApproval_IsNull(t: "opencascade::handle< StepBasic_HArray1OfApproval > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_HArray1OfApproval_IsNull(t)

def Handle_StepBasic_HArray1OfNamedUnit_Create() -> "opencascade::handle< StepBasic_HArray1OfNamedUnit >":
    return _StepBasic.Handle_StepBasic_HArray1OfNamedUnit_Create()

def Handle_StepBasic_HArray1OfNamedUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_HArray1OfNamedUnit >":
    return _StepBasic.Handle_StepBasic_HArray1OfNamedUnit_DownCast(t)

def Handle_StepBasic_HArray1OfNamedUnit_IsNull(t: "opencascade::handle< StepBasic_HArray1OfNamedUnit > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_HArray1OfNamedUnit_IsNull(t)

def Handle_StepBasic_HArray1OfProductContext_Create() -> "opencascade::handle< StepBasic_HArray1OfProductContext >":
    return _StepBasic.Handle_StepBasic_HArray1OfProductContext_Create()

def Handle_StepBasic_HArray1OfProductContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_HArray1OfProductContext >":
    return _StepBasic.Handle_StepBasic_HArray1OfProductContext_DownCast(t)

def Handle_StepBasic_HArray1OfProductContext_IsNull(t: "opencascade::handle< StepBasic_HArray1OfProductContext > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_HArray1OfProductContext_IsNull(t)

def Handle_StepBasic_HArray1OfDocument_Create() -> "opencascade::handle< StepBasic_HArray1OfDocument >":
    return _StepBasic.Handle_StepBasic_HArray1OfDocument_Create()

def Handle_StepBasic_HArray1OfDocument_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_HArray1OfDocument >":
    return _StepBasic.Handle_StepBasic_HArray1OfDocument_DownCast(t)

def Handle_StepBasic_HArray1OfDocument_IsNull(t: "opencascade::handle< StepBasic_HArray1OfDocument > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_HArray1OfDocument_IsNull(t)

def Handle_StepBasic_HArray1OfProduct_Create() -> "opencascade::handle< StepBasic_HArray1OfProduct >":
    return _StepBasic.Handle_StepBasic_HArray1OfProduct_Create()

def Handle_StepBasic_HArray1OfProduct_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepBasic_HArray1OfProduct >":
    return _StepBasic.Handle_StepBasic_HArray1OfProduct_DownCast(t)

def Handle_StepBasic_HArray1OfProduct_IsNull(t: "opencascade::handle< StepBasic_HArray1OfProduct > const &") -> "bool":
    return _StepBasic.Handle_StepBasic_HArray1OfProduct_IsNull(t)
class StepBasic_Array1OfApproval(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Approval > >::iterator":
        return _StepBasic.StepBasic_Array1OfApproval_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Approval > >::iterator":
        return _StepBasic.StepBasic_Array1OfApproval_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Approval > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfApproval_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Approval > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfApproval_cend(self)

    def __init__(self, *args):
        _StepBasic.StepBasic_Array1OfApproval_swiginit(self, _StepBasic.new_StepBasic_Array1OfApproval(*args))

    def Init(self, theValue: "opencascade::handle< StepBasic_Approval > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfApproval_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfApproval_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfApproval_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfApproval_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfApproval_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfApproval_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfApproval_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfApproval_IsAllocated(self)

    def Assign(self, theOther: "StepBasic_Array1OfApproval") -> "NCollection_Array1< opencascade::handle< StepBasic_Approval > > &":
        return _StepBasic.StepBasic_Array1OfApproval_Assign(self, theOther)

    def Move(self, theOther: "StepBasic_Array1OfApproval") -> "NCollection_Array1< opencascade::handle< StepBasic_Approval > > &":
        return _StepBasic.StepBasic_Array1OfApproval_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepBasic_Approval > > &":
        return _StepBasic.StepBasic_Array1OfApproval_Set(self, *args)

    def First(self) -> "opencascade::handle< StepBasic_Approval > const &":
        return _StepBasic.StepBasic_Array1OfApproval_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepBasic_Approval > &":
        return _StepBasic.StepBasic_Array1OfApproval_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepBasic_Approval > const &":
        return _StepBasic.StepBasic_Array1OfApproval_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepBasic_Approval > &":
        return _StepBasic.StepBasic_Array1OfApproval_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_Approval > const &":
        return _StepBasic.StepBasic_Array1OfApproval_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_Approval > &":
        return _StepBasic.StepBasic_Array1OfApproval_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepBasic_Approval > &":
        return _StepBasic.StepBasic_Array1OfApproval___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepBasic_Approval > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfApproval_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepBasic.StepBasic_Array1OfApproval_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepBasic.delete_StepBasic_Array1OfApproval

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepBasic_Array1OfApproval in _StepBasic:
_StepBasic.StepBasic_Array1OfApproval_swigregister(StepBasic_Array1OfApproval)

class StepBasic_Array1OfDerivedUnitElement(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_DerivedUnitElement > >::iterator":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepBasic_DerivedUnitElement > >::iterator":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_DerivedUnitElement > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepBasic_DerivedUnitElement > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_cend(self)

    def __init__(self, *args):
        _StepBasic.StepBasic_Array1OfDerivedUnitElement_swiginit(self, _StepBasic.new_StepBasic_Array1OfDerivedUnitElement(*args))

    def Init(self, theValue: "opencascade::handle< StepBasic_DerivedUnitElement > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_IsAllocated(self)

    def Assign(self, theOther: "StepBasic_Array1OfDerivedUnitElement") -> "NCollection_Array1< opencascade::handle< StepBasic_DerivedUnitElement > > &":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_Assign(self, theOther)

    def Move(self, theOther: "StepBasic_Array1OfDerivedUnitElement") -> "NCollection_Array1< opencascade::handle< StepBasic_DerivedUnitElement > > &":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepBasic_DerivedUnitElement > > &":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_Set(self, *args)

    def First(self) -> "opencascade::handle< StepBasic_DerivedUnitElement > const &":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepBasic_DerivedUnitElement > &":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepBasic_DerivedUnitElement > const &":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepBasic_DerivedUnitElement > &":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_DerivedUnitElement > const &":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_DerivedUnitElement > &":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepBasic_DerivedUnitElement > &":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepBasic_DerivedUnitElement > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepBasic.StepBasic_Array1OfDerivedUnitElement_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepBasic.delete_StepBasic_Array1OfDerivedUnitElement

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepBasic_Array1OfDerivedUnitElement in _StepBasic:
_StepBasic.StepBasic_Array1OfDerivedUnitElement_swigregister(StepBasic_Array1OfDerivedUnitElement)

class StepBasic_Array1OfDocument(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Document > >::iterator":
        return _StepBasic.StepBasic_Array1OfDocument_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Document > >::iterator":
        return _StepBasic.StepBasic_Array1OfDocument_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Document > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfDocument_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Document > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfDocument_cend(self)

    def __init__(self, *args):
        _StepBasic.StepBasic_Array1OfDocument_swiginit(self, _StepBasic.new_StepBasic_Array1OfDocument(*args))

    def Init(self, theValue: "opencascade::handle< StepBasic_Document > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfDocument_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfDocument_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfDocument_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfDocument_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfDocument_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfDocument_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfDocument_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfDocument_IsAllocated(self)

    def Assign(self, theOther: "StepBasic_Array1OfDocument") -> "NCollection_Array1< opencascade::handle< StepBasic_Document > > &":
        return _StepBasic.StepBasic_Array1OfDocument_Assign(self, theOther)

    def Move(self, theOther: "StepBasic_Array1OfDocument") -> "NCollection_Array1< opencascade::handle< StepBasic_Document > > &":
        return _StepBasic.StepBasic_Array1OfDocument_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepBasic_Document > > &":
        return _StepBasic.StepBasic_Array1OfDocument_Set(self, *args)

    def First(self) -> "opencascade::handle< StepBasic_Document > const &":
        return _StepBasic.StepBasic_Array1OfDocument_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepBasic_Document > &":
        return _StepBasic.StepBasic_Array1OfDocument_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepBasic_Document > const &":
        return _StepBasic.StepBasic_Array1OfDocument_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepBasic_Document > &":
        return _StepBasic.StepBasic_Array1OfDocument_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_Document > const &":
        return _StepBasic.StepBasic_Array1OfDocument_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_Document > &":
        return _StepBasic.StepBasic_Array1OfDocument_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepBasic_Document > &":
        return _StepBasic.StepBasic_Array1OfDocument___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepBasic_Document > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfDocument_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepBasic.StepBasic_Array1OfDocument_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepBasic.delete_StepBasic_Array1OfDocument

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepBasic_Array1OfDocument in _StepBasic:
_StepBasic.StepBasic_Array1OfDocument_swigregister(StepBasic_Array1OfDocument)

class StepBasic_Array1OfNamedUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_NamedUnit > >::iterator":
        return _StepBasic.StepBasic_Array1OfNamedUnit_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepBasic_NamedUnit > >::iterator":
        return _StepBasic.StepBasic_Array1OfNamedUnit_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_NamedUnit > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfNamedUnit_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepBasic_NamedUnit > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfNamedUnit_cend(self)

    def __init__(self, *args):
        _StepBasic.StepBasic_Array1OfNamedUnit_swiginit(self, _StepBasic.new_StepBasic_Array1OfNamedUnit(*args))

    def Init(self, theValue: "opencascade::handle< StepBasic_NamedUnit > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfNamedUnit_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfNamedUnit_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfNamedUnit_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfNamedUnit_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfNamedUnit_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfNamedUnit_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfNamedUnit_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfNamedUnit_IsAllocated(self)

    def Assign(self, theOther: "StepBasic_Array1OfNamedUnit") -> "NCollection_Array1< opencascade::handle< StepBasic_NamedUnit > > &":
        return _StepBasic.StepBasic_Array1OfNamedUnit_Assign(self, theOther)

    def Move(self, theOther: "StepBasic_Array1OfNamedUnit") -> "NCollection_Array1< opencascade::handle< StepBasic_NamedUnit > > &":
        return _StepBasic.StepBasic_Array1OfNamedUnit_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepBasic_NamedUnit > > &":
        return _StepBasic.StepBasic_Array1OfNamedUnit_Set(self, *args)

    def First(self) -> "opencascade::handle< StepBasic_NamedUnit > const &":
        return _StepBasic.StepBasic_Array1OfNamedUnit_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepBasic_NamedUnit > &":
        return _StepBasic.StepBasic_Array1OfNamedUnit_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepBasic_NamedUnit > const &":
        return _StepBasic.StepBasic_Array1OfNamedUnit_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepBasic_NamedUnit > &":
        return _StepBasic.StepBasic_Array1OfNamedUnit_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_NamedUnit > const &":
        return _StepBasic.StepBasic_Array1OfNamedUnit_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_NamedUnit > &":
        return _StepBasic.StepBasic_Array1OfNamedUnit_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepBasic_NamedUnit > &":
        return _StepBasic.StepBasic_Array1OfNamedUnit___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepBasic_NamedUnit > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfNamedUnit_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepBasic.StepBasic_Array1OfNamedUnit_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepBasic.delete_StepBasic_Array1OfNamedUnit

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepBasic_Array1OfNamedUnit in _StepBasic:
_StepBasic.StepBasic_Array1OfNamedUnit_swigregister(StepBasic_Array1OfNamedUnit)

class StepBasic_Array1OfOrganization(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Organization > >::iterator":
        return _StepBasic.StepBasic_Array1OfOrganization_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Organization > >::iterator":
        return _StepBasic.StepBasic_Array1OfOrganization_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Organization > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfOrganization_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Organization > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfOrganization_cend(self)

    def __init__(self, *args):
        _StepBasic.StepBasic_Array1OfOrganization_swiginit(self, _StepBasic.new_StepBasic_Array1OfOrganization(*args))

    def Init(self, theValue: "opencascade::handle< StepBasic_Organization > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfOrganization_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfOrganization_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfOrganization_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfOrganization_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfOrganization_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfOrganization_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfOrganization_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfOrganization_IsAllocated(self)

    def Assign(self, theOther: "StepBasic_Array1OfOrganization") -> "NCollection_Array1< opencascade::handle< StepBasic_Organization > > &":
        return _StepBasic.StepBasic_Array1OfOrganization_Assign(self, theOther)

    def Move(self, theOther: "StepBasic_Array1OfOrganization") -> "NCollection_Array1< opencascade::handle< StepBasic_Organization > > &":
        return _StepBasic.StepBasic_Array1OfOrganization_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepBasic_Organization > > &":
        return _StepBasic.StepBasic_Array1OfOrganization_Set(self, *args)

    def First(self) -> "opencascade::handle< StepBasic_Organization > const &":
        return _StepBasic.StepBasic_Array1OfOrganization_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepBasic_Organization > &":
        return _StepBasic.StepBasic_Array1OfOrganization_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepBasic_Organization > const &":
        return _StepBasic.StepBasic_Array1OfOrganization_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepBasic_Organization > &":
        return _StepBasic.StepBasic_Array1OfOrganization_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_Organization > const &":
        return _StepBasic.StepBasic_Array1OfOrganization_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_Organization > &":
        return _StepBasic.StepBasic_Array1OfOrganization_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepBasic_Organization > &":
        return _StepBasic.StepBasic_Array1OfOrganization___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepBasic_Organization > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfOrganization_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepBasic.StepBasic_Array1OfOrganization_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepBasic.delete_StepBasic_Array1OfOrganization

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepBasic_Array1OfOrganization in _StepBasic:
_StepBasic.StepBasic_Array1OfOrganization_swigregister(StepBasic_Array1OfOrganization)

class StepBasic_Array1OfPerson(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Person > >::iterator":
        return _StepBasic.StepBasic_Array1OfPerson_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Person > >::iterator":
        return _StepBasic.StepBasic_Array1OfPerson_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Person > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfPerson_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Person > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfPerson_cend(self)

    def __init__(self, *args):
        _StepBasic.StepBasic_Array1OfPerson_swiginit(self, _StepBasic.new_StepBasic_Array1OfPerson(*args))

    def Init(self, theValue: "opencascade::handle< StepBasic_Person > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfPerson_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfPerson_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfPerson_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfPerson_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfPerson_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfPerson_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfPerson_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfPerson_IsAllocated(self)

    def Assign(self, theOther: "StepBasic_Array1OfPerson") -> "NCollection_Array1< opencascade::handle< StepBasic_Person > > &":
        return _StepBasic.StepBasic_Array1OfPerson_Assign(self, theOther)

    def Move(self, theOther: "StepBasic_Array1OfPerson") -> "NCollection_Array1< opencascade::handle< StepBasic_Person > > &":
        return _StepBasic.StepBasic_Array1OfPerson_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepBasic_Person > > &":
        return _StepBasic.StepBasic_Array1OfPerson_Set(self, *args)

    def First(self) -> "opencascade::handle< StepBasic_Person > const &":
        return _StepBasic.StepBasic_Array1OfPerson_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepBasic_Person > &":
        return _StepBasic.StepBasic_Array1OfPerson_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepBasic_Person > const &":
        return _StepBasic.StepBasic_Array1OfPerson_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepBasic_Person > &":
        return _StepBasic.StepBasic_Array1OfPerson_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_Person > const &":
        return _StepBasic.StepBasic_Array1OfPerson_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_Person > &":
        return _StepBasic.StepBasic_Array1OfPerson_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepBasic_Person > &":
        return _StepBasic.StepBasic_Array1OfPerson___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepBasic_Person > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfPerson_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepBasic.StepBasic_Array1OfPerson_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepBasic.delete_StepBasic_Array1OfPerson

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepBasic_Array1OfPerson in _StepBasic:
_StepBasic.StepBasic_Array1OfPerson_swigregister(StepBasic_Array1OfPerson)

class StepBasic_Array1OfProduct(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Product > >::iterator":
        return _StepBasic.StepBasic_Array1OfProduct_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Product > >::iterator":
        return _StepBasic.StepBasic_Array1OfProduct_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Product > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfProduct_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepBasic_Product > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfProduct_cend(self)

    def __init__(self, *args):
        _StepBasic.StepBasic_Array1OfProduct_swiginit(self, _StepBasic.new_StepBasic_Array1OfProduct(*args))

    def Init(self, theValue: "opencascade::handle< StepBasic_Product > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfProduct_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfProduct_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfProduct_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfProduct_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfProduct_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfProduct_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfProduct_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfProduct_IsAllocated(self)

    def Assign(self, theOther: "StepBasic_Array1OfProduct") -> "NCollection_Array1< opencascade::handle< StepBasic_Product > > &":
        return _StepBasic.StepBasic_Array1OfProduct_Assign(self, theOther)

    def Move(self, theOther: "StepBasic_Array1OfProduct") -> "NCollection_Array1< opencascade::handle< StepBasic_Product > > &":
        return _StepBasic.StepBasic_Array1OfProduct_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepBasic_Product > > &":
        return _StepBasic.StepBasic_Array1OfProduct_Set(self, *args)

    def First(self) -> "opencascade::handle< StepBasic_Product > const &":
        return _StepBasic.StepBasic_Array1OfProduct_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepBasic_Product > &":
        return _StepBasic.StepBasic_Array1OfProduct_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepBasic_Product > const &":
        return _StepBasic.StepBasic_Array1OfProduct_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepBasic_Product > &":
        return _StepBasic.StepBasic_Array1OfProduct_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_Product > const &":
        return _StepBasic.StepBasic_Array1OfProduct_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_Product > &":
        return _StepBasic.StepBasic_Array1OfProduct_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepBasic_Product > &":
        return _StepBasic.StepBasic_Array1OfProduct___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepBasic_Product > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfProduct_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepBasic.StepBasic_Array1OfProduct_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepBasic.delete_StepBasic_Array1OfProduct

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepBasic_Array1OfProduct in _StepBasic:
_StepBasic.StepBasic_Array1OfProduct_swigregister(StepBasic_Array1OfProduct)

class StepBasic_Array1OfProductContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_ProductContext > >::iterator":
        return _StepBasic.StepBasic_Array1OfProductContext_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepBasic_ProductContext > >::iterator":
        return _StepBasic.StepBasic_Array1OfProductContext_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_ProductContext > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfProductContext_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepBasic_ProductContext > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfProductContext_cend(self)

    def __init__(self, *args):
        _StepBasic.StepBasic_Array1OfProductContext_swiginit(self, _StepBasic.new_StepBasic_Array1OfProductContext(*args))

    def Init(self, theValue: "opencascade::handle< StepBasic_ProductContext > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfProductContext_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfProductContext_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfProductContext_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfProductContext_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfProductContext_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfProductContext_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfProductContext_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfProductContext_IsAllocated(self)

    def Assign(self, theOther: "StepBasic_Array1OfProductContext") -> "NCollection_Array1< opencascade::handle< StepBasic_ProductContext > > &":
        return _StepBasic.StepBasic_Array1OfProductContext_Assign(self, theOther)

    def Move(self, theOther: "StepBasic_Array1OfProductContext") -> "NCollection_Array1< opencascade::handle< StepBasic_ProductContext > > &":
        return _StepBasic.StepBasic_Array1OfProductContext_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepBasic_ProductContext > > &":
        return _StepBasic.StepBasic_Array1OfProductContext_Set(self, *args)

    def First(self) -> "opencascade::handle< StepBasic_ProductContext > const &":
        return _StepBasic.StepBasic_Array1OfProductContext_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepBasic_ProductContext > &":
        return _StepBasic.StepBasic_Array1OfProductContext_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepBasic_ProductContext > const &":
        return _StepBasic.StepBasic_Array1OfProductContext_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepBasic_ProductContext > &":
        return _StepBasic.StepBasic_Array1OfProductContext_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_ProductContext > const &":
        return _StepBasic.StepBasic_Array1OfProductContext_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_ProductContext > &":
        return _StepBasic.StepBasic_Array1OfProductContext_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepBasic_ProductContext > &":
        return _StepBasic.StepBasic_Array1OfProductContext___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepBasic_ProductContext > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfProductContext_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepBasic.StepBasic_Array1OfProductContext_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepBasic.delete_StepBasic_Array1OfProductContext

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepBasic_Array1OfProductContext in _StepBasic:
_StepBasic.StepBasic_Array1OfProductContext_swigregister(StepBasic_Array1OfProductContext)

class StepBasic_Array1OfProductDefinition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_ProductDefinition > >::iterator":
        return _StepBasic.StepBasic_Array1OfProductDefinition_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepBasic_ProductDefinition > >::iterator":
        return _StepBasic.StepBasic_Array1OfProductDefinition_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_ProductDefinition > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfProductDefinition_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepBasic_ProductDefinition > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfProductDefinition_cend(self)

    def __init__(self, *args):
        _StepBasic.StepBasic_Array1OfProductDefinition_swiginit(self, _StepBasic.new_StepBasic_Array1OfProductDefinition(*args))

    def Init(self, theValue: "opencascade::handle< StepBasic_ProductDefinition > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfProductDefinition_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfProductDefinition_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfProductDefinition_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfProductDefinition_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfProductDefinition_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfProductDefinition_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfProductDefinition_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfProductDefinition_IsAllocated(self)

    def Assign(self, theOther: "StepBasic_Array1OfProductDefinition") -> "NCollection_Array1< opencascade::handle< StepBasic_ProductDefinition > > &":
        return _StepBasic.StepBasic_Array1OfProductDefinition_Assign(self, theOther)

    def Move(self, theOther: "StepBasic_Array1OfProductDefinition") -> "NCollection_Array1< opencascade::handle< StepBasic_ProductDefinition > > &":
        return _StepBasic.StepBasic_Array1OfProductDefinition_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepBasic_ProductDefinition > > &":
        return _StepBasic.StepBasic_Array1OfProductDefinition_Set(self, *args)

    def First(self) -> "opencascade::handle< StepBasic_ProductDefinition > const &":
        return _StepBasic.StepBasic_Array1OfProductDefinition_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepBasic_ProductDefinition > &":
        return _StepBasic.StepBasic_Array1OfProductDefinition_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepBasic_ProductDefinition > const &":
        return _StepBasic.StepBasic_Array1OfProductDefinition_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepBasic_ProductDefinition > &":
        return _StepBasic.StepBasic_Array1OfProductDefinition_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_ProductDefinition > const &":
        return _StepBasic.StepBasic_Array1OfProductDefinition_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_ProductDefinition > &":
        return _StepBasic.StepBasic_Array1OfProductDefinition_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition > &":
        return _StepBasic.StepBasic_Array1OfProductDefinition___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepBasic_ProductDefinition > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfProductDefinition_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepBasic.StepBasic_Array1OfProductDefinition_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepBasic.delete_StepBasic_Array1OfProductDefinition

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepBasic_Array1OfProductDefinition in _StepBasic:
_StepBasic.StepBasic_Array1OfProductDefinition_swigregister(StepBasic_Array1OfProductDefinition)

class StepBasic_Array1OfUncertaintyMeasureWithUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > >::iterator":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > >::iterator":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > >::const_iterator":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_cend(self)

    def __init__(self, *args):
        _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_swiginit(self, _StepBasic.new_StepBasic_Array1OfUncertaintyMeasureWithUnit(*args))

    def Init(self, theValue: "opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_IsAllocated(self)

    def Assign(self, theOther: "StepBasic_Array1OfUncertaintyMeasureWithUnit") -> "NCollection_Array1< opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > > &":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_Assign(self, theOther)

    def Move(self, theOther: "StepBasic_Array1OfUncertaintyMeasureWithUnit") -> "NCollection_Array1< opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > > &":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > > &":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_Set(self, *args)

    def First(self) -> "opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > const &":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > &":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > const &":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > &":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > const &":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > &":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > &":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepBasic_UncertaintyMeasureWithUnit > const &") -> "void":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepBasic.delete_StepBasic_Array1OfUncertaintyMeasureWithUnit

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepBasic_Array1OfUncertaintyMeasureWithUnit in _StepBasic:
_StepBasic.StepBasic_Array1OfUncertaintyMeasureWithUnit_swigregister(StepBasic_Array1OfUncertaintyMeasureWithUnit)

class StepBasic_Action(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_Action_swiginit(self, _StepBasic.new_StepBasic_Action(*args))

    def ChosenMethod(self, *args) -> "opencascade::handle< StepBasic_ActionMethod >":
        r"""
        Returns field chosenmethod.

        Returns
        -------
        opencascade::handle<StepBasic_ActionMethod>

        """
        return _StepBasic.StepBasic_Action_ChosenMethod(self, *args)

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Action_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Action_HasDescription(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString
        aChosenMethod: StepBasic_ActionMethod

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Action_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Action_Name(self, *args)

    def SetChosenMethod(self, *args) -> "void":
        r"""
        Set field chosenmethod.

        Parameters
        ----------
        ChosenMethod: StepBasic_ActionMethod

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Action_SetChosenMethod(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Action_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Action_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_Action_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_Action

# Register StepBasic_Action in _StepBasic:
_StepBasic.StepBasic_Action_swigregister(StepBasic_Action)

class StepBasic_ActionAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ActionAssignment_swiginit(self, _StepBasic.new_StepBasic_ActionAssignment(*args))

    def AssignedAction(self, *args) -> "opencascade::handle< StepBasic_Action >":
        r"""
        Returns field assignedaction.

        Returns
        -------
        opencascade::handle<StepBasic_Action>

        """
        return _StepBasic.StepBasic_ActionAssignment_AssignedAction(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aAssignedAction: StepBasic_Action

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ActionAssignment_Init(self, *args)

    def SetAssignedAction(self, *args) -> "void":
        r"""
        Set field assignedaction.

        Parameters
        ----------
        AssignedAction: StepBasic_Action

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ActionAssignment_SetAssignedAction(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ActionAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ActionAssignment

# Register StepBasic_ActionAssignment in _StepBasic:
_StepBasic.StepBasic_ActionAssignment_swigregister(StepBasic_ActionAssignment)

class StepBasic_ActionMethod(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ActionMethod_swiginit(self, _StepBasic.new_StepBasic_ActionMethod(*args))

    def Consequence(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field consequence.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ActionMethod_Consequence(self, *args)

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ActionMethod_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_ActionMethod_HasDescription(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString
        aConsequence: TCollection_HAsciiString
        aPurpose: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ActionMethod_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ActionMethod_Name(self, *args)

    def Purpose(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field purpose.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ActionMethod_Purpose(self, *args)

    def SetConsequence(self, *args) -> "void":
        r"""
        Set field consequence.

        Parameters
        ----------
        Consequence: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ActionMethod_SetConsequence(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ActionMethod_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ActionMethod_SetName(self, *args)

    def SetPurpose(self, *args) -> "void":
        r"""
        Set field purpose.

        Parameters
        ----------
        Purpose: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ActionMethod_SetPurpose(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ActionMethod_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ActionMethod

# Register StepBasic_ActionMethod in _StepBasic:
_StepBasic.StepBasic_ActionMethod_swigregister(StepBasic_ActionMethod)

class StepBasic_ActionRequestAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ActionRequestAssignment_swiginit(self, _StepBasic.new_StepBasic_ActionRequestAssignment(*args))

    def AssignedActionRequest(self, *args) -> "opencascade::handle< StepBasic_VersionedActionRequest >":
        r"""
        Returns field assignedactionrequest.

        Returns
        -------
        opencascade::handle<StepBasic_VersionedActionRequest>

        """
        return _StepBasic.StepBasic_ActionRequestAssignment_AssignedActionRequest(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aAssignedActionRequest: StepBasic_VersionedActionRequest

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ActionRequestAssignment_Init(self, *args)

    def SetAssignedActionRequest(self, *args) -> "void":
        r"""
        Set field assignedactionrequest.

        Parameters
        ----------
        AssignedActionRequest: StepBasic_VersionedActionRequest

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ActionRequestAssignment_SetAssignedActionRequest(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ActionRequestAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ActionRequestAssignment

# Register StepBasic_ActionRequestAssignment in _StepBasic:
_StepBasic.StepBasic_ActionRequestAssignment_swigregister(StepBasic_ActionRequestAssignment)

class StepBasic_ActionRequestSolution(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ActionRequestSolution_swiginit(self, _StepBasic.new_StepBasic_ActionRequestSolution(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aMethod: StepBasic_ActionMethod
        aRequest: StepBasic_VersionedActionRequest

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ActionRequestSolution_Init(self, *args)

    def Method(self, *args) -> "opencascade::handle< StepBasic_ActionMethod >":
        r"""
        Returns field method.

        Returns
        -------
        opencascade::handle<StepBasic_ActionMethod>

        """
        return _StepBasic.StepBasic_ActionRequestSolution_Method(self, *args)

    def Request(self, *args) -> "opencascade::handle< StepBasic_VersionedActionRequest >":
        r"""
        Returns field request.

        Returns
        -------
        opencascade::handle<StepBasic_VersionedActionRequest>

        """
        return _StepBasic.StepBasic_ActionRequestSolution_Request(self, *args)

    def SetMethod(self, *args) -> "void":
        r"""
        Set field method.

        Parameters
        ----------
        Method: StepBasic_ActionMethod

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ActionRequestSolution_SetMethod(self, *args)

    def SetRequest(self, *args) -> "void":
        r"""
        Set field request.

        Parameters
        ----------
        Request: StepBasic_VersionedActionRequest

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ActionRequestSolution_SetRequest(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ActionRequestSolution_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ActionRequestSolution

# Register StepBasic_ActionRequestSolution in _StepBasic:
_StepBasic.StepBasic_ActionRequestSolution_swigregister(StepBasic_ActionRequestSolution)

class StepBasic_Address(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a address.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_Address_swiginit(self, _StepBasic.new_StepBasic_Address(*args))

    def Country(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Address_Country(self, *args)

    def ElectronicMailAddress(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Address_ElectronicMailAddress(self, *args)

    def FacsimileNumber(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Address_FacsimileNumber(self, *args)

    def HasCountry(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Address_HasCountry(self, *args)

    def HasElectronicMailAddress(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Address_HasElectronicMailAddress(self, *args)

    def HasFacsimileNumber(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Address_HasFacsimileNumber(self, *args)

    def HasInternalLocation(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Address_HasInternalLocation(self, *args)

    def HasPostalBox(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Address_HasPostalBox(self, *args)

    def HasPostalCode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Address_HasPostalCode(self, *args)

    def HasRegion(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Address_HasRegion(self, *args)

    def HasStreet(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Address_HasStreet(self, *args)

    def HasStreetNumber(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Address_HasStreetNumber(self, *args)

    def HasTelephoneNumber(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Address_HasTelephoneNumber(self, *args)

    def HasTelexNumber(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Address_HasTelexNumber(self, *args)

    def HasTown(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Address_HasTown(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        hasAinternalLocation: bool
        aInternalLocation: TCollection_HAsciiString
        hasAstreetNumber: bool
        aStreetNumber: TCollection_HAsciiString
        hasAstreet: bool
        aStreet: TCollection_HAsciiString
        hasApostalBox: bool
        aPostalBox: TCollection_HAsciiString
        hasAtown: bool
        aTown: TCollection_HAsciiString
        hasAregion: bool
        aRegion: TCollection_HAsciiString
        hasApostalCode: bool
        aPostalCode: TCollection_HAsciiString
        hasAcountry: bool
        aCountry: TCollection_HAsciiString
        hasAfacsimileNumber: bool
        aFacsimileNumber: TCollection_HAsciiString
        hasAtelephoneNumber: bool
        aTelephoneNumber: TCollection_HAsciiString
        hasAelectronicMailAddress: bool
        aElectronicMailAddress: TCollection_HAsciiString
        hasAtelexNumber: bool
        aTelexNumber: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_Init(self, *args)

    def InternalLocation(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Address_InternalLocation(self, *args)

    def PostalBox(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Address_PostalBox(self, *args)

    def PostalCode(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Address_PostalCode(self, *args)

    def Region(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Address_Region(self, *args)

    def SetCountry(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aCountry: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_SetCountry(self, *args)

    def SetElectronicMailAddress(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aElectronicMailAddress: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_SetElectronicMailAddress(self, *args)

    def SetFacsimileNumber(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFacsimileNumber: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_SetFacsimileNumber(self, *args)

    def SetInternalLocation(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aInternalLocation: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_SetInternalLocation(self, *args)

    def SetPostalBox(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPostalBox: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_SetPostalBox(self, *args)

    def SetPostalCode(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPostalCode: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_SetPostalCode(self, *args)

    def SetRegion(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRegion: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_SetRegion(self, *args)

    def SetStreet(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStreet: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_SetStreet(self, *args)

    def SetStreetNumber(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStreetNumber: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_SetStreetNumber(self, *args)

    def SetTelephoneNumber(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aTelephoneNumber: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_SetTelephoneNumber(self, *args)

    def SetTelexNumber(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aTelexNumber: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_SetTelexNumber(self, *args)

    def SetTown(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aTown: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_SetTown(self, *args)

    def Street(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Address_Street(self, *args)

    def StreetNumber(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Address_StreetNumber(self, *args)

    def TelephoneNumber(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Address_TelephoneNumber(self, *args)

    def TelexNumber(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Address_TelexNumber(self, *args)

    def Town(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Address_Town(self, *args)

    def UnSetCountry(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_UnSetCountry(self, *args)

    def UnSetElectronicMailAddress(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_UnSetElectronicMailAddress(self, *args)

    def UnSetFacsimileNumber(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_UnSetFacsimileNumber(self, *args)

    def UnSetInternalLocation(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_UnSetInternalLocation(self, *args)

    def UnSetPostalBox(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_UnSetPostalBox(self, *args)

    def UnSetPostalCode(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_UnSetPostalCode(self, *args)

    def UnSetRegion(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_UnSetRegion(self, *args)

    def UnSetStreet(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_UnSetStreet(self, *args)

    def UnSetStreetNumber(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_UnSetStreetNumber(self, *args)

    def UnSetTelephoneNumber(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_UnSetTelephoneNumber(self, *args)

    def UnSetTelexNumber(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_UnSetTelexNumber(self, *args)

    def UnSetTown(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Address_UnSetTown(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_Address_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_Address

# Register StepBasic_Address in _StepBasic:
_StepBasic.StepBasic_Address_swigregister(StepBasic_Address)

class StepBasic_ApplicationContext(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a applicationcontext.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ApplicationContext_swiginit(self, _StepBasic.new_StepBasic_ApplicationContext(*args))

    def Application(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ApplicationContext_Application(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aApplication: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApplicationContext_Init(self, *args)

    def SetApplication(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aApplication: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApplicationContext_SetApplication(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ApplicationContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ApplicationContext

# Register StepBasic_ApplicationContext in _StepBasic:
_StepBasic.StepBasic_ApplicationContext_swigregister(StepBasic_ApplicationContext)

class StepBasic_ApplicationContextElement(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a applicationcontextelement.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ApplicationContextElement_swiginit(self, _StepBasic.new_StepBasic_ApplicationContextElement(*args))

    def FrameOfReference(self, *args) -> "opencascade::handle< StepBasic_ApplicationContext >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ApplicationContext>

        """
        return _StepBasic.StepBasic_ApplicationContextElement_FrameOfReference(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aFrameOfReference: StepBasic_ApplicationContext

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApplicationContextElement_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ApplicationContextElement_Name(self, *args)

    def SetFrameOfReference(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFrameOfReference: StepBasic_ApplicationContext

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApplicationContextElement_SetFrameOfReference(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApplicationContextElement_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ApplicationContextElement_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ApplicationContextElement

# Register StepBasic_ApplicationContextElement in _StepBasic:
_StepBasic.StepBasic_ApplicationContextElement_swigregister(StepBasic_ApplicationContextElement)

class StepBasic_ApplicationProtocolDefinition(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a applicationprotocoldefinition.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ApplicationProtocolDefinition_swiginit(self, _StepBasic.new_StepBasic_ApplicationProtocolDefinition(*args))

    def Application(self, *args) -> "opencascade::handle< StepBasic_ApplicationContext >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ApplicationContext>

        """
        return _StepBasic.StepBasic_ApplicationProtocolDefinition_Application(self, *args)

    def ApplicationInterpretedModelSchemaName(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ApplicationProtocolDefinition_ApplicationInterpretedModelSchemaName(self, *args)

    def ApplicationProtocolYear(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_ApplicationProtocolDefinition_ApplicationProtocolYear(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStatus: TCollection_HAsciiString
        aApplicationInterpretedModelSchemaName: TCollection_HAsciiString
        aApplicationProtocolYear: int
        aApplication: StepBasic_ApplicationContext

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApplicationProtocolDefinition_Init(self, *args)

    def SetApplication(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aApplication: StepBasic_ApplicationContext

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApplicationProtocolDefinition_SetApplication(self, *args)

    def SetApplicationInterpretedModelSchemaName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aApplicationInterpretedModelSchemaName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApplicationProtocolDefinition_SetApplicationInterpretedModelSchemaName(self, *args)

    def SetApplicationProtocolYear(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aApplicationProtocolYear: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApplicationProtocolDefinition_SetApplicationProtocolYear(self, *args)

    def SetStatus(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStatus: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApplicationProtocolDefinition_SetStatus(self, *args)

    def Status(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ApplicationProtocolDefinition_Status(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ApplicationProtocolDefinition_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ApplicationProtocolDefinition

# Register StepBasic_ApplicationProtocolDefinition in _StepBasic:
_StepBasic.StepBasic_ApplicationProtocolDefinition_swigregister(StepBasic_ApplicationProtocolDefinition)

class StepBasic_Approval(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a approval.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_Approval_swiginit(self, _StepBasic.new_StepBasic_Approval(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStatus: StepBasic_ApprovalStatus
        aLevel: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Approval_Init(self, *args)

    def Level(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Approval_Level(self, *args)

    def SetLevel(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLevel: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Approval_SetLevel(self, *args)

    def SetStatus(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStatus: StepBasic_ApprovalStatus

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Approval_SetStatus(self, *args)

    def Status(self, *args) -> "opencascade::handle< StepBasic_ApprovalStatus >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ApprovalStatus>

        """
        return _StepBasic.StepBasic_Approval_Status(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_Approval_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_Approval

# Register StepBasic_Approval in _StepBasic:
_StepBasic.StepBasic_Approval_swigregister(StepBasic_Approval)

class StepBasic_ApprovalAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def AssignedApproval(self, *args) -> "opencascade::handle< StepBasic_Approval >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Approval>

        """
        return _StepBasic.StepBasic_ApprovalAssignment_AssignedApproval(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedApproval: StepBasic_Approval

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalAssignment_Init(self, *args)

    def SetAssignedApproval(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedApproval: StepBasic_Approval

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalAssignment_SetAssignedApproval(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ApprovalAssignment_DownCast(t)


    __repr__ = _dumps_object


    def __init__(self):
        _StepBasic.StepBasic_ApprovalAssignment_swiginit(self, _StepBasic.new_StepBasic_ApprovalAssignment())
    __swig_destroy__ = _StepBasic.delete_StepBasic_ApprovalAssignment

# Register StepBasic_ApprovalAssignment in _StepBasic:
_StepBasic.StepBasic_ApprovalAssignment_swigregister(StepBasic_ApprovalAssignment)

class StepBasic_ApprovalDateTime(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ApprovalDateTime_swiginit(self, _StepBasic.new_StepBasic_ApprovalDateTime(*args))

    def DateTime(self, *args) -> "StepBasic_DateTimeSelect":
        r"""
        No available documentation.

        Returns
        -------
        StepBasic_DateTimeSelect

        """
        return _StepBasic.StepBasic_ApprovalDateTime_DateTime(self, *args)

    def DatedApproval(self, *args) -> "opencascade::handle< StepBasic_Approval >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Approval>

        """
        return _StepBasic.StepBasic_ApprovalDateTime_DatedApproval(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDateTime: StepBasic_DateTimeSelect
        aDatedApproval: StepBasic_Approval

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalDateTime_Init(self, *args)

    def SetDateTime(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDateTime: StepBasic_DateTimeSelect

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalDateTime_SetDateTime(self, *args)

    def SetDatedApproval(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDatedApproval: StepBasic_Approval

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalDateTime_SetDatedApproval(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ApprovalDateTime_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ApprovalDateTime

# Register StepBasic_ApprovalDateTime in _StepBasic:
_StepBasic.StepBasic_ApprovalDateTime_swigregister(StepBasic_ApprovalDateTime)

class StepBasic_ApprovalPersonOrganization(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a approvalpersonorganization.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ApprovalPersonOrganization_swiginit(self, _StepBasic.new_StepBasic_ApprovalPersonOrganization(*args))

    def AuthorizedApproval(self, *args) -> "opencascade::handle< StepBasic_Approval >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Approval>

        """
        return _StepBasic.StepBasic_ApprovalPersonOrganization_AuthorizedApproval(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPersonOrganization: StepBasic_PersonOrganizationSelect
        aAuthorizedApproval: StepBasic_Approval
        aRole: StepBasic_ApprovalRole

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalPersonOrganization_Init(self, *args)

    def PersonOrganization(self, *args) -> "StepBasic_PersonOrganizationSelect":
        r"""
        No available documentation.

        Returns
        -------
        StepBasic_PersonOrganizationSelect

        """
        return _StepBasic.StepBasic_ApprovalPersonOrganization_PersonOrganization(self, *args)

    def Role(self, *args) -> "opencascade::handle< StepBasic_ApprovalRole >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ApprovalRole>

        """
        return _StepBasic.StepBasic_ApprovalPersonOrganization_Role(self, *args)

    def SetAuthorizedApproval(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAuthorizedApproval: StepBasic_Approval

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalPersonOrganization_SetAuthorizedApproval(self, *args)

    def SetPersonOrganization(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPersonOrganization: StepBasic_PersonOrganizationSelect

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalPersonOrganization_SetPersonOrganization(self, *args)

    def SetRole(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRole: StepBasic_ApprovalRole

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalPersonOrganization_SetRole(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ApprovalPersonOrganization_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ApprovalPersonOrganization

# Register StepBasic_ApprovalPersonOrganization in _StepBasic:
_StepBasic.StepBasic_ApprovalPersonOrganization_swigregister(StepBasic_ApprovalPersonOrganization)

class StepBasic_ApprovalRelationship(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a approvalrelationship.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ApprovalRelationship_swiginit(self, _StepBasic.new_StepBasic_ApprovalRelationship(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ApprovalRelationship_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aRelatingApproval: StepBasic_Approval
        aRelatedApproval: StepBasic_Approval

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalRelationship_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ApprovalRelationship_Name(self, *args)

    def RelatedApproval(self, *args) -> "opencascade::handle< StepBasic_Approval >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Approval>

        """
        return _StepBasic.StepBasic_ApprovalRelationship_RelatedApproval(self, *args)

    def RelatingApproval(self, *args) -> "opencascade::handle< StepBasic_Approval >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Approval>

        """
        return _StepBasic.StepBasic_ApprovalRelationship_RelatingApproval(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalRelationship_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalRelationship_SetName(self, *args)

    def SetRelatedApproval(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRelatedApproval: StepBasic_Approval

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalRelationship_SetRelatedApproval(self, *args)

    def SetRelatingApproval(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRelatingApproval: StepBasic_Approval

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalRelationship_SetRelatingApproval(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ApprovalRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ApprovalRelationship

# Register StepBasic_ApprovalRelationship in _StepBasic:
_StepBasic.StepBasic_ApprovalRelationship_swigregister(StepBasic_ApprovalRelationship)

class StepBasic_ApprovalRole(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a approvalrole.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ApprovalRole_swiginit(self, _StepBasic.new_StepBasic_ApprovalRole(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRole: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalRole_Init(self, *args)

    def Role(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ApprovalRole_Role(self, *args)

    def SetRole(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRole: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalRole_SetRole(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ApprovalRole_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ApprovalRole

# Register StepBasic_ApprovalRole in _StepBasic:
_StepBasic.StepBasic_ApprovalRole_swigregister(StepBasic_ApprovalRole)

class StepBasic_ApprovalStatus(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a approvalstatus.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ApprovalStatus_swiginit(self, _StepBasic.new_StepBasic_ApprovalStatus(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalStatus_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ApprovalStatus_Name(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ApprovalStatus_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ApprovalStatus_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ApprovalStatus

# Register StepBasic_ApprovalStatus in _StepBasic:
_StepBasic.StepBasic_ApprovalStatus_swigregister(StepBasic_ApprovalStatus)

class StepBasic_Certification(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_Certification_swiginit(self, _StepBasic.new_StepBasic_Certification(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aPurpose: TCollection_HAsciiString
        aKind: StepBasic_CertificationType

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Certification_Init(self, *args)

    def Kind(self, *args) -> "opencascade::handle< StepBasic_CertificationType >":
        r"""
        Returns field kind.

        Returns
        -------
        opencascade::handle<StepBasic_CertificationType>

        """
        return _StepBasic.StepBasic_Certification_Kind(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Certification_Name(self, *args)

    def Purpose(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field purpose.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Certification_Purpose(self, *args)

    def SetKind(self, *args) -> "void":
        r"""
        Set field kind.

        Parameters
        ----------
        Kind: StepBasic_CertificationType

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Certification_SetKind(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Certification_SetName(self, *args)

    def SetPurpose(self, *args) -> "void":
        r"""
        Set field purpose.

        Parameters
        ----------
        Purpose: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Certification_SetPurpose(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_Certification_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_Certification

# Register StepBasic_Certification in _StepBasic:
_StepBasic.StepBasic_Certification_swigregister(StepBasic_Certification)

class StepBasic_CertificationAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_CertificationAssignment_swiginit(self, _StepBasic.new_StepBasic_CertificationAssignment(*args))

    def AssignedCertification(self, *args) -> "opencascade::handle< StepBasic_Certification >":
        r"""
        Returns field assignedcertification.

        Returns
        -------
        opencascade::handle<StepBasic_Certification>

        """
        return _StepBasic.StepBasic_CertificationAssignment_AssignedCertification(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aAssignedCertification: StepBasic_Certification

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CertificationAssignment_Init(self, *args)

    def SetAssignedCertification(self, *args) -> "void":
        r"""
        Set field assignedcertification.

        Parameters
        ----------
        AssignedCertification: StepBasic_Certification

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CertificationAssignment_SetAssignedCertification(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_CertificationAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_CertificationAssignment

# Register StepBasic_CertificationAssignment in _StepBasic:
_StepBasic.StepBasic_CertificationAssignment_swigregister(StepBasic_CertificationAssignment)

class StepBasic_CertificationType(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_CertificationType_swiginit(self, _StepBasic.new_StepBasic_CertificationType(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_CertificationType_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CertificationType_Init(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CertificationType_SetDescription(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_CertificationType_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_CertificationType

# Register StepBasic_CertificationType in _StepBasic:
_StepBasic.StepBasic_CertificationType_swigregister(StepBasic_CertificationType)

class StepBasic_CharacterizedObject(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_CharacterizedObject_swiginit(self, _StepBasic.new_StepBasic_CharacterizedObject(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_CharacterizedObject_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_CharacterizedObject_HasDescription(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CharacterizedObject_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_CharacterizedObject_Name(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CharacterizedObject_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CharacterizedObject_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_CharacterizedObject_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_CharacterizedObject

# Register StepBasic_CharacterizedObject in _StepBasic:
_StepBasic.StepBasic_CharacterizedObject_swigregister(StepBasic_CharacterizedObject)

class StepBasic_Contract(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_Contract_swiginit(self, _StepBasic.new_StepBasic_Contract(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aPurpose: TCollection_HAsciiString
        aKind: StepBasic_ContractType

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Contract_Init(self, *args)

    def Kind(self, *args) -> "opencascade::handle< StepBasic_ContractType >":
        r"""
        Returns field kind.

        Returns
        -------
        opencascade::handle<StepBasic_ContractType>

        """
        return _StepBasic.StepBasic_Contract_Kind(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Contract_Name(self, *args)

    def Purpose(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field purpose.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Contract_Purpose(self, *args)

    def SetKind(self, *args) -> "void":
        r"""
        Set field kind.

        Parameters
        ----------
        Kind: StepBasic_ContractType

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Contract_SetKind(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Contract_SetName(self, *args)

    def SetPurpose(self, *args) -> "void":
        r"""
        Set field purpose.

        Parameters
        ----------
        Purpose: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Contract_SetPurpose(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_Contract_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_Contract

# Register StepBasic_Contract in _StepBasic:
_StepBasic.StepBasic_Contract_swigregister(StepBasic_Contract)

class StepBasic_ContractAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ContractAssignment_swiginit(self, _StepBasic.new_StepBasic_ContractAssignment(*args))

    def AssignedContract(self, *args) -> "opencascade::handle< StepBasic_Contract >":
        r"""
        Returns field assignedcontract.

        Returns
        -------
        opencascade::handle<StepBasic_Contract>

        """
        return _StepBasic.StepBasic_ContractAssignment_AssignedContract(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aAssignedContract: StepBasic_Contract

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ContractAssignment_Init(self, *args)

    def SetAssignedContract(self, *args) -> "void":
        r"""
        Set field assignedcontract.

        Parameters
        ----------
        AssignedContract: StepBasic_Contract

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ContractAssignment_SetAssignedContract(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ContractAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ContractAssignment

# Register StepBasic_ContractAssignment in _StepBasic:
_StepBasic.StepBasic_ContractAssignment_swigregister(StepBasic_ContractAssignment)

class StepBasic_ContractType(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ContractType_swiginit(self, _StepBasic.new_StepBasic_ContractType(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ContractType_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ContractType_Init(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ContractType_SetDescription(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ContractType_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ContractType

# Register StepBasic_ContractType in _StepBasic:
_StepBasic.StepBasic_ContractType_swigregister(StepBasic_ContractType)

class StepBasic_CoordinatedUniversalTimeOffset(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a coordinateduniversaltimeoffset.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_CoordinatedUniversalTimeOffset_swiginit(self, _StepBasic.new_StepBasic_CoordinatedUniversalTimeOffset(*args))

    def HasMinuteOffset(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_CoordinatedUniversalTimeOffset_HasMinuteOffset(self, *args)

    def HourOffset(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_CoordinatedUniversalTimeOffset_HourOffset(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aHourOffset: int
        hasAminuteOffset: bool
        aMinuteOffset: int
        aSense: StepBasic_AheadOrBehind

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CoordinatedUniversalTimeOffset_Init(self, *args)

    def MinuteOffset(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_CoordinatedUniversalTimeOffset_MinuteOffset(self, *args)

    def Sense(self, *args) -> "StepBasic_AheadOrBehind":
        r"""
        No available documentation.

        Returns
        -------
        StepBasic_AheadOrBehind

        """
        return _StepBasic.StepBasic_CoordinatedUniversalTimeOffset_Sense(self, *args)

    def SetHourOffset(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aHourOffset: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CoordinatedUniversalTimeOffset_SetHourOffset(self, *args)

    def SetMinuteOffset(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMinuteOffset: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CoordinatedUniversalTimeOffset_SetMinuteOffset(self, *args)

    def SetSense(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSense: StepBasic_AheadOrBehind

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CoordinatedUniversalTimeOffset_SetSense(self, *args)

    def UnSetMinuteOffset(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CoordinatedUniversalTimeOffset_UnSetMinuteOffset(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_CoordinatedUniversalTimeOffset_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_CoordinatedUniversalTimeOffset

# Register StepBasic_CoordinatedUniversalTimeOffset in _StepBasic:
_StepBasic.StepBasic_CoordinatedUniversalTimeOffset_swigregister(StepBasic_CoordinatedUniversalTimeOffset)

class StepBasic_Date(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a date.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_Date_swiginit(self, _StepBasic.new_StepBasic_Date(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aYearComponent: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Date_Init(self, *args)

    def SetYearComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aYearComponent: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Date_SetYearComponent(self, *args)

    def YearComponent(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_Date_YearComponent(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_Date_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_Date

# Register StepBasic_Date in _StepBasic:
_StepBasic.StepBasic_Date_swigregister(StepBasic_Date)

class StepBasic_DateAndTime(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a dateandtime.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DateAndTime_swiginit(self, _StepBasic.new_StepBasic_DateAndTime(*args))

    def DateComponent(self, *args) -> "opencascade::handle< StepBasic_Date >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Date>

        """
        return _StepBasic.StepBasic_DateAndTime_DateComponent(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDateComponent: StepBasic_Date
        aTimeComponent: StepBasic_LocalTime

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DateAndTime_Init(self, *args)

    def SetDateComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDateComponent: StepBasic_Date

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DateAndTime_SetDateComponent(self, *args)

    def SetTimeComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aTimeComponent: StepBasic_LocalTime

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DateAndTime_SetTimeComponent(self, *args)

    def TimeComponent(self, *args) -> "opencascade::handle< StepBasic_LocalTime >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_LocalTime>

        """
        return _StepBasic.StepBasic_DateAndTime_TimeComponent(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DateAndTime_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DateAndTime

# Register StepBasic_DateAndTime in _StepBasic:
_StepBasic.StepBasic_DateAndTime_swigregister(StepBasic_DateAndTime)

class StepBasic_DateAndTimeAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def AssignedDateAndTime(self, *args) -> "opencascade::handle< StepBasic_DateAndTime >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_DateAndTime>

        """
        return _StepBasic.StepBasic_DateAndTimeAssignment_AssignedDateAndTime(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDateAndTime: StepBasic_DateAndTime
        aRole: StepBasic_DateTimeRole

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DateAndTimeAssignment_Init(self, *args)

    def Role(self, *args) -> "opencascade::handle< StepBasic_DateTimeRole >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_DateTimeRole>

        """
        return _StepBasic.StepBasic_DateAndTimeAssignment_Role(self, *args)

    def SetAssignedDateAndTime(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDateAndTime: StepBasic_DateAndTime

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DateAndTimeAssignment_SetAssignedDateAndTime(self, *args)

    def SetRole(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRole: StepBasic_DateTimeRole

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DateAndTimeAssignment_SetRole(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DateAndTimeAssignment_DownCast(t)


    __repr__ = _dumps_object


    def __init__(self):
        _StepBasic.StepBasic_DateAndTimeAssignment_swiginit(self, _StepBasic.new_StepBasic_DateAndTimeAssignment())
    __swig_destroy__ = _StepBasic.delete_StepBasic_DateAndTimeAssignment

# Register StepBasic_DateAndTimeAssignment in _StepBasic:
_StepBasic.StepBasic_DateAndTimeAssignment_swigregister(StepBasic_DateAndTimeAssignment)

class StepBasic_DateAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def AssignedDate(self, *args) -> "opencascade::handle< StepBasic_Date >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Date>

        """
        return _StepBasic.StepBasic_DateAssignment_AssignedDate(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDate: StepBasic_Date
        aRole: StepBasic_DateRole

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DateAssignment_Init(self, *args)

    def Role(self, *args) -> "opencascade::handle< StepBasic_DateRole >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_DateRole>

        """
        return _StepBasic.StepBasic_DateAssignment_Role(self, *args)

    def SetAssignedDate(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDate: StepBasic_Date

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DateAssignment_SetAssignedDate(self, *args)

    def SetRole(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRole: StepBasic_DateRole

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DateAssignment_SetRole(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DateAssignment_DownCast(t)


    __repr__ = _dumps_object


    def __init__(self):
        _StepBasic.StepBasic_DateAssignment_swiginit(self, _StepBasic.new_StepBasic_DateAssignment())
    __swig_destroy__ = _StepBasic.delete_StepBasic_DateAssignment

# Register StepBasic_DateAssignment in _StepBasic:
_StepBasic.StepBasic_DateAssignment_swigregister(StepBasic_DateAssignment)

class StepBasic_DateRole(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a daterole.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DateRole_swiginit(self, _StepBasic.new_StepBasic_DateRole(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DateRole_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_DateRole_Name(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DateRole_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DateRole_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DateRole

# Register StepBasic_DateRole in _StepBasic:
_StepBasic.StepBasic_DateRole_swigregister(StepBasic_DateRole)

class StepBasic_DateTimeRole(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a datetimerole.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DateTimeRole_swiginit(self, _StepBasic.new_StepBasic_DateTimeRole(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DateTimeRole_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_DateTimeRole_Name(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DateTimeRole_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DateTimeRole_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DateTimeRole

# Register StepBasic_DateTimeRole in _StepBasic:
_StepBasic.StepBasic_DateTimeRole_swigregister(StepBasic_DateTimeRole)

class StepBasic_DateTimeSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a datetimeselect selecttype.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DateTimeSelect_swiginit(self, _StepBasic.new_StepBasic_DateTimeSelect(*args))

    def Date(self, *args) -> "opencascade::handle< StepBasic_Date >":
        r"""
        Returns value as a date (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Date>

        """
        return _StepBasic.StepBasic_DateTimeSelect_Date(self, *args)

    def DateAndTime(self, *args) -> "opencascade::handle< StepBasic_DateAndTime >":
        r"""
        Returns value as a dateandtime (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_DateAndTime>

        """
        return _StepBasic.StepBasic_DateTimeSelect_DateAndTime(self, *args)

    def LocalTime(self, *args) -> "opencascade::handle< StepBasic_LocalTime >":
        r"""
        Returns value as a localtime (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_LocalTime>

        """
        return _StepBasic.StepBasic_DateTimeSelect_LocalTime(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DateTimeSelect

# Register StepBasic_DateTimeSelect in _StepBasic:
_StepBasic.StepBasic_DateTimeSelect_swigregister(StepBasic_DateTimeSelect)

class StepBasic_DerivedUnit(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DerivedUnit_swiginit(self, _StepBasic.new_StepBasic_DerivedUnit(*args))

    def Elements(self, *args) -> "opencascade::handle< StepBasic_HArray1OfDerivedUnitElement >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_HArray1OfDerivedUnitElement>

        """
        return _StepBasic.StepBasic_DerivedUnit_Elements(self, *args)

    def ElementsValue(self, *args) -> "opencascade::handle< StepBasic_DerivedUnitElement >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<StepBasic_DerivedUnitElement>

        """
        return _StepBasic.StepBasic_DerivedUnit_ElementsValue(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        elements: StepBasic_HArray1OfDerivedUnitElement

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DerivedUnit_Init(self, *args)

    def NbElements(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_DerivedUnit_NbElements(self, *args)

    def SetElements(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        elements: StepBasic_HArray1OfDerivedUnitElement

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DerivedUnit_SetElements(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DerivedUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DerivedUnit

# Register StepBasic_DerivedUnit in _StepBasic:
_StepBasic.StepBasic_DerivedUnit_swigregister(StepBasic_DerivedUnit)

class StepBasic_DerivedUnitElement(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DerivedUnitElement_swiginit(self, _StepBasic.new_StepBasic_DerivedUnitElement(*args))

    def Exponent(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepBasic.StepBasic_DerivedUnitElement_Exponent(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aUnit: StepBasic_NamedUnit
        aExponent: float

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DerivedUnitElement_Init(self, *args)

    def SetExponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aExponent: float

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DerivedUnitElement_SetExponent(self, *args)

    def SetUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aUnit: StepBasic_NamedUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DerivedUnitElement_SetUnit(self, *args)

    def Unit(self, *args) -> "opencascade::handle< StepBasic_NamedUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_NamedUnit>

        """
        return _StepBasic.StepBasic_DerivedUnitElement_Unit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DerivedUnitElement_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DerivedUnitElement

# Register StepBasic_DerivedUnitElement in _StepBasic:
_StepBasic.StepBasic_DerivedUnitElement_swigregister(StepBasic_DerivedUnitElement)

class StepBasic_DimensionalExponents(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a dimensionalexponents.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DimensionalExponents_swiginit(self, _StepBasic.new_StepBasic_DimensionalExponents(*args))

    def AmountOfSubstanceExponent(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepBasic.StepBasic_DimensionalExponents_AmountOfSubstanceExponent(self, *args)

    def ElectricCurrentExponent(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepBasic.StepBasic_DimensionalExponents_ElectricCurrentExponent(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLengthExponent: float
        aMassExponent: float
        aTimeExponent: float
        aElectricCurrentExponent: float
        aThermodynamicTemperatureExponent: float
        aAmountOfSubstanceExponent: float
        aLuminousIntensityExponent: float

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DimensionalExponents_Init(self, *args)

    def LengthExponent(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepBasic.StepBasic_DimensionalExponents_LengthExponent(self, *args)

    def LuminousIntensityExponent(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepBasic.StepBasic_DimensionalExponents_LuminousIntensityExponent(self, *args)

    def MassExponent(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepBasic.StepBasic_DimensionalExponents_MassExponent(self, *args)

    def SetAmountOfSubstanceExponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAmountOfSubstanceExponent: float

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DimensionalExponents_SetAmountOfSubstanceExponent(self, *args)

    def SetElectricCurrentExponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aElectricCurrentExponent: float

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DimensionalExponents_SetElectricCurrentExponent(self, *args)

    def SetLengthExponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLengthExponent: float

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DimensionalExponents_SetLengthExponent(self, *args)

    def SetLuminousIntensityExponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLuminousIntensityExponent: float

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DimensionalExponents_SetLuminousIntensityExponent(self, *args)

    def SetMassExponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMassExponent: float

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DimensionalExponents_SetMassExponent(self, *args)

    def SetThermodynamicTemperatureExponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aThermodynamicTemperatureExponent: float

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DimensionalExponents_SetThermodynamicTemperatureExponent(self, *args)

    def SetTimeExponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aTimeExponent: float

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DimensionalExponents_SetTimeExponent(self, *args)

    def ThermodynamicTemperatureExponent(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepBasic.StepBasic_DimensionalExponents_ThermodynamicTemperatureExponent(self, *args)

    def TimeExponent(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepBasic.StepBasic_DimensionalExponents_TimeExponent(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DimensionalExponents_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DimensionalExponents

# Register StepBasic_DimensionalExponents in _StepBasic:
_StepBasic.StepBasic_DimensionalExponents_swigregister(StepBasic_DimensionalExponents)

class StepBasic_Document(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_Document_swiginit(self, _StepBasic.new_StepBasic_Document(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Document_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Document_HasDescription(self, *args)

    def Id(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field id.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Document_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString
        aKind: StepBasic_DocumentType

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Document_Init(self, *args)

    def Kind(self, *args) -> "opencascade::handle< StepBasic_DocumentType >":
        r"""
        Returns field kind.

        Returns
        -------
        opencascade::handle<StepBasic_DocumentType>

        """
        return _StepBasic.StepBasic_Document_Kind(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Document_Name(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Document_SetDescription(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        Set field id.

        Parameters
        ----------
        Id: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Document_SetId(self, *args)

    def SetKind(self, *args) -> "void":
        r"""
        Set field kind.

        Parameters
        ----------
        Kind: StepBasic_DocumentType

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Document_SetKind(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Document_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_Document_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_Document

# Register StepBasic_Document in _StepBasic:
_StepBasic.StepBasic_Document_swigregister(StepBasic_Document)

class StepBasic_DocumentProductAssociation(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DocumentProductAssociation_swiginit(self, _StepBasic.new_StepBasic_DocumentProductAssociation(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_DocumentProductAssociation_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_DocumentProductAssociation_HasDescription(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString
        aRelatingDocument: StepBasic_Document
        aRelatedProduct: StepBasic_ProductOrFormationOrDefinition

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentProductAssociation_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_DocumentProductAssociation_Name(self, *args)

    def RelatedProduct(self, *args) -> "StepBasic_ProductOrFormationOrDefinition":
        r"""
        Returns field relatedproduct.

        Returns
        -------
        StepBasic_ProductOrFormationOrDefinition

        """
        return _StepBasic.StepBasic_DocumentProductAssociation_RelatedProduct(self, *args)

    def RelatingDocument(self, *args) -> "opencascade::handle< StepBasic_Document >":
        r"""
        Returns field relatingdocument.

        Returns
        -------
        opencascade::handle<StepBasic_Document>

        """
        return _StepBasic.StepBasic_DocumentProductAssociation_RelatingDocument(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentProductAssociation_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentProductAssociation_SetName(self, *args)

    def SetRelatedProduct(self, *args) -> "void":
        r"""
        Set field relatedproduct.

        Parameters
        ----------
        RelatedProduct: StepBasic_ProductOrFormationOrDefinition

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentProductAssociation_SetRelatedProduct(self, *args)

    def SetRelatingDocument(self, *args) -> "void":
        r"""
        Set field relatingdocument.

        Parameters
        ----------
        RelatingDocument: StepBasic_Document

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentProductAssociation_SetRelatingDocument(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DocumentProductAssociation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DocumentProductAssociation

# Register StepBasic_DocumentProductAssociation in _StepBasic:
_StepBasic.StepBasic_DocumentProductAssociation_swigregister(StepBasic_DocumentProductAssociation)

class StepBasic_DocumentReference(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def AssignedDocument(self, *args) -> "opencascade::handle< StepBasic_Document >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Document>

        """
        return _StepBasic.StepBasic_DocumentReference_AssignedDocument(self, *args)

    def Init0(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDocument: StepBasic_Document
        aSource: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentReference_Init0(self, *args)

    def SetAssignedDocument(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDocument: StepBasic_Document

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentReference_SetAssignedDocument(self, *args)

    def SetSource(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSource: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentReference_SetSource(self, *args)

    def Source(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_DocumentReference_Source(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DocumentReference_DownCast(t)


    __repr__ = _dumps_object


    def __init__(self):
        _StepBasic.StepBasic_DocumentReference_swiginit(self, _StepBasic.new_StepBasic_DocumentReference())
    __swig_destroy__ = _StepBasic.delete_StepBasic_DocumentReference

# Register StepBasic_DocumentReference in _StepBasic:
_StepBasic.StepBasic_DocumentReference_swigregister(StepBasic_DocumentReference)

class StepBasic_DocumentRelationship(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DocumentRelationship_swiginit(self, _StepBasic.new_StepBasic_DocumentRelationship(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_DocumentRelationship_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aRelating: StepBasic_Document
        aRelated: StepBasic_Document

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentRelationship_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_DocumentRelationship_Name(self, *args)

    def RelatedDocument(self, *args) -> "opencascade::handle< StepBasic_Document >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Document>

        """
        return _StepBasic.StepBasic_DocumentRelationship_RelatedDocument(self, *args)

    def RelatingDocument(self, *args) -> "opencascade::handle< StepBasic_Document >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Document>

        """
        return _StepBasic.StepBasic_DocumentRelationship_RelatingDocument(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentRelationship_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentRelationship_SetName(self, *args)

    def SetRelatedDocument(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRelated: StepBasic_Document

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentRelationship_SetRelatedDocument(self, *args)

    def SetRelatingDocument(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRelating: StepBasic_Document

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentRelationship_SetRelatingDocument(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DocumentRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DocumentRelationship

# Register StepBasic_DocumentRelationship in _StepBasic:
_StepBasic.StepBasic_DocumentRelationship_swigregister(StepBasic_DocumentRelationship)

class StepBasic_DocumentRepresentationType(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DocumentRepresentationType_swiginit(self, _StepBasic.new_StepBasic_DocumentRepresentationType(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aRepresentedDocument: StepBasic_Document

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentRepresentationType_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_DocumentRepresentationType_Name(self, *args)

    def RepresentedDocument(self, *args) -> "opencascade::handle< StepBasic_Document >":
        r"""
        Returns field representeddocument.

        Returns
        -------
        opencascade::handle<StepBasic_Document>

        """
        return _StepBasic.StepBasic_DocumentRepresentationType_RepresentedDocument(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentRepresentationType_SetName(self, *args)

    def SetRepresentedDocument(self, *args) -> "void":
        r"""
        Set field representeddocument.

        Parameters
        ----------
        RepresentedDocument: StepBasic_Document

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentRepresentationType_SetRepresentedDocument(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DocumentRepresentationType_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DocumentRepresentationType

# Register StepBasic_DocumentRepresentationType in _StepBasic:
_StepBasic.StepBasic_DocumentRepresentationType_swigregister(StepBasic_DocumentRepresentationType)

class StepBasic_DocumentType(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DocumentType_swiginit(self, _StepBasic.new_StepBasic_DocumentType(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        apdt: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentType_Init(self, *args)

    def ProductDataType(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_DocumentType_ProductDataType(self, *args)

    def SetProductDataType(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        apdt: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentType_SetProductDataType(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DocumentType_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DocumentType

# Register StepBasic_DocumentType in _StepBasic:
_StepBasic.StepBasic_DocumentType_swigregister(StepBasic_DocumentType)

class StepBasic_DocumentUsageConstraint(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DocumentUsageConstraint_swiginit(self, _StepBasic.new_StepBasic_DocumentUsageConstraint(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSource: StepBasic_Document
        ase: TCollection_HAsciiString
        asev: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentUsageConstraint_Init(self, *args)

    def SetSource(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSource: StepBasic_Document

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentUsageConstraint_SetSource(self, *args)

    def SetSubjectElement(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ase: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentUsageConstraint_SetSubjectElement(self, *args)

    def SetSubjectElementValue(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        asev: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentUsageConstraint_SetSubjectElementValue(self, *args)

    def Source(self, *args) -> "opencascade::handle< StepBasic_Document >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Document>

        """
        return _StepBasic.StepBasic_DocumentUsageConstraint_Source(self, *args)

    def SubjectElement(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_DocumentUsageConstraint_SubjectElement(self, *args)

    def SubjectElementValue(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_DocumentUsageConstraint_SubjectElementValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DocumentUsageConstraint_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DocumentUsageConstraint

# Register StepBasic_DocumentUsageConstraint in _StepBasic:
_StepBasic.StepBasic_DocumentUsageConstraint_swigregister(StepBasic_DocumentUsageConstraint)

class StepBasic_Effectivity(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_Effectivity_swiginit(self, _StepBasic.new_StepBasic_Effectivity(*args))

    def Id(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Effectivity_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aid: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Effectivity_Init(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aid: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Effectivity_SetId(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_Effectivity_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_Effectivity

# Register StepBasic_Effectivity in _StepBasic:
_StepBasic.StepBasic_Effectivity_swigregister(StepBasic_Effectivity)

class StepBasic_EffectivityAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_EffectivityAssignment_swiginit(self, _StepBasic.new_StepBasic_EffectivityAssignment(*args))

    def AssignedEffectivity(self, *args) -> "opencascade::handle< StepBasic_Effectivity >":
        r"""
        Returns field assignedeffectivity.

        Returns
        -------
        opencascade::handle<StepBasic_Effectivity>

        """
        return _StepBasic.StepBasic_EffectivityAssignment_AssignedEffectivity(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aAssignedEffectivity: StepBasic_Effectivity

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_EffectivityAssignment_Init(self, *args)

    def SetAssignedEffectivity(self, *args) -> "void":
        r"""
        Set field assignedeffectivity.

        Parameters
        ----------
        AssignedEffectivity: StepBasic_Effectivity

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_EffectivityAssignment_SetAssignedEffectivity(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_EffectivityAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_EffectivityAssignment

# Register StepBasic_EffectivityAssignment in _StepBasic:
_StepBasic.StepBasic_EffectivityAssignment_swigregister(StepBasic_EffectivityAssignment)

class StepBasic_EulerAngles(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_EulerAngles_swiginit(self, _StepBasic.new_StepBasic_EulerAngles(*args))

    def Angles(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns field angles.

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _StepBasic.StepBasic_EulerAngles_Angles(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aAngles: TColStd_HArray1OfReal

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_EulerAngles_Init(self, *args)

    def SetAngles(self, *args) -> "void":
        r"""
        Set field angles.

        Parameters
        ----------
        Angles: TColStd_HArray1OfReal

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_EulerAngles_SetAngles(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_EulerAngles_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_EulerAngles

# Register StepBasic_EulerAngles in _StepBasic:
_StepBasic.StepBasic_EulerAngles_swigregister(StepBasic_EulerAngles)

class StepBasic_ExternalSource(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ExternalSource_swiginit(self, _StepBasic.new_StepBasic_ExternalSource(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aSourceId: StepBasic_SourceItem

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ExternalSource_Init(self, *args)

    def SetSourceId(self, *args) -> "void":
        r"""
        Set field sourceid.

        Parameters
        ----------
        SourceId: StepBasic_SourceItem

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ExternalSource_SetSourceId(self, *args)

    def SourceId(self, *args) -> "StepBasic_SourceItem":
        r"""
        Returns field sourceid.

        Returns
        -------
        StepBasic_SourceItem

        """
        return _StepBasic.StepBasic_ExternalSource_SourceId(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ExternalSource_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ExternalSource

# Register StepBasic_ExternalSource in _StepBasic:
_StepBasic.StepBasic_ExternalSource_swigregister(StepBasic_ExternalSource)

class StepBasic_ExternallyDefinedItem(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ExternallyDefinedItem_swiginit(self, _StepBasic.new_StepBasic_ExternallyDefinedItem(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aItemId: StepBasic_SourceItem
        aSource: StepBasic_ExternalSource

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ExternallyDefinedItem_Init(self, *args)

    def ItemId(self, *args) -> "StepBasic_SourceItem":
        r"""
        Returns field itemid.

        Returns
        -------
        StepBasic_SourceItem

        """
        return _StepBasic.StepBasic_ExternallyDefinedItem_ItemId(self, *args)

    def SetItemId(self, *args) -> "void":
        r"""
        Set field itemid.

        Parameters
        ----------
        ItemId: StepBasic_SourceItem

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ExternallyDefinedItem_SetItemId(self, *args)

    def SetSource(self, *args) -> "void":
        r"""
        Set field source.

        Parameters
        ----------
        Source: StepBasic_ExternalSource

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ExternallyDefinedItem_SetSource(self, *args)

    def Source(self, *args) -> "opencascade::handle< StepBasic_ExternalSource >":
        r"""
        Returns field source.

        Returns
        -------
        opencascade::handle<StepBasic_ExternalSource>

        """
        return _StepBasic.StepBasic_ExternallyDefinedItem_Source(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ExternallyDefinedItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ExternallyDefinedItem

# Register StepBasic_ExternallyDefinedItem in _StepBasic:
_StepBasic.StepBasic_ExternallyDefinedItem_swigregister(StepBasic_ExternallyDefinedItem)

class StepBasic_GeneralProperty(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_GeneralProperty_swiginit(self, _StepBasic.new_StepBasic_GeneralProperty(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_GeneralProperty_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_GeneralProperty_HasDescription(self, *args)

    def Id(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field id.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_GeneralProperty_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_GeneralProperty_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_GeneralProperty_Name(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_GeneralProperty_SetDescription(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        Set field id.

        Parameters
        ----------
        Id: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_GeneralProperty_SetId(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_GeneralProperty_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_GeneralProperty_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_GeneralProperty

# Register StepBasic_GeneralProperty in _StepBasic:
_StepBasic.StepBasic_GeneralProperty_swigregister(StepBasic_GeneralProperty)

class StepBasic_Group(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_Group_swiginit(self, _StepBasic.new_StepBasic_Group(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Group_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Group_HasDescription(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Group_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Group_Name(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Group_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Group_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_Group_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_Group

# Register StepBasic_Group in _StepBasic:
_StepBasic.StepBasic_Group_swigregister(StepBasic_Group)

class StepBasic_GroupAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_GroupAssignment_swiginit(self, _StepBasic.new_StepBasic_GroupAssignment(*args))

    def AssignedGroup(self, *args) -> "opencascade::handle< StepBasic_Group >":
        r"""
        Returns field assignedgroup.

        Returns
        -------
        opencascade::handle<StepBasic_Group>

        """
        return _StepBasic.StepBasic_GroupAssignment_AssignedGroup(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aAssignedGroup: StepBasic_Group

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_GroupAssignment_Init(self, *args)

    def SetAssignedGroup(self, *args) -> "void":
        r"""
        Set field assignedgroup.

        Parameters
        ----------
        AssignedGroup: StepBasic_Group

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_GroupAssignment_SetAssignedGroup(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_GroupAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_GroupAssignment

# Register StepBasic_GroupAssignment in _StepBasic:
_StepBasic.StepBasic_GroupAssignment_swigregister(StepBasic_GroupAssignment)

class StepBasic_GroupRelationship(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_GroupRelationship_swiginit(self, _StepBasic.new_StepBasic_GroupRelationship(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_GroupRelationship_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_GroupRelationship_HasDescription(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString
        aRelatingGroup: StepBasic_Group
        aRelatedGroup: StepBasic_Group

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_GroupRelationship_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_GroupRelationship_Name(self, *args)

    def RelatedGroup(self, *args) -> "opencascade::handle< StepBasic_Group >":
        r"""
        Returns field relatedgroup.

        Returns
        -------
        opencascade::handle<StepBasic_Group>

        """
        return _StepBasic.StepBasic_GroupRelationship_RelatedGroup(self, *args)

    def RelatingGroup(self, *args) -> "opencascade::handle< StepBasic_Group >":
        r"""
        Returns field relatinggroup.

        Returns
        -------
        opencascade::handle<StepBasic_Group>

        """
        return _StepBasic.StepBasic_GroupRelationship_RelatingGroup(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_GroupRelationship_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_GroupRelationship_SetName(self, *args)

    def SetRelatedGroup(self, *args) -> "void":
        r"""
        Set field relatedgroup.

        Parameters
        ----------
        RelatedGroup: StepBasic_Group

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_GroupRelationship_SetRelatedGroup(self, *args)

    def SetRelatingGroup(self, *args) -> "void":
        r"""
        Set field relatinggroup.

        Parameters
        ----------
        RelatingGroup: StepBasic_Group

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_GroupRelationship_SetRelatingGroup(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_GroupRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_GroupRelationship

# Register StepBasic_GroupRelationship in _StepBasic:
_StepBasic.StepBasic_GroupRelationship_swigregister(StepBasic_GroupRelationship)

class StepBasic_IdentificationAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_IdentificationAssignment_swiginit(self, _StepBasic.new_StepBasic_IdentificationAssignment(*args))

    def AssignedId(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field assignedid.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_IdentificationAssignment_AssignedId(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aAssignedId: TCollection_HAsciiString
        aRole: StepBasic_IdentificationRole

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_IdentificationAssignment_Init(self, *args)

    def Role(self, *args) -> "opencascade::handle< StepBasic_IdentificationRole >":
        r"""
        Returns field role.

        Returns
        -------
        opencascade::handle<StepBasic_IdentificationRole>

        """
        return _StepBasic.StepBasic_IdentificationAssignment_Role(self, *args)

    def SetAssignedId(self, *args) -> "void":
        r"""
        Set field assignedid.

        Parameters
        ----------
        AssignedId: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_IdentificationAssignment_SetAssignedId(self, *args)

    def SetRole(self, *args) -> "void":
        r"""
        Set field role.

        Parameters
        ----------
        Role: StepBasic_IdentificationRole

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_IdentificationAssignment_SetRole(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_IdentificationAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_IdentificationAssignment

# Register StepBasic_IdentificationAssignment in _StepBasic:
_StepBasic.StepBasic_IdentificationAssignment_swigregister(StepBasic_IdentificationAssignment)

class StepBasic_IdentificationRole(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_IdentificationRole_swiginit(self, _StepBasic.new_StepBasic_IdentificationRole(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_IdentificationRole_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_IdentificationRole_HasDescription(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_IdentificationRole_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_IdentificationRole_Name(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_IdentificationRole_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_IdentificationRole_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_IdentificationRole_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_IdentificationRole

# Register StepBasic_IdentificationRole in _StepBasic:
_StepBasic.StepBasic_IdentificationRole_swigregister(StepBasic_IdentificationRole)

class StepBasic_LocalTime(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a localtime.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_LocalTime_swiginit(self, _StepBasic.new_StepBasic_LocalTime(*args))

    def HasMinuteComponent(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_LocalTime_HasMinuteComponent(self, *args)

    def HasSecondComponent(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_LocalTime_HasSecondComponent(self, *args)

    def HourComponent(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_LocalTime_HourComponent(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aHourComponent: int
        hasAminuteComponent: bool
        aMinuteComponent: int
        hasAsecondComponent: bool
        aSecondComponent: float
        aZone: StepBasic_CoordinatedUniversalTimeOffset

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_LocalTime_Init(self, *args)

    def MinuteComponent(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_LocalTime_MinuteComponent(self, *args)

    def SecondComponent(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepBasic.StepBasic_LocalTime_SecondComponent(self, *args)

    def SetHourComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aHourComponent: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_LocalTime_SetHourComponent(self, *args)

    def SetMinuteComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMinuteComponent: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_LocalTime_SetMinuteComponent(self, *args)

    def SetSecondComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSecondComponent: float

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_LocalTime_SetSecondComponent(self, *args)

    def SetZone(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aZone: StepBasic_CoordinatedUniversalTimeOffset

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_LocalTime_SetZone(self, *args)

    def UnSetMinuteComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_LocalTime_UnSetMinuteComponent(self, *args)

    def UnSetSecondComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_LocalTime_UnSetSecondComponent(self, *args)

    def Zone(self, *args) -> "opencascade::handle< StepBasic_CoordinatedUniversalTimeOffset >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_CoordinatedUniversalTimeOffset>

        """
        return _StepBasic.StepBasic_LocalTime_Zone(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_LocalTime_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_LocalTime

# Register StepBasic_LocalTime in _StepBasic:
_StepBasic.StepBasic_LocalTime_swigregister(StepBasic_LocalTime)

class StepBasic_MeasureValueMember(OCC.Core.StepData.StepData_SelectReal):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_MeasureValueMember_swiginit(self, _StepBasic.new_StepBasic_MeasureValueMember(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_MeasureValueMember_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_MeasureValueMember

# Register StepBasic_MeasureValueMember in _StepBasic:
_StepBasic.StepBasic_MeasureValueMember_swigregister(StepBasic_MeasureValueMember)

class StepBasic_MeasureWithUnit(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a measurewithunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_MeasureWithUnit_swiginit(self, _StepBasic.new_StepBasic_MeasureWithUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aValueComponent: StepBasic_MeasureValueMember
        aUnitComponent: StepBasic_Unit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_MeasureWithUnit_Init(self, *args)

    def SetUnitComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aUnitComponent: StepBasic_Unit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_MeasureWithUnit_SetUnitComponent(self, *args)

    def SetValueComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aValueComponent: float

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_MeasureWithUnit_SetValueComponent(self, *args)

    def SetValueComponentMember(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        val: StepBasic_MeasureValueMember

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_MeasureWithUnit_SetValueComponentMember(self, *args)

    def UnitComponent(self, *args) -> "StepBasic_Unit":
        r"""
        No available documentation.

        Returns
        -------
        StepBasic_Unit

        """
        return _StepBasic.StepBasic_MeasureWithUnit_UnitComponent(self, *args)

    def ValueComponent(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepBasic.StepBasic_MeasureWithUnit_ValueComponent(self, *args)

    def ValueComponentMember(self, *args) -> "opencascade::handle< StepBasic_MeasureValueMember >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_MeasureValueMember>

        """
        return _StepBasic.StepBasic_MeasureWithUnit_ValueComponentMember(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_MeasureWithUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_MeasureWithUnit

# Register StepBasic_MeasureWithUnit in _StepBasic:
_StepBasic.StepBasic_MeasureWithUnit_swigregister(StepBasic_MeasureWithUnit)

class StepBasic_NameAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_NameAssignment_swiginit(self, _StepBasic.new_StepBasic_NameAssignment(*args))

    def AssignedName(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field assignedname.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_NameAssignment_AssignedName(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aAssignedName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_NameAssignment_Init(self, *args)

    def SetAssignedName(self, *args) -> "void":
        r"""
        Set field assignedname.

        Parameters
        ----------
        AssignedName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_NameAssignment_SetAssignedName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_NameAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_NameAssignment

# Register StepBasic_NameAssignment in _StepBasic:
_StepBasic.StepBasic_NameAssignment_swigregister(StepBasic_NameAssignment)

class StepBasic_NamedUnit(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a namedunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_NamedUnit_swiginit(self, _StepBasic.new_StepBasic_NamedUnit(*args))

    def Dimensions(self, *args) -> "opencascade::handle< StepBasic_DimensionalExponents >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_DimensionalExponents>

        """
        return _StepBasic.StepBasic_NamedUnit_Dimensions(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDimensions: StepBasic_DimensionalExponents

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_NamedUnit_Init(self, *args)

    def SetDimensions(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDimensions: StepBasic_DimensionalExponents

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_NamedUnit_SetDimensions(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_NamedUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_NamedUnit

# Register StepBasic_NamedUnit in _StepBasic:
_StepBasic.StepBasic_NamedUnit_swigregister(StepBasic_NamedUnit)

class StepBasic_ObjectRole(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ObjectRole_swiginit(self, _StepBasic.new_StepBasic_ObjectRole(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ObjectRole_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_ObjectRole_HasDescription(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ObjectRole_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ObjectRole_Name(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ObjectRole_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ObjectRole_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ObjectRole_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ObjectRole

# Register StepBasic_ObjectRole in _StepBasic:
_StepBasic.StepBasic_ObjectRole_swigregister(StepBasic_ObjectRole)

class StepBasic_Organization(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a organization.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_Organization_swiginit(self, _StepBasic.new_StepBasic_Organization(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Organization_Description(self, *args)

    def HasId(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Organization_HasId(self, *args)

    def Id(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Organization_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        hasAid: bool
        aId: TCollection_HAsciiString
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Organization_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Organization_Name(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Organization_SetDescription(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aId: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Organization_SetId(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Organization_SetName(self, *args)

    def UnSetId(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Organization_UnSetId(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_Organization_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_Organization

# Register StepBasic_Organization in _StepBasic:
_StepBasic.StepBasic_Organization_swigregister(StepBasic_Organization)

class StepBasic_OrganizationAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def AssignedOrganization(self, *args) -> "opencascade::handle< StepBasic_Organization >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Organization>

        """
        return _StepBasic.StepBasic_OrganizationAssignment_AssignedOrganization(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedOrganization: StepBasic_Organization
        aRole: StepBasic_OrganizationRole

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_OrganizationAssignment_Init(self, *args)

    def Role(self, *args) -> "opencascade::handle< StepBasic_OrganizationRole >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_OrganizationRole>

        """
        return _StepBasic.StepBasic_OrganizationAssignment_Role(self, *args)

    def SetAssignedOrganization(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedOrganization: StepBasic_Organization

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_OrganizationAssignment_SetAssignedOrganization(self, *args)

    def SetRole(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRole: StepBasic_OrganizationRole

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_OrganizationAssignment_SetRole(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_OrganizationAssignment_DownCast(t)


    __repr__ = _dumps_object


    def __init__(self):
        _StepBasic.StepBasic_OrganizationAssignment_swiginit(self, _StepBasic.new_StepBasic_OrganizationAssignment())
    __swig_destroy__ = _StepBasic.delete_StepBasic_OrganizationAssignment

# Register StepBasic_OrganizationAssignment in _StepBasic:
_StepBasic.StepBasic_OrganizationAssignment_swigregister(StepBasic_OrganizationAssignment)

class StepBasic_OrganizationRole(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a organizationrole.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_OrganizationRole_swiginit(self, _StepBasic.new_StepBasic_OrganizationRole(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_OrganizationRole_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_OrganizationRole_Name(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_OrganizationRole_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_OrganizationRole_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_OrganizationRole

# Register StepBasic_OrganizationRole in _StepBasic:
_StepBasic.StepBasic_OrganizationRole_swigregister(StepBasic_OrganizationRole)

class StepBasic_Person(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a person.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_Person_swiginit(self, _StepBasic.new_StepBasic_Person(*args))

    def FirstName(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Person_FirstName(self, *args)

    def HasFirstName(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Person_HasFirstName(self, *args)

    def HasLastName(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Person_HasLastName(self, *args)

    def HasMiddleNames(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Person_HasMiddleNames(self, *args)

    def HasPrefixTitles(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Person_HasPrefixTitles(self, *args)

    def HasSuffixTitles(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_Person_HasSuffixTitles(self, *args)

    def Id(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Person_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aId: TCollection_HAsciiString
        hasAlastName: bool
        aLastName: TCollection_HAsciiString
        hasAfirstName: bool
        aFirstName: TCollection_HAsciiString
        hasAmiddleNames: bool
        aMiddleNames: Interface_HArray1OfHAsciiString
        hasAprefixTitles: bool
        aPrefixTitles: Interface_HArray1OfHAsciiString
        hasAsuffixTitles: bool
        aSuffixTitles: Interface_HArray1OfHAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Person_Init(self, *args)

    def LastName(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Person_LastName(self, *args)

    def MiddleNames(self, *args) -> "opencascade::handle< Interface_HArray1OfHAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Interface_HArray1OfHAsciiString>

        """
        return _StepBasic.StepBasic_Person_MiddleNames(self, *args)

    def MiddleNamesValue(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Person_MiddleNamesValue(self, *args)

    def NbMiddleNames(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_Person_NbMiddleNames(self, *args)

    def NbPrefixTitles(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_Person_NbPrefixTitles(self, *args)

    def NbSuffixTitles(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_Person_NbSuffixTitles(self, *args)

    def PrefixTitles(self, *args) -> "opencascade::handle< Interface_HArray1OfHAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Interface_HArray1OfHAsciiString>

        """
        return _StepBasic.StepBasic_Person_PrefixTitles(self, *args)

    def PrefixTitlesValue(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Person_PrefixTitlesValue(self, *args)

    def SetFirstName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFirstName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Person_SetFirstName(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aId: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Person_SetId(self, *args)

    def SetLastName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLastName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Person_SetLastName(self, *args)

    def SetMiddleNames(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMiddleNames: Interface_HArray1OfHAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Person_SetMiddleNames(self, *args)

    def SetPrefixTitles(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPrefixTitles: Interface_HArray1OfHAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Person_SetPrefixTitles(self, *args)

    def SetSuffixTitles(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSuffixTitles: Interface_HArray1OfHAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Person_SetSuffixTitles(self, *args)

    def SuffixTitles(self, *args) -> "opencascade::handle< Interface_HArray1OfHAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Interface_HArray1OfHAsciiString>

        """
        return _StepBasic.StepBasic_Person_SuffixTitles(self, *args)

    def SuffixTitlesValue(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Person_SuffixTitlesValue(self, *args)

    def UnSetFirstName(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Person_UnSetFirstName(self, *args)

    def UnSetLastName(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Person_UnSetLastName(self, *args)

    def UnSetMiddleNames(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Person_UnSetMiddleNames(self, *args)

    def UnSetPrefixTitles(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Person_UnSetPrefixTitles(self, *args)

    def UnSetSuffixTitles(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Person_UnSetSuffixTitles(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_Person_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_Person

# Register StepBasic_Person in _StepBasic:
_StepBasic.StepBasic_Person_swigregister(StepBasic_Person)

class StepBasic_PersonAndOrganization(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a personandorganization.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_PersonAndOrganization_swiginit(self, _StepBasic.new_StepBasic_PersonAndOrganization(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aThePerson: StepBasic_Person
        aTheOrganization: StepBasic_Organization

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_PersonAndOrganization_Init(self, *args)

    def SetTheOrganization(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aTheOrganization: StepBasic_Organization

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_PersonAndOrganization_SetTheOrganization(self, *args)

    def SetThePerson(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aThePerson: StepBasic_Person

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_PersonAndOrganization_SetThePerson(self, *args)

    def TheOrganization(self, *args) -> "opencascade::handle< StepBasic_Organization >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Organization>

        """
        return _StepBasic.StepBasic_PersonAndOrganization_TheOrganization(self, *args)

    def ThePerson(self, *args) -> "opencascade::handle< StepBasic_Person >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Person>

        """
        return _StepBasic.StepBasic_PersonAndOrganization_ThePerson(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_PersonAndOrganization_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_PersonAndOrganization

# Register StepBasic_PersonAndOrganization in _StepBasic:
_StepBasic.StepBasic_PersonAndOrganization_swigregister(StepBasic_PersonAndOrganization)

class StepBasic_PersonAndOrganizationAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def AssignedPersonAndOrganization(self, *args) -> "opencascade::handle< StepBasic_PersonAndOrganization >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_PersonAndOrganization>

        """
        return _StepBasic.StepBasic_PersonAndOrganizationAssignment_AssignedPersonAndOrganization(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedPersonAndOrganization: StepBasic_PersonAndOrganization
        aRole: StepBasic_PersonAndOrganizationRole

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_PersonAndOrganizationAssignment_Init(self, *args)

    def Role(self, *args) -> "opencascade::handle< StepBasic_PersonAndOrganizationRole >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_PersonAndOrganizationRole>

        """
        return _StepBasic.StepBasic_PersonAndOrganizationAssignment_Role(self, *args)

    def SetAssignedPersonAndOrganization(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedPersonAndOrganization: StepBasic_PersonAndOrganization

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_PersonAndOrganizationAssignment_SetAssignedPersonAndOrganization(self, *args)

    def SetRole(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRole: StepBasic_PersonAndOrganizationRole

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_PersonAndOrganizationAssignment_SetRole(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_PersonAndOrganizationAssignment_DownCast(t)


    __repr__ = _dumps_object


    def __init__(self):
        _StepBasic.StepBasic_PersonAndOrganizationAssignment_swiginit(self, _StepBasic.new_StepBasic_PersonAndOrganizationAssignment())
    __swig_destroy__ = _StepBasic.delete_StepBasic_PersonAndOrganizationAssignment

# Register StepBasic_PersonAndOrganizationAssignment in _StepBasic:
_StepBasic.StepBasic_PersonAndOrganizationAssignment_swigregister(StepBasic_PersonAndOrganizationAssignment)

class StepBasic_PersonAndOrganizationRole(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a personandorganizationrole.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_PersonAndOrganizationRole_swiginit(self, _StepBasic.new_StepBasic_PersonAndOrganizationRole(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_PersonAndOrganizationRole_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_PersonAndOrganizationRole_Name(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_PersonAndOrganizationRole_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_PersonAndOrganizationRole_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_PersonAndOrganizationRole

# Register StepBasic_PersonAndOrganizationRole in _StepBasic:
_StepBasic.StepBasic_PersonAndOrganizationRole_swigregister(StepBasic_PersonAndOrganizationRole)

class StepBasic_PersonOrganizationSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a personorganizationselect selecttype.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_PersonOrganizationSelect_swiginit(self, _StepBasic.new_StepBasic_PersonOrganizationSelect(*args))

    def Organization(self, *args) -> "opencascade::handle< StepBasic_Organization >":
        r"""
        Returns value as a organization (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Organization>

        """
        return _StepBasic.StepBasic_PersonOrganizationSelect_Organization(self, *args)

    def Person(self, *args) -> "opencascade::handle< StepBasic_Person >":
        r"""
        Returns value as a person (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Person>

        """
        return _StepBasic.StepBasic_PersonOrganizationSelect_Person(self, *args)

    def PersonAndOrganization(self, *args) -> "opencascade::handle< StepBasic_PersonAndOrganization >":
        r"""
        Returns value as a personandorganization (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_PersonAndOrganization>

        """
        return _StepBasic.StepBasic_PersonOrganizationSelect_PersonAndOrganization(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_PersonOrganizationSelect

# Register StepBasic_PersonOrganizationSelect in _StepBasic:
_StepBasic.StepBasic_PersonOrganizationSelect_swigregister(StepBasic_PersonOrganizationSelect)

class StepBasic_Product(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a product.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_Product_swiginit(self, _StepBasic.new_StepBasic_Product(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Product_Description(self, *args)

    def FrameOfReference(self, *args) -> "opencascade::handle< StepBasic_HArray1OfProductContext >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_HArray1OfProductContext>

        """
        return _StepBasic.StepBasic_Product_FrameOfReference(self, *args)

    def FrameOfReferenceValue(self, *args) -> "opencascade::handle< StepBasic_ProductContext >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<StepBasic_ProductContext>

        """
        return _StepBasic.StepBasic_Product_FrameOfReferenceValue(self, *args)

    def Id(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Product_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aFrameOfReference: StepBasic_HArray1OfProductContext

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Product_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_Product_Name(self, *args)

    def NbFrameOfReference(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_Product_NbFrameOfReference(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Product_SetDescription(self, *args)

    def SetFrameOfReference(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFrameOfReference: StepBasic_HArray1OfProductContext

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Product_SetFrameOfReference(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aId: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Product_SetId(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_Product_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_Product_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_Product

# Register StepBasic_Product in _StepBasic:
_StepBasic.StepBasic_Product_swigregister(StepBasic_Product)

class StepBasic_ProductCategory(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a productcategory.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductCategory_swiginit(self, _StepBasic.new_StepBasic_ProductCategory(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductCategory_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_ProductCategory_HasDescription(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        hasAdescription: bool
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductCategory_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductCategory_Name(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductCategory_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductCategory_SetName(self, *args)

    def UnSetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductCategory_UnSetDescription(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductCategory_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductCategory

# Register StepBasic_ProductCategory in _StepBasic:
_StepBasic.StepBasic_ProductCategory_swigregister(StepBasic_ProductCategory)

class StepBasic_ProductCategoryRelationship(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductCategoryRelationship_swiginit(self, _StepBasic.new_StepBasic_ProductCategoryRelationship(*args))

    def Category(self, *args) -> "opencascade::handle< StepBasic_ProductCategory >":
        r"""
        Returns field category.

        Returns
        -------
        opencascade::handle<StepBasic_ProductCategory>

        """
        return _StepBasic.StepBasic_ProductCategoryRelationship_Category(self, *args)

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductCategoryRelationship_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_ProductCategoryRelationship_HasDescription(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString
        aCategory: StepBasic_ProductCategory
        aSubCategory: StepBasic_ProductCategory

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductCategoryRelationship_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductCategoryRelationship_Name(self, *args)

    def SetCategory(self, *args) -> "void":
        r"""
        Set field category.

        Parameters
        ----------
        Category: StepBasic_ProductCategory

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductCategoryRelationship_SetCategory(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductCategoryRelationship_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductCategoryRelationship_SetName(self, *args)

    def SetSubCategory(self, *args) -> "void":
        r"""
        Set field subcategory.

        Parameters
        ----------
        SubCategory: StepBasic_ProductCategory

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductCategoryRelationship_SetSubCategory(self, *args)

    def SubCategory(self, *args) -> "opencascade::handle< StepBasic_ProductCategory >":
        r"""
        Returns field subcategory.

        Returns
        -------
        opencascade::handle<StepBasic_ProductCategory>

        """
        return _StepBasic.StepBasic_ProductCategoryRelationship_SubCategory(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductCategoryRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductCategoryRelationship

# Register StepBasic_ProductCategoryRelationship in _StepBasic:
_StepBasic.StepBasic_ProductCategoryRelationship_swigregister(StepBasic_ProductCategoryRelationship)

class StepBasic_ProductDefinition(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a productdefinition.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductDefinition_swiginit(self, _StepBasic.new_StepBasic_ProductDefinition(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinition_Description(self, *args)

    def Formation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepBasic.StepBasic_ProductDefinition_Formation(self, *args)

    def FrameOfReference(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionContext >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionContext>

        """
        return _StepBasic.StepBasic_ProductDefinition_FrameOfReference(self, *args)

    def Id(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinition_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aFormation: StepBasic_ProductDefinitionFormation
        aFrameOfReference: StepBasic_ProductDefinitionContext

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinition_Init(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinition_SetDescription(self, *args)

    def SetFormation(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFormation: StepBasic_ProductDefinitionFormation

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinition_SetFormation(self, *args)

    def SetFrameOfReference(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFrameOfReference: StepBasic_ProductDefinitionContext

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinition_SetFrameOfReference(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aId: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinition_SetId(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductDefinition_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductDefinition

# Register StepBasic_ProductDefinition in _StepBasic:
_StepBasic.StepBasic_ProductDefinition_swigregister(StepBasic_ProductDefinition)

class StepBasic_ProductDefinitionFormation(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a productdefinitionformation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductDefinitionFormation_swiginit(self, _StepBasic.new_StepBasic_ProductDefinitionFormation(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinitionFormation_Description(self, *args)

    def Id(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinitionFormation_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aOfProduct: StepBasic_Product

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionFormation_Init(self, *args)

    def OfProduct(self, *args) -> "opencascade::handle< StepBasic_Product >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Product>

        """
        return _StepBasic.StepBasic_ProductDefinitionFormation_OfProduct(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionFormation_SetDescription(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aId: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionFormation_SetId(self, *args)

    def SetOfProduct(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aOfProduct: StepBasic_Product

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionFormation_SetOfProduct(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductDefinitionFormation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductDefinitionFormation

# Register StepBasic_ProductDefinitionFormation in _StepBasic:
_StepBasic.StepBasic_ProductDefinitionFormation_swigregister(StepBasic_ProductDefinitionFormation)

class StepBasic_ProductDefinitionFormationRelationship(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductDefinitionFormationRelationship_swiginit(self, _StepBasic.new_StepBasic_ProductDefinitionFormationRelationship(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationRelationship_Description(self, *args)

    def Id(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field id.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationRelationship_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aRelatingProductDefinitionFormation: StepBasic_ProductDefinitionFormation
        aRelatedProductDefinitionFormation: StepBasic_ProductDefinitionFormation

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationRelationship_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationRelationship_Name(self, *args)

    def RelatedProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns field relatedproductdefinitionformation.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationRelationship_RelatedProductDefinitionFormation(self, *args)

    def RelatingProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns field relatingproductdefinitionformation.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationRelationship_RelatingProductDefinitionFormation(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationRelationship_SetDescription(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        Set field id.

        Parameters
        ----------
        Id: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationRelationship_SetId(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationRelationship_SetName(self, *args)

    def SetRelatedProductDefinitionFormation(self, *args) -> "void":
        r"""
        Set field relatedproductdefinitionformation.

        Parameters
        ----------
        RelatedProductDefinitionFormation: StepBasic_ProductDefinitionFormation

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationRelationship_SetRelatedProductDefinitionFormation(self, *args)

    def SetRelatingProductDefinitionFormation(self, *args) -> "void":
        r"""
        Set field relatingproductdefinitionformation.

        Parameters
        ----------
        RelatingProductDefinitionFormation: StepBasic_ProductDefinitionFormation

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationRelationship_SetRelatingProductDefinitionFormation(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductDefinitionFormationRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductDefinitionFormationRelationship

# Register StepBasic_ProductDefinitionFormationRelationship in _StepBasic:
_StepBasic.StepBasic_ProductDefinitionFormationRelationship_swigregister(StepBasic_ProductDefinitionFormationRelationship)

class StepBasic_ProductDefinitionOrReference(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a productdefinitionorreference selecttype.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductDefinitionOrReference_swiginit(self, _StepBasic.new_StepBasic_ProductDefinitionOrReference(*args))

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as a productdefinition (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepBasic.StepBasic_ProductDefinitionOrReference_ProductDefinition(self, *args)

    def ProductDefinitionReference(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionReference >":
        r"""
        Returns value as a productdefinitionreference (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionReference>

        """
        return _StepBasic.StepBasic_ProductDefinitionOrReference_ProductDefinitionReference(self, *args)

    def ProductDefinitionReferenceWithLocalRepresentation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionReferenceWithLocalRepresentation >":
        r"""
        Returns value as a productdefinitionreferencewithlocalrepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionReferenceWithLocalRepresentation>

        """
        return _StepBasic.StepBasic_ProductDefinitionOrReference_ProductDefinitionReferenceWithLocalRepresentation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductDefinitionOrReference

# Register StepBasic_ProductDefinitionOrReference in _StepBasic:
_StepBasic.StepBasic_ProductDefinitionOrReference_swigregister(StepBasic_ProductDefinitionOrReference)

class StepBasic_ProductDefinitionReference(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductDefinitionReference_swiginit(self, _StepBasic.new_StepBasic_ProductDefinitionReference(*args))

    def HasIdOwningOrganizationName(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if idowningorganizationname exists.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_ProductDefinitionReference_HasIdOwningOrganizationName(self, *args)

    def IdOwningOrganizationName(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field idowningorganizationname.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinitionReference_IdOwningOrganizationName(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        theSource: StepBasic_ExternalSource
        theProductId: TCollection_HAsciiString
        theProductDefinitionFormationId: TCollection_HAsciiString
        theProductDefinitionId: TCollection_HAsciiString
        theIdOwningOrganizationName: TCollection_HAsciiString

        Returns
        -------
        None
        Initialize all fields (own and inherited).

        Parameters
        ----------
        theSource: StepBasic_ExternalSource
        theProductId: TCollection_HAsciiString
        theProductDefinitionFormationId: TCollection_HAsciiString
        theProductDefinitionId: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionReference_Init(self, *args)

    def ProductDefinitionFormationId(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field productdefinitionformationid.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinitionReference_ProductDefinitionFormationId(self, *args)

    def ProductDefinitionId(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field productdefinitionid.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinitionReference_ProductDefinitionId(self, *args)

    def ProductId(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field productid.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinitionReference_ProductId(self, *args)

    def SetIdOwningOrganizationName(self, *args) -> "void":
        r"""
        Set field idowningorganizationname.

        Parameters
        ----------
        theIdOwningOrganizationName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionReference_SetIdOwningOrganizationName(self, *args)

    def SetProductDefinitionFormationId(self, *args) -> "void":
        r"""
        Set field productdefinitionformationid.

        Parameters
        ----------
        theProductDefinitionFormationId: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionReference_SetProductDefinitionFormationId(self, *args)

    def SetProductDefinitionId(self, *args) -> "void":
        r"""
        Set field productdefinitionid.

        Parameters
        ----------
        theProductDefinitionId: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionReference_SetProductDefinitionId(self, *args)

    def SetProductId(self, *args) -> "void":
        r"""
        Set field productid.

        Parameters
        ----------
        theProductId: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionReference_SetProductId(self, *args)

    def SetSource(self, *args) -> "void":
        r"""
        Set field source.

        Parameters
        ----------
        theSource: StepBasic_ExternalSource

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionReference_SetSource(self, *args)

    def Source(self, *args) -> "opencascade::handle< StepBasic_ExternalSource >":
        r"""
        Returns field source.

        Returns
        -------
        opencascade::handle<StepBasic_ExternalSource>

        """
        return _StepBasic.StepBasic_ProductDefinitionReference_Source(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductDefinitionReference_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductDefinitionReference

# Register StepBasic_ProductDefinitionReference in _StepBasic:
_StepBasic.StepBasic_ProductDefinitionReference_swigregister(StepBasic_ProductDefinitionReference)

class StepBasic_ProductDefinitionRelationship(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductDefinitionRelationship_swiginit(self, _StepBasic.new_StepBasic_ProductDefinitionRelationship(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_HasDescription(self, *args)

    def Id(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field id.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString
        aRelatingProductDefinition: StepBasic_ProductDefinition
        aRelatedProductDefinition: StepBasic_ProductDefinition

        Returns
        -------
        None
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString
        aRelatingProductDefinition: StepBasic_ProductDefinitionOrReference
        aRelatedProductDefinition: StepBasic_ProductDefinitionOrReference

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_Name(self, *args)

    def RelatedProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns field relatedproductdefinition.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_RelatedProductDefinition(self, *args)

    def RelatedProductDefinitionAP242(self, *args) -> "StepBasic_ProductDefinitionOrReference":
        r"""
        Returns field relatedproductdefinition in ap242.

        Returns
        -------
        StepBasic_ProductDefinitionOrReference

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_RelatedProductDefinitionAP242(self, *args)

    def RelatingProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns field relatingproductdefinition.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_RelatingProductDefinition(self, *args)

    def RelatingProductDefinitionAP242(self, *args) -> "StepBasic_ProductDefinitionOrReference":
        r"""
        Returns field relatingproductdefinition in ap242.

        Returns
        -------
        StepBasic_ProductDefinitionOrReference

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_RelatingProductDefinitionAP242(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_SetDescription(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        Set field id.

        Parameters
        ----------
        Id: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_SetId(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_SetName(self, *args)

    def SetRelatedProductDefinition(self, *args) -> "void":
        r"""
        Set field relatedproductdefinition.

        Parameters
        ----------
        RelatedProductDefinition: StepBasic_ProductDefinition

        Returns
        -------
        None
        Set field relatedproductdefinition in ap242.

        Parameters
        ----------
        RelatedProductDefinition: StepBasic_ProductDefinitionOrReference

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_SetRelatedProductDefinition(self, *args)

    def SetRelatingProductDefinition(self, *args) -> "void":
        r"""
        Set field relatingproductdefinition.

        Parameters
        ----------
        RelatingProductDefinition: StepBasic_ProductDefinition

        Returns
        -------
        None
        Set field relatingproductdefinition in ap242.

        Parameters
        ----------
        RelatingProductDefinition: StepBasic_ProductDefinitionOrReference

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionRelationship_SetRelatingProductDefinition(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductDefinitionRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductDefinitionRelationship

# Register StepBasic_ProductDefinitionRelationship in _StepBasic:
_StepBasic.StepBasic_ProductDefinitionRelationship_swigregister(StepBasic_ProductDefinitionRelationship)

class StepBasic_ProductOrFormationOrDefinition(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductOrFormationOrDefinition_swiginit(self, _StepBasic.new_StepBasic_ProductOrFormationOrDefinition(*args))

    def Product(self, *args) -> "opencascade::handle< StepBasic_Product >":
        r"""
        Returns value as product (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Product>

        """
        return _StepBasic.StepBasic_ProductOrFormationOrDefinition_Product(self, *args)

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as productdefinition (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepBasic.StepBasic_ProductOrFormationOrDefinition_ProductDefinition(self, *args)

    def ProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns value as productdefinitionformation (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepBasic.StepBasic_ProductOrFormationOrDefinition_ProductDefinitionFormation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductOrFormationOrDefinition

# Register StepBasic_ProductOrFormationOrDefinition in _StepBasic:
_StepBasic.StepBasic_ProductOrFormationOrDefinition_swigregister(StepBasic_ProductOrFormationOrDefinition)

class StepBasic_RoleAssociation(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_RoleAssociation_swiginit(self, _StepBasic.new_StepBasic_RoleAssociation(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRole: StepBasic_ObjectRole
        aItemWithRole: StepBasic_RoleSelect

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_RoleAssociation_Init(self, *args)

    def ItemWithRole(self, *args) -> "StepBasic_RoleSelect":
        r"""
        Returns field itemwithrole.

        Returns
        -------
        StepBasic_RoleSelect

        """
        return _StepBasic.StepBasic_RoleAssociation_ItemWithRole(self, *args)

    def Role(self, *args) -> "opencascade::handle< StepBasic_ObjectRole >":
        r"""
        Returns field role.

        Returns
        -------
        opencascade::handle<StepBasic_ObjectRole>

        """
        return _StepBasic.StepBasic_RoleAssociation_Role(self, *args)

    def SetItemWithRole(self, *args) -> "void":
        r"""
        Set field itemwithrole.

        Parameters
        ----------
        ItemWithRole: StepBasic_RoleSelect

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_RoleAssociation_SetItemWithRole(self, *args)

    def SetRole(self, *args) -> "void":
        r"""
        Set field role.

        Parameters
        ----------
        Role: StepBasic_ObjectRole

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_RoleAssociation_SetRole(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_RoleAssociation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_RoleAssociation

# Register StepBasic_RoleAssociation in _StepBasic:
_StepBasic.StepBasic_RoleAssociation_swigregister(StepBasic_RoleAssociation)

class StepBasic_RoleSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_RoleSelect_swiginit(self, _StepBasic.new_StepBasic_RoleSelect(*args))

    def ActionAssignment(self, *args) -> "opencascade::handle< StepBasic_ActionAssignment >":
        r"""
        Returns value as actionassignment (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ActionAssignment>

        """
        return _StepBasic.StepBasic_RoleSelect_ActionAssignment(self, *args)

    def ActionRequestAssignment(self, *args) -> "opencascade::handle< StepBasic_ActionRequestAssignment >":
        r"""
        Returns value as actionrequestassignment (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ActionRequestAssignment>

        """
        return _StepBasic.StepBasic_RoleSelect_ActionRequestAssignment(self, *args)

    def ApprovalAssignment(self, *args) -> "opencascade::handle< StepBasic_ApprovalAssignment >":
        r"""
        Returns value as approvalassignment (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ApprovalAssignment>

        """
        return _StepBasic.StepBasic_RoleSelect_ApprovalAssignment(self, *args)

    def ApprovalDateTime(self, *args) -> "opencascade::handle< StepBasic_ApprovalDateTime >":
        r"""
        Returns value as approvaldatetime (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ApprovalDateTime>

        """
        return _StepBasic.StepBasic_RoleSelect_ApprovalDateTime(self, *args)

    def CertificationAssignment(self, *args) -> "opencascade::handle< StepBasic_CertificationAssignment >":
        r"""
        Returns value as certificationassignment (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_CertificationAssignment>

        """
        return _StepBasic.StepBasic_RoleSelect_CertificationAssignment(self, *args)

    def ContractAssignment(self, *args) -> "opencascade::handle< StepBasic_ContractAssignment >":
        r"""
        Returns value as contractassignment (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ContractAssignment>

        """
        return _StepBasic.StepBasic_RoleSelect_ContractAssignment(self, *args)

    def DocumentReference(self, *args) -> "opencascade::handle< StepBasic_DocumentReference >":
        r"""
        Returns value as documentreference (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_DocumentReference>

        """
        return _StepBasic.StepBasic_RoleSelect_DocumentReference(self, *args)

    def EffectivityAssignment(self, *args) -> "opencascade::handle< StepBasic_EffectivityAssignment >":
        r"""
        Returns value as effectivityassignment (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_EffectivityAssignment>

        """
        return _StepBasic.StepBasic_RoleSelect_EffectivityAssignment(self, *args)

    def GroupAssignment(self, *args) -> "opencascade::handle< StepBasic_GroupAssignment >":
        r"""
        Returns value as groupassignment (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_GroupAssignment>

        """
        return _StepBasic.StepBasic_RoleSelect_GroupAssignment(self, *args)

    def NameAssignment(self, *args) -> "opencascade::handle< StepBasic_NameAssignment >":
        r"""
        Returns value as nameassignment (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_NameAssignment>

        """
        return _StepBasic.StepBasic_RoleSelect_NameAssignment(self, *args)

    def SecurityClassificationAssignment(self, *args) -> "opencascade::handle< StepBasic_SecurityClassificationAssignment >":
        r"""
        Returns value as securityclassificationassignment (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_SecurityClassificationAssignment>

        """
        return _StepBasic.StepBasic_RoleSelect_SecurityClassificationAssignment(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_RoleSelect

# Register StepBasic_RoleSelect in _StepBasic:
_StepBasic.StepBasic_RoleSelect_swigregister(StepBasic_RoleSelect)

class StepBasic_SecurityClassification(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a securityclassification.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SecurityClassification_swiginit(self, _StepBasic.new_StepBasic_SecurityClassification(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aPurpose: TCollection_HAsciiString
        aSecurityLevel: StepBasic_SecurityClassificationLevel

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SecurityClassification_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_SecurityClassification_Name(self, *args)

    def Purpose(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_SecurityClassification_Purpose(self, *args)

    def SecurityLevel(self, *args) -> "opencascade::handle< StepBasic_SecurityClassificationLevel >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_SecurityClassificationLevel>

        """
        return _StepBasic.StepBasic_SecurityClassification_SecurityLevel(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SecurityClassification_SetName(self, *args)

    def SetPurpose(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPurpose: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SecurityClassification_SetPurpose(self, *args)

    def SetSecurityLevel(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSecurityLevel: StepBasic_SecurityClassificationLevel

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SecurityClassification_SetSecurityLevel(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SecurityClassification_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SecurityClassification

# Register StepBasic_SecurityClassification in _StepBasic:
_StepBasic.StepBasic_SecurityClassification_swigregister(StepBasic_SecurityClassification)

class StepBasic_SecurityClassificationAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def AssignedSecurityClassification(self, *args) -> "opencascade::handle< StepBasic_SecurityClassification >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_SecurityClassification>

        """
        return _StepBasic.StepBasic_SecurityClassificationAssignment_AssignedSecurityClassification(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedSecurityClassification: StepBasic_SecurityClassification

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SecurityClassificationAssignment_Init(self, *args)

    def SetAssignedSecurityClassification(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedSecurityClassification: StepBasic_SecurityClassification

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SecurityClassificationAssignment_SetAssignedSecurityClassification(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SecurityClassificationAssignment_DownCast(t)


    __repr__ = _dumps_object


    def __init__(self):
        _StepBasic.StepBasic_SecurityClassificationAssignment_swiginit(self, _StepBasic.new_StepBasic_SecurityClassificationAssignment())
    __swig_destroy__ = _StepBasic.delete_StepBasic_SecurityClassificationAssignment

# Register StepBasic_SecurityClassificationAssignment in _StepBasic:
_StepBasic.StepBasic_SecurityClassificationAssignment_swigregister(StepBasic_SecurityClassificationAssignment)

class StepBasic_SecurityClassificationLevel(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a securityclassificationlevel.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SecurityClassificationLevel_swiginit(self, _StepBasic.new_StepBasic_SecurityClassificationLevel(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SecurityClassificationLevel_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_SecurityClassificationLevel_Name(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SecurityClassificationLevel_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SecurityClassificationLevel_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SecurityClassificationLevel

# Register StepBasic_SecurityClassificationLevel in _StepBasic:
_StepBasic.StepBasic_SecurityClassificationLevel_swigregister(StepBasic_SecurityClassificationLevel)

class StepBasic_SizeMember(OCC.Core.StepData.StepData_SelectReal):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SizeMember_swiginit(self, _StepBasic.new_StepBasic_SizeMember(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SizeMember_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SizeMember

# Register StepBasic_SizeMember in _StepBasic:
_StepBasic.StepBasic_SizeMember_swigregister(StepBasic_SizeMember)

class StepBasic_SizeSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a sizeselect selecttype.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SizeSelect_swiginit(self, _StepBasic.new_StepBasic_SizeSelect(*args))

    def RealValue(self, *args) -> "Standard_Real":
        r"""
        Returns value as a real (null if another type).

        Returns
        -------
        float

        """
        return _StepBasic.StepBasic_SizeSelect_RealValue(self, *args)

    def SetRealValue(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aReal: float

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SizeSelect_SetRealValue(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SizeSelect

# Register StepBasic_SizeSelect in _StepBasic:
_StepBasic.StepBasic_SizeSelect_swigregister(StepBasic_SizeSelect)

class StepBasic_SourceItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SourceItem_swiginit(self, _StepBasic.new_StepBasic_SourceItem(*args))

    def Identifier(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns value as identifier (or null if another type).

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_SourceItem_Identifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SourceItem

# Register StepBasic_SourceItem in _StepBasic:
_StepBasic.StepBasic_SourceItem_swigregister(StepBasic_SourceItem)

class StepBasic_Unit(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates empty object.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_Unit_swiginit(self, _StepBasic.new_StepBasic_Unit(*args))

    def DerivedUnit(self, *args) -> "opencascade::handle< StepBasic_DerivedUnit >":
        r"""
        Returns value as a derivedunit (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_DerivedUnit>

        """
        return _StepBasic.StepBasic_Unit_DerivedUnit(self, *args)

    def NamedUnit(self, *args) -> "opencascade::handle< StepBasic_NamedUnit >":
        r"""
        Returns value as a namedunit (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_NamedUnit>

        """
        return _StepBasic.StepBasic_Unit_NamedUnit(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_Unit

# Register StepBasic_Unit in _StepBasic:
_StepBasic.StepBasic_Unit_swigregister(StepBasic_Unit)

class StepBasic_VersionedActionRequest(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_VersionedActionRequest_swiginit(self, _StepBasic.new_StepBasic_VersionedActionRequest(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_VersionedActionRequest_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_VersionedActionRequest_HasDescription(self, *args)

    def Id(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field id.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_VersionedActionRequest_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aVersion: TCollection_HAsciiString
        aPurpose: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_VersionedActionRequest_Init(self, *args)

    def Purpose(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field purpose.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_VersionedActionRequest_Purpose(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_VersionedActionRequest_SetDescription(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        Set field id.

        Parameters
        ----------
        Id: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_VersionedActionRequest_SetId(self, *args)

    def SetPurpose(self, *args) -> "void":
        r"""
        Set field purpose.

        Parameters
        ----------
        Purpose: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_VersionedActionRequest_SetPurpose(self, *args)

    def SetVersion(self, *args) -> "void":
        r"""
        Set field version.

        Parameters
        ----------
        Version: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_VersionedActionRequest_SetVersion(self, *args)

    def Version(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field version.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_VersionedActionRequest_Version(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_VersionedActionRequest_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_VersionedActionRequest

# Register StepBasic_VersionedActionRequest in _StepBasic:
_StepBasic.StepBasic_VersionedActionRequest_swigregister(StepBasic_VersionedActionRequest)

class StepBasic_AreaUnit(StepBasic_NamedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_AreaUnit_swiginit(self, _StepBasic.new_StepBasic_AreaUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_AreaUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_AreaUnit

# Register StepBasic_AreaUnit in _StepBasic:
_StepBasic.StepBasic_AreaUnit_swigregister(StepBasic_AreaUnit)

class StepBasic_CalendarDate(StepBasic_Date):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a calendardate.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_CalendarDate_swiginit(self, _StepBasic.new_StepBasic_CalendarDate(*args))

    def DayComponent(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_CalendarDate_DayComponent(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aYearComponent: int
        aDayComponent: int
        aMonthComponent: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CalendarDate_Init(self, *args)

    def MonthComponent(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_CalendarDate_MonthComponent(self, *args)

    def SetDayComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDayComponent: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CalendarDate_SetDayComponent(self, *args)

    def SetMonthComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMonthComponent: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_CalendarDate_SetMonthComponent(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_CalendarDate_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_CalendarDate

# Register StepBasic_CalendarDate in _StepBasic:
_StepBasic.StepBasic_CalendarDate_swigregister(StepBasic_CalendarDate)

class StepBasic_ConversionBasedUnit(StepBasic_NamedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a conversionbasedunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ConversionBasedUnit_swiginit(self, _StepBasic.new_StepBasic_ConversionBasedUnit(*args))

    def ConversionFactor(self, *args) -> "opencascade::handle< StepBasic_MeasureWithUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_MeasureWithUnit>

        """
        return _StepBasic.StepBasic_ConversionBasedUnit_ConversionFactor(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDimensions: StepBasic_DimensionalExponents
        aName: TCollection_HAsciiString
        aConversionFactor: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnit_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ConversionBasedUnit_Name(self, *args)

    def SetConversionFactor(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConversionFactor: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnit_SetConversionFactor(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnit_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ConversionBasedUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ConversionBasedUnit

# Register StepBasic_ConversionBasedUnit in _StepBasic:
_StepBasic.StepBasic_ConversionBasedUnit_swigregister(StepBasic_ConversionBasedUnit)

class StepBasic_DigitalDocument(StepBasic_Document):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DigitalDocument_swiginit(self, _StepBasic.new_StepBasic_DigitalDocument(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DigitalDocument_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DigitalDocument

# Register StepBasic_DigitalDocument in _StepBasic:
_StepBasic.StepBasic_DigitalDocument_swigregister(StepBasic_DigitalDocument)

class StepBasic_DocumentFile(StepBasic_Document):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DocumentFile_swiginit(self, _StepBasic.new_StepBasic_DocumentFile(*args))

    def CharacterizedObject(self, *args) -> "opencascade::handle< StepBasic_CharacterizedObject >":
        r"""
        Returns data for supertype characterizedobject.

        Returns
        -------
        opencascade::handle<StepBasic_CharacterizedObject>

        """
        return _StepBasic.StepBasic_DocumentFile_CharacterizedObject(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aDocument_Id: TCollection_HAsciiString
        aDocument_Name: TCollection_HAsciiString
        hasDocument_Description: bool
        aDocument_Description: TCollection_HAsciiString
        aDocument_Kind: StepBasic_DocumentType
        aCharacterizedObject_Name: TCollection_HAsciiString
        hasCharacterizedObject_Description: bool
        aCharacterizedObject_Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentFile_Init(self, *args)

    def SetCharacterizedObject(self, *args) -> "void":
        r"""
        Set data for supertype characterizedobject.

        Parameters
        ----------
        CharacterizedObject: StepBasic_CharacterizedObject

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_DocumentFile_SetCharacterizedObject(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DocumentFile_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DocumentFile

# Register StepBasic_DocumentFile in _StepBasic:
_StepBasic.StepBasic_DocumentFile_swigregister(StepBasic_DocumentFile)

class StepBasic_DocumentProductEquivalence(StepBasic_DocumentProductAssociation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DocumentProductEquivalence_swiginit(self, _StepBasic.new_StepBasic_DocumentProductEquivalence(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DocumentProductEquivalence_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DocumentProductEquivalence

# Register StepBasic_DocumentProductEquivalence in _StepBasic:
_StepBasic.StepBasic_DocumentProductEquivalence_swigregister(StepBasic_DocumentProductEquivalence)

class StepBasic_ExternalIdentificationAssignment(StepBasic_IdentificationAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ExternalIdentificationAssignment_swiginit(self, _StepBasic.new_StepBasic_ExternalIdentificationAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aIdentificationAssignment_AssignedId: TCollection_HAsciiString
        aIdentificationAssignment_Role: StepBasic_IdentificationRole
        aSource: StepBasic_ExternalSource

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ExternalIdentificationAssignment_Init(self, *args)

    def SetSource(self, *args) -> "void":
        r"""
        Set field source.

        Parameters
        ----------
        Source: StepBasic_ExternalSource

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ExternalIdentificationAssignment_SetSource(self, *args)

    def Source(self, *args) -> "opencascade::handle< StepBasic_ExternalSource >":
        r"""
        Returns field source.

        Returns
        -------
        opencascade::handle<StepBasic_ExternalSource>

        """
        return _StepBasic.StepBasic_ExternalIdentificationAssignment_Source(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ExternalIdentificationAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ExternalIdentificationAssignment

# Register StepBasic_ExternalIdentificationAssignment in _StepBasic:
_StepBasic.StepBasic_ExternalIdentificationAssignment_swigregister(StepBasic_ExternalIdentificationAssignment)

class StepBasic_LengthMeasureWithUnit(StepBasic_MeasureWithUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a lengthmeasurewithunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_LengthMeasureWithUnit_swiginit(self, _StepBasic.new_StepBasic_LengthMeasureWithUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_LengthMeasureWithUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_LengthMeasureWithUnit

# Register StepBasic_LengthMeasureWithUnit in _StepBasic:
_StepBasic.StepBasic_LengthMeasureWithUnit_swigregister(StepBasic_LengthMeasureWithUnit)

class StepBasic_LengthUnit(StepBasic_NamedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a lengthunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_LengthUnit_swiginit(self, _StepBasic.new_StepBasic_LengthUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_LengthUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_LengthUnit

# Register StepBasic_LengthUnit in _StepBasic:
_StepBasic.StepBasic_LengthUnit_swigregister(StepBasic_LengthUnit)

class StepBasic_MassMeasureWithUnit(StepBasic_MeasureWithUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a massmeasurewithunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_MassMeasureWithUnit_swiginit(self, _StepBasic.new_StepBasic_MassMeasureWithUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_MassMeasureWithUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_MassMeasureWithUnit

# Register StepBasic_MassMeasureWithUnit in _StepBasic:
_StepBasic.StepBasic_MassMeasureWithUnit_swigregister(StepBasic_MassMeasureWithUnit)

class StepBasic_MassUnit(StepBasic_NamedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_MassUnit_swiginit(self, _StepBasic.new_StepBasic_MassUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_MassUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_MassUnit

# Register StepBasic_MassUnit in _StepBasic:
_StepBasic.StepBasic_MassUnit_swigregister(StepBasic_MassUnit)

class StepBasic_OrdinalDate(StepBasic_Date):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a ordinaldate.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_OrdinalDate_swiginit(self, _StepBasic.new_StepBasic_OrdinalDate(*args))

    def DayComponent(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_OrdinalDate_DayComponent(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aYearComponent: int
        aDayComponent: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_OrdinalDate_Init(self, *args)

    def SetDayComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDayComponent: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_OrdinalDate_SetDayComponent(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_OrdinalDate_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_OrdinalDate

# Register StepBasic_OrdinalDate in _StepBasic:
_StepBasic.StepBasic_OrdinalDate_swigregister(StepBasic_OrdinalDate)

class StepBasic_OrganizationalAddress(StepBasic_Address):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a organizationaladdress.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_OrganizationalAddress_swiginit(self, _StepBasic.new_StepBasic_OrganizationalAddress(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_OrganizationalAddress_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        hasAinternalLocation: bool
        aInternalLocation: TCollection_HAsciiString
        hasAstreetNumber: bool
        aStreetNumber: TCollection_HAsciiString
        hasAstreet: bool
        aStreet: TCollection_HAsciiString
        hasApostalBox: bool
        aPostalBox: TCollection_HAsciiString
        hasAtown: bool
        aTown: TCollection_HAsciiString
        hasAregion: bool
        aRegion: TCollection_HAsciiString
        hasApostalCode: bool
        aPostalCode: TCollection_HAsciiString
        hasAcountry: bool
        aCountry: TCollection_HAsciiString
        hasAfacsimileNumber: bool
        aFacsimileNumber: TCollection_HAsciiString
        hasAtelephoneNumber: bool
        aTelephoneNumber: TCollection_HAsciiString
        hasAelectronicMailAddress: bool
        aElectronicMailAddress: TCollection_HAsciiString
        hasAtelexNumber: bool
        aTelexNumber: TCollection_HAsciiString
        aOrganizations: StepBasic_HArray1OfOrganization
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_OrganizationalAddress_Init(self, *args)

    def NbOrganizations(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_OrganizationalAddress_NbOrganizations(self, *args)

    def Organizations(self, *args) -> "opencascade::handle< StepBasic_HArray1OfOrganization >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_HArray1OfOrganization>

        """
        return _StepBasic.StepBasic_OrganizationalAddress_Organizations(self, *args)

    def OrganizationsValue(self, *args) -> "opencascade::handle< StepBasic_Organization >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<StepBasic_Organization>

        """
        return _StepBasic.StepBasic_OrganizationalAddress_OrganizationsValue(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_OrganizationalAddress_SetDescription(self, *args)

    def SetOrganizations(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aOrganizations: StepBasic_HArray1OfOrganization

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_OrganizationalAddress_SetOrganizations(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_OrganizationalAddress_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_OrganizationalAddress

# Register StepBasic_OrganizationalAddress in _StepBasic:
_StepBasic.StepBasic_OrganizationalAddress_swigregister(StepBasic_OrganizationalAddress)

class StepBasic_PersonalAddress(StepBasic_Address):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a personaladdress.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_PersonalAddress_swiginit(self, _StepBasic.new_StepBasic_PersonalAddress(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_PersonalAddress_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        hasAinternalLocation: bool
        aInternalLocation: TCollection_HAsciiString
        hasAstreetNumber: bool
        aStreetNumber: TCollection_HAsciiString
        hasAstreet: bool
        aStreet: TCollection_HAsciiString
        hasApostalBox: bool
        aPostalBox: TCollection_HAsciiString
        hasAtown: bool
        aTown: TCollection_HAsciiString
        hasAregion: bool
        aRegion: TCollection_HAsciiString
        hasApostalCode: bool
        aPostalCode: TCollection_HAsciiString
        hasAcountry: bool
        aCountry: TCollection_HAsciiString
        hasAfacsimileNumber: bool
        aFacsimileNumber: TCollection_HAsciiString
        hasAtelephoneNumber: bool
        aTelephoneNumber: TCollection_HAsciiString
        hasAelectronicMailAddress: bool
        aElectronicMailAddress: TCollection_HAsciiString
        hasAtelexNumber: bool
        aTelexNumber: TCollection_HAsciiString
        aPeople: StepBasic_HArray1OfPerson
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_PersonalAddress_Init(self, *args)

    def NbPeople(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_PersonalAddress_NbPeople(self, *args)

    def People(self, *args) -> "opencascade::handle< StepBasic_HArray1OfPerson >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_HArray1OfPerson>

        """
        return _StepBasic.StepBasic_PersonalAddress_People(self, *args)

    def PeopleValue(self, *args) -> "opencascade::handle< StepBasic_Person >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<StepBasic_Person>

        """
        return _StepBasic.StepBasic_PersonalAddress_PeopleValue(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_PersonalAddress_SetDescription(self, *args)

    def SetPeople(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPeople: StepBasic_HArray1OfPerson

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_PersonalAddress_SetPeople(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_PersonalAddress_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_PersonalAddress

# Register StepBasic_PersonalAddress in _StepBasic:
_StepBasic.StepBasic_PersonalAddress_swigregister(StepBasic_PersonalAddress)

class StepBasic_PhysicallyModeledProductDefinition(StepBasic_ProductDefinition):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_PhysicallyModeledProductDefinition_swiginit(self, _StepBasic.new_StepBasic_PhysicallyModeledProductDefinition(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_PhysicallyModeledProductDefinition_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_PhysicallyModeledProductDefinition

# Register StepBasic_PhysicallyModeledProductDefinition in _StepBasic:
_StepBasic.StepBasic_PhysicallyModeledProductDefinition_swigregister(StepBasic_PhysicallyModeledProductDefinition)

class StepBasic_PlaneAngleMeasureWithUnit(StepBasic_MeasureWithUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a planeanglemeasurewithunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_PlaneAngleMeasureWithUnit_swiginit(self, _StepBasic.new_StepBasic_PlaneAngleMeasureWithUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_PlaneAngleMeasureWithUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_PlaneAngleMeasureWithUnit

# Register StepBasic_PlaneAngleMeasureWithUnit in _StepBasic:
_StepBasic.StepBasic_PlaneAngleMeasureWithUnit_swigregister(StepBasic_PlaneAngleMeasureWithUnit)

class StepBasic_PlaneAngleUnit(StepBasic_NamedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a planeangleunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_PlaneAngleUnit_swiginit(self, _StepBasic.new_StepBasic_PlaneAngleUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_PlaneAngleUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_PlaneAngleUnit

# Register StepBasic_PlaneAngleUnit in _StepBasic:
_StepBasic.StepBasic_PlaneAngleUnit_swigregister(StepBasic_PlaneAngleUnit)

class StepBasic_ProductConceptContext(StepBasic_ApplicationContextElement):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductConceptContext_swiginit(self, _StepBasic.new_StepBasic_ProductConceptContext(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aApplicationContextElement_Name: TCollection_HAsciiString
        aApplicationContextElement_FrameOfReference: StepBasic_ApplicationContext
        aMarketSegmentType: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductConceptContext_Init(self, *args)

    def MarketSegmentType(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field marketsegmenttype.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductConceptContext_MarketSegmentType(self, *args)

    def SetMarketSegmentType(self, *args) -> "void":
        r"""
        Set field marketsegmenttype.

        Parameters
        ----------
        MarketSegmentType: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductConceptContext_SetMarketSegmentType(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductConceptContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductConceptContext

# Register StepBasic_ProductConceptContext in _StepBasic:
_StepBasic.StepBasic_ProductConceptContext_swigregister(StepBasic_ProductConceptContext)

class StepBasic_ProductContext(StepBasic_ApplicationContextElement):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a productcontext.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductContext_swiginit(self, _StepBasic.new_StepBasic_ProductContext(*args))

    def DisciplineType(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductContext_DisciplineType(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aFrameOfReference: StepBasic_ApplicationContext
        aDisciplineType: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductContext_Init(self, *args)

    def SetDisciplineType(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDisciplineType: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductContext_SetDisciplineType(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductContext

# Register StepBasic_ProductContext in _StepBasic:
_StepBasic.StepBasic_ProductContext_swigregister(StepBasic_ProductContext)

class StepBasic_ProductDefinitionContext(StepBasic_ApplicationContextElement):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a productdefinitioncontext.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductDefinitionContext_swiginit(self, _StepBasic.new_StepBasic_ProductDefinitionContext(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aFrameOfReference: StepBasic_ApplicationContext
        aLifeCycleStage: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionContext_Init(self, *args)

    def LifeCycleStage(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_ProductDefinitionContext_LifeCycleStage(self, *args)

    def SetLifeCycleStage(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLifeCycleStage: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionContext_SetLifeCycleStage(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductDefinitionContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductDefinitionContext

# Register StepBasic_ProductDefinitionContext in _StepBasic:
_StepBasic.StepBasic_ProductDefinitionContext_swigregister(StepBasic_ProductDefinitionContext)

class StepBasic_ProductDefinitionEffectivity(StepBasic_Effectivity):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductDefinitionEffectivity_swiginit(self, _StepBasic.new_StepBasic_ProductDefinitionEffectivity(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aUsage: StepBasic_ProductDefinitionRelationship

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionEffectivity_Init(self, *args)

    def SetUsage(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aUsage: StepBasic_ProductDefinitionRelationship

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionEffectivity_SetUsage(self, *args)

    def Usage(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionRelationship >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionRelationship>

        """
        return _StepBasic.StepBasic_ProductDefinitionEffectivity_Usage(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductDefinitionEffectivity_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductDefinitionEffectivity

# Register StepBasic_ProductDefinitionEffectivity in _StepBasic:
_StepBasic.StepBasic_ProductDefinitionEffectivity_swigregister(StepBasic_ProductDefinitionEffectivity)

class StepBasic_ProductDefinitionFormationWithSpecifiedSource(StepBasic_ProductDefinitionFormation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a productdefinitionformationwithspecifiedsource.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductDefinitionFormationWithSpecifiedSource_swiginit(self, _StepBasic.new_StepBasic_ProductDefinitionFormationWithSpecifiedSource(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aOfProduct: StepBasic_Product
        aMakeOrBuy: StepBasic_Source

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationWithSpecifiedSource_Init(self, *args)

    def MakeOrBuy(self, *args) -> "StepBasic_Source":
        r"""
        No available documentation.

        Returns
        -------
        StepBasic_Source

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationWithSpecifiedSource_MakeOrBuy(self, *args)

    def SetMakeOrBuy(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMakeOrBuy: StepBasic_Source

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionFormationWithSpecifiedSource_SetMakeOrBuy(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductDefinitionFormationWithSpecifiedSource_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductDefinitionFormationWithSpecifiedSource

# Register StepBasic_ProductDefinitionFormationWithSpecifiedSource in _StepBasic:
_StepBasic.StepBasic_ProductDefinitionFormationWithSpecifiedSource_swigregister(StepBasic_ProductDefinitionFormationWithSpecifiedSource)

class StepBasic_ProductDefinitionReferenceWithLocalRepresentation(StepBasic_ProductDefinition):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a productdefinitionreferencewithlocalrepresentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductDefinitionReferenceWithLocalRepresentation_swiginit(self, _StepBasic.new_StepBasic_ProductDefinitionReferenceWithLocalRepresentation(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: StepBasic_ExternalSource
        theId: TCollection_HAsciiString
        theDescription: TCollection_HAsciiString
        theFormation: StepBasic_ProductDefinitionFormation
        theFrameOfReference: StepBasic_ProductDefinitionContext

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionReferenceWithLocalRepresentation_Init(self, *args)

    def SetSource(self, *args) -> "void":
        r"""
        Set field source.

        Parameters
        ----------
        theSource: StepBasic_ExternalSource

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionReferenceWithLocalRepresentation_SetSource(self, *args)

    def Source(self, *args) -> "opencascade::handle< StepBasic_ExternalSource >":
        r"""
        Returns field source.

        Returns
        -------
        opencascade::handle<StepBasic_ExternalSource>

        """
        return _StepBasic.StepBasic_ProductDefinitionReferenceWithLocalRepresentation_Source(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductDefinitionReferenceWithLocalRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductDefinitionReferenceWithLocalRepresentation

# Register StepBasic_ProductDefinitionReferenceWithLocalRepresentation in _StepBasic:
_StepBasic.StepBasic_ProductDefinitionReferenceWithLocalRepresentation_swigregister(StepBasic_ProductDefinitionReferenceWithLocalRepresentation)

class StepBasic_ProductDefinitionWithAssociatedDocuments(StepBasic_ProductDefinition):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductDefinitionWithAssociatedDocuments_swiginit(self, _StepBasic.new_StepBasic_ProductDefinitionWithAssociatedDocuments(*args))

    def DocIds(self, *args) -> "opencascade::handle< StepBasic_HArray1OfDocument >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_HArray1OfDocument>

        """
        return _StepBasic.StepBasic_ProductDefinitionWithAssociatedDocuments_DocIds(self, *args)

    def DocIdsValue(self, *args) -> "opencascade::handle< StepBasic_Document >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<StepBasic_Document>

        """
        return _StepBasic.StepBasic_ProductDefinitionWithAssociatedDocuments_DocIdsValue(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aFormation: StepBasic_ProductDefinitionFormation
        aFrame: StepBasic_ProductDefinitionContext
        aDocIds: StepBasic_HArray1OfDocument

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionWithAssociatedDocuments_Init(self, *args)

    def NbDocIds(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_ProductDefinitionWithAssociatedDocuments_NbDocIds(self, *args)

    def SetDocIds(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        DocIds: StepBasic_HArray1OfDocument

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionWithAssociatedDocuments_SetDocIds(self, *args)

    def SetDocIdsValue(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int
        adoc: StepBasic_Document

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductDefinitionWithAssociatedDocuments_SetDocIdsValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductDefinitionWithAssociatedDocuments_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductDefinitionWithAssociatedDocuments

# Register StepBasic_ProductDefinitionWithAssociatedDocuments in _StepBasic:
_StepBasic.StepBasic_ProductDefinitionWithAssociatedDocuments_swigregister(StepBasic_ProductDefinitionWithAssociatedDocuments)

class StepBasic_ProductRelatedProductCategory(StepBasic_ProductCategory):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a productrelatedproductcategory.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductRelatedProductCategory_swiginit(self, _StepBasic.new_StepBasic_ProductRelatedProductCategory(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        hasAdescription: bool
        aDescription: TCollection_HAsciiString
        aProducts: StepBasic_HArray1OfProduct

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductRelatedProductCategory_Init(self, *args)

    def NbProducts(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_ProductRelatedProductCategory_NbProducts(self, *args)

    def Products(self, *args) -> "opencascade::handle< StepBasic_HArray1OfProduct >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_HArray1OfProduct>

        """
        return _StepBasic.StepBasic_ProductRelatedProductCategory_Products(self, *args)

    def ProductsValue(self, *args) -> "opencascade::handle< StepBasic_Product >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<StepBasic_Product>

        """
        return _StepBasic.StepBasic_ProductRelatedProductCategory_ProductsValue(self, *args)

    def SetProducts(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aProducts: StepBasic_HArray1OfProduct

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ProductRelatedProductCategory_SetProducts(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductRelatedProductCategory_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductRelatedProductCategory

# Register StepBasic_ProductRelatedProductCategory in _StepBasic:
_StepBasic.StepBasic_ProductRelatedProductCategory_swigregister(StepBasic_ProductRelatedProductCategory)

class StepBasic_RatioMeasureWithUnit(StepBasic_MeasureWithUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a ratiomeasurewithunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_RatioMeasureWithUnit_swiginit(self, _StepBasic.new_StepBasic_RatioMeasureWithUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_RatioMeasureWithUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_RatioMeasureWithUnit

# Register StepBasic_RatioMeasureWithUnit in _StepBasic:
_StepBasic.StepBasic_RatioMeasureWithUnit_swigregister(StepBasic_RatioMeasureWithUnit)

class StepBasic_RatioUnit(StepBasic_NamedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a ratiounit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_RatioUnit_swiginit(self, _StepBasic.new_StepBasic_RatioUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_RatioUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_RatioUnit

# Register StepBasic_RatioUnit in _StepBasic:
_StepBasic.StepBasic_RatioUnit_swigregister(StepBasic_RatioUnit)

class StepBasic_SiUnit(StepBasic_NamedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a siunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SiUnit_swiginit(self, _StepBasic.new_StepBasic_SiUnit(*args))

    def HasPrefix(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_SiUnit_HasPrefix(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        hasAprefix: bool
        aPrefix: StepBasic_SiPrefix
        aName: StepBasic_SiUnitName

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnit_Init(self, *args)

    def Name(self, *args) -> "StepBasic_SiUnitName":
        r"""
        No available documentation.

        Returns
        -------
        StepBasic_SiUnitName

        """
        return _StepBasic.StepBasic_SiUnit_Name(self, *args)

    def Prefix(self, *args) -> "StepBasic_SiPrefix":
        r"""
        No available documentation.

        Returns
        -------
        StepBasic_SiPrefix

        """
        return _StepBasic.StepBasic_SiUnit_Prefix(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: StepBasic_SiUnitName

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnit_SetName(self, *args)

    def SetPrefix(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPrefix: StepBasic_SiPrefix

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnit_SetPrefix(self, *args)

    def UnSetPrefix(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnit_UnSetPrefix(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SiUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SiUnit

# Register StepBasic_SiUnit in _StepBasic:
_StepBasic.StepBasic_SiUnit_swigregister(StepBasic_SiUnit)

class StepBasic_SolidAngleMeasureWithUnit(StepBasic_MeasureWithUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a solidanglemeasurewithunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SolidAngleMeasureWithUnit_swiginit(self, _StepBasic.new_StepBasic_SolidAngleMeasureWithUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SolidAngleMeasureWithUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SolidAngleMeasureWithUnit

# Register StepBasic_SolidAngleMeasureWithUnit in _StepBasic:
_StepBasic.StepBasic_SolidAngleMeasureWithUnit_swigregister(StepBasic_SolidAngleMeasureWithUnit)

class StepBasic_SolidAngleUnit(StepBasic_NamedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a solidangleunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SolidAngleUnit_swiginit(self, _StepBasic.new_StepBasic_SolidAngleUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SolidAngleUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SolidAngleUnit

# Register StepBasic_SolidAngleUnit in _StepBasic:
_StepBasic.StepBasic_SolidAngleUnit_swigregister(StepBasic_SolidAngleUnit)

class StepBasic_ThermodynamicTemperatureUnit(StepBasic_NamedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ThermodynamicTemperatureUnit_swiginit(self, _StepBasic.new_StepBasic_ThermodynamicTemperatureUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ThermodynamicTemperatureUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ThermodynamicTemperatureUnit

# Register StepBasic_ThermodynamicTemperatureUnit in _StepBasic:
_StepBasic.StepBasic_ThermodynamicTemperatureUnit_swigregister(StepBasic_ThermodynamicTemperatureUnit)

class StepBasic_TimeMeasureWithUnit(StepBasic_MeasureWithUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a timemeasurewithunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_TimeMeasureWithUnit_swiginit(self, _StepBasic.new_StepBasic_TimeMeasureWithUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_TimeMeasureWithUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_TimeMeasureWithUnit

# Register StepBasic_TimeMeasureWithUnit in _StepBasic:
_StepBasic.StepBasic_TimeMeasureWithUnit_swigregister(StepBasic_TimeMeasureWithUnit)

class StepBasic_TimeUnit(StepBasic_NamedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a timeunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_TimeUnit_swiginit(self, _StepBasic.new_StepBasic_TimeUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_TimeUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_TimeUnit

# Register StepBasic_TimeUnit in _StepBasic:
_StepBasic.StepBasic_TimeUnit_swigregister(StepBasic_TimeUnit)

class StepBasic_UncertaintyMeasureWithUnit(StepBasic_MeasureWithUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a uncertaintymeasurewithunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_UncertaintyMeasureWithUnit_swiginit(self, _StepBasic.new_StepBasic_UncertaintyMeasureWithUnit(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_UncertaintyMeasureWithUnit_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aValueComponent: StepBasic_MeasureValueMember
        aUnitComponent: StepBasic_Unit
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_UncertaintyMeasureWithUnit_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepBasic.StepBasic_UncertaintyMeasureWithUnit_Name(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_UncertaintyMeasureWithUnit_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_UncertaintyMeasureWithUnit_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_UncertaintyMeasureWithUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_UncertaintyMeasureWithUnit

# Register StepBasic_UncertaintyMeasureWithUnit in _StepBasic:
_StepBasic.StepBasic_UncertaintyMeasureWithUnit_swigregister(StepBasic_UncertaintyMeasureWithUnit)

class StepBasic_VolumeUnit(StepBasic_NamedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_VolumeUnit_swiginit(self, _StepBasic.new_StepBasic_VolumeUnit(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_VolumeUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_VolumeUnit

# Register StepBasic_VolumeUnit in _StepBasic:
_StepBasic.StepBasic_VolumeUnit_swigregister(StepBasic_VolumeUnit)

class StepBasic_WeekOfYearAndDayDate(StepBasic_Date):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a weekofyearanddaydate.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_WeekOfYearAndDayDate_swiginit(self, _StepBasic.new_StepBasic_WeekOfYearAndDayDate(*args))

    def DayComponent(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_WeekOfYearAndDayDate_DayComponent(self, *args)

    def HasDayComponent(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepBasic.StepBasic_WeekOfYearAndDayDate_HasDayComponent(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aYearComponent: int
        aWeekComponent: int
        hasAdayComponent: bool
        aDayComponent: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_WeekOfYearAndDayDate_Init(self, *args)

    def SetDayComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDayComponent: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_WeekOfYearAndDayDate_SetDayComponent(self, *args)

    def SetWeekComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aWeekComponent: int

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_WeekOfYearAndDayDate_SetWeekComponent(self, *args)

    def UnSetDayComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_WeekOfYearAndDayDate_UnSetDayComponent(self, *args)

    def WeekComponent(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepBasic.StepBasic_WeekOfYearAndDayDate_WeekComponent(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_WeekOfYearAndDayDate_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_WeekOfYearAndDayDate

# Register StepBasic_WeekOfYearAndDayDate in _StepBasic:
_StepBasic.StepBasic_WeekOfYearAndDayDate_swigregister(StepBasic_WeekOfYearAndDayDate)

class StepBasic_ConversionBasedUnitAndAreaUnit(StepBasic_ConversionBasedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a conversionbasedunitandareaunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ConversionBasedUnitAndAreaUnit_swiginit(self, _StepBasic.new_StepBasic_ConversionBasedUnitAndAreaUnit(*args))

    def AreaUnit(self, *args) -> "opencascade::handle< StepBasic_AreaUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_AreaUnit>

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndAreaUnit_AreaUnit(self, *args)

    def SetAreaUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anAreaUnit: StepBasic_AreaUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndAreaUnit_SetAreaUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ConversionBasedUnitAndAreaUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ConversionBasedUnitAndAreaUnit

# Register StepBasic_ConversionBasedUnitAndAreaUnit in _StepBasic:
_StepBasic.StepBasic_ConversionBasedUnitAndAreaUnit_swigregister(StepBasic_ConversionBasedUnitAndAreaUnit)

class StepBasic_ConversionBasedUnitAndLengthUnit(StepBasic_ConversionBasedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a conversionbasedunitandlengthunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ConversionBasedUnitAndLengthUnit_swiginit(self, _StepBasic.new_StepBasic_ConversionBasedUnitAndLengthUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDimensions: StepBasic_DimensionalExponents
        aName: TCollection_HAsciiString
        aConversionFactor: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndLengthUnit_Init(self, *args)

    def LengthUnit(self, *args) -> "opencascade::handle< StepBasic_LengthUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_LengthUnit>

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndLengthUnit_LengthUnit(self, *args)

    def SetLengthUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLengthUnit: StepBasic_LengthUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndLengthUnit_SetLengthUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ConversionBasedUnitAndLengthUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ConversionBasedUnitAndLengthUnit

# Register StepBasic_ConversionBasedUnitAndLengthUnit in _StepBasic:
_StepBasic.StepBasic_ConversionBasedUnitAndLengthUnit_swigregister(StepBasic_ConversionBasedUnitAndLengthUnit)

class StepBasic_ConversionBasedUnitAndMassUnit(StepBasic_ConversionBasedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a conversionbasedunitandlengthunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ConversionBasedUnitAndMassUnit_swiginit(self, _StepBasic.new_StepBasic_ConversionBasedUnitAndMassUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDimensions: StepBasic_DimensionalExponents
        aName: TCollection_HAsciiString
        aConversionFactor: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndMassUnit_Init(self, *args)

    def MassUnit(self, *args) -> "opencascade::handle< StepBasic_MassUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_MassUnit>

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndMassUnit_MassUnit(self, *args)

    def SetMassUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMassUnit: StepBasic_MassUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndMassUnit_SetMassUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ConversionBasedUnitAndMassUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ConversionBasedUnitAndMassUnit

# Register StepBasic_ConversionBasedUnitAndMassUnit in _StepBasic:
_StepBasic.StepBasic_ConversionBasedUnitAndMassUnit_swigregister(StepBasic_ConversionBasedUnitAndMassUnit)

class StepBasic_ConversionBasedUnitAndPlaneAngleUnit(StepBasic_ConversionBasedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a conversionbasedunitandplaneangleunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ConversionBasedUnitAndPlaneAngleUnit_swiginit(self, _StepBasic.new_StepBasic_ConversionBasedUnitAndPlaneAngleUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDimensions: StepBasic_DimensionalExponents
        aName: TCollection_HAsciiString
        aConversionFactor: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndPlaneAngleUnit_Init(self, *args)

    def PlaneAngleUnit(self, *args) -> "opencascade::handle< StepBasic_PlaneAngleUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_PlaneAngleUnit>

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndPlaneAngleUnit_PlaneAngleUnit(self, *args)

    def SetPlaneAngleUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPlaneAngleUnit: StepBasic_PlaneAngleUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndPlaneAngleUnit_SetPlaneAngleUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ConversionBasedUnitAndPlaneAngleUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ConversionBasedUnitAndPlaneAngleUnit

# Register StepBasic_ConversionBasedUnitAndPlaneAngleUnit in _StepBasic:
_StepBasic.StepBasic_ConversionBasedUnitAndPlaneAngleUnit_swigregister(StepBasic_ConversionBasedUnitAndPlaneAngleUnit)

class StepBasic_ConversionBasedUnitAndRatioUnit(StepBasic_ConversionBasedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a conversionbasedunitandratiounit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ConversionBasedUnitAndRatioUnit_swiginit(self, _StepBasic.new_StepBasic_ConversionBasedUnitAndRatioUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDimensions: StepBasic_DimensionalExponents
        aName: TCollection_HAsciiString
        aConversionFactor: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndRatioUnit_Init(self, *args)

    def RatioUnit(self, *args) -> "opencascade::handle< StepBasic_RatioUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_RatioUnit>

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndRatioUnit_RatioUnit(self, *args)

    def SetRatioUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRatioUnit: StepBasic_RatioUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndRatioUnit_SetRatioUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ConversionBasedUnitAndRatioUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ConversionBasedUnitAndRatioUnit

# Register StepBasic_ConversionBasedUnitAndRatioUnit in _StepBasic:
_StepBasic.StepBasic_ConversionBasedUnitAndRatioUnit_swigregister(StepBasic_ConversionBasedUnitAndRatioUnit)

class StepBasic_ConversionBasedUnitAndSolidAngleUnit(StepBasic_ConversionBasedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a conversionbasedunitandsolidangleunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ConversionBasedUnitAndSolidAngleUnit_swiginit(self, _StepBasic.new_StepBasic_ConversionBasedUnitAndSolidAngleUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDimensions: StepBasic_DimensionalExponents
        aName: TCollection_HAsciiString
        aConversionFactor: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndSolidAngleUnit_Init(self, *args)

    def SetSolidAngleUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSolidAngleUnit: StepBasic_SolidAngleUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndSolidAngleUnit_SetSolidAngleUnit(self, *args)

    def SolidAngleUnit(self, *args) -> "opencascade::handle< StepBasic_SolidAngleUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_SolidAngleUnit>

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndSolidAngleUnit_SolidAngleUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ConversionBasedUnitAndSolidAngleUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ConversionBasedUnitAndSolidAngleUnit

# Register StepBasic_ConversionBasedUnitAndSolidAngleUnit in _StepBasic:
_StepBasic.StepBasic_ConversionBasedUnitAndSolidAngleUnit_swigregister(StepBasic_ConversionBasedUnitAndSolidAngleUnit)

class StepBasic_ConversionBasedUnitAndTimeUnit(StepBasic_ConversionBasedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a conversionbasedunitandtimeunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ConversionBasedUnitAndTimeUnit_swiginit(self, _StepBasic.new_StepBasic_ConversionBasedUnitAndTimeUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDimensions: StepBasic_DimensionalExponents
        aName: TCollection_HAsciiString
        aConversionFactor: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndTimeUnit_Init(self, *args)

    def SetTimeUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aTimeUnit: StepBasic_TimeUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndTimeUnit_SetTimeUnit(self, *args)

    def TimeUnit(self, *args) -> "opencascade::handle< StepBasic_TimeUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_TimeUnit>

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndTimeUnit_TimeUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ConversionBasedUnitAndTimeUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ConversionBasedUnitAndTimeUnit

# Register StepBasic_ConversionBasedUnitAndTimeUnit in _StepBasic:
_StepBasic.StepBasic_ConversionBasedUnitAndTimeUnit_swigregister(StepBasic_ConversionBasedUnitAndTimeUnit)

class StepBasic_ConversionBasedUnitAndVolumeUnit(StepBasic_ConversionBasedUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a conversionbasedunitandvolumeunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ConversionBasedUnitAndVolumeUnit_swiginit(self, _StepBasic.new_StepBasic_ConversionBasedUnitAndVolumeUnit(*args))

    def SetVolumeUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aVolumeUnit: StepBasic_VolumeUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndVolumeUnit_SetVolumeUnit(self, *args)

    def VolumeUnit(self, *args) -> "opencascade::handle< StepBasic_VolumeUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_VolumeUnit>

        """
        return _StepBasic.StepBasic_ConversionBasedUnitAndVolumeUnit_VolumeUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ConversionBasedUnitAndVolumeUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ConversionBasedUnitAndVolumeUnit

# Register StepBasic_ConversionBasedUnitAndVolumeUnit in _StepBasic:
_StepBasic.StepBasic_ConversionBasedUnitAndVolumeUnit_swigregister(StepBasic_ConversionBasedUnitAndVolumeUnit)

class StepBasic_DesignContext(StepBasic_ProductDefinitionContext):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_DesignContext_swiginit(self, _StepBasic.new_StepBasic_DesignContext(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_DesignContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_DesignContext

# Register StepBasic_DesignContext in _StepBasic:
_StepBasic.StepBasic_DesignContext_swigregister(StepBasic_DesignContext)

class StepBasic_MechanicalContext(StepBasic_ProductContext):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a mechanicalcontext.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_MechanicalContext_swiginit(self, _StepBasic.new_StepBasic_MechanicalContext(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_MechanicalContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_MechanicalContext

# Register StepBasic_MechanicalContext in _StepBasic:
_StepBasic.StepBasic_MechanicalContext_swigregister(StepBasic_MechanicalContext)

class StepBasic_ProductType(StepBasic_ProductRelatedProductCategory):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a producttype.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_ProductType_swiginit(self, _StepBasic.new_StepBasic_ProductType(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_ProductType_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_ProductType

# Register StepBasic_ProductType in _StepBasic:
_StepBasic.StepBasic_ProductType_swigregister(StepBasic_ProductType)

class StepBasic_SiUnitAndAreaUnit(StepBasic_SiUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a siunitandareaunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SiUnitAndAreaUnit_swiginit(self, _StepBasic.new_StepBasic_SiUnitAndAreaUnit(*args))

    def AreaUnit(self, *args) -> "opencascade::handle< StepBasic_AreaUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_AreaUnit>

        """
        return _StepBasic.StepBasic_SiUnitAndAreaUnit_AreaUnit(self, *args)

    def SetAreaUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anAreaUnit: StepBasic_AreaUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndAreaUnit_SetAreaUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SiUnitAndAreaUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SiUnitAndAreaUnit

# Register StepBasic_SiUnitAndAreaUnit in _StepBasic:
_StepBasic.StepBasic_SiUnitAndAreaUnit_swigregister(StepBasic_SiUnitAndAreaUnit)

class StepBasic_SiUnitAndLengthUnit(StepBasic_SiUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a siunitandlengthunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SiUnitAndLengthUnit_swiginit(self, _StepBasic.new_StepBasic_SiUnitAndLengthUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        hasAprefix: bool
        aPrefix: StepBasic_SiPrefix
        aName: StepBasic_SiUnitName

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndLengthUnit_Init(self, *args)

    def LengthUnit(self, *args) -> "opencascade::handle< StepBasic_LengthUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_LengthUnit>

        """
        return _StepBasic.StepBasic_SiUnitAndLengthUnit_LengthUnit(self, *args)

    def SetLengthUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLengthUnit: StepBasic_LengthUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndLengthUnit_SetLengthUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SiUnitAndLengthUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SiUnitAndLengthUnit

# Register StepBasic_SiUnitAndLengthUnit in _StepBasic:
_StepBasic.StepBasic_SiUnitAndLengthUnit_swigregister(StepBasic_SiUnitAndLengthUnit)

class StepBasic_SiUnitAndMassUnit(StepBasic_SiUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a siunitandmassunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SiUnitAndMassUnit_swiginit(self, _StepBasic.new_StepBasic_SiUnitAndMassUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        hasAprefix: bool
        aPrefix: StepBasic_SiPrefix
        aName: StepBasic_SiUnitName

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndMassUnit_Init(self, *args)

    def MassUnit(self, *args) -> "opencascade::handle< StepBasic_MassUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_MassUnit>

        """
        return _StepBasic.StepBasic_SiUnitAndMassUnit_MassUnit(self, *args)

    def SetMassUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMassUnit: StepBasic_MassUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndMassUnit_SetMassUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SiUnitAndMassUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SiUnitAndMassUnit

# Register StepBasic_SiUnitAndMassUnit in _StepBasic:
_StepBasic.StepBasic_SiUnitAndMassUnit_swigregister(StepBasic_SiUnitAndMassUnit)

class StepBasic_SiUnitAndPlaneAngleUnit(StepBasic_SiUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a siunitandplaneangleunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SiUnitAndPlaneAngleUnit_swiginit(self, _StepBasic.new_StepBasic_SiUnitAndPlaneAngleUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        hasAprefix: bool
        aPrefix: StepBasic_SiPrefix
        aName: StepBasic_SiUnitName

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndPlaneAngleUnit_Init(self, *args)

    def PlaneAngleUnit(self, *args) -> "opencascade::handle< StepBasic_PlaneAngleUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_PlaneAngleUnit>

        """
        return _StepBasic.StepBasic_SiUnitAndPlaneAngleUnit_PlaneAngleUnit(self, *args)

    def SetPlaneAngleUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPlaneAngleUnit: StepBasic_PlaneAngleUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndPlaneAngleUnit_SetPlaneAngleUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SiUnitAndPlaneAngleUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SiUnitAndPlaneAngleUnit

# Register StepBasic_SiUnitAndPlaneAngleUnit in _StepBasic:
_StepBasic.StepBasic_SiUnitAndPlaneAngleUnit_swigregister(StepBasic_SiUnitAndPlaneAngleUnit)

class StepBasic_SiUnitAndRatioUnit(StepBasic_SiUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a siunitandratiounit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SiUnitAndRatioUnit_swiginit(self, _StepBasic.new_StepBasic_SiUnitAndRatioUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        hasAprefix: bool
        aPrefix: StepBasic_SiPrefix
        aName: StepBasic_SiUnitName

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndRatioUnit_Init(self, *args)

    def RatioUnit(self, *args) -> "opencascade::handle< StepBasic_RatioUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_RatioUnit>

        """
        return _StepBasic.StepBasic_SiUnitAndRatioUnit_RatioUnit(self, *args)

    def SetRatioUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRatioUnit: StepBasic_RatioUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndRatioUnit_SetRatioUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SiUnitAndRatioUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SiUnitAndRatioUnit

# Register StepBasic_SiUnitAndRatioUnit in _StepBasic:
_StepBasic.StepBasic_SiUnitAndRatioUnit_swigregister(StepBasic_SiUnitAndRatioUnit)

class StepBasic_SiUnitAndSolidAngleUnit(StepBasic_SiUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a siunitandsolidangleunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SiUnitAndSolidAngleUnit_swiginit(self, _StepBasic.new_StepBasic_SiUnitAndSolidAngleUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        hasAprefix: bool
        aPrefix: StepBasic_SiPrefix
        aName: StepBasic_SiUnitName

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndSolidAngleUnit_Init(self, *args)

    def SetSolidAngleUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSolidAngleUnit: StepBasic_SolidAngleUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndSolidAngleUnit_SetSolidAngleUnit(self, *args)

    def SolidAngleUnit(self, *args) -> "opencascade::handle< StepBasic_SolidAngleUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_SolidAngleUnit>

        """
        return _StepBasic.StepBasic_SiUnitAndSolidAngleUnit_SolidAngleUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SiUnitAndSolidAngleUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SiUnitAndSolidAngleUnit

# Register StepBasic_SiUnitAndSolidAngleUnit in _StepBasic:
_StepBasic.StepBasic_SiUnitAndSolidAngleUnit_swigregister(StepBasic_SiUnitAndSolidAngleUnit)

class StepBasic_SiUnitAndThermodynamicTemperatureUnit(StepBasic_SiUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a siunitandthermodynamictemperatureunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SiUnitAndThermodynamicTemperatureUnit_swiginit(self, _StepBasic.new_StepBasic_SiUnitAndThermodynamicTemperatureUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        hasAprefix: bool
        aPrefix: StepBasic_SiPrefix
        aName: StepBasic_SiUnitName

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndThermodynamicTemperatureUnit_Init(self, *args)

    def SetThermodynamicTemperatureUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aThermodynamicTemperatureUnit: StepBasic_ThermodynamicTemperatureUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndThermodynamicTemperatureUnit_SetThermodynamicTemperatureUnit(self, *args)

    def ThermodynamicTemperatureUnit(self, *args) -> "opencascade::handle< StepBasic_ThermodynamicTemperatureUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ThermodynamicTemperatureUnit>

        """
        return _StepBasic.StepBasic_SiUnitAndThermodynamicTemperatureUnit_ThermodynamicTemperatureUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SiUnitAndThermodynamicTemperatureUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SiUnitAndThermodynamicTemperatureUnit

# Register StepBasic_SiUnitAndThermodynamicTemperatureUnit in _StepBasic:
_StepBasic.StepBasic_SiUnitAndThermodynamicTemperatureUnit_swigregister(StepBasic_SiUnitAndThermodynamicTemperatureUnit)

class StepBasic_SiUnitAndTimeUnit(StepBasic_SiUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a siunitandtimeunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SiUnitAndTimeUnit_swiginit(self, _StepBasic.new_StepBasic_SiUnitAndTimeUnit(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        hasAprefix: bool
        aPrefix: StepBasic_SiPrefix
        aName: StepBasic_SiUnitName

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndTimeUnit_Init(self, *args)

    def SetTimeUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aTimeUnit: StepBasic_TimeUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndTimeUnit_SetTimeUnit(self, *args)

    def TimeUnit(self, *args) -> "opencascade::handle< StepBasic_TimeUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_TimeUnit>

        """
        return _StepBasic.StepBasic_SiUnitAndTimeUnit_TimeUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SiUnitAndTimeUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SiUnitAndTimeUnit

# Register StepBasic_SiUnitAndTimeUnit in _StepBasic:
_StepBasic.StepBasic_SiUnitAndTimeUnit_swigregister(StepBasic_SiUnitAndTimeUnit)

class StepBasic_SiUnitAndVolumeUnit(StepBasic_SiUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a siunitandvolumeunit.

        Returns
        -------
        None

        """
        _StepBasic.StepBasic_SiUnitAndVolumeUnit_swiginit(self, _StepBasic.new_StepBasic_SiUnitAndVolumeUnit(*args))

    def SetVolumeUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aVolumeUnit: StepBasic_VolumeUnit

        Returns
        -------
        None

        """
        return _StepBasic.StepBasic_SiUnitAndVolumeUnit_SetVolumeUnit(self, *args)

    def VolumeUnit(self, *args) -> "opencascade::handle< StepBasic_VolumeUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_VolumeUnit>

        """
        return _StepBasic.StepBasic_SiUnitAndVolumeUnit_VolumeUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_SiUnitAndVolumeUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepBasic.delete_StepBasic_SiUnitAndVolumeUnit

# Register StepBasic_SiUnitAndVolumeUnit in _StepBasic:
_StepBasic.StepBasic_SiUnitAndVolumeUnit_swigregister(StepBasic_SiUnitAndVolumeUnit)

class StepBasic_HArray1OfOrganization(StepBasic_Array1OfOrganization, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepBasic.StepBasic_HArray1OfOrganization_swiginit(self, _StepBasic.new_StepBasic_HArray1OfOrganization(*args))

    def Array1(self) -> "StepBasic_Array1OfOrganization const &":
        return _StepBasic.StepBasic_HArray1OfOrganization_Array1(self)

    def ChangeArray1(self) -> "StepBasic_Array1OfOrganization &":
        return _StepBasic.StepBasic_HArray1OfOrganization_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_HArray1OfOrganization_DownCast(t)

    __swig_destroy__ = _StepBasic.delete_StepBasic_HArray1OfOrganization

# Register StepBasic_HArray1OfOrganization in _StepBasic:
_StepBasic.StepBasic_HArray1OfOrganization_swigregister(StepBasic_HArray1OfOrganization)

class StepBasic_HArray1OfProductDefinition(StepBasic_Array1OfProductDefinition, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepBasic.StepBasic_HArray1OfProductDefinition_swiginit(self, _StepBasic.new_StepBasic_HArray1OfProductDefinition(*args))

    def Array1(self) -> "StepBasic_Array1OfProductDefinition const &":
        return _StepBasic.StepBasic_HArray1OfProductDefinition_Array1(self)

    def ChangeArray1(self) -> "StepBasic_Array1OfProductDefinition &":
        return _StepBasic.StepBasic_HArray1OfProductDefinition_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_HArray1OfProductDefinition_DownCast(t)

    __swig_destroy__ = _StepBasic.delete_StepBasic_HArray1OfProductDefinition

# Register StepBasic_HArray1OfProductDefinition in _StepBasic:
_StepBasic.StepBasic_HArray1OfProductDefinition_swigregister(StepBasic_HArray1OfProductDefinition)

class StepBasic_HArray1OfDerivedUnitElement(StepBasic_Array1OfDerivedUnitElement, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepBasic.StepBasic_HArray1OfDerivedUnitElement_swiginit(self, _StepBasic.new_StepBasic_HArray1OfDerivedUnitElement(*args))

    def Array1(self) -> "StepBasic_Array1OfDerivedUnitElement const &":
        return _StepBasic.StepBasic_HArray1OfDerivedUnitElement_Array1(self)

    def ChangeArray1(self) -> "StepBasic_Array1OfDerivedUnitElement &":
        return _StepBasic.StepBasic_HArray1OfDerivedUnitElement_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_HArray1OfDerivedUnitElement_DownCast(t)

    __swig_destroy__ = _StepBasic.delete_StepBasic_HArray1OfDerivedUnitElement

# Register StepBasic_HArray1OfDerivedUnitElement in _StepBasic:
_StepBasic.StepBasic_HArray1OfDerivedUnitElement_swigregister(StepBasic_HArray1OfDerivedUnitElement)

class StepBasic_HArray1OfPerson(StepBasic_Array1OfPerson, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepBasic.StepBasic_HArray1OfPerson_swiginit(self, _StepBasic.new_StepBasic_HArray1OfPerson(*args))

    def Array1(self) -> "StepBasic_Array1OfPerson const &":
        return _StepBasic.StepBasic_HArray1OfPerson_Array1(self)

    def ChangeArray1(self) -> "StepBasic_Array1OfPerson &":
        return _StepBasic.StepBasic_HArray1OfPerson_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_HArray1OfPerson_DownCast(t)

    __swig_destroy__ = _StepBasic.delete_StepBasic_HArray1OfPerson

# Register StepBasic_HArray1OfPerson in _StepBasic:
_StepBasic.StepBasic_HArray1OfPerson_swigregister(StepBasic_HArray1OfPerson)

class StepBasic_HArray1OfUncertaintyMeasureWithUnit(StepBasic_Array1OfUncertaintyMeasureWithUnit, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepBasic.StepBasic_HArray1OfUncertaintyMeasureWithUnit_swiginit(self, _StepBasic.new_StepBasic_HArray1OfUncertaintyMeasureWithUnit(*args))

    def Array1(self) -> "StepBasic_Array1OfUncertaintyMeasureWithUnit const &":
        return _StepBasic.StepBasic_HArray1OfUncertaintyMeasureWithUnit_Array1(self)

    def ChangeArray1(self) -> "StepBasic_Array1OfUncertaintyMeasureWithUnit &":
        return _StepBasic.StepBasic_HArray1OfUncertaintyMeasureWithUnit_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_HArray1OfUncertaintyMeasureWithUnit_DownCast(t)

    __swig_destroy__ = _StepBasic.delete_StepBasic_HArray1OfUncertaintyMeasureWithUnit

# Register StepBasic_HArray1OfUncertaintyMeasureWithUnit in _StepBasic:
_StepBasic.StepBasic_HArray1OfUncertaintyMeasureWithUnit_swigregister(StepBasic_HArray1OfUncertaintyMeasureWithUnit)

class StepBasic_HArray1OfApproval(StepBasic_Array1OfApproval, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepBasic.StepBasic_HArray1OfApproval_swiginit(self, _StepBasic.new_StepBasic_HArray1OfApproval(*args))

    def Array1(self) -> "StepBasic_Array1OfApproval const &":
        return _StepBasic.StepBasic_HArray1OfApproval_Array1(self)

    def ChangeArray1(self) -> "StepBasic_Array1OfApproval &":
        return _StepBasic.StepBasic_HArray1OfApproval_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_HArray1OfApproval_DownCast(t)

    __swig_destroy__ = _StepBasic.delete_StepBasic_HArray1OfApproval

# Register StepBasic_HArray1OfApproval in _StepBasic:
_StepBasic.StepBasic_HArray1OfApproval_swigregister(StepBasic_HArray1OfApproval)

class StepBasic_HArray1OfNamedUnit(StepBasic_Array1OfNamedUnit, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepBasic.StepBasic_HArray1OfNamedUnit_swiginit(self, _StepBasic.new_StepBasic_HArray1OfNamedUnit(*args))

    def Array1(self) -> "StepBasic_Array1OfNamedUnit const &":
        return _StepBasic.StepBasic_HArray1OfNamedUnit_Array1(self)

    def ChangeArray1(self) -> "StepBasic_Array1OfNamedUnit &":
        return _StepBasic.StepBasic_HArray1OfNamedUnit_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_HArray1OfNamedUnit_DownCast(t)

    __swig_destroy__ = _StepBasic.delete_StepBasic_HArray1OfNamedUnit

# Register StepBasic_HArray1OfNamedUnit in _StepBasic:
_StepBasic.StepBasic_HArray1OfNamedUnit_swigregister(StepBasic_HArray1OfNamedUnit)

class StepBasic_HArray1OfProductContext(StepBasic_Array1OfProductContext, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepBasic.StepBasic_HArray1OfProductContext_swiginit(self, _StepBasic.new_StepBasic_HArray1OfProductContext(*args))

    def Array1(self) -> "StepBasic_Array1OfProductContext const &":
        return _StepBasic.StepBasic_HArray1OfProductContext_Array1(self)

    def ChangeArray1(self) -> "StepBasic_Array1OfProductContext &":
        return _StepBasic.StepBasic_HArray1OfProductContext_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_HArray1OfProductContext_DownCast(t)

    __swig_destroy__ = _StepBasic.delete_StepBasic_HArray1OfProductContext

# Register StepBasic_HArray1OfProductContext in _StepBasic:
_StepBasic.StepBasic_HArray1OfProductContext_swigregister(StepBasic_HArray1OfProductContext)

class StepBasic_HArray1OfDocument(StepBasic_Array1OfDocument, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepBasic.StepBasic_HArray1OfDocument_swiginit(self, _StepBasic.new_StepBasic_HArray1OfDocument(*args))

    def Array1(self) -> "StepBasic_Array1OfDocument const &":
        return _StepBasic.StepBasic_HArray1OfDocument_Array1(self)

    def ChangeArray1(self) -> "StepBasic_Array1OfDocument &":
        return _StepBasic.StepBasic_HArray1OfDocument_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_HArray1OfDocument_DownCast(t)

    __swig_destroy__ = _StepBasic.delete_StepBasic_HArray1OfDocument

# Register StepBasic_HArray1OfDocument in _StepBasic:
_StepBasic.StepBasic_HArray1OfDocument_swigregister(StepBasic_HArray1OfDocument)

class StepBasic_HArray1OfProduct(StepBasic_Array1OfProduct, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepBasic.StepBasic_HArray1OfProduct_swiginit(self, _StepBasic.new_StepBasic_HArray1OfProduct(*args))

    def Array1(self) -> "StepBasic_Array1OfProduct const &":
        return _StepBasic.StepBasic_HArray1OfProduct_Array1(self)

    def ChangeArray1(self) -> "StepBasic_Array1OfProduct &":
        return _StepBasic.StepBasic_HArray1OfProduct_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepBasic_HArray1OfProduct_DownCast(t)

    __swig_destroy__ = _StepBasic.delete_StepBasic_HArray1OfProduct

# Register StepBasic_HArray1OfProduct in _StepBasic:
_StepBasic.StepBasic_HArray1OfProduct_swigregister(StepBasic_HArray1OfProduct)





