# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
StepVisual module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_stepvisual.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _StepVisual
else:
    import _StepVisual

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _StepVisual.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _StepVisual.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepVisual.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepVisual.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _StepVisual.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _StepVisual.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _StepVisual.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _StepVisual.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _StepVisual.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _StepVisual.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepVisual.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _StepVisual.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _StepVisual.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepVisual.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepVisual.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepVisual.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _StepVisual.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _StepVisual:
_StepVisual.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _StepVisual.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.StepShape
import OCC.Core.StepGeom
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepRepr
import OCC.Core.StepBasic
import OCC.Core.TColgp

from enum import IntEnum
from OCC.Core.Exception import *

StepVisual_Null = _StepVisual.StepVisual_Null
StepVisual_copCentral = _StepVisual.StepVisual_copCentral
StepVisual_copParallel = _StepVisual.StepVisual_copParallel
StepVisual_ssNegative = _StepVisual.StepVisual_ssNegative
StepVisual_ssPositive = _StepVisual.StepVisual_ssPositive
StepVisual_ssBoth = _StepVisual.StepVisual_ssBoth
StepVisual_tpUp = _StepVisual.StepVisual_tpUp
StepVisual_tpRight = _StepVisual.StepVisual_tpRight
StepVisual_tpDown = _StepVisual.StepVisual_tpDown
StepVisual_tpLeft = _StepVisual.StepVisual_tpLeft
StepVisual_mtDot = _StepVisual.StepVisual_mtDot
StepVisual_mtX = _StepVisual.StepVisual_mtX
StepVisual_mtPlus = _StepVisual.StepVisual_mtPlus
StepVisual_mtAsterisk = _StepVisual.StepVisual_mtAsterisk
StepVisual_mtRing = _StepVisual.StepVisual_mtRing
StepVisual_mtSquare = _StepVisual.StepVisual_mtSquare
StepVisual_mtTriangle = _StepVisual.StepVisual_mtTriangle
StepVisual_ssmConstantShading = _StepVisual.StepVisual_ssmConstantShading
StepVisual_ssmColourShading = _StepVisual.StepVisual_ssmColourShading
StepVisual_ssmDotShading = _StepVisual.StepVisual_ssmDotShading
StepVisual_ssmNormalShading = _StepVisual.StepVisual_ssmNormalShading


class StepVisual_NullStyle(IntEnum):
	StepVisual_Null = 0
StepVisual_Null = StepVisual_NullStyle.StepVisual_Null

class StepVisual_CentralOrParallel(IntEnum):
	StepVisual_copCentral = 0
	StepVisual_copParallel = 1
StepVisual_copCentral = StepVisual_CentralOrParallel.StepVisual_copCentral
StepVisual_copParallel = StepVisual_CentralOrParallel.StepVisual_copParallel

class StepVisual_SurfaceSide(IntEnum):
	StepVisual_ssNegative = 0
	StepVisual_ssPositive = 1
	StepVisual_ssBoth = 2
StepVisual_ssNegative = StepVisual_SurfaceSide.StepVisual_ssNegative
StepVisual_ssPositive = StepVisual_SurfaceSide.StepVisual_ssPositive
StepVisual_ssBoth = StepVisual_SurfaceSide.StepVisual_ssBoth

class StepVisual_TextPath(IntEnum):
	StepVisual_tpUp = 0
	StepVisual_tpRight = 1
	StepVisual_tpDown = 2
	StepVisual_tpLeft = 3
StepVisual_tpUp = StepVisual_TextPath.StepVisual_tpUp
StepVisual_tpRight = StepVisual_TextPath.StepVisual_tpRight
StepVisual_tpDown = StepVisual_TextPath.StepVisual_tpDown
StepVisual_tpLeft = StepVisual_TextPath.StepVisual_tpLeft

class StepVisual_MarkerType(IntEnum):
	StepVisual_mtDot = 0
	StepVisual_mtX = 1
	StepVisual_mtPlus = 2
	StepVisual_mtAsterisk = 3
	StepVisual_mtRing = 4
	StepVisual_mtSquare = 5
	StepVisual_mtTriangle = 6
StepVisual_mtDot = StepVisual_MarkerType.StepVisual_mtDot
StepVisual_mtX = StepVisual_MarkerType.StepVisual_mtX
StepVisual_mtPlus = StepVisual_MarkerType.StepVisual_mtPlus
StepVisual_mtAsterisk = StepVisual_MarkerType.StepVisual_mtAsterisk
StepVisual_mtRing = StepVisual_MarkerType.StepVisual_mtRing
StepVisual_mtSquare = StepVisual_MarkerType.StepVisual_mtSquare
StepVisual_mtTriangle = StepVisual_MarkerType.StepVisual_mtTriangle

class StepVisual_ShadingSurfaceMethod(IntEnum):
	StepVisual_ssmConstantShading = 0
	StepVisual_ssmColourShading = 1
	StepVisual_ssmDotShading = 2
	StepVisual_ssmNormalShading = 3
StepVisual_ssmConstantShading = StepVisual_ShadingSurfaceMethod.StepVisual_ssmConstantShading
StepVisual_ssmColourShading = StepVisual_ShadingSurfaceMethod.StepVisual_ssmColourShading
StepVisual_ssmDotShading = StepVisual_ShadingSurfaceMethod.StepVisual_ssmDotShading
StepVisual_ssmNormalShading = StepVisual_ShadingSurfaceMethod.StepVisual_ssmNormalShading


def Handle_StepVisual_AnnotationFillArea_Create() -> "opencascade::handle< StepVisual_AnnotationFillArea >":
    return _StepVisual.Handle_StepVisual_AnnotationFillArea_Create()

def Handle_StepVisual_AnnotationFillArea_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_AnnotationFillArea >":
    return _StepVisual.Handle_StepVisual_AnnotationFillArea_DownCast(t)

def Handle_StepVisual_AnnotationFillArea_IsNull(t: "opencascade::handle< StepVisual_AnnotationFillArea > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_AnnotationFillArea_IsNull(t)

def Handle_StepVisual_AnnotationText_Create() -> "opencascade::handle< StepVisual_AnnotationText >":
    return _StepVisual.Handle_StepVisual_AnnotationText_Create()

def Handle_StepVisual_AnnotationText_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_AnnotationText >":
    return _StepVisual.Handle_StepVisual_AnnotationText_DownCast(t)

def Handle_StepVisual_AnnotationText_IsNull(t: "opencascade::handle< StepVisual_AnnotationText > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_AnnotationText_IsNull(t)

def Handle_StepVisual_AreaInSet_Create() -> "opencascade::handle< StepVisual_AreaInSet >":
    return _StepVisual.Handle_StepVisual_AreaInSet_Create()

def Handle_StepVisual_AreaInSet_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_AreaInSet >":
    return _StepVisual.Handle_StepVisual_AreaInSet_DownCast(t)

def Handle_StepVisual_AreaInSet_IsNull(t: "opencascade::handle< StepVisual_AreaInSet > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_AreaInSet_IsNull(t)

def Handle_StepVisual_CameraImage_Create() -> "opencascade::handle< StepVisual_CameraImage >":
    return _StepVisual.Handle_StepVisual_CameraImage_Create()

def Handle_StepVisual_CameraImage_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CameraImage >":
    return _StepVisual.Handle_StepVisual_CameraImage_DownCast(t)

def Handle_StepVisual_CameraImage_IsNull(t: "opencascade::handle< StepVisual_CameraImage > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CameraImage_IsNull(t)

def Handle_StepVisual_CameraModel_Create() -> "opencascade::handle< StepVisual_CameraModel >":
    return _StepVisual.Handle_StepVisual_CameraModel_Create()

def Handle_StepVisual_CameraModel_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CameraModel >":
    return _StepVisual.Handle_StepVisual_CameraModel_DownCast(t)

def Handle_StepVisual_CameraModel_IsNull(t: "opencascade::handle< StepVisual_CameraModel > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CameraModel_IsNull(t)

def Handle_StepVisual_CameraModelD3MultiClippingIntersection_Create() -> "opencascade::handle< StepVisual_CameraModelD3MultiClippingIntersection >":
    return _StepVisual.Handle_StepVisual_CameraModelD3MultiClippingIntersection_Create()

def Handle_StepVisual_CameraModelD3MultiClippingIntersection_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CameraModelD3MultiClippingIntersection >":
    return _StepVisual.Handle_StepVisual_CameraModelD3MultiClippingIntersection_DownCast(t)

def Handle_StepVisual_CameraModelD3MultiClippingIntersection_IsNull(t: "opencascade::handle< StepVisual_CameraModelD3MultiClippingIntersection > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CameraModelD3MultiClippingIntersection_IsNull(t)

def Handle_StepVisual_CameraModelD3MultiClippingUnion_Create() -> "opencascade::handle< StepVisual_CameraModelD3MultiClippingUnion >":
    return _StepVisual.Handle_StepVisual_CameraModelD3MultiClippingUnion_Create()

def Handle_StepVisual_CameraModelD3MultiClippingUnion_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CameraModelD3MultiClippingUnion >":
    return _StepVisual.Handle_StepVisual_CameraModelD3MultiClippingUnion_DownCast(t)

def Handle_StepVisual_CameraModelD3MultiClippingUnion_IsNull(t: "opencascade::handle< StepVisual_CameraModelD3MultiClippingUnion > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CameraModelD3MultiClippingUnion_IsNull(t)

def Handle_StepVisual_CameraUsage_Create() -> "opencascade::handle< StepVisual_CameraUsage >":
    return _StepVisual.Handle_StepVisual_CameraUsage_Create()

def Handle_StepVisual_CameraUsage_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CameraUsage >":
    return _StepVisual.Handle_StepVisual_CameraUsage_DownCast(t)

def Handle_StepVisual_CameraUsage_IsNull(t: "opencascade::handle< StepVisual_CameraUsage > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CameraUsage_IsNull(t)

def Handle_StepVisual_Colour_Create() -> "opencascade::handle< StepVisual_Colour >":
    return _StepVisual.Handle_StepVisual_Colour_Create()

def Handle_StepVisual_Colour_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_Colour >":
    return _StepVisual.Handle_StepVisual_Colour_DownCast(t)

def Handle_StepVisual_Colour_IsNull(t: "opencascade::handle< StepVisual_Colour > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_Colour_IsNull(t)

def Handle_StepVisual_CompositeText_Create() -> "opencascade::handle< StepVisual_CompositeText >":
    return _StepVisual.Handle_StepVisual_CompositeText_Create()

def Handle_StepVisual_CompositeText_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CompositeText >":
    return _StepVisual.Handle_StepVisual_CompositeText_DownCast(t)

def Handle_StepVisual_CompositeText_IsNull(t: "opencascade::handle< StepVisual_CompositeText > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CompositeText_IsNull(t)

def Handle_StepVisual_CurveStyle_Create() -> "opencascade::handle< StepVisual_CurveStyle >":
    return _StepVisual.Handle_StepVisual_CurveStyle_Create()

def Handle_StepVisual_CurveStyle_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CurveStyle >":
    return _StepVisual.Handle_StepVisual_CurveStyle_DownCast(t)

def Handle_StepVisual_CurveStyle_IsNull(t: "opencascade::handle< StepVisual_CurveStyle > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CurveStyle_IsNull(t)

def Handle_StepVisual_CurveStyleFont_Create() -> "opencascade::handle< StepVisual_CurveStyleFont >":
    return _StepVisual.Handle_StepVisual_CurveStyleFont_Create()

def Handle_StepVisual_CurveStyleFont_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CurveStyleFont >":
    return _StepVisual.Handle_StepVisual_CurveStyleFont_DownCast(t)

def Handle_StepVisual_CurveStyleFont_IsNull(t: "opencascade::handle< StepVisual_CurveStyleFont > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CurveStyleFont_IsNull(t)

def Handle_StepVisual_CurveStyleFontPattern_Create() -> "opencascade::handle< StepVisual_CurveStyleFontPattern >":
    return _StepVisual.Handle_StepVisual_CurveStyleFontPattern_Create()

def Handle_StepVisual_CurveStyleFontPattern_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CurveStyleFontPattern >":
    return _StepVisual.Handle_StepVisual_CurveStyleFontPattern_DownCast(t)

def Handle_StepVisual_CurveStyleFontPattern_IsNull(t: "opencascade::handle< StepVisual_CurveStyleFontPattern > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CurveStyleFontPattern_IsNull(t)

def Handle_StepVisual_DraughtingCallout_Create() -> "opencascade::handle< StepVisual_DraughtingCallout >":
    return _StepVisual.Handle_StepVisual_DraughtingCallout_Create()

def Handle_StepVisual_DraughtingCallout_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_DraughtingCallout >":
    return _StepVisual.Handle_StepVisual_DraughtingCallout_DownCast(t)

def Handle_StepVisual_DraughtingCallout_IsNull(t: "opencascade::handle< StepVisual_DraughtingCallout > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_DraughtingCallout_IsNull(t)

def Handle_StepVisual_DraughtingModel_Create() -> "opencascade::handle< StepVisual_DraughtingModel >":
    return _StepVisual.Handle_StepVisual_DraughtingModel_Create()

def Handle_StepVisual_DraughtingModel_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_DraughtingModel >":
    return _StepVisual.Handle_StepVisual_DraughtingModel_DownCast(t)

def Handle_StepVisual_DraughtingModel_IsNull(t: "opencascade::handle< StepVisual_DraughtingModel > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_DraughtingModel_IsNull(t)

def Handle_StepVisual_ExternallyDefinedCurveFont_Create() -> "opencascade::handle< StepVisual_ExternallyDefinedCurveFont >":
    return _StepVisual.Handle_StepVisual_ExternallyDefinedCurveFont_Create()

def Handle_StepVisual_ExternallyDefinedCurveFont_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_ExternallyDefinedCurveFont >":
    return _StepVisual.Handle_StepVisual_ExternallyDefinedCurveFont_DownCast(t)

def Handle_StepVisual_ExternallyDefinedCurveFont_IsNull(t: "opencascade::handle< StepVisual_ExternallyDefinedCurveFont > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_ExternallyDefinedCurveFont_IsNull(t)

def Handle_StepVisual_ExternallyDefinedTextFont_Create() -> "opencascade::handle< StepVisual_ExternallyDefinedTextFont >":
    return _StepVisual.Handle_StepVisual_ExternallyDefinedTextFont_Create()

def Handle_StepVisual_ExternallyDefinedTextFont_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_ExternallyDefinedTextFont >":
    return _StepVisual.Handle_StepVisual_ExternallyDefinedTextFont_DownCast(t)

def Handle_StepVisual_ExternallyDefinedTextFont_IsNull(t: "opencascade::handle< StepVisual_ExternallyDefinedTextFont > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_ExternallyDefinedTextFont_IsNull(t)

def Handle_StepVisual_FillAreaStyle_Create() -> "opencascade::handle< StepVisual_FillAreaStyle >":
    return _StepVisual.Handle_StepVisual_FillAreaStyle_Create()

def Handle_StepVisual_FillAreaStyle_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_FillAreaStyle >":
    return _StepVisual.Handle_StepVisual_FillAreaStyle_DownCast(t)

def Handle_StepVisual_FillAreaStyle_IsNull(t: "opencascade::handle< StepVisual_FillAreaStyle > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_FillAreaStyle_IsNull(t)

def Handle_StepVisual_FillAreaStyleColour_Create() -> "opencascade::handle< StepVisual_FillAreaStyleColour >":
    return _StepVisual.Handle_StepVisual_FillAreaStyleColour_Create()

def Handle_StepVisual_FillAreaStyleColour_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_FillAreaStyleColour >":
    return _StepVisual.Handle_StepVisual_FillAreaStyleColour_DownCast(t)

def Handle_StepVisual_FillAreaStyleColour_IsNull(t: "opencascade::handle< StepVisual_FillAreaStyleColour > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_FillAreaStyleColour_IsNull(t)

def Handle_StepVisual_Invisibility_Create() -> "opencascade::handle< StepVisual_Invisibility >":
    return _StepVisual.Handle_StepVisual_Invisibility_Create()

def Handle_StepVisual_Invisibility_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_Invisibility >":
    return _StepVisual.Handle_StepVisual_Invisibility_DownCast(t)

def Handle_StepVisual_Invisibility_IsNull(t: "opencascade::handle< StepVisual_Invisibility > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_Invisibility_IsNull(t)

def Handle_StepVisual_MarkerMember_Create() -> "opencascade::handle< StepVisual_MarkerMember >":
    return _StepVisual.Handle_StepVisual_MarkerMember_Create()

def Handle_StepVisual_MarkerMember_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_MarkerMember >":
    return _StepVisual.Handle_StepVisual_MarkerMember_DownCast(t)

def Handle_StepVisual_MarkerMember_IsNull(t: "opencascade::handle< StepVisual_MarkerMember > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_MarkerMember_IsNull(t)

def Handle_StepVisual_NullStyleMember_Create() -> "opencascade::handle< StepVisual_NullStyleMember >":
    return _StepVisual.Handle_StepVisual_NullStyleMember_Create()

def Handle_StepVisual_NullStyleMember_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_NullStyleMember >":
    return _StepVisual.Handle_StepVisual_NullStyleMember_DownCast(t)

def Handle_StepVisual_NullStyleMember_IsNull(t: "opencascade::handle< StepVisual_NullStyleMember > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_NullStyleMember_IsNull(t)

def Handle_StepVisual_PlanarExtent_Create() -> "opencascade::handle< StepVisual_PlanarExtent >":
    return _StepVisual.Handle_StepVisual_PlanarExtent_Create()

def Handle_StepVisual_PlanarExtent_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PlanarExtent >":
    return _StepVisual.Handle_StepVisual_PlanarExtent_DownCast(t)

def Handle_StepVisual_PlanarExtent_IsNull(t: "opencascade::handle< StepVisual_PlanarExtent > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PlanarExtent_IsNull(t)

def Handle_StepVisual_PointStyle_Create() -> "opencascade::handle< StepVisual_PointStyle >":
    return _StepVisual.Handle_StepVisual_PointStyle_Create()

def Handle_StepVisual_PointStyle_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PointStyle >":
    return _StepVisual.Handle_StepVisual_PointStyle_DownCast(t)

def Handle_StepVisual_PointStyle_IsNull(t: "opencascade::handle< StepVisual_PointStyle > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PointStyle_IsNull(t)

def Handle_StepVisual_PreDefinedItem_Create() -> "opencascade::handle< StepVisual_PreDefinedItem >":
    return _StepVisual.Handle_StepVisual_PreDefinedItem_Create()

def Handle_StepVisual_PreDefinedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PreDefinedItem >":
    return _StepVisual.Handle_StepVisual_PreDefinedItem_DownCast(t)

def Handle_StepVisual_PreDefinedItem_IsNull(t: "opencascade::handle< StepVisual_PreDefinedItem > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PreDefinedItem_IsNull(t)

def Handle_StepVisual_PresentationLayerAssignment_Create() -> "opencascade::handle< StepVisual_PresentationLayerAssignment >":
    return _StepVisual.Handle_StepVisual_PresentationLayerAssignment_Create()

def Handle_StepVisual_PresentationLayerAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PresentationLayerAssignment >":
    return _StepVisual.Handle_StepVisual_PresentationLayerAssignment_DownCast(t)

def Handle_StepVisual_PresentationLayerAssignment_IsNull(t: "opencascade::handle< StepVisual_PresentationLayerAssignment > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PresentationLayerAssignment_IsNull(t)

def Handle_StepVisual_PresentationLayerUsage_Create() -> "opencascade::handle< StepVisual_PresentationLayerUsage >":
    return _StepVisual.Handle_StepVisual_PresentationLayerUsage_Create()

def Handle_StepVisual_PresentationLayerUsage_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PresentationLayerUsage >":
    return _StepVisual.Handle_StepVisual_PresentationLayerUsage_DownCast(t)

def Handle_StepVisual_PresentationLayerUsage_IsNull(t: "opencascade::handle< StepVisual_PresentationLayerUsage > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PresentationLayerUsage_IsNull(t)

def Handle_StepVisual_PresentationRepresentation_Create() -> "opencascade::handle< StepVisual_PresentationRepresentation >":
    return _StepVisual.Handle_StepVisual_PresentationRepresentation_Create()

def Handle_StepVisual_PresentationRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PresentationRepresentation >":
    return _StepVisual.Handle_StepVisual_PresentationRepresentation_DownCast(t)

def Handle_StepVisual_PresentationRepresentation_IsNull(t: "opencascade::handle< StepVisual_PresentationRepresentation > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PresentationRepresentation_IsNull(t)

def Handle_StepVisual_PresentationSet_Create() -> "opencascade::handle< StepVisual_PresentationSet >":
    return _StepVisual.Handle_StepVisual_PresentationSet_Create()

def Handle_StepVisual_PresentationSet_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PresentationSet >":
    return _StepVisual.Handle_StepVisual_PresentationSet_DownCast(t)

def Handle_StepVisual_PresentationSet_IsNull(t: "opencascade::handle< StepVisual_PresentationSet > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PresentationSet_IsNull(t)

def Handle_StepVisual_PresentationSize_Create() -> "opencascade::handle< StepVisual_PresentationSize >":
    return _StepVisual.Handle_StepVisual_PresentationSize_Create()

def Handle_StepVisual_PresentationSize_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PresentationSize >":
    return _StepVisual.Handle_StepVisual_PresentationSize_DownCast(t)

def Handle_StepVisual_PresentationSize_IsNull(t: "opencascade::handle< StepVisual_PresentationSize > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PresentationSize_IsNull(t)

def Handle_StepVisual_PresentationStyleAssignment_Create() -> "opencascade::handle< StepVisual_PresentationStyleAssignment >":
    return _StepVisual.Handle_StepVisual_PresentationStyleAssignment_Create()

def Handle_StepVisual_PresentationStyleAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PresentationStyleAssignment >":
    return _StepVisual.Handle_StepVisual_PresentationStyleAssignment_DownCast(t)

def Handle_StepVisual_PresentationStyleAssignment_IsNull(t: "opencascade::handle< StepVisual_PresentationStyleAssignment > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PresentationStyleAssignment_IsNull(t)

def Handle_StepVisual_PresentedItem_Create() -> "opencascade::handle< StepVisual_PresentedItem >":
    return _StepVisual.Handle_StepVisual_PresentedItem_Create()

def Handle_StepVisual_PresentedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PresentedItem >":
    return _StepVisual.Handle_StepVisual_PresentedItem_DownCast(t)

def Handle_StepVisual_PresentedItem_IsNull(t: "opencascade::handle< StepVisual_PresentedItem > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PresentedItem_IsNull(t)

def Handle_StepVisual_PresentedItemRepresentation_Create() -> "opencascade::handle< StepVisual_PresentedItemRepresentation >":
    return _StepVisual.Handle_StepVisual_PresentedItemRepresentation_Create()

def Handle_StepVisual_PresentedItemRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PresentedItemRepresentation >":
    return _StepVisual.Handle_StepVisual_PresentedItemRepresentation_DownCast(t)

def Handle_StepVisual_PresentedItemRepresentation_IsNull(t: "opencascade::handle< StepVisual_PresentedItemRepresentation > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PresentedItemRepresentation_IsNull(t)

def Handle_StepVisual_StyledItem_Create() -> "opencascade::handle< StepVisual_StyledItem >":
    return _StepVisual.Handle_StepVisual_StyledItem_Create()

def Handle_StepVisual_StyledItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_StyledItem >":
    return _StepVisual.Handle_StepVisual_StyledItem_DownCast(t)

def Handle_StepVisual_StyledItem_IsNull(t: "opencascade::handle< StepVisual_StyledItem > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_StyledItem_IsNull(t)

def Handle_StepVisual_SurfaceSideStyle_Create() -> "opencascade::handle< StepVisual_SurfaceSideStyle >":
    return _StepVisual.Handle_StepVisual_SurfaceSideStyle_Create()

def Handle_StepVisual_SurfaceSideStyle_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_SurfaceSideStyle >":
    return _StepVisual.Handle_StepVisual_SurfaceSideStyle_DownCast(t)

def Handle_StepVisual_SurfaceSideStyle_IsNull(t: "opencascade::handle< StepVisual_SurfaceSideStyle > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_SurfaceSideStyle_IsNull(t)

def Handle_StepVisual_SurfaceStyleBoundary_Create() -> "opencascade::handle< StepVisual_SurfaceStyleBoundary >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleBoundary_Create()

def Handle_StepVisual_SurfaceStyleBoundary_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_SurfaceStyleBoundary >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleBoundary_DownCast(t)

def Handle_StepVisual_SurfaceStyleBoundary_IsNull(t: "opencascade::handle< StepVisual_SurfaceStyleBoundary > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_SurfaceStyleBoundary_IsNull(t)

def Handle_StepVisual_SurfaceStyleControlGrid_Create() -> "opencascade::handle< StepVisual_SurfaceStyleControlGrid >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleControlGrid_Create()

def Handle_StepVisual_SurfaceStyleControlGrid_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_SurfaceStyleControlGrid >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleControlGrid_DownCast(t)

def Handle_StepVisual_SurfaceStyleControlGrid_IsNull(t: "opencascade::handle< StepVisual_SurfaceStyleControlGrid > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_SurfaceStyleControlGrid_IsNull(t)

def Handle_StepVisual_SurfaceStyleFillArea_Create() -> "opencascade::handle< StepVisual_SurfaceStyleFillArea >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleFillArea_Create()

def Handle_StepVisual_SurfaceStyleFillArea_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_SurfaceStyleFillArea >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleFillArea_DownCast(t)

def Handle_StepVisual_SurfaceStyleFillArea_IsNull(t: "opencascade::handle< StepVisual_SurfaceStyleFillArea > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_SurfaceStyleFillArea_IsNull(t)

def Handle_StepVisual_SurfaceStyleParameterLine_Create() -> "opencascade::handle< StepVisual_SurfaceStyleParameterLine >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleParameterLine_Create()

def Handle_StepVisual_SurfaceStyleParameterLine_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_SurfaceStyleParameterLine >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleParameterLine_DownCast(t)

def Handle_StepVisual_SurfaceStyleParameterLine_IsNull(t: "opencascade::handle< StepVisual_SurfaceStyleParameterLine > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_SurfaceStyleParameterLine_IsNull(t)

def Handle_StepVisual_SurfaceStyleReflectanceAmbient_Create() -> "opencascade::handle< StepVisual_SurfaceStyleReflectanceAmbient >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleReflectanceAmbient_Create()

def Handle_StepVisual_SurfaceStyleReflectanceAmbient_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_SurfaceStyleReflectanceAmbient >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleReflectanceAmbient_DownCast(t)

def Handle_StepVisual_SurfaceStyleReflectanceAmbient_IsNull(t: "opencascade::handle< StepVisual_SurfaceStyleReflectanceAmbient > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_SurfaceStyleReflectanceAmbient_IsNull(t)

def Handle_StepVisual_SurfaceStyleRendering_Create() -> "opencascade::handle< StepVisual_SurfaceStyleRendering >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleRendering_Create()

def Handle_StepVisual_SurfaceStyleRendering_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_SurfaceStyleRendering >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleRendering_DownCast(t)

def Handle_StepVisual_SurfaceStyleRendering_IsNull(t: "opencascade::handle< StepVisual_SurfaceStyleRendering > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_SurfaceStyleRendering_IsNull(t)

def Handle_StepVisual_SurfaceStyleSegmentationCurve_Create() -> "opencascade::handle< StepVisual_SurfaceStyleSegmentationCurve >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleSegmentationCurve_Create()

def Handle_StepVisual_SurfaceStyleSegmentationCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_SurfaceStyleSegmentationCurve >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleSegmentationCurve_DownCast(t)

def Handle_StepVisual_SurfaceStyleSegmentationCurve_IsNull(t: "opencascade::handle< StepVisual_SurfaceStyleSegmentationCurve > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_SurfaceStyleSegmentationCurve_IsNull(t)

def Handle_StepVisual_SurfaceStyleSilhouette_Create() -> "opencascade::handle< StepVisual_SurfaceStyleSilhouette >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleSilhouette_Create()

def Handle_StepVisual_SurfaceStyleSilhouette_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_SurfaceStyleSilhouette >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleSilhouette_DownCast(t)

def Handle_StepVisual_SurfaceStyleSilhouette_IsNull(t: "opencascade::handle< StepVisual_SurfaceStyleSilhouette > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_SurfaceStyleSilhouette_IsNull(t)

def Handle_StepVisual_SurfaceStyleTransparent_Create() -> "opencascade::handle< StepVisual_SurfaceStyleTransparent >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleTransparent_Create()

def Handle_StepVisual_SurfaceStyleTransparent_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_SurfaceStyleTransparent >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleTransparent_DownCast(t)

def Handle_StepVisual_SurfaceStyleTransparent_IsNull(t: "opencascade::handle< StepVisual_SurfaceStyleTransparent > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_SurfaceStyleTransparent_IsNull(t)

def Handle_StepVisual_SurfaceStyleUsage_Create() -> "opencascade::handle< StepVisual_SurfaceStyleUsage >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleUsage_Create()

def Handle_StepVisual_SurfaceStyleUsage_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_SurfaceStyleUsage >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleUsage_DownCast(t)

def Handle_StepVisual_SurfaceStyleUsage_IsNull(t: "opencascade::handle< StepVisual_SurfaceStyleUsage > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_SurfaceStyleUsage_IsNull(t)

def Handle_StepVisual_Template_Create() -> "opencascade::handle< StepVisual_Template >":
    return _StepVisual.Handle_StepVisual_Template_Create()

def Handle_StepVisual_Template_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_Template >":
    return _StepVisual.Handle_StepVisual_Template_DownCast(t)

def Handle_StepVisual_Template_IsNull(t: "opencascade::handle< StepVisual_Template > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_Template_IsNull(t)

def Handle_StepVisual_TemplateInstance_Create() -> "opencascade::handle< StepVisual_TemplateInstance >":
    return _StepVisual.Handle_StepVisual_TemplateInstance_Create()

def Handle_StepVisual_TemplateInstance_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_TemplateInstance >":
    return _StepVisual.Handle_StepVisual_TemplateInstance_DownCast(t)

def Handle_StepVisual_TemplateInstance_IsNull(t: "opencascade::handle< StepVisual_TemplateInstance > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_TemplateInstance_IsNull(t)

def Handle_StepVisual_TessellatedItem_Create() -> "opencascade::handle< StepVisual_TessellatedItem >":
    return _StepVisual.Handle_StepVisual_TessellatedItem_Create()

def Handle_StepVisual_TessellatedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_TessellatedItem >":
    return _StepVisual.Handle_StepVisual_TessellatedItem_DownCast(t)

def Handle_StepVisual_TessellatedItem_IsNull(t: "opencascade::handle< StepVisual_TessellatedItem > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_TessellatedItem_IsNull(t)

def Handle_StepVisual_TextLiteral_Create() -> "opencascade::handle< StepVisual_TextLiteral >":
    return _StepVisual.Handle_StepVisual_TextLiteral_Create()

def Handle_StepVisual_TextLiteral_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_TextLiteral >":
    return _StepVisual.Handle_StepVisual_TextLiteral_DownCast(t)

def Handle_StepVisual_TextLiteral_IsNull(t: "opencascade::handle< StepVisual_TextLiteral > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_TextLiteral_IsNull(t)

def Handle_StepVisual_TextStyle_Create() -> "opencascade::handle< StepVisual_TextStyle >":
    return _StepVisual.Handle_StepVisual_TextStyle_Create()

def Handle_StepVisual_TextStyle_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_TextStyle >":
    return _StepVisual.Handle_StepVisual_TextStyle_DownCast(t)

def Handle_StepVisual_TextStyle_IsNull(t: "opencascade::handle< StepVisual_TextStyle > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_TextStyle_IsNull(t)

def Handle_StepVisual_TextStyleForDefinedFont_Create() -> "opencascade::handle< StepVisual_TextStyleForDefinedFont >":
    return _StepVisual.Handle_StepVisual_TextStyleForDefinedFont_Create()

def Handle_StepVisual_TextStyleForDefinedFont_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_TextStyleForDefinedFont >":
    return _StepVisual.Handle_StepVisual_TextStyleForDefinedFont_DownCast(t)

def Handle_StepVisual_TextStyleForDefinedFont_IsNull(t: "opencascade::handle< StepVisual_TextStyleForDefinedFont > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_TextStyleForDefinedFont_IsNull(t)

def Handle_StepVisual_ViewVolume_Create() -> "opencascade::handle< StepVisual_ViewVolume >":
    return _StepVisual.Handle_StepVisual_ViewVolume_Create()

def Handle_StepVisual_ViewVolume_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_ViewVolume >":
    return _StepVisual.Handle_StepVisual_ViewVolume_DownCast(t)

def Handle_StepVisual_ViewVolume_IsNull(t: "opencascade::handle< StepVisual_ViewVolume > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_ViewVolume_IsNull(t)

def Handle_StepVisual_AnnotationOccurrence_Create() -> "opencascade::handle< StepVisual_AnnotationOccurrence >":
    return _StepVisual.Handle_StepVisual_AnnotationOccurrence_Create()

def Handle_StepVisual_AnnotationOccurrence_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_AnnotationOccurrence >":
    return _StepVisual.Handle_StepVisual_AnnotationOccurrence_DownCast(t)

def Handle_StepVisual_AnnotationOccurrence_IsNull(t: "opencascade::handle< StepVisual_AnnotationOccurrence > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_AnnotationOccurrence_IsNull(t)

def Handle_StepVisual_BackgroundColour_Create() -> "opencascade::handle< StepVisual_BackgroundColour >":
    return _StepVisual.Handle_StepVisual_BackgroundColour_Create()

def Handle_StepVisual_BackgroundColour_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_BackgroundColour >":
    return _StepVisual.Handle_StepVisual_BackgroundColour_DownCast(t)

def Handle_StepVisual_BackgroundColour_IsNull(t: "opencascade::handle< StepVisual_BackgroundColour > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_BackgroundColour_IsNull(t)

def Handle_StepVisual_CameraImage2dWithScale_Create() -> "opencascade::handle< StepVisual_CameraImage2dWithScale >":
    return _StepVisual.Handle_StepVisual_CameraImage2dWithScale_Create()

def Handle_StepVisual_CameraImage2dWithScale_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CameraImage2dWithScale >":
    return _StepVisual.Handle_StepVisual_CameraImage2dWithScale_DownCast(t)

def Handle_StepVisual_CameraImage2dWithScale_IsNull(t: "opencascade::handle< StepVisual_CameraImage2dWithScale > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CameraImage2dWithScale_IsNull(t)

def Handle_StepVisual_CameraImage3dWithScale_Create() -> "opencascade::handle< StepVisual_CameraImage3dWithScale >":
    return _StepVisual.Handle_StepVisual_CameraImage3dWithScale_Create()

def Handle_StepVisual_CameraImage3dWithScale_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CameraImage3dWithScale >":
    return _StepVisual.Handle_StepVisual_CameraImage3dWithScale_DownCast(t)

def Handle_StepVisual_CameraImage3dWithScale_IsNull(t: "opencascade::handle< StepVisual_CameraImage3dWithScale > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CameraImage3dWithScale_IsNull(t)

def Handle_StepVisual_CameraModelD2_Create() -> "opencascade::handle< StepVisual_CameraModelD2 >":
    return _StepVisual.Handle_StepVisual_CameraModelD2_Create()

def Handle_StepVisual_CameraModelD2_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CameraModelD2 >":
    return _StepVisual.Handle_StepVisual_CameraModelD2_DownCast(t)

def Handle_StepVisual_CameraModelD2_IsNull(t: "opencascade::handle< StepVisual_CameraModelD2 > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CameraModelD2_IsNull(t)

def Handle_StepVisual_CameraModelD3_Create() -> "opencascade::handle< StepVisual_CameraModelD3 >":
    return _StepVisual.Handle_StepVisual_CameraModelD3_Create()

def Handle_StepVisual_CameraModelD3_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CameraModelD3 >":
    return _StepVisual.Handle_StepVisual_CameraModelD3_DownCast(t)

def Handle_StepVisual_CameraModelD3_IsNull(t: "opencascade::handle< StepVisual_CameraModelD3 > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CameraModelD3_IsNull(t)

def Handle_StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel_Create() -> "opencascade::handle< StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel >":
    return _StepVisual.Handle_StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel_Create()

def Handle_StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel >":
    return _StepVisual.Handle_StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel_DownCast(t)

def Handle_StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel_IsNull(t: "opencascade::handle< StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel_IsNull(t)

def Handle_StepVisual_ColourSpecification_Create() -> "opencascade::handle< StepVisual_ColourSpecification >":
    return _StepVisual.Handle_StepVisual_ColourSpecification_Create()

def Handle_StepVisual_ColourSpecification_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_ColourSpecification >":
    return _StepVisual.Handle_StepVisual_ColourSpecification_DownCast(t)

def Handle_StepVisual_ColourSpecification_IsNull(t: "opencascade::handle< StepVisual_ColourSpecification > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_ColourSpecification_IsNull(t)

def Handle_StepVisual_CompositeTextWithExtent_Create() -> "opencascade::handle< StepVisual_CompositeTextWithExtent >":
    return _StepVisual.Handle_StepVisual_CompositeTextWithExtent_Create()

def Handle_StepVisual_CompositeTextWithExtent_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CompositeTextWithExtent >":
    return _StepVisual.Handle_StepVisual_CompositeTextWithExtent_DownCast(t)

def Handle_StepVisual_CompositeTextWithExtent_IsNull(t: "opencascade::handle< StepVisual_CompositeTextWithExtent > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CompositeTextWithExtent_IsNull(t)

def Handle_StepVisual_ContextDependentInvisibility_Create() -> "opencascade::handle< StepVisual_ContextDependentInvisibility >":
    return _StepVisual.Handle_StepVisual_ContextDependentInvisibility_Create()

def Handle_StepVisual_ContextDependentInvisibility_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_ContextDependentInvisibility >":
    return _StepVisual.Handle_StepVisual_ContextDependentInvisibility_DownCast(t)

def Handle_StepVisual_ContextDependentInvisibility_IsNull(t: "opencascade::handle< StepVisual_ContextDependentInvisibility > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_ContextDependentInvisibility_IsNull(t)

def Handle_StepVisual_CoordinatesList_Create() -> "opencascade::handle< StepVisual_CoordinatesList >":
    return _StepVisual.Handle_StepVisual_CoordinatesList_Create()

def Handle_StepVisual_CoordinatesList_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CoordinatesList >":
    return _StepVisual.Handle_StepVisual_CoordinatesList_DownCast(t)

def Handle_StepVisual_CoordinatesList_IsNull(t: "opencascade::handle< StepVisual_CoordinatesList > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CoordinatesList_IsNull(t)

def Handle_StepVisual_MechanicalDesignGeometricPresentationRepresentation_Create() -> "opencascade::handle< StepVisual_MechanicalDesignGeometricPresentationRepresentation >":
    return _StepVisual.Handle_StepVisual_MechanicalDesignGeometricPresentationRepresentation_Create()

def Handle_StepVisual_MechanicalDesignGeometricPresentationRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_MechanicalDesignGeometricPresentationRepresentation >":
    return _StepVisual.Handle_StepVisual_MechanicalDesignGeometricPresentationRepresentation_DownCast(t)

def Handle_StepVisual_MechanicalDesignGeometricPresentationRepresentation_IsNull(t: "opencascade::handle< StepVisual_MechanicalDesignGeometricPresentationRepresentation > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_MechanicalDesignGeometricPresentationRepresentation_IsNull(t)

def Handle_StepVisual_OverRidingStyledItem_Create() -> "opencascade::handle< StepVisual_OverRidingStyledItem >":
    return _StepVisual.Handle_StepVisual_OverRidingStyledItem_Create()

def Handle_StepVisual_OverRidingStyledItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_OverRidingStyledItem >":
    return _StepVisual.Handle_StepVisual_OverRidingStyledItem_DownCast(t)

def Handle_StepVisual_OverRidingStyledItem_IsNull(t: "opencascade::handle< StepVisual_OverRidingStyledItem > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_OverRidingStyledItem_IsNull(t)

def Handle_StepVisual_PlanarBox_Create() -> "opencascade::handle< StepVisual_PlanarBox >":
    return _StepVisual.Handle_StepVisual_PlanarBox_Create()

def Handle_StepVisual_PlanarBox_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PlanarBox >":
    return _StepVisual.Handle_StepVisual_PlanarBox_DownCast(t)

def Handle_StepVisual_PlanarBox_IsNull(t: "opencascade::handle< StepVisual_PlanarBox > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PlanarBox_IsNull(t)

def Handle_StepVisual_PreDefinedColour_Create() -> "opencascade::handle< StepVisual_PreDefinedColour >":
    return _StepVisual.Handle_StepVisual_PreDefinedColour_Create()

def Handle_StepVisual_PreDefinedColour_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PreDefinedColour >":
    return _StepVisual.Handle_StepVisual_PreDefinedColour_DownCast(t)

def Handle_StepVisual_PreDefinedColour_IsNull(t: "opencascade::handle< StepVisual_PreDefinedColour > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PreDefinedColour_IsNull(t)

def Handle_StepVisual_PreDefinedCurveFont_Create() -> "opencascade::handle< StepVisual_PreDefinedCurveFont >":
    return _StepVisual.Handle_StepVisual_PreDefinedCurveFont_Create()

def Handle_StepVisual_PreDefinedCurveFont_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PreDefinedCurveFont >":
    return _StepVisual.Handle_StepVisual_PreDefinedCurveFont_DownCast(t)

def Handle_StepVisual_PreDefinedCurveFont_IsNull(t: "opencascade::handle< StepVisual_PreDefinedCurveFont > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PreDefinedCurveFont_IsNull(t)

def Handle_StepVisual_PreDefinedTextFont_Create() -> "opencascade::handle< StepVisual_PreDefinedTextFont >":
    return _StepVisual.Handle_StepVisual_PreDefinedTextFont_Create()

def Handle_StepVisual_PreDefinedTextFont_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PreDefinedTextFont >":
    return _StepVisual.Handle_StepVisual_PreDefinedTextFont_DownCast(t)

def Handle_StepVisual_PreDefinedTextFont_IsNull(t: "opencascade::handle< StepVisual_PreDefinedTextFont > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PreDefinedTextFont_IsNull(t)

def Handle_StepVisual_PresentationArea_Create() -> "opencascade::handle< StepVisual_PresentationArea >":
    return _StepVisual.Handle_StepVisual_PresentationArea_Create()

def Handle_StepVisual_PresentationArea_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PresentationArea >":
    return _StepVisual.Handle_StepVisual_PresentationArea_DownCast(t)

def Handle_StepVisual_PresentationArea_IsNull(t: "opencascade::handle< StepVisual_PresentationArea > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PresentationArea_IsNull(t)

def Handle_StepVisual_PresentationStyleByContext_Create() -> "opencascade::handle< StepVisual_PresentationStyleByContext >":
    return _StepVisual.Handle_StepVisual_PresentationStyleByContext_Create()

def Handle_StepVisual_PresentationStyleByContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PresentationStyleByContext >":
    return _StepVisual.Handle_StepVisual_PresentationStyleByContext_DownCast(t)

def Handle_StepVisual_PresentationStyleByContext_IsNull(t: "opencascade::handle< StepVisual_PresentationStyleByContext > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PresentationStyleByContext_IsNull(t)

def Handle_StepVisual_PresentationView_Create() -> "opencascade::handle< StepVisual_PresentationView >":
    return _StepVisual.Handle_StepVisual_PresentationView_Create()

def Handle_StepVisual_PresentationView_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_PresentationView >":
    return _StepVisual.Handle_StepVisual_PresentationView_DownCast(t)

def Handle_StepVisual_PresentationView_IsNull(t: "opencascade::handle< StepVisual_PresentationView > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_PresentationView_IsNull(t)

def Handle_StepVisual_SurfaceStyleRenderingWithProperties_Create() -> "opencascade::handle< StepVisual_SurfaceStyleRenderingWithProperties >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleRenderingWithProperties_Create()

def Handle_StepVisual_SurfaceStyleRenderingWithProperties_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_SurfaceStyleRenderingWithProperties >":
    return _StepVisual.Handle_StepVisual_SurfaceStyleRenderingWithProperties_DownCast(t)

def Handle_StepVisual_SurfaceStyleRenderingWithProperties_IsNull(t: "opencascade::handle< StepVisual_SurfaceStyleRenderingWithProperties > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_SurfaceStyleRenderingWithProperties_IsNull(t)

def Handle_StepVisual_TessellatedAnnotationOccurrence_Create() -> "opencascade::handle< StepVisual_TessellatedAnnotationOccurrence >":
    return _StepVisual.Handle_StepVisual_TessellatedAnnotationOccurrence_Create()

def Handle_StepVisual_TessellatedAnnotationOccurrence_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_TessellatedAnnotationOccurrence >":
    return _StepVisual.Handle_StepVisual_TessellatedAnnotationOccurrence_DownCast(t)

def Handle_StepVisual_TessellatedAnnotationOccurrence_IsNull(t: "opencascade::handle< StepVisual_TessellatedAnnotationOccurrence > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_TessellatedAnnotationOccurrence_IsNull(t)

def Handle_StepVisual_TessellatedCurveSet_Create() -> "opencascade::handle< StepVisual_TessellatedCurveSet >":
    return _StepVisual.Handle_StepVisual_TessellatedCurveSet_Create()

def Handle_StepVisual_TessellatedCurveSet_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_TessellatedCurveSet >":
    return _StepVisual.Handle_StepVisual_TessellatedCurveSet_DownCast(t)

def Handle_StepVisual_TessellatedCurveSet_IsNull(t: "opencascade::handle< StepVisual_TessellatedCurveSet > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_TessellatedCurveSet_IsNull(t)

def Handle_StepVisual_TessellatedGeometricSet_Create() -> "opencascade::handle< StepVisual_TessellatedGeometricSet >":
    return _StepVisual.Handle_StepVisual_TessellatedGeometricSet_Create()

def Handle_StepVisual_TessellatedGeometricSet_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_TessellatedGeometricSet >":
    return _StepVisual.Handle_StepVisual_TessellatedGeometricSet_DownCast(t)

def Handle_StepVisual_TessellatedGeometricSet_IsNull(t: "opencascade::handle< StepVisual_TessellatedGeometricSet > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_TessellatedGeometricSet_IsNull(t)

def Handle_StepVisual_TextStyleWithBoxCharacteristics_Create() -> "opencascade::handle< StepVisual_TextStyleWithBoxCharacteristics >":
    return _StepVisual.Handle_StepVisual_TextStyleWithBoxCharacteristics_Create()

def Handle_StepVisual_TextStyleWithBoxCharacteristics_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_TextStyleWithBoxCharacteristics >":
    return _StepVisual.Handle_StepVisual_TextStyleWithBoxCharacteristics_DownCast(t)

def Handle_StepVisual_TextStyleWithBoxCharacteristics_IsNull(t: "opencascade::handle< StepVisual_TextStyleWithBoxCharacteristics > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_TextStyleWithBoxCharacteristics_IsNull(t)

def Handle_StepVisual_AnnotationCurveOccurrence_Create() -> "opencascade::handle< StepVisual_AnnotationCurveOccurrence >":
    return _StepVisual.Handle_StepVisual_AnnotationCurveOccurrence_Create()

def Handle_StepVisual_AnnotationCurveOccurrence_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_AnnotationCurveOccurrence >":
    return _StepVisual.Handle_StepVisual_AnnotationCurveOccurrence_DownCast(t)

def Handle_StepVisual_AnnotationCurveOccurrence_IsNull(t: "opencascade::handle< StepVisual_AnnotationCurveOccurrence > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_AnnotationCurveOccurrence_IsNull(t)

def Handle_StepVisual_AnnotationFillAreaOccurrence_Create() -> "opencascade::handle< StepVisual_AnnotationFillAreaOccurrence >":
    return _StepVisual.Handle_StepVisual_AnnotationFillAreaOccurrence_Create()

def Handle_StepVisual_AnnotationFillAreaOccurrence_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_AnnotationFillAreaOccurrence >":
    return _StepVisual.Handle_StepVisual_AnnotationFillAreaOccurrence_DownCast(t)

def Handle_StepVisual_AnnotationFillAreaOccurrence_IsNull(t: "opencascade::handle< StepVisual_AnnotationFillAreaOccurrence > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_AnnotationFillAreaOccurrence_IsNull(t)

def Handle_StepVisual_AnnotationPlane_Create() -> "opencascade::handle< StepVisual_AnnotationPlane >":
    return _StepVisual.Handle_StepVisual_AnnotationPlane_Create()

def Handle_StepVisual_AnnotationPlane_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_AnnotationPlane >":
    return _StepVisual.Handle_StepVisual_AnnotationPlane_DownCast(t)

def Handle_StepVisual_AnnotationPlane_IsNull(t: "opencascade::handle< StepVisual_AnnotationPlane > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_AnnotationPlane_IsNull(t)

def Handle_StepVisual_AnnotationTextOccurrence_Create() -> "opencascade::handle< StepVisual_AnnotationTextOccurrence >":
    return _StepVisual.Handle_StepVisual_AnnotationTextOccurrence_Create()

def Handle_StepVisual_AnnotationTextOccurrence_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_AnnotationTextOccurrence >":
    return _StepVisual.Handle_StepVisual_AnnotationTextOccurrence_DownCast(t)

def Handle_StepVisual_AnnotationTextOccurrence_IsNull(t: "opencascade::handle< StepVisual_AnnotationTextOccurrence > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_AnnotationTextOccurrence_IsNull(t)

def Handle_StepVisual_CameraModelD3MultiClipping_Create() -> "opencascade::handle< StepVisual_CameraModelD3MultiClipping >":
    return _StepVisual.Handle_StepVisual_CameraModelD3MultiClipping_Create()

def Handle_StepVisual_CameraModelD3MultiClipping_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_CameraModelD3MultiClipping >":
    return _StepVisual.Handle_StepVisual_CameraModelD3MultiClipping_DownCast(t)

def Handle_StepVisual_CameraModelD3MultiClipping_IsNull(t: "opencascade::handle< StepVisual_CameraModelD3MultiClipping > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_CameraModelD3MultiClipping_IsNull(t)

def Handle_StepVisual_ColourRgb_Create() -> "opencascade::handle< StepVisual_ColourRgb >":
    return _StepVisual.Handle_StepVisual_ColourRgb_Create()

def Handle_StepVisual_ColourRgb_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_ColourRgb >":
    return _StepVisual.Handle_StepVisual_ColourRgb_DownCast(t)

def Handle_StepVisual_ColourRgb_IsNull(t: "opencascade::handle< StepVisual_ColourRgb > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_ColourRgb_IsNull(t)

def Handle_StepVisual_ContextDependentOverRidingStyledItem_Create() -> "opencascade::handle< StepVisual_ContextDependentOverRidingStyledItem >":
    return _StepVisual.Handle_StepVisual_ContextDependentOverRidingStyledItem_Create()

def Handle_StepVisual_ContextDependentOverRidingStyledItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_ContextDependentOverRidingStyledItem >":
    return _StepVisual.Handle_StepVisual_ContextDependentOverRidingStyledItem_DownCast(t)

def Handle_StepVisual_ContextDependentOverRidingStyledItem_IsNull(t: "opencascade::handle< StepVisual_ContextDependentOverRidingStyledItem > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_ContextDependentOverRidingStyledItem_IsNull(t)

def Handle_StepVisual_DraughtingAnnotationOccurrence_Create() -> "opencascade::handle< StepVisual_DraughtingAnnotationOccurrence >":
    return _StepVisual.Handle_StepVisual_DraughtingAnnotationOccurrence_Create()

def Handle_StepVisual_DraughtingAnnotationOccurrence_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_DraughtingAnnotationOccurrence >":
    return _StepVisual.Handle_StepVisual_DraughtingAnnotationOccurrence_DownCast(t)

def Handle_StepVisual_DraughtingAnnotationOccurrence_IsNull(t: "opencascade::handle< StepVisual_DraughtingAnnotationOccurrence > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_DraughtingAnnotationOccurrence_IsNull(t)

def Handle_StepVisual_DraughtingPreDefinedColour_Create() -> "opencascade::handle< StepVisual_DraughtingPreDefinedColour >":
    return _StepVisual.Handle_StepVisual_DraughtingPreDefinedColour_Create()

def Handle_StepVisual_DraughtingPreDefinedColour_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_DraughtingPreDefinedColour >":
    return _StepVisual.Handle_StepVisual_DraughtingPreDefinedColour_DownCast(t)

def Handle_StepVisual_DraughtingPreDefinedColour_IsNull(t: "opencascade::handle< StepVisual_DraughtingPreDefinedColour > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_DraughtingPreDefinedColour_IsNull(t)

def Handle_StepVisual_DraughtingPreDefinedCurveFont_Create() -> "opencascade::handle< StepVisual_DraughtingPreDefinedCurveFont >":
    return _StepVisual.Handle_StepVisual_DraughtingPreDefinedCurveFont_Create()

def Handle_StepVisual_DraughtingPreDefinedCurveFont_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_DraughtingPreDefinedCurveFont >":
    return _StepVisual.Handle_StepVisual_DraughtingPreDefinedCurveFont_DownCast(t)

def Handle_StepVisual_DraughtingPreDefinedCurveFont_IsNull(t: "opencascade::handle< StepVisual_DraughtingPreDefinedCurveFont > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_DraughtingPreDefinedCurveFont_IsNull(t)

def Handle_StepVisual_MechanicalDesignGeometricPresentationArea_Create() -> "opencascade::handle< StepVisual_MechanicalDesignGeometricPresentationArea >":
    return _StepVisual.Handle_StepVisual_MechanicalDesignGeometricPresentationArea_Create()

def Handle_StepVisual_MechanicalDesignGeometricPresentationArea_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_MechanicalDesignGeometricPresentationArea >":
    return _StepVisual.Handle_StepVisual_MechanicalDesignGeometricPresentationArea_DownCast(t)

def Handle_StepVisual_MechanicalDesignGeometricPresentationArea_IsNull(t: "opencascade::handle< StepVisual_MechanicalDesignGeometricPresentationArea > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_MechanicalDesignGeometricPresentationArea_IsNull(t)

def Handle_StepVisual_AnnotationCurveOccurrenceAndGeomReprItem_Create() -> "opencascade::handle< StepVisual_AnnotationCurveOccurrenceAndGeomReprItem >":
    return _StepVisual.Handle_StepVisual_AnnotationCurveOccurrenceAndGeomReprItem_Create()

def Handle_StepVisual_AnnotationCurveOccurrenceAndGeomReprItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_AnnotationCurveOccurrenceAndGeomReprItem >":
    return _StepVisual.Handle_StepVisual_AnnotationCurveOccurrenceAndGeomReprItem_DownCast(t)

def Handle_StepVisual_AnnotationCurveOccurrenceAndGeomReprItem_IsNull(t: "opencascade::handle< StepVisual_AnnotationCurveOccurrenceAndGeomReprItem > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_AnnotationCurveOccurrenceAndGeomReprItem_IsNull(t)

def Handle_StepVisual_HArray1OfAnnotationPlaneElement_Create() -> "opencascade::handle< StepVisual_HArray1OfAnnotationPlaneElement >":
    return _StepVisual.Handle_StepVisual_HArray1OfAnnotationPlaneElement_Create()

def Handle_StepVisual_HArray1OfAnnotationPlaneElement_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfAnnotationPlaneElement >":
    return _StepVisual.Handle_StepVisual_HArray1OfAnnotationPlaneElement_DownCast(t)

def Handle_StepVisual_HArray1OfAnnotationPlaneElement_IsNull(t: "opencascade::handle< StepVisual_HArray1OfAnnotationPlaneElement > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfAnnotationPlaneElement_IsNull(t)

def Handle_StepVisual_HArray1OfDraughtingCalloutElement_Create() -> "opencascade::handle< StepVisual_HArray1OfDraughtingCalloutElement >":
    return _StepVisual.Handle_StepVisual_HArray1OfDraughtingCalloutElement_Create()

def Handle_StepVisual_HArray1OfDraughtingCalloutElement_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfDraughtingCalloutElement >":
    return _StepVisual.Handle_StepVisual_HArray1OfDraughtingCalloutElement_DownCast(t)

def Handle_StepVisual_HArray1OfDraughtingCalloutElement_IsNull(t: "opencascade::handle< StepVisual_HArray1OfDraughtingCalloutElement > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfDraughtingCalloutElement_IsNull(t)

def Handle_StepVisual_HArray1OfDirectionCountSelect_Create() -> "opencascade::handle< StepVisual_HArray1OfDirectionCountSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfDirectionCountSelect_Create()

def Handle_StepVisual_HArray1OfDirectionCountSelect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfDirectionCountSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfDirectionCountSelect_DownCast(t)

def Handle_StepVisual_HArray1OfDirectionCountSelect_IsNull(t: "opencascade::handle< StepVisual_HArray1OfDirectionCountSelect > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfDirectionCountSelect_IsNull(t)

def Handle_StepVisual_HArray1OfStyleContextSelect_Create() -> "opencascade::handle< StepVisual_HArray1OfStyleContextSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfStyleContextSelect_Create()

def Handle_StepVisual_HArray1OfStyleContextSelect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfStyleContextSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfStyleContextSelect_DownCast(t)

def Handle_StepVisual_HArray1OfStyleContextSelect_IsNull(t: "opencascade::handle< StepVisual_HArray1OfStyleContextSelect > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfStyleContextSelect_IsNull(t)

def Handle_StepVisual_HArray1OfPresentationStyleSelect_Create() -> "opencascade::handle< StepVisual_HArray1OfPresentationStyleSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfPresentationStyleSelect_Create()

def Handle_StepVisual_HArray1OfPresentationStyleSelect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfPresentationStyleSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfPresentationStyleSelect_DownCast(t)

def Handle_StepVisual_HArray1OfPresentationStyleSelect_IsNull(t: "opencascade::handle< StepVisual_HArray1OfPresentationStyleSelect > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfPresentationStyleSelect_IsNull(t)

def Handle_StepVisual_HArray1OfCurveStyleFontPattern_Create() -> "opencascade::handle< StepVisual_HArray1OfCurveStyleFontPattern >":
    return _StepVisual.Handle_StepVisual_HArray1OfCurveStyleFontPattern_Create()

def Handle_StepVisual_HArray1OfCurveStyleFontPattern_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfCurveStyleFontPattern >":
    return _StepVisual.Handle_StepVisual_HArray1OfCurveStyleFontPattern_DownCast(t)

def Handle_StepVisual_HArray1OfCurveStyleFontPattern_IsNull(t: "opencascade::handle< StepVisual_HArray1OfCurveStyleFontPattern > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfCurveStyleFontPattern_IsNull(t)

def Handle_StepVisual_HArray1OfRenderingPropertiesSelect_Create() -> "opencascade::handle< StepVisual_HArray1OfRenderingPropertiesSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfRenderingPropertiesSelect_Create()

def Handle_StepVisual_HArray1OfRenderingPropertiesSelect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfRenderingPropertiesSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfRenderingPropertiesSelect_DownCast(t)

def Handle_StepVisual_HArray1OfRenderingPropertiesSelect_IsNull(t: "opencascade::handle< StepVisual_HArray1OfRenderingPropertiesSelect > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfRenderingPropertiesSelect_IsNull(t)

def Handle_StepVisual_HArray1OfBoxCharacteristicSelect_Create() -> "opencascade::handle< StepVisual_HArray1OfBoxCharacteristicSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfBoxCharacteristicSelect_Create()

def Handle_StepVisual_HArray1OfBoxCharacteristicSelect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfBoxCharacteristicSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfBoxCharacteristicSelect_DownCast(t)

def Handle_StepVisual_HArray1OfBoxCharacteristicSelect_IsNull(t: "opencascade::handle< StepVisual_HArray1OfBoxCharacteristicSelect > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfBoxCharacteristicSelect_IsNull(t)

def Handle_StepVisual_HArray1OfPresentationStyleAssignment_Create() -> "opencascade::handle< StepVisual_HArray1OfPresentationStyleAssignment >":
    return _StepVisual.Handle_StepVisual_HArray1OfPresentationStyleAssignment_Create()

def Handle_StepVisual_HArray1OfPresentationStyleAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfPresentationStyleAssignment >":
    return _StepVisual.Handle_StepVisual_HArray1OfPresentationStyleAssignment_DownCast(t)

def Handle_StepVisual_HArray1OfPresentationStyleAssignment_IsNull(t: "opencascade::handle< StepVisual_HArray1OfPresentationStyleAssignment > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfPresentationStyleAssignment_IsNull(t)

def Handle_StepVisual_HArray1OfFillStyleSelect_Create() -> "opencascade::handle< StepVisual_HArray1OfFillStyleSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfFillStyleSelect_Create()

def Handle_StepVisual_HArray1OfFillStyleSelect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfFillStyleSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfFillStyleSelect_DownCast(t)

def Handle_StepVisual_HArray1OfFillStyleSelect_IsNull(t: "opencascade::handle< StepVisual_HArray1OfFillStyleSelect > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfFillStyleSelect_IsNull(t)

def Handle_StepVisual_HArray1OfTextOrCharacter_Create() -> "opencascade::handle< StepVisual_HArray1OfTextOrCharacter >":
    return _StepVisual.Handle_StepVisual_HArray1OfTextOrCharacter_Create()

def Handle_StepVisual_HArray1OfTextOrCharacter_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfTextOrCharacter >":
    return _StepVisual.Handle_StepVisual_HArray1OfTextOrCharacter_DownCast(t)

def Handle_StepVisual_HArray1OfTextOrCharacter_IsNull(t: "opencascade::handle< StepVisual_HArray1OfTextOrCharacter > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfTextOrCharacter_IsNull(t)

def Handle_StepVisual_HArray1OfSurfaceStyleElementSelect_Create() -> "opencascade::handle< StepVisual_HArray1OfSurfaceStyleElementSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfSurfaceStyleElementSelect_Create()

def Handle_StepVisual_HArray1OfSurfaceStyleElementSelect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfSurfaceStyleElementSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfSurfaceStyleElementSelect_DownCast(t)

def Handle_StepVisual_HArray1OfSurfaceStyleElementSelect_IsNull(t: "opencascade::handle< StepVisual_HArray1OfSurfaceStyleElementSelect > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfSurfaceStyleElementSelect_IsNull(t)

def Handle_StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect_Create() -> "opencascade::handle< StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect_Create()

def Handle_StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect_DownCast(t)

def Handle_StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect_IsNull(t: "opencascade::handle< StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect_IsNull(t)

def Handle_StepVisual_HArray1OfLayeredItem_Create() -> "opencascade::handle< StepVisual_HArray1OfLayeredItem >":
    return _StepVisual.Handle_StepVisual_HArray1OfLayeredItem_Create()

def Handle_StepVisual_HArray1OfLayeredItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfLayeredItem >":
    return _StepVisual.Handle_StepVisual_HArray1OfLayeredItem_DownCast(t)

def Handle_StepVisual_HArray1OfLayeredItem_IsNull(t: "opencascade::handle< StepVisual_HArray1OfLayeredItem > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfLayeredItem_IsNull(t)

def Handle_StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect_Create() -> "opencascade::handle< StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect_Create()

def Handle_StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect >":
    return _StepVisual.Handle_StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect_DownCast(t)

def Handle_StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect_IsNull(t: "opencascade::handle< StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect_IsNull(t)

def Handle_StepVisual_HArray1OfInvisibleItem_Create() -> "opencascade::handle< StepVisual_HArray1OfInvisibleItem >":
    return _StepVisual.Handle_StepVisual_HArray1OfInvisibleItem_Create()

def Handle_StepVisual_HArray1OfInvisibleItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepVisual_HArray1OfInvisibleItem >":
    return _StepVisual.Handle_StepVisual_HArray1OfInvisibleItem_DownCast(t)

def Handle_StepVisual_HArray1OfInvisibleItem_IsNull(t: "opencascade::handle< StepVisual_HArray1OfInvisibleItem > const &") -> "bool":
    return _StepVisual.Handle_StepVisual_HArray1OfInvisibleItem_IsNull(t)
class StepVisual_Array1OfAnnotationPlaneElement(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_AnnotationPlaneElement >::iterator":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_AnnotationPlaneElement >::iterator":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_AnnotationPlaneElement >::const_iterator":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_AnnotationPlaneElement >::const_iterator":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_swiginit(self, _StepVisual.new_StepVisual_Array1OfAnnotationPlaneElement(*args))

    def Init(self, theValue: "StepVisual_AnnotationPlaneElement") -> "void":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfAnnotationPlaneElement") -> "NCollection_Array1< StepVisual_AnnotationPlaneElement > &":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfAnnotationPlaneElement") -> "NCollection_Array1< StepVisual_AnnotationPlaneElement > &":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_AnnotationPlaneElement > &":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_Set(self, *args)

    def First(self) -> "StepVisual_AnnotationPlaneElement const &":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_First(self)

    def ChangeFirst(self) -> "StepVisual_AnnotationPlaneElement &":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_ChangeFirst(self)

    def Last(self) -> "StepVisual_AnnotationPlaneElement const &":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_Last(self)

    def ChangeLast(self) -> "StepVisual_AnnotationPlaneElement &":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_AnnotationPlaneElement const &":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_AnnotationPlaneElement &":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_AnnotationPlaneElement &":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_AnnotationPlaneElement") -> "void":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfAnnotationPlaneElement_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfAnnotationPlaneElement

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfAnnotationPlaneElement in _StepVisual:
_StepVisual.StepVisual_Array1OfAnnotationPlaneElement_swigregister(StepVisual_Array1OfAnnotationPlaneElement)

class StepVisual_Array1OfBoxCharacteristicSelect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_BoxCharacteristicSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_BoxCharacteristicSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_BoxCharacteristicSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_BoxCharacteristicSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_swiginit(self, _StepVisual.new_StepVisual_Array1OfBoxCharacteristicSelect(*args))

    def Init(self, theValue: "StepVisual_BoxCharacteristicSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfBoxCharacteristicSelect") -> "NCollection_Array1< StepVisual_BoxCharacteristicSelect > &":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfBoxCharacteristicSelect") -> "NCollection_Array1< StepVisual_BoxCharacteristicSelect > &":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_BoxCharacteristicSelect > &":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_Set(self, *args)

    def First(self) -> "StepVisual_BoxCharacteristicSelect const &":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_First(self)

    def ChangeFirst(self) -> "StepVisual_BoxCharacteristicSelect &":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_ChangeFirst(self)

    def Last(self) -> "StepVisual_BoxCharacteristicSelect const &":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_Last(self)

    def ChangeLast(self) -> "StepVisual_BoxCharacteristicSelect &":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_BoxCharacteristicSelect const &":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_BoxCharacteristicSelect &":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_BoxCharacteristicSelect &":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_BoxCharacteristicSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfBoxCharacteristicSelect

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfBoxCharacteristicSelect in _StepVisual:
_StepVisual.StepVisual_Array1OfBoxCharacteristicSelect_swigregister(StepVisual_Array1OfBoxCharacteristicSelect)

class StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingInterectionSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingInterectionSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingInterectionSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingInterectionSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_swiginit(self, _StepVisual.new_StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect(*args))

    def Init(self, theValue: "StepVisual_CameraModelD3MultiClippingInterectionSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect") -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingInterectionSelect > &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect") -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingInterectionSelect > &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingInterectionSelect > &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_Set(self, *args)

    def First(self) -> "StepVisual_CameraModelD3MultiClippingInterectionSelect const &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_First(self)

    def ChangeFirst(self) -> "StepVisual_CameraModelD3MultiClippingInterectionSelect &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_ChangeFirst(self)

    def Last(self) -> "StepVisual_CameraModelD3MultiClippingInterectionSelect const &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_Last(self)

    def ChangeLast(self) -> "StepVisual_CameraModelD3MultiClippingInterectionSelect &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_CameraModelD3MultiClippingInterectionSelect const &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_CameraModelD3MultiClippingInterectionSelect &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_CameraModelD3MultiClippingInterectionSelect &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_CameraModelD3MultiClippingInterectionSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect in _StepVisual:
_StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect_swigregister(StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect)

class StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingUnionSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingUnionSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingUnionSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingUnionSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_swiginit(self, _StepVisual.new_StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect(*args))

    def Init(self, theValue: "StepVisual_CameraModelD3MultiClippingUnionSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect") -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingUnionSelect > &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect") -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingUnionSelect > &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_CameraModelD3MultiClippingUnionSelect > &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_Set(self, *args)

    def First(self) -> "StepVisual_CameraModelD3MultiClippingUnionSelect const &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_First(self)

    def ChangeFirst(self) -> "StepVisual_CameraModelD3MultiClippingUnionSelect &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_ChangeFirst(self)

    def Last(self) -> "StepVisual_CameraModelD3MultiClippingUnionSelect const &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_Last(self)

    def ChangeLast(self) -> "StepVisual_CameraModelD3MultiClippingUnionSelect &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_CameraModelD3MultiClippingUnionSelect const &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_CameraModelD3MultiClippingUnionSelect &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_CameraModelD3MultiClippingUnionSelect &":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_CameraModelD3MultiClippingUnionSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect in _StepVisual:
_StepVisual.StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect_swigregister(StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect)

class StepVisual_Array1OfCurveStyleFontPattern(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepVisual_CurveStyleFontPattern > >::iterator":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepVisual_CurveStyleFontPattern > >::iterator":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepVisual_CurveStyleFontPattern > >::const_iterator":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepVisual_CurveStyleFontPattern > >::const_iterator":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_swiginit(self, _StepVisual.new_StepVisual_Array1OfCurveStyleFontPattern(*args))

    def Init(self, theValue: "opencascade::handle< StepVisual_CurveStyleFontPattern > const &") -> "void":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfCurveStyleFontPattern") -> "NCollection_Array1< opencascade::handle< StepVisual_CurveStyleFontPattern > > &":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfCurveStyleFontPattern") -> "NCollection_Array1< opencascade::handle< StepVisual_CurveStyleFontPattern > > &":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepVisual_CurveStyleFontPattern > > &":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_Set(self, *args)

    def First(self) -> "opencascade::handle< StepVisual_CurveStyleFontPattern > const &":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepVisual_CurveStyleFontPattern > &":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepVisual_CurveStyleFontPattern > const &":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepVisual_CurveStyleFontPattern > &":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepVisual_CurveStyleFontPattern > const &":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepVisual_CurveStyleFontPattern > &":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepVisual_CurveStyleFontPattern > &":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepVisual_CurveStyleFontPattern > const &") -> "void":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfCurveStyleFontPattern_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfCurveStyleFontPattern

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfCurveStyleFontPattern in _StepVisual:
_StepVisual.StepVisual_Array1OfCurveStyleFontPattern_swigregister(StepVisual_Array1OfCurveStyleFontPattern)

class StepVisual_Array1OfDirectionCountSelect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_DirectionCountSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_DirectionCountSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_DirectionCountSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_DirectionCountSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfDirectionCountSelect_swiginit(self, _StepVisual.new_StepVisual_Array1OfDirectionCountSelect(*args))

    def Init(self, theValue: "StepVisual_DirectionCountSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfDirectionCountSelect") -> "NCollection_Array1< StepVisual_DirectionCountSelect > &":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfDirectionCountSelect") -> "NCollection_Array1< StepVisual_DirectionCountSelect > &":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_DirectionCountSelect > &":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_Set(self, *args)

    def First(self) -> "StepVisual_DirectionCountSelect const &":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_First(self)

    def ChangeFirst(self) -> "StepVisual_DirectionCountSelect &":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_ChangeFirst(self)

    def Last(self) -> "StepVisual_DirectionCountSelect const &":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_Last(self)

    def ChangeLast(self) -> "StepVisual_DirectionCountSelect &":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_DirectionCountSelect const &":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_DirectionCountSelect &":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_DirectionCountSelect &":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_DirectionCountSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfDirectionCountSelect_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfDirectionCountSelect

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfDirectionCountSelect in _StepVisual:
_StepVisual.StepVisual_Array1OfDirectionCountSelect_swigregister(StepVisual_Array1OfDirectionCountSelect)

class StepVisual_Array1OfDraughtingCalloutElement(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_DraughtingCalloutElement >::iterator":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_DraughtingCalloutElement >::iterator":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_DraughtingCalloutElement >::const_iterator":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_DraughtingCalloutElement >::const_iterator":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_swiginit(self, _StepVisual.new_StepVisual_Array1OfDraughtingCalloutElement(*args))

    def Init(self, theValue: "StepVisual_DraughtingCalloutElement") -> "void":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfDraughtingCalloutElement") -> "NCollection_Array1< StepVisual_DraughtingCalloutElement > &":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfDraughtingCalloutElement") -> "NCollection_Array1< StepVisual_DraughtingCalloutElement > &":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_DraughtingCalloutElement > &":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_Set(self, *args)

    def First(self) -> "StepVisual_DraughtingCalloutElement const &":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_First(self)

    def ChangeFirst(self) -> "StepVisual_DraughtingCalloutElement &":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_ChangeFirst(self)

    def Last(self) -> "StepVisual_DraughtingCalloutElement const &":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_Last(self)

    def ChangeLast(self) -> "StepVisual_DraughtingCalloutElement &":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_DraughtingCalloutElement const &":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_DraughtingCalloutElement &":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_DraughtingCalloutElement &":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_DraughtingCalloutElement") -> "void":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfDraughtingCalloutElement_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfDraughtingCalloutElement

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfDraughtingCalloutElement in _StepVisual:
_StepVisual.StepVisual_Array1OfDraughtingCalloutElement_swigregister(StepVisual_Array1OfDraughtingCalloutElement)

class StepVisual_Array1OfFillStyleSelect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_FillStyleSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_FillStyleSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_FillStyleSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_FillStyleSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfFillStyleSelect_swiginit(self, _StepVisual.new_StepVisual_Array1OfFillStyleSelect(*args))

    def Init(self, theValue: "StepVisual_FillStyleSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfFillStyleSelect") -> "NCollection_Array1< StepVisual_FillStyleSelect > &":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfFillStyleSelect") -> "NCollection_Array1< StepVisual_FillStyleSelect > &":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_FillStyleSelect > &":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_Set(self, *args)

    def First(self) -> "StepVisual_FillStyleSelect const &":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_First(self)

    def ChangeFirst(self) -> "StepVisual_FillStyleSelect &":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_ChangeFirst(self)

    def Last(self) -> "StepVisual_FillStyleSelect const &":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_Last(self)

    def ChangeLast(self) -> "StepVisual_FillStyleSelect &":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_FillStyleSelect const &":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_FillStyleSelect &":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_FillStyleSelect &":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_FillStyleSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfFillStyleSelect_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfFillStyleSelect

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfFillStyleSelect in _StepVisual:
_StepVisual.StepVisual_Array1OfFillStyleSelect_swigregister(StepVisual_Array1OfFillStyleSelect)

class StepVisual_Array1OfInvisibleItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_InvisibleItem >::iterator":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_InvisibleItem >::iterator":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_InvisibleItem >::const_iterator":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_InvisibleItem >::const_iterator":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfInvisibleItem_swiginit(self, _StepVisual.new_StepVisual_Array1OfInvisibleItem(*args))

    def Init(self, theValue: "StepVisual_InvisibleItem") -> "void":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfInvisibleItem") -> "NCollection_Array1< StepVisual_InvisibleItem > &":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfInvisibleItem") -> "NCollection_Array1< StepVisual_InvisibleItem > &":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_InvisibleItem > &":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_Set(self, *args)

    def First(self) -> "StepVisual_InvisibleItem const &":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_First(self)

    def ChangeFirst(self) -> "StepVisual_InvisibleItem &":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_ChangeFirst(self)

    def Last(self) -> "StepVisual_InvisibleItem const &":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_Last(self)

    def ChangeLast(self) -> "StepVisual_InvisibleItem &":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_InvisibleItem const &":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_InvisibleItem &":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_InvisibleItem &":
        return _StepVisual.StepVisual_Array1OfInvisibleItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_InvisibleItem") -> "void":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfInvisibleItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfInvisibleItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfInvisibleItem in _StepVisual:
_StepVisual.StepVisual_Array1OfInvisibleItem_swigregister(StepVisual_Array1OfInvisibleItem)

class StepVisual_Array1OfLayeredItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_LayeredItem >::iterator":
        return _StepVisual.StepVisual_Array1OfLayeredItem_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_LayeredItem >::iterator":
        return _StepVisual.StepVisual_Array1OfLayeredItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_LayeredItem >::const_iterator":
        return _StepVisual.StepVisual_Array1OfLayeredItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_LayeredItem >::const_iterator":
        return _StepVisual.StepVisual_Array1OfLayeredItem_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfLayeredItem_swiginit(self, _StepVisual.new_StepVisual_Array1OfLayeredItem(*args))

    def Init(self, theValue: "StepVisual_LayeredItem") -> "void":
        return _StepVisual.StepVisual_Array1OfLayeredItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfLayeredItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfLayeredItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfLayeredItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfLayeredItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfLayeredItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfLayeredItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfLayeredItem_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfLayeredItem") -> "NCollection_Array1< StepVisual_LayeredItem > &":
        return _StepVisual.StepVisual_Array1OfLayeredItem_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfLayeredItem") -> "NCollection_Array1< StepVisual_LayeredItem > &":
        return _StepVisual.StepVisual_Array1OfLayeredItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_LayeredItem > &":
        return _StepVisual.StepVisual_Array1OfLayeredItem_Set(self, *args)

    def First(self) -> "StepVisual_LayeredItem const &":
        return _StepVisual.StepVisual_Array1OfLayeredItem_First(self)

    def ChangeFirst(self) -> "StepVisual_LayeredItem &":
        return _StepVisual.StepVisual_Array1OfLayeredItem_ChangeFirst(self)

    def Last(self) -> "StepVisual_LayeredItem const &":
        return _StepVisual.StepVisual_Array1OfLayeredItem_Last(self)

    def ChangeLast(self) -> "StepVisual_LayeredItem &":
        return _StepVisual.StepVisual_Array1OfLayeredItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_LayeredItem const &":
        return _StepVisual.StepVisual_Array1OfLayeredItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_LayeredItem &":
        return _StepVisual.StepVisual_Array1OfLayeredItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_LayeredItem &":
        return _StepVisual.StepVisual_Array1OfLayeredItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_LayeredItem") -> "void":
        return _StepVisual.StepVisual_Array1OfLayeredItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfLayeredItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfLayeredItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfLayeredItem in _StepVisual:
_StepVisual.StepVisual_Array1OfLayeredItem_swigregister(StepVisual_Array1OfLayeredItem)

class StepVisual_Array1OfPresentationStyleAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepVisual_PresentationStyleAssignment > >::iterator":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepVisual_PresentationStyleAssignment > >::iterator":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepVisual_PresentationStyleAssignment > >::const_iterator":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepVisual_PresentationStyleAssignment > >::const_iterator":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_swiginit(self, _StepVisual.new_StepVisual_Array1OfPresentationStyleAssignment(*args))

    def Init(self, theValue: "opencascade::handle< StepVisual_PresentationStyleAssignment > const &") -> "void":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfPresentationStyleAssignment") -> "NCollection_Array1< opencascade::handle< StepVisual_PresentationStyleAssignment > > &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfPresentationStyleAssignment") -> "NCollection_Array1< opencascade::handle< StepVisual_PresentationStyleAssignment > > &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepVisual_PresentationStyleAssignment > > &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_Set(self, *args)

    def First(self) -> "opencascade::handle< StepVisual_PresentationStyleAssignment > const &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepVisual_PresentationStyleAssignment > &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepVisual_PresentationStyleAssignment > const &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepVisual_PresentationStyleAssignment > &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepVisual_PresentationStyleAssignment > const &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepVisual_PresentationStyleAssignment > &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepVisual_PresentationStyleAssignment > &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepVisual_PresentationStyleAssignment > const &") -> "void":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfPresentationStyleAssignment_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfPresentationStyleAssignment

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfPresentationStyleAssignment in _StepVisual:
_StepVisual.StepVisual_Array1OfPresentationStyleAssignment_swigregister(StepVisual_Array1OfPresentationStyleAssignment)

class StepVisual_Array1OfPresentationStyleSelect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_PresentationStyleSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_PresentationStyleSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_PresentationStyleSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_PresentationStyleSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfPresentationStyleSelect_swiginit(self, _StepVisual.new_StepVisual_Array1OfPresentationStyleSelect(*args))

    def Init(self, theValue: "StepVisual_PresentationStyleSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfPresentationStyleSelect") -> "NCollection_Array1< StepVisual_PresentationStyleSelect > &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfPresentationStyleSelect") -> "NCollection_Array1< StepVisual_PresentationStyleSelect > &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_PresentationStyleSelect > &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_Set(self, *args)

    def First(self) -> "StepVisual_PresentationStyleSelect const &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_First(self)

    def ChangeFirst(self) -> "StepVisual_PresentationStyleSelect &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_ChangeFirst(self)

    def Last(self) -> "StepVisual_PresentationStyleSelect const &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_Last(self)

    def ChangeLast(self) -> "StepVisual_PresentationStyleSelect &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_PresentationStyleSelect const &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_PresentationStyleSelect &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_PresentationStyleSelect &":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_PresentationStyleSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfPresentationStyleSelect_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfPresentationStyleSelect

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfPresentationStyleSelect in _StepVisual:
_StepVisual.StepVisual_Array1OfPresentationStyleSelect_swigregister(StepVisual_Array1OfPresentationStyleSelect)

class StepVisual_Array1OfRenderingPropertiesSelect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_RenderingPropertiesSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_RenderingPropertiesSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_RenderingPropertiesSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_RenderingPropertiesSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_swiginit(self, _StepVisual.new_StepVisual_Array1OfRenderingPropertiesSelect(*args))

    def Init(self, theValue: "StepVisual_RenderingPropertiesSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfRenderingPropertiesSelect") -> "NCollection_Array1< StepVisual_RenderingPropertiesSelect > &":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfRenderingPropertiesSelect") -> "NCollection_Array1< StepVisual_RenderingPropertiesSelect > &":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_RenderingPropertiesSelect > &":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_Set(self, *args)

    def First(self) -> "StepVisual_RenderingPropertiesSelect const &":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_First(self)

    def ChangeFirst(self) -> "StepVisual_RenderingPropertiesSelect &":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_ChangeFirst(self)

    def Last(self) -> "StepVisual_RenderingPropertiesSelect const &":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_Last(self)

    def ChangeLast(self) -> "StepVisual_RenderingPropertiesSelect &":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_RenderingPropertiesSelect const &":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_RenderingPropertiesSelect &":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_RenderingPropertiesSelect &":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_RenderingPropertiesSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfRenderingPropertiesSelect

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfRenderingPropertiesSelect in _StepVisual:
_StepVisual.StepVisual_Array1OfRenderingPropertiesSelect_swigregister(StepVisual_Array1OfRenderingPropertiesSelect)

class StepVisual_Array1OfStyleContextSelect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_StyleContextSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_StyleContextSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_StyleContextSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_StyleContextSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfStyleContextSelect_swiginit(self, _StepVisual.new_StepVisual_Array1OfStyleContextSelect(*args))

    def Init(self, theValue: "StepVisual_StyleContextSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfStyleContextSelect") -> "NCollection_Array1< StepVisual_StyleContextSelect > &":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfStyleContextSelect") -> "NCollection_Array1< StepVisual_StyleContextSelect > &":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_StyleContextSelect > &":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_Set(self, *args)

    def First(self) -> "StepVisual_StyleContextSelect const &":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_First(self)

    def ChangeFirst(self) -> "StepVisual_StyleContextSelect &":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_ChangeFirst(self)

    def Last(self) -> "StepVisual_StyleContextSelect const &":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_Last(self)

    def ChangeLast(self) -> "StepVisual_StyleContextSelect &":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_StyleContextSelect const &":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_StyleContextSelect &":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_StyleContextSelect &":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_StyleContextSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfStyleContextSelect_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfStyleContextSelect

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfStyleContextSelect in _StepVisual:
_StepVisual.StepVisual_Array1OfStyleContextSelect_swigregister(StepVisual_Array1OfStyleContextSelect)

class StepVisual_Array1OfSurfaceStyleElementSelect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_SurfaceStyleElementSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_SurfaceStyleElementSelect >::iterator":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_SurfaceStyleElementSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_SurfaceStyleElementSelect >::const_iterator":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_swiginit(self, _StepVisual.new_StepVisual_Array1OfSurfaceStyleElementSelect(*args))

    def Init(self, theValue: "StepVisual_SurfaceStyleElementSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfSurfaceStyleElementSelect") -> "NCollection_Array1< StepVisual_SurfaceStyleElementSelect > &":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfSurfaceStyleElementSelect") -> "NCollection_Array1< StepVisual_SurfaceStyleElementSelect > &":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_SurfaceStyleElementSelect > &":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_Set(self, *args)

    def First(self) -> "StepVisual_SurfaceStyleElementSelect const &":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_First(self)

    def ChangeFirst(self) -> "StepVisual_SurfaceStyleElementSelect &":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_ChangeFirst(self)

    def Last(self) -> "StepVisual_SurfaceStyleElementSelect const &":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_Last(self)

    def ChangeLast(self) -> "StepVisual_SurfaceStyleElementSelect &":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_SurfaceStyleElementSelect const &":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_SurfaceStyleElementSelect &":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_SurfaceStyleElementSelect &":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_SurfaceStyleElementSelect") -> "void":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfSurfaceStyleElementSelect

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfSurfaceStyleElementSelect in _StepVisual:
_StepVisual.StepVisual_Array1OfSurfaceStyleElementSelect_swigregister(StepVisual_Array1OfSurfaceStyleElementSelect)

class StepVisual_Array1OfTessellatedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepVisual_TessellatedItem > >::iterator":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepVisual_TessellatedItem > >::iterator":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepVisual_TessellatedItem > >::const_iterator":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepVisual_TessellatedItem > >::const_iterator":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfTessellatedItem_swiginit(self, _StepVisual.new_StepVisual_Array1OfTessellatedItem(*args))

    def Init(self, theValue: "opencascade::handle< StepVisual_TessellatedItem > const &") -> "void":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfTessellatedItem") -> "NCollection_Array1< opencascade::handle< StepVisual_TessellatedItem > > &":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfTessellatedItem") -> "NCollection_Array1< opencascade::handle< StepVisual_TessellatedItem > > &":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepVisual_TessellatedItem > > &":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_Set(self, *args)

    def First(self) -> "opencascade::handle< StepVisual_TessellatedItem > const &":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepVisual_TessellatedItem > &":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepVisual_TessellatedItem > const &":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepVisual_TessellatedItem > &":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepVisual_TessellatedItem > const &":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepVisual_TessellatedItem > &":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepVisual_TessellatedItem > &":
        return _StepVisual.StepVisual_Array1OfTessellatedItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepVisual_TessellatedItem > const &") -> "void":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfTessellatedItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfTessellatedItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfTessellatedItem in _StepVisual:
_StepVisual.StepVisual_Array1OfTessellatedItem_swigregister(StepVisual_Array1OfTessellatedItem)

class StepVisual_Array1OfTextOrCharacter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepVisual_TextOrCharacter >::iterator":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_begin(self)

    def end(self) -> "NCollection_Array1< StepVisual_TextOrCharacter >::iterator":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_end(self)

    def cbegin(self) -> "NCollection_Array1< StepVisual_TextOrCharacter >::const_iterator":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepVisual_TextOrCharacter >::const_iterator":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_Array1OfTextOrCharacter_swiginit(self, _StepVisual.new_StepVisual_Array1OfTextOrCharacter(*args))

    def Init(self, theValue: "StepVisual_TextOrCharacter") -> "void":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_IsAllocated(self)

    def Assign(self, theOther: "StepVisual_Array1OfTextOrCharacter") -> "NCollection_Array1< StepVisual_TextOrCharacter > &":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_Assign(self, theOther)

    def Move(self, theOther: "StepVisual_Array1OfTextOrCharacter") -> "NCollection_Array1< StepVisual_TextOrCharacter > &":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepVisual_TextOrCharacter > &":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_Set(self, *args)

    def First(self) -> "StepVisual_TextOrCharacter const &":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_First(self)

    def ChangeFirst(self) -> "StepVisual_TextOrCharacter &":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_ChangeFirst(self)

    def Last(self) -> "StepVisual_TextOrCharacter const &":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_Last(self)

    def ChangeLast(self) -> "StepVisual_TextOrCharacter &":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepVisual_TextOrCharacter const &":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepVisual_TextOrCharacter &":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepVisual_TextOrCharacter &":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepVisual_TextOrCharacter") -> "void":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepVisual.StepVisual_Array1OfTextOrCharacter_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepVisual.delete_StepVisual_Array1OfTextOrCharacter

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepVisual_Array1OfTextOrCharacter in _StepVisual:
_StepVisual.StepVisual_Array1OfTextOrCharacter_swigregister(StepVisual_Array1OfTextOrCharacter)

class StepVisual_VectorOfHSequenceOfInteger(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Vector< opencascade::handle< TColStd_HSequenceOfInteger > >::iterator":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_begin(self)

    def end(self) -> "NCollection_Vector< opencascade::handle< TColStd_HSequenceOfInteger > >::iterator":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_end(self)

    def cbegin(self) -> "NCollection_Vector< opencascade::handle< TColStd_HSequenceOfInteger > >::const_iterator":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_cbegin(self)

    def cend(self) -> "NCollection_Vector< opencascade::handle< TColStd_HSequenceOfInteger > >::const_iterator":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_cend(self)

    def __init__(self, *args):
        _StepVisual.StepVisual_VectorOfHSequenceOfInteger_swiginit(self, _StepVisual.new_StepVisual_VectorOfHSequenceOfInteger(*args))
    __swig_destroy__ = _StepVisual.delete_StepVisual_VectorOfHSequenceOfInteger

    def Length(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_Length(self)

    def Size(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_Size(self)

    def Lower(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_IsEmpty(self)

    def Assign(self, *args) -> "void":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_Assign(self, *args)

    def Set(self, theOther: "StepVisual_VectorOfHSequenceOfInteger") -> "NCollection_Vector< opencascade::handle< TColStd_HSequenceOfInteger > > &":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_Set(self, theOther)

    def Append(self, theValue: "opencascade::handle< TColStd_HSequenceOfInteger > const &") -> "opencascade::handle< TColStd_HSequenceOfInteger > &":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_Append(self, theValue)

    def Appended(self) -> "opencascade::handle< TColStd_HSequenceOfInteger > &":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_Appended(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< TColStd_HSequenceOfInteger > const &":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_Value(self, theIndex)

    def First(self) -> "opencascade::handle< TColStd_HSequenceOfInteger > const &":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_First(self)

    def ChangeFirst(self) -> "opencascade::handle< TColStd_HSequenceOfInteger > &":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< TColStd_HSequenceOfInteger > const &":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_Last(self)

    def ChangeLast(self) -> "opencascade::handle< TColStd_HSequenceOfInteger > &":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_ChangeLast(self)

    def __call__(self, *args) -> "opencascade::handle< TColStd_HSequenceOfInteger > &":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger___call__(self, *args)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< TColStd_HSequenceOfInteger > &":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_ChangeValue(self, theIndex)

    def SetValue(self, theIndex: "Standard_Integer const", theValue: "opencascade::handle< TColStd_HSequenceOfInteger > const &") -> "opencascade::handle< TColStd_HSequenceOfInteger > &":
        return _StepVisual.StepVisual_VectorOfHSequenceOfInteger_SetValue(self, theIndex, theValue)

# Register StepVisual_VectorOfHSequenceOfInteger in _StepVisual:
_StepVisual.StepVisual_VectorOfHSequenceOfInteger_swigregister(StepVisual_VectorOfHSequenceOfInteger)

class StepVisual_AnnotationFillArea(OCC.Core.StepShape.StepShape_GeometricCurveSet):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a annotationfillarea.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_AnnotationFillArea_swiginit(self, _StepVisual.new_StepVisual_AnnotationFillArea(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_AnnotationFillArea_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_AnnotationFillArea

# Register StepVisual_AnnotationFillArea in _StepVisual:
_StepVisual.StepVisual_AnnotationFillArea_swigregister(StepVisual_AnnotationFillArea)

class StepVisual_AnnotationPlaneElement(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a annotationplaneelement select type.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_AnnotationPlaneElement_swiginit(self, _StepVisual.new_StepVisual_AnnotationPlaneElement(*args))

    def DraughtingCallout(self, *args) -> "opencascade::handle< StepVisual_DraughtingCallout >":
        r"""
        Returns value as a draughtingcallout (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_DraughtingCallout>

        """
        return _StepVisual.StepVisual_AnnotationPlaneElement_DraughtingCallout(self, *args)

    def StyledItem(self, *args) -> "opencascade::handle< StepVisual_StyledItem >":
        r"""
        Returns value as a styleditem (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_StyledItem>

        """
        return _StepVisual.StepVisual_AnnotationPlaneElement_StyledItem(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_AnnotationPlaneElement

# Register StepVisual_AnnotationPlaneElement in _StepVisual:
_StepVisual.StepVisual_AnnotationPlaneElement_swigregister(StepVisual_AnnotationPlaneElement)

class StepVisual_AnnotationText(OCC.Core.StepRepr.StepRepr_MappedItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a annotationtext.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_AnnotationText_swiginit(self, _StepVisual.new_StepVisual_AnnotationText(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_AnnotationText_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_AnnotationText

# Register StepVisual_AnnotationText in _StepVisual:
_StepVisual.StepVisual_AnnotationText_swigregister(StepVisual_AnnotationText)

class StepVisual_AreaInSet(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a areainset.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_AreaInSet_swiginit(self, _StepVisual.new_StepVisual_AreaInSet(*args))

    def Area(self, *args) -> "opencascade::handle< StepVisual_PresentationArea >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_PresentationArea>

        """
        return _StepVisual.StepVisual_AreaInSet_Area(self, *args)

    def InSet(self, *args) -> "opencascade::handle< StepVisual_PresentationSet >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_PresentationSet>

        """
        return _StepVisual.StepVisual_AreaInSet_InSet(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aArea: StepVisual_PresentationArea
        aInSet: StepVisual_PresentationSet

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_AreaInSet_Init(self, *args)

    def SetArea(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aArea: StepVisual_PresentationArea

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_AreaInSet_SetArea(self, *args)

    def SetInSet(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aInSet: StepVisual_PresentationSet

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_AreaInSet_SetInSet(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_AreaInSet_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_AreaInSet

# Register StepVisual_AreaInSet in _StepVisual:
_StepVisual.StepVisual_AreaInSet_swigregister(StepVisual_AreaInSet)

class StepVisual_AreaOrView(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a areaorview selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_AreaOrView_swiginit(self, _StepVisual.new_StepVisual_AreaOrView(*args))

    def PresentationArea(self, *args) -> "opencascade::handle< StepVisual_PresentationArea >":
        r"""
        Returns value as a presentationarea (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PresentationArea>

        """
        return _StepVisual.StepVisual_AreaOrView_PresentationArea(self, *args)

    def PresentationView(self, *args) -> "opencascade::handle< StepVisual_PresentationView >":
        r"""
        Returns value as a presentationview (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PresentationView>

        """
        return _StepVisual.StepVisual_AreaOrView_PresentationView(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_AreaOrView

# Register StepVisual_AreaOrView in _StepVisual:
_StepVisual.StepVisual_AreaOrView_swigregister(StepVisual_AreaOrView)

class StepVisual_BoxCharacteristicSelect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_BoxCharacteristicSelect_swiginit(self, _StepVisual.new_StepVisual_BoxCharacteristicSelect(*args))

    def RealValue(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepVisual.StepVisual_BoxCharacteristicSelect_RealValue(self, *args)

    def SetRealValue(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aValue: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_BoxCharacteristicSelect_SetRealValue(self, *args)

    def SetTypeOfContent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aType: int

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_BoxCharacteristicSelect_SetTypeOfContent(self, *args)

    def TypeOfContent(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_BoxCharacteristicSelect_TypeOfContent(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_BoxCharacteristicSelect

# Register StepVisual_BoxCharacteristicSelect in _StepVisual:
_StepVisual.StepVisual_BoxCharacteristicSelect_swigregister(StepVisual_BoxCharacteristicSelect)

class StepVisual_CameraImage(OCC.Core.StepRepr.StepRepr_MappedItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a cameraimage.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CameraImage_swiginit(self, _StepVisual.new_StepVisual_CameraImage(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CameraImage_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CameraImage

# Register StepVisual_CameraImage in _StepVisual:
_StepVisual.StepVisual_CameraImage_swigregister(StepVisual_CameraImage)

class StepVisual_CameraModel(OCC.Core.StepGeom.StepGeom_GeometricRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a cameramodel.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CameraModel_swiginit(self, _StepVisual.new_StepVisual_CameraModel(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CameraModel_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CameraModel

# Register StepVisual_CameraModel in _StepVisual:
_StepVisual.StepVisual_CameraModel_swigregister(StepVisual_CameraModel)

class StepVisual_CameraModelD3MultiClippingInterectionSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a cameramodeld3multiclippinginterectionselect select type.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CameraModelD3MultiClippingInterectionSelect_swiginit(self, _StepVisual.new_StepVisual_CameraModelD3MultiClippingInterectionSelect(*args))

    def CameraModelD3MultiClippingUnion(self, *args) -> "opencascade::handle< StepVisual_CameraModelD3MultiClippingUnion >":
        r"""
        Returns value as a cameramodeld3multiclippingunion (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_CameraModelD3MultiClippingUnion>

        """
        return _StepVisual.StepVisual_CameraModelD3MultiClippingInterectionSelect_CameraModelD3MultiClippingUnion(self, *args)

    def Plane(self, *args) -> "opencascade::handle< StepGeom_Plane >":
        r"""
        Returns value as a plane (null if another type).

        Returns
        -------
        opencascade::handle<StepGeom_Plane>

        """
        return _StepVisual.StepVisual_CameraModelD3MultiClippingInterectionSelect_Plane(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CameraModelD3MultiClippingInterectionSelect

# Register StepVisual_CameraModelD3MultiClippingInterectionSelect in _StepVisual:
_StepVisual.StepVisual_CameraModelD3MultiClippingInterectionSelect_swigregister(StepVisual_CameraModelD3MultiClippingInterectionSelect)

class StepVisual_CameraModelD3MultiClippingIntersection(OCC.Core.StepGeom.StepGeom_GeometricRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a stepvisual_cameramodeld3multiclippingintersection.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CameraModelD3MultiClippingIntersection_swiginit(self, _StepVisual.new_StepVisual_CameraModelD3MultiClippingIntersection(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theName: TCollection_HAsciiString
        theShapeClipping: StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CameraModelD3MultiClippingIntersection_Init(self, *args)

    def SetShapeClipping(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theShapeClipping: StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CameraModelD3MultiClippingIntersection_SetShapeClipping(self, *args)

    def ShapeClipping(self, *args) -> "opencascade::handle< StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect > const":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect>

        """
        return _StepVisual.StepVisual_CameraModelD3MultiClippingIntersection_ShapeClipping(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CameraModelD3MultiClippingIntersection_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CameraModelD3MultiClippingIntersection

# Register StepVisual_CameraModelD3MultiClippingIntersection in _StepVisual:
_StepVisual.StepVisual_CameraModelD3MultiClippingIntersection_swigregister(StepVisual_CameraModelD3MultiClippingIntersection)

class StepVisual_CameraModelD3MultiClippingUnion(OCC.Core.StepGeom.StepGeom_GeometricRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a stepvisual_cameramodeld3multiclippingunion.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CameraModelD3MultiClippingUnion_swiginit(self, _StepVisual.new_StepVisual_CameraModelD3MultiClippingUnion(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theName: TCollection_HAsciiString
        theShapeClipping: StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CameraModelD3MultiClippingUnion_Init(self, *args)

    def SetShapeClipping(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theShapeClipping: StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CameraModelD3MultiClippingUnion_SetShapeClipping(self, *args)

    def ShapeClipping(self, *args) -> "opencascade::handle< StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect > const":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect>

        """
        return _StepVisual.StepVisual_CameraModelD3MultiClippingUnion_ShapeClipping(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CameraModelD3MultiClippingUnion_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CameraModelD3MultiClippingUnion

# Register StepVisual_CameraModelD3MultiClippingUnion in _StepVisual:
_StepVisual.StepVisual_CameraModelD3MultiClippingUnion_swigregister(StepVisual_CameraModelD3MultiClippingUnion)

class StepVisual_CameraModelD3MultiClippingUnionSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a cameramodeld3multiclippingunionselect select type.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CameraModelD3MultiClippingUnionSelect_swiginit(self, _StepVisual.new_StepVisual_CameraModelD3MultiClippingUnionSelect(*args))

    def CameraModelD3MultiClippingIntersection(self, *args) -> "opencascade::handle< StepVisual_CameraModelD3MultiClippingIntersection >":
        r"""
        Returns value as a cameramodeld3multiclippingintersection (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_CameraModelD3MultiClippingIntersection>

        """
        return _StepVisual.StepVisual_CameraModelD3MultiClippingUnionSelect_CameraModelD3MultiClippingIntersection(self, *args)

    def Plane(self, *args) -> "opencascade::handle< StepGeom_Plane >":
        r"""
        Returns value as a plane (null if another type).

        Returns
        -------
        opencascade::handle<StepGeom_Plane>

        """
        return _StepVisual.StepVisual_CameraModelD3MultiClippingUnionSelect_Plane(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CameraModelD3MultiClippingUnionSelect

# Register StepVisual_CameraModelD3MultiClippingUnionSelect in _StepVisual:
_StepVisual.StepVisual_CameraModelD3MultiClippingUnionSelect_swigregister(StepVisual_CameraModelD3MultiClippingUnionSelect)

class StepVisual_CameraUsage(OCC.Core.StepRepr.StepRepr_RepresentationMap):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a camerausage.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CameraUsage_swiginit(self, _StepVisual.new_StepVisual_CameraUsage(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CameraUsage_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CameraUsage

# Register StepVisual_CameraUsage in _StepVisual:
_StepVisual.StepVisual_CameraUsage_swigregister(StepVisual_CameraUsage)

class StepVisual_Colour(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a colour.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_Colour_swiginit(self, _StepVisual.new_StepVisual_Colour(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_Colour_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_Colour

# Register StepVisual_Colour in _StepVisual:
_StepVisual.StepVisual_Colour_swigregister(StepVisual_Colour)

class StepVisual_CompositeText(OCC.Core.StepGeom.StepGeom_GeometricRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a compositetext.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CompositeText_swiginit(self, _StepVisual.new_StepVisual_CompositeText(*args))

    def CollectedText(self, *args) -> "opencascade::handle< StepVisual_HArray1OfTextOrCharacter >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfTextOrCharacter>

        """
        return _StepVisual.StepVisual_CompositeText_CollectedText(self, *args)

    def CollectedTextValue(self, *args) -> "StepVisual_TextOrCharacter":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepVisual_TextOrCharacter

        """
        return _StepVisual.StepVisual_CompositeText_CollectedTextValue(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aCollectedText: StepVisual_HArray1OfTextOrCharacter

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CompositeText_Init(self, *args)

    def NbCollectedText(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_CompositeText_NbCollectedText(self, *args)

    def SetCollectedText(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aCollectedText: StepVisual_HArray1OfTextOrCharacter

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CompositeText_SetCollectedText(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CompositeText_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CompositeText

# Register StepVisual_CompositeText in _StepVisual:
_StepVisual.StepVisual_CompositeText_swigregister(StepVisual_CompositeText)

class StepVisual_CurveStyle(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a curvestyle.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CurveStyle_swiginit(self, _StepVisual.new_StepVisual_CurveStyle(*args))

    def CurveColour(self, *args) -> "opencascade::handle< StepVisual_Colour >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_Colour>

        """
        return _StepVisual.StepVisual_CurveStyle_CurveColour(self, *args)

    def CurveFont(self, *args) -> "StepVisual_CurveStyleFontSelect":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_CurveStyleFontSelect

        """
        return _StepVisual.StepVisual_CurveStyle_CurveFont(self, *args)

    def CurveWidth(self, *args) -> "StepBasic_SizeSelect":
        r"""
        No available documentation.

        Returns
        -------
        StepBasic_SizeSelect

        """
        return _StepVisual.StepVisual_CurveStyle_CurveWidth(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aCurveFont: StepVisual_CurveStyleFontSelect
        aCurveWidth: StepBasic_SizeSelect
        aCurveColour: StepVisual_Colour

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CurveStyle_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepVisual.StepVisual_CurveStyle_Name(self, *args)

    def SetCurveColour(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aCurveColour: StepVisual_Colour

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CurveStyle_SetCurveColour(self, *args)

    def SetCurveFont(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aCurveFont: StepVisual_CurveStyleFontSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CurveStyle_SetCurveFont(self, *args)

    def SetCurveWidth(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aCurveWidth: StepBasic_SizeSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CurveStyle_SetCurveWidth(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CurveStyle_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CurveStyle_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CurveStyle

# Register StepVisual_CurveStyle in _StepVisual:
_StepVisual.StepVisual_CurveStyle_swigregister(StepVisual_CurveStyle)

class StepVisual_CurveStyleFont(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a curvestylefont.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CurveStyleFont_swiginit(self, _StepVisual.new_StepVisual_CurveStyleFont(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aPatternList: StepVisual_HArray1OfCurveStyleFontPattern

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CurveStyleFont_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepVisual.StepVisual_CurveStyleFont_Name(self, *args)

    def NbPatternList(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_CurveStyleFont_NbPatternList(self, *args)

    def PatternList(self, *args) -> "opencascade::handle< StepVisual_HArray1OfCurveStyleFontPattern >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfCurveStyleFontPattern>

        """
        return _StepVisual.StepVisual_CurveStyleFont_PatternList(self, *args)

    def PatternListValue(self, *args) -> "opencascade::handle< StepVisual_CurveStyleFontPattern >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<StepVisual_CurveStyleFontPattern>

        """
        return _StepVisual.StepVisual_CurveStyleFont_PatternListValue(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CurveStyleFont_SetName(self, *args)

    def SetPatternList(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPatternList: StepVisual_HArray1OfCurveStyleFontPattern

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CurveStyleFont_SetPatternList(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CurveStyleFont_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CurveStyleFont

# Register StepVisual_CurveStyleFont in _StepVisual:
_StepVisual.StepVisual_CurveStyleFont_swigregister(StepVisual_CurveStyleFont)

class StepVisual_CurveStyleFontPattern(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a curvestylefontpattern.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CurveStyleFontPattern_swiginit(self, _StepVisual.new_StepVisual_CurveStyleFontPattern(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aVisibleSegmentLength: float
        aInvisibleSegmentLength: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CurveStyleFontPattern_Init(self, *args)

    def InvisibleSegmentLength(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepVisual.StepVisual_CurveStyleFontPattern_InvisibleSegmentLength(self, *args)

    def SetInvisibleSegmentLength(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aInvisibleSegmentLength: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CurveStyleFontPattern_SetInvisibleSegmentLength(self, *args)

    def SetVisibleSegmentLength(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aVisibleSegmentLength: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CurveStyleFontPattern_SetVisibleSegmentLength(self, *args)

    def VisibleSegmentLength(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepVisual.StepVisual_CurveStyleFontPattern_VisibleSegmentLength(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CurveStyleFontPattern_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CurveStyleFontPattern

# Register StepVisual_CurveStyleFontPattern in _StepVisual:
_StepVisual.StepVisual_CurveStyleFontPattern_swigregister(StepVisual_CurveStyleFontPattern)

class StepVisual_CurveStyleFontSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a curvestylefontselect selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CurveStyleFontSelect_swiginit(self, _StepVisual.new_StepVisual_CurveStyleFontSelect(*args))

    def CurveStyleFont(self, *args) -> "opencascade::handle< StepVisual_CurveStyleFont >":
        r"""
        Returns value as a curvestylefont (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_CurveStyleFont>

        """
        return _StepVisual.StepVisual_CurveStyleFontSelect_CurveStyleFont(self, *args)

    def ExternallyDefinedCurveFont(self, *args) -> "opencascade::handle< StepVisual_ExternallyDefinedCurveFont >":
        r"""
        Returns value as a externallydefinedcurvefont (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_ExternallyDefinedCurveFont>

        """
        return _StepVisual.StepVisual_CurveStyleFontSelect_ExternallyDefinedCurveFont(self, *args)

    def PreDefinedCurveFont(self, *args) -> "opencascade::handle< StepVisual_PreDefinedCurveFont >":
        r"""
        Returns value as a predefinedcurvefont (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PreDefinedCurveFont>

        """
        return _StepVisual.StepVisual_CurveStyleFontSelect_PreDefinedCurveFont(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CurveStyleFontSelect

# Register StepVisual_CurveStyleFontSelect in _StepVisual:
_StepVisual.StepVisual_CurveStyleFontSelect_swigregister(StepVisual_CurveStyleFontSelect)

class StepVisual_DirectionCountSelect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_DirectionCountSelect_swiginit(self, _StepVisual.new_StepVisual_DirectionCountSelect(*args))

    def SetTypeOfContent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aTypeOfContent: int

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_DirectionCountSelect_SetTypeOfContent(self, *args)

    def SetUDirectionCount(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aUDirectionCount: int

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_DirectionCountSelect_SetUDirectionCount(self, *args)

    def SetVDirectionCount(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aUDirectionCount: int

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_DirectionCountSelect_SetVDirectionCount(self, *args)

    def TypeOfContent(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_DirectionCountSelect_TypeOfContent(self, *args)

    def UDirectionCount(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_DirectionCountSelect_UDirectionCount(self, *args)

    def VDirectionCount(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_DirectionCountSelect_VDirectionCount(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_DirectionCountSelect

# Register StepVisual_DirectionCountSelect in _StepVisual:
_StepVisual.StepVisual_DirectionCountSelect_swigregister(StepVisual_DirectionCountSelect)

class StepVisual_DraughtingCallout(OCC.Core.StepGeom.StepGeom_GeometricRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a draughtingcallout.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_DraughtingCallout_swiginit(self, _StepVisual.new_StepVisual_DraughtingCallout(*args))

    def Contents(self, *args) -> "opencascade::handle< StepVisual_HArray1OfDraughtingCalloutElement >":
        r"""
        Returns field contents.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfDraughtingCalloutElement>

        """
        return _StepVisual.StepVisual_DraughtingCallout_Contents(self, *args)

    def ContentsValue(self, *args) -> "StepVisual_DraughtingCalloutElement":
        r"""
        Returns contents with the given number.

        Parameters
        ----------
        theNum: int

        Returns
        -------
        StepVisual_DraughtingCalloutElement

        """
        return _StepVisual.StepVisual_DraughtingCallout_ContentsValue(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Init.

        Parameters
        ----------
        theName: TCollection_HAsciiString
        theContents: StepVisual_HArray1OfDraughtingCalloutElement

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_DraughtingCallout_Init(self, *args)

    def NbContents(self, *args) -> "Standard_Integer":
        r"""
        Returns number of contents.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_DraughtingCallout_NbContents(self, *args)

    def SetContents(self, *args) -> "void":
        r"""
        Set field contents.

        Parameters
        ----------
        theContents: StepVisual_HArray1OfDraughtingCalloutElement

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_DraughtingCallout_SetContents(self, *args)

    def SetContentsValue(self, *args) -> "void":
        r"""
        Sets contents with given number.

        Parameters
        ----------
        theNum: int
        theItem: StepVisual_DraughtingCalloutElement

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_DraughtingCallout_SetContentsValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_DraughtingCallout_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_DraughtingCallout

# Register StepVisual_DraughtingCallout in _StepVisual:
_StepVisual.StepVisual_DraughtingCallout_swigregister(StepVisual_DraughtingCallout)

class StepVisual_DraughtingCalloutElement(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a draughtingcalloutelement select type.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_DraughtingCalloutElement_swiginit(self, _StepVisual.new_StepVisual_DraughtingCalloutElement(*args))

    def AnnotationCurveOccurrence(self, *args) -> "opencascade::handle< StepVisual_AnnotationCurveOccurrence >":
        r"""
        Returns value as a annotationcurveoccurrence (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_AnnotationCurveOccurrence>

        """
        return _StepVisual.StepVisual_DraughtingCalloutElement_AnnotationCurveOccurrence(self, *args)

    def AnnotationFillAreaOccurrence(self, *args) -> "opencascade::handle< StepVisual_AnnotationFillAreaOccurrence >":
        r"""
        Returns value as a annotationfillareaoccurrence.

        Returns
        -------
        opencascade::handle<StepVisual_AnnotationFillAreaOccurrence>

        """
        return _StepVisual.StepVisual_DraughtingCalloutElement_AnnotationFillAreaOccurrence(self, *args)

    def AnnotationTextOccurrence(self, *args) -> "opencascade::handle< StepVisual_AnnotationTextOccurrence >":
        r"""
        Returns value as a annotationtextoccurrence.

        Returns
        -------
        opencascade::handle<StepVisual_AnnotationTextOccurrence>

        """
        return _StepVisual.StepVisual_DraughtingCalloutElement_AnnotationTextOccurrence(self, *args)

    def TessellatedAnnotationOccurrence(self, *args) -> "opencascade::handle< StepVisual_TessellatedAnnotationOccurrence >":
        r"""
        Returns value as a tessellatedannotationoccurrence.

        Returns
        -------
        opencascade::handle<StepVisual_TessellatedAnnotationOccurrence>

        """
        return _StepVisual.StepVisual_DraughtingCalloutElement_TessellatedAnnotationOccurrence(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_DraughtingCalloutElement

# Register StepVisual_DraughtingCalloutElement in _StepVisual:
_StepVisual.StepVisual_DraughtingCalloutElement_swigregister(StepVisual_DraughtingCalloutElement)

class StepVisual_DraughtingModel(OCC.Core.StepRepr.StepRepr_Representation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_DraughtingModel_swiginit(self, _StepVisual.new_StepVisual_DraughtingModel(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_DraughtingModel_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_DraughtingModel

# Register StepVisual_DraughtingModel in _StepVisual:
_StepVisual.StepVisual_DraughtingModel_swigregister(StepVisual_DraughtingModel)

class StepVisual_ExternallyDefinedCurveFont(OCC.Core.StepBasic.StepBasic_ExternallyDefinedItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_ExternallyDefinedCurveFont_swiginit(self, _StepVisual.new_StepVisual_ExternallyDefinedCurveFont(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_ExternallyDefinedCurveFont_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_ExternallyDefinedCurveFont

# Register StepVisual_ExternallyDefinedCurveFont in _StepVisual:
_StepVisual.StepVisual_ExternallyDefinedCurveFont_swigregister(StepVisual_ExternallyDefinedCurveFont)

class StepVisual_ExternallyDefinedTextFont(OCC.Core.StepBasic.StepBasic_ExternallyDefinedItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_ExternallyDefinedTextFont_swiginit(self, _StepVisual.new_StepVisual_ExternallyDefinedTextFont(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_ExternallyDefinedTextFont_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_ExternallyDefinedTextFont

# Register StepVisual_ExternallyDefinedTextFont in _StepVisual:
_StepVisual.StepVisual_ExternallyDefinedTextFont_swigregister(StepVisual_ExternallyDefinedTextFont)

class StepVisual_FillAreaStyle(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a fillareastyle.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_FillAreaStyle_swiginit(self, _StepVisual.new_StepVisual_FillAreaStyle(*args))

    def FillStyles(self, *args) -> "opencascade::handle< StepVisual_HArray1OfFillStyleSelect >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfFillStyleSelect>

        """
        return _StepVisual.StepVisual_FillAreaStyle_FillStyles(self, *args)

    def FillStylesValue(self, *args) -> "StepVisual_FillStyleSelect":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepVisual_FillStyleSelect

        """
        return _StepVisual.StepVisual_FillAreaStyle_FillStylesValue(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aFillStyles: StepVisual_HArray1OfFillStyleSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_FillAreaStyle_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepVisual.StepVisual_FillAreaStyle_Name(self, *args)

    def NbFillStyles(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_FillAreaStyle_NbFillStyles(self, *args)

    def SetFillStyles(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFillStyles: StepVisual_HArray1OfFillStyleSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_FillAreaStyle_SetFillStyles(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_FillAreaStyle_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_FillAreaStyle_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_FillAreaStyle

# Register StepVisual_FillAreaStyle in _StepVisual:
_StepVisual.StepVisual_FillAreaStyle_swigregister(StepVisual_FillAreaStyle)

class StepVisual_FillAreaStyleColour(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a fillareastylecolour.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_FillAreaStyleColour_swiginit(self, _StepVisual.new_StepVisual_FillAreaStyleColour(*args))

    def FillColour(self, *args) -> "opencascade::handle< StepVisual_Colour >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_Colour>

        """
        return _StepVisual.StepVisual_FillAreaStyleColour_FillColour(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aFillColour: StepVisual_Colour

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_FillAreaStyleColour_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepVisual.StepVisual_FillAreaStyleColour_Name(self, *args)

    def SetFillColour(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFillColour: StepVisual_Colour

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_FillAreaStyleColour_SetFillColour(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_FillAreaStyleColour_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_FillAreaStyleColour_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_FillAreaStyleColour

# Register StepVisual_FillAreaStyleColour in _StepVisual:
_StepVisual.StepVisual_FillAreaStyleColour_swigregister(StepVisual_FillAreaStyleColour)

class StepVisual_FillStyleSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a fillstyleselect selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_FillStyleSelect_swiginit(self, _StepVisual.new_StepVisual_FillStyleSelect(*args))

    def FillAreaStyleColour(self, *args) -> "opencascade::handle< StepVisual_FillAreaStyleColour >":
        r"""
        Returns value as a fillareastylecolour (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_FillAreaStyleColour>

        """
        return _StepVisual.StepVisual_FillStyleSelect_FillAreaStyleColour(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_FillStyleSelect

# Register StepVisual_FillStyleSelect in _StepVisual:
_StepVisual.StepVisual_FillStyleSelect_swigregister(StepVisual_FillStyleSelect)

class StepVisual_FontSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a fontselect selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_FontSelect_swiginit(self, _StepVisual.new_StepVisual_FontSelect(*args))

    def ExternallyDefinedTextFont(self, *args) -> "opencascade::handle< StepVisual_ExternallyDefinedTextFont >":
        r"""
        Returns value as a externallydefinedtextfont (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_ExternallyDefinedTextFont>

        """
        return _StepVisual.StepVisual_FontSelect_ExternallyDefinedTextFont(self, *args)

    def PreDefinedTextFont(self, *args) -> "opencascade::handle< StepVisual_PreDefinedTextFont >":
        r"""
        Returns value as a predefinedtextfont (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PreDefinedTextFont>

        """
        return _StepVisual.StepVisual_FontSelect_PreDefinedTextFont(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_FontSelect

# Register StepVisual_FontSelect in _StepVisual:
_StepVisual.StepVisual_FontSelect_swigregister(StepVisual_FontSelect)

class StepVisual_Invisibility(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a invisibility.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_Invisibility_swiginit(self, _StepVisual.new_StepVisual_Invisibility(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aInvisibleItems: StepVisual_HArray1OfInvisibleItem

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_Invisibility_Init(self, *args)

    def InvisibleItems(self, *args) -> "opencascade::handle< StepVisual_HArray1OfInvisibleItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfInvisibleItem>

        """
        return _StepVisual.StepVisual_Invisibility_InvisibleItems(self, *args)

    def InvisibleItemsValue(self, *args) -> "StepVisual_InvisibleItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepVisual_InvisibleItem

        """
        return _StepVisual.StepVisual_Invisibility_InvisibleItemsValue(self, *args)

    def NbInvisibleItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_Invisibility_NbInvisibleItems(self, *args)

    def SetInvisibleItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aInvisibleItems: StepVisual_HArray1OfInvisibleItem

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_Invisibility_SetInvisibleItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_Invisibility_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_Invisibility

# Register StepVisual_Invisibility in _StepVisual:
_StepVisual.StepVisual_Invisibility_swigregister(StepVisual_Invisibility)

class StepVisual_InvisibilityContext(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a invisibilitycontext selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_InvisibilityContext_swiginit(self, _StepVisual.new_StepVisual_InvisibilityContext(*args))

    def DraughtingModel(self, *args) -> "opencascade::handle< StepVisual_DraughtingModel >":
        r"""
        Returns value as a presentationset (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_DraughtingModel>

        """
        return _StepVisual.StepVisual_InvisibilityContext_DraughtingModel(self, *args)

    def PresentationRepresentation(self, *args) -> "opencascade::handle< StepVisual_PresentationRepresentation >":
        r"""
        Returns value as a presentationrepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PresentationRepresentation>

        """
        return _StepVisual.StepVisual_InvisibilityContext_PresentationRepresentation(self, *args)

    def PresentationSet(self, *args) -> "opencascade::handle< StepVisual_PresentationSet >":
        r"""
        Returns value as a presentationset (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PresentationSet>

        """
        return _StepVisual.StepVisual_InvisibilityContext_PresentationSet(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_InvisibilityContext

# Register StepVisual_InvisibilityContext in _StepVisual:
_StepVisual.StepVisual_InvisibilityContext_swigregister(StepVisual_InvisibilityContext)

class StepVisual_InvisibleItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a invisibleitem selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_InvisibleItem_swiginit(self, _StepVisual.new_StepVisual_InvisibleItem(*args))

    def PresentationLayerAssignment(self, *args) -> "opencascade::handle< StepVisual_PresentationLayerAssignment >":
        r"""
        Returns value as a presentationlayerassignment (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PresentationLayerAssignment>

        """
        return _StepVisual.StepVisual_InvisibleItem_PresentationLayerAssignment(self, *args)

    def PresentationRepresentation(self, *args) -> "opencascade::handle< StepVisual_PresentationRepresentation >":
        r"""
        Returns value as a presentationrepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PresentationRepresentation>

        """
        return _StepVisual.StepVisual_InvisibleItem_PresentationRepresentation(self, *args)

    def StyledItem(self, *args) -> "opencascade::handle< StepVisual_StyledItem >":
        r"""
        Returns value as a styleditem (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_StyledItem>

        """
        return _StepVisual.StepVisual_InvisibleItem_StyledItem(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_InvisibleItem

# Register StepVisual_InvisibleItem in _StepVisual:
_StepVisual.StepVisual_InvisibleItem_swigregister(StepVisual_InvisibleItem)

class StepVisual_LayeredItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a layereditem selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_LayeredItem_swiginit(self, _StepVisual.new_StepVisual_LayeredItem(*args))

    def PresentationRepresentation(self, *args) -> "opencascade::handle< StepVisual_PresentationRepresentation >":
        r"""
        Returns value as a presentationrepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PresentationRepresentation>

        """
        return _StepVisual.StepVisual_LayeredItem_PresentationRepresentation(self, *args)

    def RepresentationItem(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem >":
        r"""
        Returns value as a representationitem (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepVisual.StepVisual_LayeredItem_RepresentationItem(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_LayeredItem

# Register StepVisual_LayeredItem in _StepVisual:
_StepVisual.StepVisual_LayeredItem_swigregister(StepVisual_LayeredItem)

class StepVisual_MarkerMember(OCC.Core.StepData.StepData_SelectInt):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_MarkerMember_swiginit(self, _StepVisual.new_StepVisual_MarkerMember(*args))

    def SetValue(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        val: StepVisual_MarkerType

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_MarkerMember_SetValue(self, *args)

    def Value(self, *args) -> "StepVisual_MarkerType":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_MarkerType

        """
        return _StepVisual.StepVisual_MarkerMember_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_MarkerMember_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_MarkerMember

# Register StepVisual_MarkerMember in _StepVisual:
_StepVisual.StepVisual_MarkerMember_swigregister(StepVisual_MarkerMember)

class StepVisual_MarkerSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a markerselect selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_MarkerSelect_swiginit(self, _StepVisual.new_StepVisual_MarkerSelect(*args))

    def MarkerMember(self, *args) -> "opencascade::handle< StepVisual_MarkerMember >":
        r"""
        Gives access to the markermember in order to get/set its value.

        Returns
        -------
        opencascade::handle<StepVisual_MarkerMember>

        """
        return _StepVisual.StepVisual_MarkerSelect_MarkerMember(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_MarkerSelect

# Register StepVisual_MarkerSelect in _StepVisual:
_StepVisual.StepVisual_MarkerSelect_swigregister(StepVisual_MarkerSelect)

class StepVisual_NullStyleMember(OCC.Core.StepData.StepData_SelectInt):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_NullStyleMember_swiginit(self, _StepVisual.new_StepVisual_NullStyleMember(*args))

    def SetName(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        Standard_CString: 

        Returns
        -------
        bool

        """
        return _StepVisual.StepVisual_NullStyleMember_SetName(self, *args)

    def SetValue(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: StepVisual_NullStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_NullStyleMember_SetValue(self, *args)

    def Value(self, *args) -> "StepVisual_NullStyle":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_NullStyle

        """
        return _StepVisual.StepVisual_NullStyleMember_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_NullStyleMember_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_NullStyleMember

# Register StepVisual_NullStyleMember in _StepVisual:
_StepVisual.StepVisual_NullStyleMember_swigregister(StepVisual_NullStyleMember)

class StepVisual_PlanarExtent(OCC.Core.StepGeom.StepGeom_GeometricRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a planarextent.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PlanarExtent_swiginit(self, _StepVisual.new_StepVisual_PlanarExtent(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aSizeInX: float
        aSizeInY: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PlanarExtent_Init(self, *args)

    def SetSizeInX(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSizeInX: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PlanarExtent_SetSizeInX(self, *args)

    def SetSizeInY(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSizeInY: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PlanarExtent_SetSizeInY(self, *args)

    def SizeInX(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepVisual.StepVisual_PlanarExtent_SizeInX(self, *args)

    def SizeInY(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepVisual.StepVisual_PlanarExtent_SizeInY(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PlanarExtent_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PlanarExtent

# Register StepVisual_PlanarExtent in _StepVisual:
_StepVisual.StepVisual_PlanarExtent_swigregister(StepVisual_PlanarExtent)

class StepVisual_PointStyle(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a pointstyle.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PointStyle_swiginit(self, _StepVisual.new_StepVisual_PointStyle(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aMarker: StepVisual_MarkerSelect
        aMarkerSize: StepBasic_SizeSelect
        aMarkerColour: StepVisual_Colour

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PointStyle_Init(self, *args)

    def Marker(self, *args) -> "StepVisual_MarkerSelect":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_MarkerSelect

        """
        return _StepVisual.StepVisual_PointStyle_Marker(self, *args)

    def MarkerColour(self, *args) -> "opencascade::handle< StepVisual_Colour >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_Colour>

        """
        return _StepVisual.StepVisual_PointStyle_MarkerColour(self, *args)

    def MarkerSize(self, *args) -> "StepBasic_SizeSelect":
        r"""
        No available documentation.

        Returns
        -------
        StepBasic_SizeSelect

        """
        return _StepVisual.StepVisual_PointStyle_MarkerSize(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepVisual.StepVisual_PointStyle_Name(self, *args)

    def SetMarker(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMarker: StepVisual_MarkerSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PointStyle_SetMarker(self, *args)

    def SetMarkerColour(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMarkerColour: StepVisual_Colour

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PointStyle_SetMarkerColour(self, *args)

    def SetMarkerSize(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMarkerSize: StepBasic_SizeSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PointStyle_SetMarkerSize(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PointStyle_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PointStyle_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PointStyle

# Register StepVisual_PointStyle in _StepVisual:
_StepVisual.StepVisual_PointStyle_swigregister(StepVisual_PointStyle)

class StepVisual_PreDefinedItem(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a predefineditem.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PreDefinedItem_swiginit(self, _StepVisual.new_StepVisual_PreDefinedItem(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PreDefinedItem_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepVisual.StepVisual_PreDefinedItem_Name(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PreDefinedItem_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PreDefinedItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PreDefinedItem

# Register StepVisual_PreDefinedItem in _StepVisual:
_StepVisual.StepVisual_PreDefinedItem_swigregister(StepVisual_PreDefinedItem)

class StepVisual_PresentationLayerAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a presentationlayerassignment.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PresentationLayerAssignment_swiginit(self, _StepVisual.new_StepVisual_PresentationLayerAssignment(*args))

    def AssignedItems(self, *args) -> "opencascade::handle< StepVisual_HArray1OfLayeredItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfLayeredItem>

        """
        return _StepVisual.StepVisual_PresentationLayerAssignment_AssignedItems(self, *args)

    def AssignedItemsValue(self, *args) -> "StepVisual_LayeredItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepVisual_LayeredItem

        """
        return _StepVisual.StepVisual_PresentationLayerAssignment_AssignedItemsValue(self, *args)

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepVisual.StepVisual_PresentationLayerAssignment_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aAssignedItems: StepVisual_HArray1OfLayeredItem

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationLayerAssignment_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepVisual.StepVisual_PresentationLayerAssignment_Name(self, *args)

    def NbAssignedItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_PresentationLayerAssignment_NbAssignedItems(self, *args)

    def SetAssignedItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedItems: StepVisual_HArray1OfLayeredItem

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationLayerAssignment_SetAssignedItems(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationLayerAssignment_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationLayerAssignment_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PresentationLayerAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentationLayerAssignment

# Register StepVisual_PresentationLayerAssignment in _StepVisual:
_StepVisual.StepVisual_PresentationLayerAssignment_swigregister(StepVisual_PresentationLayerAssignment)

class StepVisual_PresentationLayerUsage(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PresentationLayerUsage_swiginit(self, _StepVisual.new_StepVisual_PresentationLayerUsage(*args))

    def Assignment(self, *args) -> "opencascade::handle< StepVisual_PresentationLayerAssignment >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_PresentationLayerAssignment>

        """
        return _StepVisual.StepVisual_PresentationLayerUsage_Assignment(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignment: StepVisual_PresentationLayerAssignment
        aPresentation: StepVisual_PresentationRepresentation

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationLayerUsage_Init(self, *args)

    def Presentation(self, *args) -> "opencascade::handle< StepVisual_PresentationRepresentation >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_PresentationRepresentation>

        """
        return _StepVisual.StepVisual_PresentationLayerUsage_Presentation(self, *args)

    def SetAssignment(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignment: StepVisual_PresentationLayerAssignment

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationLayerUsage_SetAssignment(self, *args)

    def SetPresentation(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPresentation: StepVisual_PresentationRepresentation

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationLayerUsage_SetPresentation(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PresentationLayerUsage_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentationLayerUsage

# Register StepVisual_PresentationLayerUsage in _StepVisual:
_StepVisual.StepVisual_PresentationLayerUsage_swigregister(StepVisual_PresentationLayerUsage)

class StepVisual_PresentationRepresentation(OCC.Core.StepRepr.StepRepr_Representation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a presentationrepresentation.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PresentationRepresentation_swiginit(self, _StepVisual.new_StepVisual_PresentationRepresentation(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PresentationRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentationRepresentation

# Register StepVisual_PresentationRepresentation in _StepVisual:
_StepVisual.StepVisual_PresentationRepresentation_swigregister(StepVisual_PresentationRepresentation)

class StepVisual_PresentationRepresentationSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a presentationrepresentationselect selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PresentationRepresentationSelect_swiginit(self, _StepVisual.new_StepVisual_PresentationRepresentationSelect(*args))

    def PresentationRepresentation(self, *args) -> "opencascade::handle< StepVisual_PresentationRepresentation >":
        r"""
        Returns value as a presentationrepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PresentationRepresentation>

        """
        return _StepVisual.StepVisual_PresentationRepresentationSelect_PresentationRepresentation(self, *args)

    def PresentationSet(self, *args) -> "opencascade::handle< StepVisual_PresentationSet >":
        r"""
        Returns value as a presentationset (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PresentationSet>

        """
        return _StepVisual.StepVisual_PresentationRepresentationSelect_PresentationSet(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentationRepresentationSelect

# Register StepVisual_PresentationRepresentationSelect in _StepVisual:
_StepVisual.StepVisual_PresentationRepresentationSelect_swigregister(StepVisual_PresentationRepresentationSelect)

class StepVisual_PresentationSet(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a presentationset.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PresentationSet_swiginit(self, _StepVisual.new_StepVisual_PresentationSet(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PresentationSet_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentationSet

# Register StepVisual_PresentationSet in _StepVisual:
_StepVisual.StepVisual_PresentationSet_swigregister(StepVisual_PresentationSet)

class StepVisual_PresentationSize(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a presentationsize.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PresentationSize_swiginit(self, _StepVisual.new_StepVisual_PresentationSize(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aUnit: StepVisual_PresentationSizeAssignmentSelect
        aSize: StepVisual_PlanarBox

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationSize_Init(self, *args)

    def SetSize(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSize: StepVisual_PlanarBox

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationSize_SetSize(self, *args)

    def SetUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aUnit: StepVisual_PresentationSizeAssignmentSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationSize_SetUnit(self, *args)

    def Size(self, *args) -> "opencascade::handle< StepVisual_PlanarBox >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_PlanarBox>

        """
        return _StepVisual.StepVisual_PresentationSize_Size(self, *args)

    def Unit(self, *args) -> "StepVisual_PresentationSizeAssignmentSelect":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_PresentationSizeAssignmentSelect

        """
        return _StepVisual.StepVisual_PresentationSize_Unit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PresentationSize_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentationSize

# Register StepVisual_PresentationSize in _StepVisual:
_StepVisual.StepVisual_PresentationSize_swigregister(StepVisual_PresentationSize)

class StepVisual_PresentationSizeAssignmentSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a presentationsizeassignmentselect selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PresentationSizeAssignmentSelect_swiginit(self, _StepVisual.new_StepVisual_PresentationSizeAssignmentSelect(*args))

    def AreaInSet(self, *args) -> "opencascade::handle< StepVisual_AreaInSet >":
        r"""
        Returns value as a areainset (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_AreaInSet>

        """
        return _StepVisual.StepVisual_PresentationSizeAssignmentSelect_AreaInSet(self, *args)

    def PresentationArea(self, *args) -> "opencascade::handle< StepVisual_PresentationArea >":
        r"""
        Returns value as a presentationarea (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PresentationArea>

        """
        return _StepVisual.StepVisual_PresentationSizeAssignmentSelect_PresentationArea(self, *args)

    def PresentationView(self, *args) -> "opencascade::handle< StepVisual_PresentationView >":
        r"""
        Returns value as a presentationview (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PresentationView>

        """
        return _StepVisual.StepVisual_PresentationSizeAssignmentSelect_PresentationView(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentationSizeAssignmentSelect

# Register StepVisual_PresentationSizeAssignmentSelect in _StepVisual:
_StepVisual.StepVisual_PresentationSizeAssignmentSelect_swigregister(StepVisual_PresentationSizeAssignmentSelect)

class StepVisual_PresentationStyleAssignment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a presentationstyleassignment.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PresentationStyleAssignment_swiginit(self, _StepVisual.new_StepVisual_PresentationStyleAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyles: StepVisual_HArray1OfPresentationStyleSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationStyleAssignment_Init(self, *args)

    def NbStyles(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_PresentationStyleAssignment_NbStyles(self, *args)

    def SetStyles(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyles: StepVisual_HArray1OfPresentationStyleSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationStyleAssignment_SetStyles(self, *args)

    def Styles(self, *args) -> "opencascade::handle< StepVisual_HArray1OfPresentationStyleSelect >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfPresentationStyleSelect>

        """
        return _StepVisual.StepVisual_PresentationStyleAssignment_Styles(self, *args)

    def StylesValue(self, *args) -> "StepVisual_PresentationStyleSelect":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepVisual_PresentationStyleSelect

        """
        return _StepVisual.StepVisual_PresentationStyleAssignment_StylesValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PresentationStyleAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentationStyleAssignment

# Register StepVisual_PresentationStyleAssignment in _StepVisual:
_StepVisual.StepVisual_PresentationStyleAssignment_swigregister(StepVisual_PresentationStyleAssignment)

class StepVisual_PresentationStyleSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a presentationstyleselect selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PresentationStyleSelect_swiginit(self, _StepVisual.new_StepVisual_PresentationStyleSelect(*args))

    def CurveStyle(self, *args) -> "opencascade::handle< StepVisual_CurveStyle >":
        r"""
        Returns value as a curvestyle (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_CurveStyle>

        """
        return _StepVisual.StepVisual_PresentationStyleSelect_CurveStyle(self, *args)

    def NullStyle(self, *args) -> "opencascade::handle< StepVisual_NullStyleMember >":
        r"""
        Returns value as a nullstylemember (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_NullStyleMember>

        """
        return _StepVisual.StepVisual_PresentationStyleSelect_NullStyle(self, *args)

    def PointStyle(self, *args) -> "opencascade::handle< StepVisual_PointStyle >":
        r"""
        Returns value as a pointstyle (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PointStyle>

        """
        return _StepVisual.StepVisual_PresentationStyleSelect_PointStyle(self, *args)

    def SurfaceStyleUsage(self, *args) -> "opencascade::handle< StepVisual_SurfaceStyleUsage >":
        r"""
        Returns value as a surfacestyleusage (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_SurfaceStyleUsage>

        """
        return _StepVisual.StepVisual_PresentationStyleSelect_SurfaceStyleUsage(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentationStyleSelect

# Register StepVisual_PresentationStyleSelect in _StepVisual:
_StepVisual.StepVisual_PresentationStyleSelect_swigregister(StepVisual_PresentationStyleSelect)

class StepVisual_PresentedItem(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PresentedItem_DownCast(t)


    __repr__ = _dumps_object


    def __init__(self):
        _StepVisual.StepVisual_PresentedItem_swiginit(self, _StepVisual.new_StepVisual_PresentedItem())
    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentedItem

# Register StepVisual_PresentedItem in _StepVisual:
_StepVisual.StepVisual_PresentedItem_swigregister(StepVisual_PresentedItem)

class StepVisual_PresentedItemRepresentation(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PresentedItemRepresentation_swiginit(self, _StepVisual.new_StepVisual_PresentedItemRepresentation(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPresentation: StepVisual_PresentationRepresentationSelect
        aItem: StepVisual_PresentedItem

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentedItemRepresentation_Init(self, *args)

    def Item(self, *args) -> "opencascade::handle< StepVisual_PresentedItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_PresentedItem>

        """
        return _StepVisual.StepVisual_PresentedItemRepresentation_Item(self, *args)

    def Presentation(self, *args) -> "StepVisual_PresentationRepresentationSelect":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_PresentationRepresentationSelect

        """
        return _StepVisual.StepVisual_PresentedItemRepresentation_Presentation(self, *args)

    def SetItem(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItem: StepVisual_PresentedItem

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentedItemRepresentation_SetItem(self, *args)

    def SetPresentation(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPresentation: StepVisual_PresentationRepresentationSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentedItemRepresentation_SetPresentation(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PresentedItemRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentedItemRepresentation

# Register StepVisual_PresentedItemRepresentation in _StepVisual:
_StepVisual.StepVisual_PresentedItemRepresentation_swigregister(StepVisual_PresentedItemRepresentation)

class StepVisual_RenderingPropertiesSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_RenderingPropertiesSelect_swiginit(self, _StepVisual.new_StepVisual_RenderingPropertiesSelect(*args))

    def SurfaceStyleReflectanceAmbient(self, *args) -> "opencascade::handle< StepVisual_SurfaceStyleReflectanceAmbient >":
        r"""
        Returns value as surfacestylereflectanceambient (or null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_SurfaceStyleReflectanceAmbient>

        """
        return _StepVisual.StepVisual_RenderingPropertiesSelect_SurfaceStyleReflectanceAmbient(self, *args)

    def SurfaceStyleTransparent(self, *args) -> "opencascade::handle< StepVisual_SurfaceStyleTransparent >":
        r"""
        Returns value as surfacestyletransparent (or null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_SurfaceStyleTransparent>

        """
        return _StepVisual.StepVisual_RenderingPropertiesSelect_SurfaceStyleTransparent(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_RenderingPropertiesSelect

# Register StepVisual_RenderingPropertiesSelect in _StepVisual:
_StepVisual.StepVisual_RenderingPropertiesSelect_swigregister(StepVisual_RenderingPropertiesSelect)

class StepVisual_StyleContextSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a stylecontextselect selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_StyleContextSelect_swiginit(self, _StepVisual.new_StepVisual_StyleContextSelect(*args))

    def PresentationSet(self, *args) -> "opencascade::handle< StepVisual_PresentationSet >":
        r"""
        Returns value as a presentationset (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PresentationSet>

        """
        return _StepVisual.StepVisual_StyleContextSelect_PresentationSet(self, *args)

    def Representation(self, *args) -> "opencascade::handle< StepRepr_Representation >":
        r"""
        Returns value as a representation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_Representation>

        """
        return _StepVisual.StepVisual_StyleContextSelect_Representation(self, *args)

    def RepresentationItem(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem >":
        r"""
        Returns value as a representationitem (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepVisual.StepVisual_StyleContextSelect_RepresentationItem(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_StyleContextSelect

# Register StepVisual_StyleContextSelect in _StepVisual:
_StepVisual.StepVisual_StyleContextSelect_swigregister(StepVisual_StyleContextSelect)

class StepVisual_StyledItem(OCC.Core.StepRepr.StepRepr_RepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a styleditem.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_StyledItem_swiginit(self, _StepVisual.new_StepVisual_StyledItem(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aStyles: StepVisual_HArray1OfPresentationStyleAssignment
        aItem: Standard_Transient

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_StyledItem_Init(self, *args)

    def Item(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepVisual.StepVisual_StyledItem_Item(self, *args)

    def ItemAP242(self, *args) -> "StepVisual_StyledItemTarget":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_StyledItemTarget

        """
        return _StepVisual.StepVisual_StyledItem_ItemAP242(self, *args)

    def NbStyles(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_StyledItem_NbStyles(self, *args)

    def SetItem(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItem: StepRepr_RepresentationItem

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        aItem: StepVisual_StyledItemTarget

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_StyledItem_SetItem(self, *args)

    def SetStyles(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyles: StepVisual_HArray1OfPresentationStyleAssignment

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_StyledItem_SetStyles(self, *args)

    def Styles(self, *args) -> "opencascade::handle< StepVisual_HArray1OfPresentationStyleAssignment > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfPresentationStyleAssignment>

        """
        return _StepVisual.StepVisual_StyledItem_Styles(self, *args)

    def StylesValue(self, *args) -> "opencascade::handle< StepVisual_PresentationStyleAssignment > const &":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<StepVisual_PresentationStyleAssignment>

        """
        return _StepVisual.StepVisual_StyledItem_StylesValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_StyledItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_StyledItem

# Register StepVisual_StyledItem in _StepVisual:
_StepVisual.StepVisual_StyledItem_swigregister(StepVisual_StyledItem)

class StepVisual_StyledItemTarget(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a styleditemtarget select type.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_StyledItemTarget_swiginit(self, _StepVisual.new_StepVisual_StyledItemTarget(*args))

    def GeometricRepresentationItem(self, *args) -> "opencascade::handle< StepGeom_GeometricRepresentationItem >":
        r"""
        Returns value as a geometricrepresentationitem (null if another type).

        Returns
        -------
        opencascade::handle<StepGeom_GeometricRepresentationItem>

        """
        return _StepVisual.StepVisual_StyledItemTarget_GeometricRepresentationItem(self, *args)

    def MappedItem(self, *args) -> "opencascade::handle< StepRepr_MappedItem >":
        r"""
        Returns value as a mappeditem (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_MappedItem>

        """
        return _StepVisual.StepVisual_StyledItemTarget_MappedItem(self, *args)

    def Representation(self, *args) -> "opencascade::handle< StepRepr_Representation >":
        r"""
        Returns value as a representation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_Representation>

        """
        return _StepVisual.StepVisual_StyledItemTarget_Representation(self, *args)

    def TopologicalRepresentationItem(self, *args) -> "opencascade::handle< StepShape_TopologicalRepresentationItem >":
        r"""
        Returns value as a topologicalrepresentationitem (null if another type).

        Returns
        -------
        opencascade::handle<StepShape_TopologicalRepresentationItem>

        """
        return _StepVisual.StepVisual_StyledItemTarget_TopologicalRepresentationItem(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_StyledItemTarget

# Register StepVisual_StyledItemTarget in _StepVisual:
_StepVisual.StepVisual_StyledItemTarget_swigregister(StepVisual_StyledItemTarget)

class StepVisual_SurfaceSideStyle(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a surfacesidestyle.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_SurfaceSideStyle_swiginit(self, _StepVisual.new_StepVisual_SurfaceSideStyle(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aStyles: StepVisual_HArray1OfSurfaceStyleElementSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceSideStyle_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepVisual.StepVisual_SurfaceSideStyle_Name(self, *args)

    def NbStyles(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_SurfaceSideStyle_NbStyles(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceSideStyle_SetName(self, *args)

    def SetStyles(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyles: StepVisual_HArray1OfSurfaceStyleElementSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceSideStyle_SetStyles(self, *args)

    def Styles(self, *args) -> "opencascade::handle< StepVisual_HArray1OfSurfaceStyleElementSelect >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfSurfaceStyleElementSelect>

        """
        return _StepVisual.StepVisual_SurfaceSideStyle_Styles(self, *args)

    def StylesValue(self, *args) -> "StepVisual_SurfaceStyleElementSelect":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepVisual_SurfaceStyleElementSelect

        """
        return _StepVisual.StepVisual_SurfaceSideStyle_StylesValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_SurfaceSideStyle_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_SurfaceSideStyle

# Register StepVisual_SurfaceSideStyle in _StepVisual:
_StepVisual.StepVisual_SurfaceSideStyle_swigregister(StepVisual_SurfaceSideStyle)

class StepVisual_SurfaceStyleBoundary(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a surfacestyleboundary.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_SurfaceStyleBoundary_swiginit(self, _StepVisual.new_StepVisual_SurfaceStyleBoundary(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyleOfBoundary: StepVisual_CurveStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleBoundary_Init(self, *args)

    def SetStyleOfBoundary(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyleOfBoundary: StepVisual_CurveStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleBoundary_SetStyleOfBoundary(self, *args)

    def StyleOfBoundary(self, *args) -> "opencascade::handle< StepVisual_CurveStyle >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_CurveStyle>

        """
        return _StepVisual.StepVisual_SurfaceStyleBoundary_StyleOfBoundary(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_SurfaceStyleBoundary_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_SurfaceStyleBoundary

# Register StepVisual_SurfaceStyleBoundary in _StepVisual:
_StepVisual.StepVisual_SurfaceStyleBoundary_swigregister(StepVisual_SurfaceStyleBoundary)

class StepVisual_SurfaceStyleControlGrid(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a surfacestylecontrolgrid.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_SurfaceStyleControlGrid_swiginit(self, _StepVisual.new_StepVisual_SurfaceStyleControlGrid(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyleOfControlGrid: StepVisual_CurveStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleControlGrid_Init(self, *args)

    def SetStyleOfControlGrid(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyleOfControlGrid: StepVisual_CurveStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleControlGrid_SetStyleOfControlGrid(self, *args)

    def StyleOfControlGrid(self, *args) -> "opencascade::handle< StepVisual_CurveStyle >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_CurveStyle>

        """
        return _StepVisual.StepVisual_SurfaceStyleControlGrid_StyleOfControlGrid(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_SurfaceStyleControlGrid_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_SurfaceStyleControlGrid

# Register StepVisual_SurfaceStyleControlGrid in _StepVisual:
_StepVisual.StepVisual_SurfaceStyleControlGrid_swigregister(StepVisual_SurfaceStyleControlGrid)

class StepVisual_SurfaceStyleElementSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a surfacestyleelementselect selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_SurfaceStyleElementSelect_swiginit(self, _StepVisual.new_StepVisual_SurfaceStyleElementSelect(*args))

    def SurfaceStyleBoundary(self, *args) -> "opencascade::handle< StepVisual_SurfaceStyleBoundary >":
        r"""
        Returns value as a surfacestyleboundary (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_SurfaceStyleBoundary>

        """
        return _StepVisual.StepVisual_SurfaceStyleElementSelect_SurfaceStyleBoundary(self, *args)

    def SurfaceStyleFillArea(self, *args) -> "opencascade::handle< StepVisual_SurfaceStyleFillArea >":
        r"""
        Returns value as a surfacestylefillarea (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_SurfaceStyleFillArea>

        """
        return _StepVisual.StepVisual_SurfaceStyleElementSelect_SurfaceStyleFillArea(self, *args)

    def SurfaceStyleParameterLine(self, *args) -> "opencascade::handle< StepVisual_SurfaceStyleParameterLine >":
        r"""
        Returns value as a surfacestyleparameterline (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_SurfaceStyleParameterLine>

        """
        return _StepVisual.StepVisual_SurfaceStyleElementSelect_SurfaceStyleParameterLine(self, *args)

    def SurfaceStyleRendering(self, *args) -> "opencascade::handle< StepVisual_SurfaceStyleRendering >":
        r"""
        Returns value as a surfacestylerendering (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_SurfaceStyleRendering>

        """
        return _StepVisual.StepVisual_SurfaceStyleElementSelect_SurfaceStyleRendering(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_SurfaceStyleElementSelect

# Register StepVisual_SurfaceStyleElementSelect in _StepVisual:
_StepVisual.StepVisual_SurfaceStyleElementSelect_swigregister(StepVisual_SurfaceStyleElementSelect)

class StepVisual_SurfaceStyleFillArea(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a surfacestylefillarea.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_SurfaceStyleFillArea_swiginit(self, _StepVisual.new_StepVisual_SurfaceStyleFillArea(*args))

    def FillArea(self, *args) -> "opencascade::handle< StepVisual_FillAreaStyle >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_FillAreaStyle>

        """
        return _StepVisual.StepVisual_SurfaceStyleFillArea_FillArea(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFillArea: StepVisual_FillAreaStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleFillArea_Init(self, *args)

    def SetFillArea(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFillArea: StepVisual_FillAreaStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleFillArea_SetFillArea(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_SurfaceStyleFillArea_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_SurfaceStyleFillArea

# Register StepVisual_SurfaceStyleFillArea in _StepVisual:
_StepVisual.StepVisual_SurfaceStyleFillArea_swigregister(StepVisual_SurfaceStyleFillArea)

class StepVisual_SurfaceStyleParameterLine(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a surfacestyleparameterline.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_SurfaceStyleParameterLine_swiginit(self, _StepVisual.new_StepVisual_SurfaceStyleParameterLine(*args))

    def DirectionCounts(self, *args) -> "opencascade::handle< StepVisual_HArray1OfDirectionCountSelect >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfDirectionCountSelect>

        """
        return _StepVisual.StepVisual_SurfaceStyleParameterLine_DirectionCounts(self, *args)

    def DirectionCountsValue(self, *args) -> "StepVisual_DirectionCountSelect":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepVisual_DirectionCountSelect

        """
        return _StepVisual.StepVisual_SurfaceStyleParameterLine_DirectionCountsValue(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyleOfParameterLines: StepVisual_CurveStyle
        aDirectionCounts: StepVisual_HArray1OfDirectionCountSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleParameterLine_Init(self, *args)

    def NbDirectionCounts(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_SurfaceStyleParameterLine_NbDirectionCounts(self, *args)

    def SetDirectionCounts(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDirectionCounts: StepVisual_HArray1OfDirectionCountSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleParameterLine_SetDirectionCounts(self, *args)

    def SetStyleOfParameterLines(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyleOfParameterLines: StepVisual_CurveStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleParameterLine_SetStyleOfParameterLines(self, *args)

    def StyleOfParameterLines(self, *args) -> "opencascade::handle< StepVisual_CurveStyle >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_CurveStyle>

        """
        return _StepVisual.StepVisual_SurfaceStyleParameterLine_StyleOfParameterLines(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_SurfaceStyleParameterLine_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_SurfaceStyleParameterLine

# Register StepVisual_SurfaceStyleParameterLine in _StepVisual:
_StepVisual.StepVisual_SurfaceStyleParameterLine_swigregister(StepVisual_SurfaceStyleParameterLine)

class StepVisual_SurfaceStyleReflectanceAmbient(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Default constructor.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_SurfaceStyleReflectanceAmbient_swiginit(self, _StepVisual.new_StepVisual_SurfaceStyleReflectanceAmbient(*args))

    def AmbientReflectance(self, *args) -> "Standard_Real":
        r"""
        Returns field ambientreflectance.

        Returns
        -------
        float

        """
        return _StepVisual.StepVisual_SurfaceStyleReflectanceAmbient_AmbientReflectance(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        theAmbientReflectance: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleReflectanceAmbient_Init(self, *args)

    def SetAmbientReflectance(self, *args) -> "void":
        r"""
        Sets field ambientreflectance.

        Parameters
        ----------
        theAmbientReflectance: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleReflectanceAmbient_SetAmbientReflectance(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_SurfaceStyleReflectanceAmbient_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_SurfaceStyleReflectanceAmbient

# Register StepVisual_SurfaceStyleReflectanceAmbient in _StepVisual:
_StepVisual.StepVisual_SurfaceStyleReflectanceAmbient_swigregister(StepVisual_SurfaceStyleReflectanceAmbient)

class StepVisual_SurfaceStyleRendering(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Default constructor.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_SurfaceStyleRendering_swiginit(self, _StepVisual.new_StepVisual_SurfaceStyleRendering(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        theRenderingMethod: StepVisual_ShadingSurfaceMethod
        theSurfaceColour: StepVisual_Colour

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleRendering_Init(self, *args)

    def RenderingMethod(self, *args) -> "StepVisual_ShadingSurfaceMethod":
        r"""
        Returns field renderingmethod.

        Returns
        -------
        StepVisual_ShadingSurfaceMethod

        """
        return _StepVisual.StepVisual_SurfaceStyleRendering_RenderingMethod(self, *args)

    def SetRenderingMethod(self, *args) -> "void":
        r"""
        Sets field renderingmethod.

        Parameters
        ----------
        theRenderingMethod: StepVisual_ShadingSurfaceMethod

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleRendering_SetRenderingMethod(self, *args)

    def SetSurfaceColour(self, *args) -> "void":
        r"""
        Sets field surfacecolour.

        Parameters
        ----------
        theSurfaceColour: StepVisual_Colour

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleRendering_SetSurfaceColour(self, *args)

    def SurfaceColour(self, *args) -> "opencascade::handle< StepVisual_Colour >":
        r"""
        Returns field surfacecolour.

        Returns
        -------
        opencascade::handle<StepVisual_Colour>

        """
        return _StepVisual.StepVisual_SurfaceStyleRendering_SurfaceColour(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_SurfaceStyleRendering_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_SurfaceStyleRendering

# Register StepVisual_SurfaceStyleRendering in _StepVisual:
_StepVisual.StepVisual_SurfaceStyleRendering_swigregister(StepVisual_SurfaceStyleRendering)

class StepVisual_SurfaceStyleSegmentationCurve(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a surfacestylesegmentationcurve.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_SurfaceStyleSegmentationCurve_swiginit(self, _StepVisual.new_StepVisual_SurfaceStyleSegmentationCurve(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyleOfSegmentationCurve: StepVisual_CurveStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleSegmentationCurve_Init(self, *args)

    def SetStyleOfSegmentationCurve(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyleOfSegmentationCurve: StepVisual_CurveStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleSegmentationCurve_SetStyleOfSegmentationCurve(self, *args)

    def StyleOfSegmentationCurve(self, *args) -> "opencascade::handle< StepVisual_CurveStyle >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_CurveStyle>

        """
        return _StepVisual.StepVisual_SurfaceStyleSegmentationCurve_StyleOfSegmentationCurve(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_SurfaceStyleSegmentationCurve_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_SurfaceStyleSegmentationCurve

# Register StepVisual_SurfaceStyleSegmentationCurve in _StepVisual:
_StepVisual.StepVisual_SurfaceStyleSegmentationCurve_swigregister(StepVisual_SurfaceStyleSegmentationCurve)

class StepVisual_SurfaceStyleSilhouette(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a surfacestylesilhouette.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_SurfaceStyleSilhouette_swiginit(self, _StepVisual.new_StepVisual_SurfaceStyleSilhouette(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyleOfSilhouette: StepVisual_CurveStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleSilhouette_Init(self, *args)

    def SetStyleOfSilhouette(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyleOfSilhouette: StepVisual_CurveStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleSilhouette_SetStyleOfSilhouette(self, *args)

    def StyleOfSilhouette(self, *args) -> "opencascade::handle< StepVisual_CurveStyle >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_CurveStyle>

        """
        return _StepVisual.StepVisual_SurfaceStyleSilhouette_StyleOfSilhouette(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_SurfaceStyleSilhouette_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_SurfaceStyleSilhouette

# Register StepVisual_SurfaceStyleSilhouette in _StepVisual:
_StepVisual.StepVisual_SurfaceStyleSilhouette_swigregister(StepVisual_SurfaceStyleSilhouette)

class StepVisual_SurfaceStyleTransparent(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Default constructor.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_SurfaceStyleTransparent_swiginit(self, _StepVisual.new_StepVisual_SurfaceStyleTransparent(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        theTransparency: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleTransparent_Init(self, *args)

    def SetTransparency(self, *args) -> "void":
        r"""
        Sets field transparency.

        Parameters
        ----------
        theTransparency: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleTransparent_SetTransparency(self, *args)

    def Transparency(self, *args) -> "Standard_Real":
        r"""
        Returns field transparency.

        Returns
        -------
        float

        """
        return _StepVisual.StepVisual_SurfaceStyleTransparent_Transparency(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_SurfaceStyleTransparent_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_SurfaceStyleTransparent

# Register StepVisual_SurfaceStyleTransparent in _StepVisual:
_StepVisual.StepVisual_SurfaceStyleTransparent_swigregister(StepVisual_SurfaceStyleTransparent)

class StepVisual_SurfaceStyleUsage(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a surfacestyleusage.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_SurfaceStyleUsage_swiginit(self, _StepVisual.new_StepVisual_SurfaceStyleUsage(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSide: StepVisual_SurfaceSide
        aStyle: StepVisual_SurfaceSideStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleUsage_Init(self, *args)

    def SetSide(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSide: StepVisual_SurfaceSide

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleUsage_SetSide(self, *args)

    def SetStyle(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyle: StepVisual_SurfaceSideStyle

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleUsage_SetStyle(self, *args)

    def Side(self, *args) -> "StepVisual_SurfaceSide":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_SurfaceSide

        """
        return _StepVisual.StepVisual_SurfaceStyleUsage_Side(self, *args)

    def Style(self, *args) -> "opencascade::handle< StepVisual_SurfaceSideStyle >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_SurfaceSideStyle>

        """
        return _StepVisual.StepVisual_SurfaceStyleUsage_Style(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_SurfaceStyleUsage_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_SurfaceStyleUsage

# Register StepVisual_SurfaceStyleUsage in _StepVisual:
_StepVisual.StepVisual_SurfaceStyleUsage_swigregister(StepVisual_SurfaceStyleUsage)

class StepVisual_Template(OCC.Core.StepRepr.StepRepr_Representation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a template.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_Template_swiginit(self, _StepVisual.new_StepVisual_Template(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_Template_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_Template

# Register StepVisual_Template in _StepVisual:
_StepVisual.StepVisual_Template_swigregister(StepVisual_Template)

class StepVisual_TemplateInstance(OCC.Core.StepRepr.StepRepr_MappedItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a templateinstance.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_TemplateInstance_swiginit(self, _StepVisual.new_StepVisual_TemplateInstance(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_TemplateInstance_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_TemplateInstance

# Register StepVisual_TemplateInstance in _StepVisual:
_StepVisual.StepVisual_TemplateInstance_swigregister(StepVisual_TemplateInstance)

class StepVisual_TessellatedItem(OCC.Core.StepGeom.StepGeom_GeometricRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a draughtingcalloutelement select type.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_TessellatedItem_swiginit(self, _StepVisual.new_StepVisual_TessellatedItem(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_TessellatedItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_TessellatedItem

# Register StepVisual_TessellatedItem in _StepVisual:
_StepVisual.StepVisual_TessellatedItem_swigregister(StepVisual_TessellatedItem)

class StepVisual_TextLiteral(OCC.Core.StepGeom.StepGeom_GeometricRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a textliteral.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_TextLiteral_swiginit(self, _StepVisual.new_StepVisual_TextLiteral(*args))

    def Alignment(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepVisual.StepVisual_TextLiteral_Alignment(self, *args)

    def Font(self, *args) -> "StepVisual_FontSelect":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_FontSelect

        """
        return _StepVisual.StepVisual_TextLiteral_Font(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aLiteral: TCollection_HAsciiString
        aPlacement: StepGeom_Axis2Placement
        aAlignment: TCollection_HAsciiString
        aPath: StepVisual_TextPath
        aFont: StepVisual_FontSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TextLiteral_Init(self, *args)

    def Literal(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepVisual.StepVisual_TextLiteral_Literal(self, *args)

    def Path(self, *args) -> "StepVisual_TextPath":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_TextPath

        """
        return _StepVisual.StepVisual_TextLiteral_Path(self, *args)

    def Placement(self, *args) -> "StepGeom_Axis2Placement":
        r"""
        No available documentation.

        Returns
        -------
        StepGeom_Axis2Placement

        """
        return _StepVisual.StepVisual_TextLiteral_Placement(self, *args)

    def SetAlignment(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAlignment: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TextLiteral_SetAlignment(self, *args)

    def SetFont(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFont: StepVisual_FontSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TextLiteral_SetFont(self, *args)

    def SetLiteral(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLiteral: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TextLiteral_SetLiteral(self, *args)

    def SetPath(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPath: StepVisual_TextPath

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TextLiteral_SetPath(self, *args)

    def SetPlacement(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPlacement: StepGeom_Axis2Placement

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TextLiteral_SetPlacement(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_TextLiteral_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_TextLiteral

# Register StepVisual_TextLiteral in _StepVisual:
_StepVisual.StepVisual_TextLiteral_swigregister(StepVisual_TextLiteral)

class StepVisual_TextOrCharacter(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a textorcharacter selecttype.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_TextOrCharacter_swiginit(self, _StepVisual.new_StepVisual_TextOrCharacter(*args))

    def AnnotationText(self, *args) -> "opencascade::handle< StepVisual_AnnotationText >":
        r"""
        Returns value as a annotationtext (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_AnnotationText>

        """
        return _StepVisual.StepVisual_TextOrCharacter_AnnotationText(self, *args)

    def CompositeText(self, *args) -> "opencascade::handle< StepVisual_CompositeText >":
        r"""
        Returns value as a compositetext (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_CompositeText>

        """
        return _StepVisual.StepVisual_TextOrCharacter_CompositeText(self, *args)

    def TextLiteral(self, *args) -> "opencascade::handle< StepVisual_TextLiteral >":
        r"""
        Returns value as a textliteral (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_TextLiteral>

        """
        return _StepVisual.StepVisual_TextOrCharacter_TextLiteral(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_TextOrCharacter

# Register StepVisual_TextOrCharacter in _StepVisual:
_StepVisual.StepVisual_TextOrCharacter_swigregister(StepVisual_TextOrCharacter)

class StepVisual_TextStyle(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a textstyle.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_TextStyle_swiginit(self, _StepVisual.new_StepVisual_TextStyle(*args))

    def CharacterAppearance(self, *args) -> "opencascade::handle< StepVisual_TextStyleForDefinedFont >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_TextStyleForDefinedFont>

        """
        return _StepVisual.StepVisual_TextStyle_CharacterAppearance(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aCharacterAppearance: StepVisual_TextStyleForDefinedFont

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TextStyle_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepVisual.StepVisual_TextStyle_Name(self, *args)

    def SetCharacterAppearance(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aCharacterAppearance: StepVisual_TextStyleForDefinedFont

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TextStyle_SetCharacterAppearance(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TextStyle_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_TextStyle_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_TextStyle

# Register StepVisual_TextStyle in _StepVisual:
_StepVisual.StepVisual_TextStyle_swigregister(StepVisual_TextStyle)

class StepVisual_TextStyleForDefinedFont(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a textstylefordefinedfont.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_TextStyleForDefinedFont_swiginit(self, _StepVisual.new_StepVisual_TextStyleForDefinedFont(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aTextColour: StepVisual_Colour

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TextStyleForDefinedFont_Init(self, *args)

    def SetTextColour(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aTextColour: StepVisual_Colour

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TextStyleForDefinedFont_SetTextColour(self, *args)

    def TextColour(self, *args) -> "opencascade::handle< StepVisual_Colour >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_Colour>

        """
        return _StepVisual.StepVisual_TextStyleForDefinedFont_TextColour(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_TextStyleForDefinedFont_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_TextStyleForDefinedFont

# Register StepVisual_TextStyleForDefinedFont in _StepVisual:
_StepVisual.StepVisual_TextStyleForDefinedFont_swigregister(StepVisual_TextStyleForDefinedFont)

class StepVisual_ViewVolume(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a viewvolume.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_ViewVolume_swiginit(self, _StepVisual.new_StepVisual_ViewVolume(*args))

    def BackPlaneClipping(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepVisual.StepVisual_ViewVolume_BackPlaneClipping(self, *args)

    def BackPlaneDistance(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepVisual.StepVisual_ViewVolume_BackPlaneDistance(self, *args)

    def FrontPlaneClipping(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepVisual.StepVisual_ViewVolume_FrontPlaneClipping(self, *args)

    def FrontPlaneDistance(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepVisual.StepVisual_ViewVolume_FrontPlaneDistance(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aProjectionType: StepVisual_CentralOrParallel
        aProjectionPoint: StepGeom_CartesianPoint
        aViewPlaneDistance: float
        aFrontPlaneDistance: float
        aFrontPlaneClipping: bool
        aBackPlaneDistance: float
        aBackPlaneClipping: bool
        aViewVolumeSidesClipping: bool
        aViewWindow: StepVisual_PlanarBox

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ViewVolume_Init(self, *args)

    def ProjectionPoint(self, *args) -> "opencascade::handle< StepGeom_CartesianPoint >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_CartesianPoint>

        """
        return _StepVisual.StepVisual_ViewVolume_ProjectionPoint(self, *args)

    def ProjectionType(self, *args) -> "StepVisual_CentralOrParallel":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_CentralOrParallel

        """
        return _StepVisual.StepVisual_ViewVolume_ProjectionType(self, *args)

    def SetBackPlaneClipping(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aBackPlaneClipping: bool

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ViewVolume_SetBackPlaneClipping(self, *args)

    def SetBackPlaneDistance(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aBackPlaneDistance: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ViewVolume_SetBackPlaneDistance(self, *args)

    def SetFrontPlaneClipping(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFrontPlaneClipping: bool

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ViewVolume_SetFrontPlaneClipping(self, *args)

    def SetFrontPlaneDistance(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFrontPlaneDistance: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ViewVolume_SetFrontPlaneDistance(self, *args)

    def SetProjectionPoint(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aProjectionPoint: StepGeom_CartesianPoint

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ViewVolume_SetProjectionPoint(self, *args)

    def SetProjectionType(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aProjectionType: StepVisual_CentralOrParallel

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ViewVolume_SetProjectionType(self, *args)

    def SetViewPlaneDistance(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aViewPlaneDistance: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ViewVolume_SetViewPlaneDistance(self, *args)

    def SetViewVolumeSidesClipping(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aViewVolumeSidesClipping: bool

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ViewVolume_SetViewVolumeSidesClipping(self, *args)

    def SetViewWindow(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aViewWindow: StepVisual_PlanarBox

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ViewVolume_SetViewWindow(self, *args)

    def ViewPlaneDistance(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepVisual.StepVisual_ViewVolume_ViewPlaneDistance(self, *args)

    def ViewVolumeSidesClipping(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepVisual.StepVisual_ViewVolume_ViewVolumeSidesClipping(self, *args)

    def ViewWindow(self, *args) -> "opencascade::handle< StepVisual_PlanarBox >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_PlanarBox>

        """
        return _StepVisual.StepVisual_ViewVolume_ViewWindow(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_ViewVolume_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_ViewVolume

# Register StepVisual_ViewVolume in _StepVisual:
_StepVisual.StepVisual_ViewVolume_swigregister(StepVisual_ViewVolume)

class StepVisual_AnnotationOccurrence(StepVisual_StyledItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a annotationoccurrence.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_AnnotationOccurrence_swiginit(self, _StepVisual.new_StepVisual_AnnotationOccurrence(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_AnnotationOccurrence_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_AnnotationOccurrence

# Register StepVisual_AnnotationOccurrence in _StepVisual:
_StepVisual.StepVisual_AnnotationOccurrence_swigregister(StepVisual_AnnotationOccurrence)

class StepVisual_BackgroundColour(StepVisual_Colour):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a backgroundcolour.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_BackgroundColour_swiginit(self, _StepVisual.new_StepVisual_BackgroundColour(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPresentation: StepVisual_AreaOrView

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_BackgroundColour_Init(self, *args)

    def Presentation(self, *args) -> "StepVisual_AreaOrView":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_AreaOrView

        """
        return _StepVisual.StepVisual_BackgroundColour_Presentation(self, *args)

    def SetPresentation(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPresentation: StepVisual_AreaOrView

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_BackgroundColour_SetPresentation(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_BackgroundColour_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_BackgroundColour

# Register StepVisual_BackgroundColour in _StepVisual:
_StepVisual.StepVisual_BackgroundColour_swigregister(StepVisual_BackgroundColour)

class StepVisual_CameraImage2dWithScale(StepVisual_CameraImage):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CameraImage2dWithScale_swiginit(self, _StepVisual.new_StepVisual_CameraImage2dWithScale(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CameraImage2dWithScale_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CameraImage2dWithScale

# Register StepVisual_CameraImage2dWithScale in _StepVisual:
_StepVisual.StepVisual_CameraImage2dWithScale_swigregister(StepVisual_CameraImage2dWithScale)

class StepVisual_CameraImage3dWithScale(StepVisual_CameraImage):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CameraImage3dWithScale_swiginit(self, _StepVisual.new_StepVisual_CameraImage3dWithScale(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CameraImage3dWithScale_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CameraImage3dWithScale

# Register StepVisual_CameraImage3dWithScale in _StepVisual:
_StepVisual.StepVisual_CameraImage3dWithScale_swigregister(StepVisual_CameraImage3dWithScale)

class StepVisual_CameraModelD2(StepVisual_CameraModel):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a cameramodeld2.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CameraModelD2_swiginit(self, _StepVisual.new_StepVisual_CameraModelD2(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aViewWindow: StepVisual_PlanarBox
        aViewWindowClipping: bool

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CameraModelD2_Init(self, *args)

    def SetViewWindow(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aViewWindow: StepVisual_PlanarBox

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CameraModelD2_SetViewWindow(self, *args)

    def SetViewWindowClipping(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aViewWindowClipping: bool

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CameraModelD2_SetViewWindowClipping(self, *args)

    def ViewWindow(self, *args) -> "opencascade::handle< StepVisual_PlanarBox >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_PlanarBox>

        """
        return _StepVisual.StepVisual_CameraModelD2_ViewWindow(self, *args)

    def ViewWindowClipping(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _StepVisual.StepVisual_CameraModelD2_ViewWindowClipping(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CameraModelD2_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CameraModelD2

# Register StepVisual_CameraModelD2 in _StepVisual:
_StepVisual.StepVisual_CameraModelD2_swigregister(StepVisual_CameraModelD2)

class StepVisual_CameraModelD3(StepVisual_CameraModel):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a cameramodeld3.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CameraModelD3_swiginit(self, _StepVisual.new_StepVisual_CameraModelD3(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aViewReferenceSystem: StepGeom_Axis2Placement3d
        aPerspectiveOfVolume: StepVisual_ViewVolume

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CameraModelD3_Init(self, *args)

    def PerspectiveOfVolume(self, *args) -> "opencascade::handle< StepVisual_ViewVolume >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_ViewVolume>

        """
        return _StepVisual.StepVisual_CameraModelD3_PerspectiveOfVolume(self, *args)

    def SetPerspectiveOfVolume(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPerspectiveOfVolume: StepVisual_ViewVolume

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CameraModelD3_SetPerspectiveOfVolume(self, *args)

    def SetViewReferenceSystem(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aViewReferenceSystem: StepGeom_Axis2Placement3d

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CameraModelD3_SetViewReferenceSystem(self, *args)

    def ViewReferenceSystem(self, *args) -> "opencascade::handle< StepGeom_Axis2Placement3d >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Axis2Placement3d>

        """
        return _StepVisual.StepVisual_CameraModelD3_ViewReferenceSystem(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CameraModelD3_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CameraModelD3

# Register StepVisual_CameraModelD3 in _StepVisual:
_StepVisual.StepVisual_CameraModelD3_swigregister(StepVisual_CameraModelD3)

class StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel(StepVisual_DraughtingModel):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel_swiginit(self, _StepVisual.new_StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel

# Register StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel in _StepVisual:
_StepVisual.StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel_swigregister(StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel)

class StepVisual_ColourSpecification(StepVisual_Colour):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a colourspecification.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_ColourSpecification_swiginit(self, _StepVisual.new_StepVisual_ColourSpecification(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ColourSpecification_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepVisual.StepVisual_ColourSpecification_Name(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ColourSpecification_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_ColourSpecification_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_ColourSpecification

# Register StepVisual_ColourSpecification in _StepVisual:
_StepVisual.StepVisual_ColourSpecification_swigregister(StepVisual_ColourSpecification)

class StepVisual_CompositeTextWithExtent(StepVisual_CompositeText):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a compositetextwithextent.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CompositeTextWithExtent_swiginit(self, _StepVisual.new_StepVisual_CompositeTextWithExtent(*args))

    def Extent(self, *args) -> "opencascade::handle< StepVisual_PlanarExtent >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_PlanarExtent>

        """
        return _StepVisual.StepVisual_CompositeTextWithExtent_Extent(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aCollectedText: StepVisual_HArray1OfTextOrCharacter
        aExtent: StepVisual_PlanarExtent

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CompositeTextWithExtent_Init(self, *args)

    def SetExtent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aExtent: StepVisual_PlanarExtent

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CompositeTextWithExtent_SetExtent(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CompositeTextWithExtent_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CompositeTextWithExtent

# Register StepVisual_CompositeTextWithExtent in _StepVisual:
_StepVisual.StepVisual_CompositeTextWithExtent_swigregister(StepVisual_CompositeTextWithExtent)

class StepVisual_ContextDependentInvisibility(StepVisual_Invisibility):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a contextdependentinvisibility.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_ContextDependentInvisibility_swiginit(self, _StepVisual.new_StepVisual_ContextDependentInvisibility(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aInvisibleItems: StepVisual_HArray1OfInvisibleItem
        aPresentationContext: StepVisual_InvisibilityContext

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ContextDependentInvisibility_Init(self, *args)

    def PresentationContext(self, *args) -> "StepVisual_InvisibilityContext":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_InvisibilityContext

        """
        return _StepVisual.StepVisual_ContextDependentInvisibility_PresentationContext(self, *args)

    def SetPresentationContext(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPresentationContext: StepVisual_InvisibilityContext

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ContextDependentInvisibility_SetPresentationContext(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_ContextDependentInvisibility_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_ContextDependentInvisibility

# Register StepVisual_ContextDependentInvisibility in _StepVisual:
_StepVisual.StepVisual_ContextDependentInvisibility_swigregister(StepVisual_ContextDependentInvisibility)

class StepVisual_CoordinatesList(StepVisual_TessellatedItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a coordinate list.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CoordinatesList_swiginit(self, _StepVisual.new_StepVisual_CoordinatesList(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theName: TCollection_HAsciiString
        thePoints: TColgp_HArray1OfXYZ

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CoordinatesList_Init(self, *args)

    def Points(self, *args) -> "opencascade::handle< TColgp_HArray1OfXYZ >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TColgp_HArray1OfXYZ>

        """
        return _StepVisual.StepVisual_CoordinatesList_Points(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CoordinatesList_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CoordinatesList

# Register StepVisual_CoordinatesList in _StepVisual:
_StepVisual.StepVisual_CoordinatesList_swigregister(StepVisual_CoordinatesList)

class StepVisual_MechanicalDesignGeometricPresentationRepresentation(StepVisual_PresentationRepresentation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a mechanicaldesigngeometricpresentationrepresentation.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_MechanicalDesignGeometricPresentationRepresentation_swiginit(self, _StepVisual.new_StepVisual_MechanicalDesignGeometricPresentationRepresentation(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_MechanicalDesignGeometricPresentationRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_MechanicalDesignGeometricPresentationRepresentation

# Register StepVisual_MechanicalDesignGeometricPresentationRepresentation in _StepVisual:
_StepVisual.StepVisual_MechanicalDesignGeometricPresentationRepresentation_swigregister(StepVisual_MechanicalDesignGeometricPresentationRepresentation)

class StepVisual_OverRidingStyledItem(StepVisual_StyledItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a overridingstyleditem.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_OverRidingStyledItem_swiginit(self, _StepVisual.new_StepVisual_OverRidingStyledItem(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aStyles: StepVisual_HArray1OfPresentationStyleAssignment
        aItem: Standard_Transient
        aOverRiddenStyle: StepVisual_StyledItem

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_OverRidingStyledItem_Init(self, *args)

    def OverRiddenStyle(self, *args) -> "opencascade::handle< StepVisual_StyledItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_StyledItem>

        """
        return _StepVisual.StepVisual_OverRidingStyledItem_OverRiddenStyle(self, *args)

    def SetOverRiddenStyle(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aOverRiddenStyle: StepVisual_StyledItem

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_OverRidingStyledItem_SetOverRiddenStyle(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_OverRidingStyledItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_OverRidingStyledItem

# Register StepVisual_OverRidingStyledItem in _StepVisual:
_StepVisual.StepVisual_OverRidingStyledItem_swigregister(StepVisual_OverRidingStyledItem)

class StepVisual_PlanarBox(StepVisual_PlanarExtent):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a planarbox.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PlanarBox_swiginit(self, _StepVisual.new_StepVisual_PlanarBox(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aSizeInX: float
        aSizeInY: float
        aPlacement: StepGeom_Axis2Placement

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PlanarBox_Init(self, *args)

    def Placement(self, *args) -> "StepGeom_Axis2Placement":
        r"""
        No available documentation.

        Returns
        -------
        StepGeom_Axis2Placement

        """
        return _StepVisual.StepVisual_PlanarBox_Placement(self, *args)

    def SetPlacement(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPlacement: StepGeom_Axis2Placement

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PlanarBox_SetPlacement(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PlanarBox_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PlanarBox

# Register StepVisual_PlanarBox in _StepVisual:
_StepVisual.StepVisual_PlanarBox_swigregister(StepVisual_PlanarBox)

class StepVisual_PreDefinedColour(StepVisual_Colour):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a predefinedcolour.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PreDefinedColour_swiginit(self, _StepVisual.new_StepVisual_PreDefinedColour(*args))

    def GetPreDefinedItem(self, *args) -> "opencascade::handle< StepVisual_PreDefinedItem > const &":
        r"""
        Return a pre_defined_item part.

        Returns
        -------
        opencascade::handle<StepVisual_PreDefinedItem>

        """
        return _StepVisual.StepVisual_PreDefinedColour_GetPreDefinedItem(self, *args)

    def SetPreDefinedItem(self, *args) -> "void":
        r"""
        Set a pre_defined_item part.

        Parameters
        ----------
        item: StepVisual_PreDefinedItem

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PreDefinedColour_SetPreDefinedItem(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PreDefinedColour_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PreDefinedColour

# Register StepVisual_PreDefinedColour in _StepVisual:
_StepVisual.StepVisual_PreDefinedColour_swigregister(StepVisual_PreDefinedColour)

class StepVisual_PreDefinedCurveFont(StepVisual_PreDefinedItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a predefinedcurvefont.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PreDefinedCurveFont_swiginit(self, _StepVisual.new_StepVisual_PreDefinedCurveFont(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PreDefinedCurveFont_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PreDefinedCurveFont

# Register StepVisual_PreDefinedCurveFont in _StepVisual:
_StepVisual.StepVisual_PreDefinedCurveFont_swigregister(StepVisual_PreDefinedCurveFont)

class StepVisual_PreDefinedTextFont(StepVisual_PreDefinedItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a predefinedtextfont.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PreDefinedTextFont_swiginit(self, _StepVisual.new_StepVisual_PreDefinedTextFont(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PreDefinedTextFont_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PreDefinedTextFont

# Register StepVisual_PreDefinedTextFont in _StepVisual:
_StepVisual.StepVisual_PreDefinedTextFont_swigregister(StepVisual_PreDefinedTextFont)

class StepVisual_PresentationArea(StepVisual_PresentationRepresentation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a presentationarea.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PresentationArea_swiginit(self, _StepVisual.new_StepVisual_PresentationArea(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PresentationArea_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentationArea

# Register StepVisual_PresentationArea in _StepVisual:
_StepVisual.StepVisual_PresentationArea_swigregister(StepVisual_PresentationArea)

class StepVisual_PresentationStyleByContext(StepVisual_PresentationStyleAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a presentationstylebycontext.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PresentationStyleByContext_swiginit(self, _StepVisual.new_StepVisual_PresentationStyleByContext(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyles: StepVisual_HArray1OfPresentationStyleSelect
        aStyleContext: StepVisual_StyleContextSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationStyleByContext_Init(self, *args)

    def SetStyleContext(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyleContext: StepVisual_StyleContextSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_PresentationStyleByContext_SetStyleContext(self, *args)

    def StyleContext(self, *args) -> "StepVisual_StyleContextSelect":
        r"""
        No available documentation.

        Returns
        -------
        StepVisual_StyleContextSelect

        """
        return _StepVisual.StepVisual_PresentationStyleByContext_StyleContext(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PresentationStyleByContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentationStyleByContext

# Register StepVisual_PresentationStyleByContext in _StepVisual:
_StepVisual.StepVisual_PresentationStyleByContext_swigregister(StepVisual_PresentationStyleByContext)

class StepVisual_PresentationView(StepVisual_PresentationRepresentation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a presentationview.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_PresentationView_swiginit(self, _StepVisual.new_StepVisual_PresentationView(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_PresentationView_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_PresentationView

# Register StepVisual_PresentationView in _StepVisual:
_StepVisual.StepVisual_PresentationView_swigregister(StepVisual_PresentationView)

class StepVisual_SurfaceStyleRenderingWithProperties(StepVisual_SurfaceStyleRendering):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Default constructor.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_SurfaceStyleRenderingWithProperties_swiginit(self, _StepVisual.new_StepVisual_SurfaceStyleRenderingWithProperties(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        theSurfaceStyleRendering_RenderingMethod: StepVisual_ShadingSurfaceMethod
        theSurfaceStyleRendering_SurfaceColour: StepVisual_Colour
        theProperties: StepVisual_HArray1OfRenderingPropertiesSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleRenderingWithProperties_Init(self, *args)

    def Properties(self, *args) -> "opencascade::handle< StepVisual_HArray1OfRenderingPropertiesSelect >":
        r"""
        Returns field properties.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfRenderingPropertiesSelect>

        """
        return _StepVisual.StepVisual_SurfaceStyleRenderingWithProperties_Properties(self, *args)

    def SetProperties(self, *args) -> "void":
        r"""
        Sets field properties.

        Parameters
        ----------
        theProperties: StepVisual_HArray1OfRenderingPropertiesSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_SurfaceStyleRenderingWithProperties_SetProperties(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_SurfaceStyleRenderingWithProperties_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_SurfaceStyleRenderingWithProperties

# Register StepVisual_SurfaceStyleRenderingWithProperties in _StepVisual:
_StepVisual.StepVisual_SurfaceStyleRenderingWithProperties_swigregister(StepVisual_SurfaceStyleRenderingWithProperties)

class StepVisual_TessellatedAnnotationOccurrence(StepVisual_StyledItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a tesselatedannotationoccurence.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_TessellatedAnnotationOccurrence_swiginit(self, _StepVisual.new_StepVisual_TessellatedAnnotationOccurrence(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_TessellatedAnnotationOccurrence_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_TessellatedAnnotationOccurrence

# Register StepVisual_TessellatedAnnotationOccurrence in _StepVisual:
_StepVisual.StepVisual_TessellatedAnnotationOccurrence_swigregister(StepVisual_TessellatedAnnotationOccurrence)

class StepVisual_TessellatedCurveSet(StepVisual_TessellatedItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a draughtingcalloutelement select type.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_TessellatedCurveSet_swiginit(self, _StepVisual.new_StepVisual_TessellatedCurveSet(*args))

    def CoordList(self, *args) -> "opencascade::handle< StepVisual_CoordinatesList >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_CoordinatesList>

        """
        return _StepVisual.StepVisual_TessellatedCurveSet_CoordList(self, *args)

    def Curves(self, *args) -> "NCollection_Handle< StepVisual_VectorOfHSequenceOfInteger >":
        r"""
        No available documentation.

        Returns
        -------
        NCollection_Handle<StepVisual_VectorOfHSequenceOfInteger >

        """
        return _StepVisual.StepVisual_TessellatedCurveSet_Curves(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theName: TCollection_HAsciiString
        theCoordList: StepVisual_CoordinatesList
        theCurves: NCollection_Handle<StepVisual_VectorOfHSequenceOfInteger>

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TessellatedCurveSet_Init(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_TessellatedCurveSet_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_TessellatedCurveSet

# Register StepVisual_TessellatedCurveSet in _StepVisual:
_StepVisual.StepVisual_TessellatedCurveSet_swigregister(StepVisual_TessellatedCurveSet)

class StepVisual_TessellatedGeometricSet(StepVisual_TessellatedItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a draughtingcalloutelement select type.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_TessellatedGeometricSet_swiginit(self, _StepVisual.new_StepVisual_TessellatedGeometricSet(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theName: TCollection_HAsciiString
        theItems: NCollection_Handle<StepVisual_Array1OfTessellatedItem>

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TessellatedGeometricSet_Init(self, *args)

    def Items(self, *args) -> "NCollection_Handle< StepVisual_Array1OfTessellatedItem >":
        r"""
        No available documentation.

        Returns
        -------
        NCollection_Handle<StepVisual_Array1OfTessellatedItem >

        """
        return _StepVisual.StepVisual_TessellatedGeometricSet_Items(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_TessellatedGeometricSet_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_TessellatedGeometricSet

# Register StepVisual_TessellatedGeometricSet in _StepVisual:
_StepVisual.StepVisual_TessellatedGeometricSet_swigregister(StepVisual_TessellatedGeometricSet)

class StepVisual_TextStyleWithBoxCharacteristics(StepVisual_TextStyle):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a textstylewithboxcharacteristics.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_TextStyleWithBoxCharacteristics_swiginit(self, _StepVisual.new_StepVisual_TextStyleWithBoxCharacteristics(*args))

    def Characteristics(self, *args) -> "opencascade::handle< StepVisual_HArray1OfBoxCharacteristicSelect >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfBoxCharacteristicSelect>

        """
        return _StepVisual.StepVisual_TextStyleWithBoxCharacteristics_Characteristics(self, *args)

    def CharacteristicsValue(self, *args) -> "StepVisual_BoxCharacteristicSelect":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepVisual_BoxCharacteristicSelect

        """
        return _StepVisual.StepVisual_TextStyleWithBoxCharacteristics_CharacteristicsValue(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aCharacterAppearance: StepVisual_TextStyleForDefinedFont
        aCharacteristics: StepVisual_HArray1OfBoxCharacteristicSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TextStyleWithBoxCharacteristics_Init(self, *args)

    def NbCharacteristics(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_TextStyleWithBoxCharacteristics_NbCharacteristics(self, *args)

    def SetCharacteristics(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aCharacteristics: StepVisual_HArray1OfBoxCharacteristicSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_TextStyleWithBoxCharacteristics_SetCharacteristics(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_TextStyleWithBoxCharacteristics_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_TextStyleWithBoxCharacteristics

# Register StepVisual_TextStyleWithBoxCharacteristics in _StepVisual:
_StepVisual.StepVisual_TextStyleWithBoxCharacteristics_swigregister(StepVisual_TextStyleWithBoxCharacteristics)

class StepVisual_AnnotationCurveOccurrence(StepVisual_AnnotationOccurrence):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a annotationcurveoccurrence.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_AnnotationCurveOccurrence_swiginit(self, _StepVisual.new_StepVisual_AnnotationCurveOccurrence(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_AnnotationCurveOccurrence_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_AnnotationCurveOccurrence

# Register StepVisual_AnnotationCurveOccurrence in _StepVisual:
_StepVisual.StepVisual_AnnotationCurveOccurrence_swigregister(StepVisual_AnnotationCurveOccurrence)

class StepVisual_AnnotationFillAreaOccurrence(StepVisual_AnnotationOccurrence):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a annotationfillareaoccurrence.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_AnnotationFillAreaOccurrence_swiginit(self, _StepVisual.new_StepVisual_AnnotationFillAreaOccurrence(*args))

    def FillStyleTarget(self, *args) -> "opencascade::handle< StepGeom_GeometricRepresentationItem >":
        r"""
        Returns field fill_style_target.

        Returns
        -------
        opencascade::handle<StepGeom_GeometricRepresentationItem>

        """
        return _StepVisual.StepVisual_AnnotationFillAreaOccurrence_FillStyleTarget(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        theName: TCollection_HAsciiString
        theStyles: StepVisual_HArray1OfPresentationStyleAssignment
        theItem: Standard_Transient
        theFillStyleTarget: StepGeom_GeometricRepresentationItem

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_AnnotationFillAreaOccurrence_Init(self, *args)

    def SetFillStyleTarget(self, *args) -> "void":
        r"""
        Set field fill_style_target.

        Parameters
        ----------
        theTarget: StepGeom_GeometricRepresentationItem

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_AnnotationFillAreaOccurrence_SetFillStyleTarget(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_AnnotationFillAreaOccurrence_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_AnnotationFillAreaOccurrence

# Register StepVisual_AnnotationFillAreaOccurrence in _StepVisual:
_StepVisual.StepVisual_AnnotationFillAreaOccurrence_swigregister(StepVisual_AnnotationFillAreaOccurrence)

class StepVisual_AnnotationPlane(StepVisual_AnnotationOccurrence):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a annotationplane.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_AnnotationPlane_swiginit(self, _StepVisual.new_StepVisual_AnnotationPlane(*args))

    def Elements(self, *args) -> "opencascade::handle< StepVisual_HArray1OfAnnotationPlaneElement >":
        r"""
        Returns field elements.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfAnnotationPlaneElement>

        """
        return _StepVisual.StepVisual_AnnotationPlane_Elements(self, *args)

    def ElementsValue(self, *args) -> "StepVisual_AnnotationPlaneElement":
        r"""
        Returns elements with the given number.

        Parameters
        ----------
        theNum: int

        Returns
        -------
        StepVisual_AnnotationPlaneElement

        """
        return _StepVisual.StepVisual_AnnotationPlane_ElementsValue(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theName: TCollection_HAsciiString
        theStyles: StepVisual_HArray1OfPresentationStyleAssignment
        theItem: Standard_Transient
        theElements: StepVisual_HArray1OfAnnotationPlaneElement

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_AnnotationPlane_Init(self, *args)

    def NbElements(self, *args) -> "Standard_Integer":
        r"""
        Returns number of elements.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_AnnotationPlane_NbElements(self, *args)

    def SetElements(self, *args) -> "void":
        r"""
        Set field elements.

        Parameters
        ----------
        theElements: StepVisual_HArray1OfAnnotationPlaneElement

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_AnnotationPlane_SetElements(self, *args)

    def SetElementsValue(self, *args) -> "void":
        r"""
        Sets elements with given number.

        Parameters
        ----------
        theNum: int
        theItem: StepVisual_AnnotationPlaneElement

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_AnnotationPlane_SetElementsValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_AnnotationPlane_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_AnnotationPlane

# Register StepVisual_AnnotationPlane in _StepVisual:
_StepVisual.StepVisual_AnnotationPlane_swigregister(StepVisual_AnnotationPlane)

class StepVisual_AnnotationTextOccurrence(StepVisual_AnnotationOccurrence):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a annotationtextoccurrence.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_AnnotationTextOccurrence_swiginit(self, _StepVisual.new_StepVisual_AnnotationTextOccurrence(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_AnnotationTextOccurrence_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_AnnotationTextOccurrence

# Register StepVisual_AnnotationTextOccurrence in _StepVisual:
_StepVisual.StepVisual_AnnotationTextOccurrence_swigregister(StepVisual_AnnotationTextOccurrence)

class StepVisual_CameraModelD3MultiClipping(StepVisual_CameraModelD3):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a cameramodeld3multiclipping.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_CameraModelD3MultiClipping_swiginit(self, _StepVisual.new_StepVisual_CameraModelD3MultiClipping(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theName: TCollection_HAsciiString
        theViewReferenceSystem: StepGeom_Axis2Placement3d
        thePerspectiveOfVolume: StepVisual_ViewVolume
        theShapeClipping: StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CameraModelD3MultiClipping_Init(self, *args)

    def SetShapeClipping(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theShapeClipping: StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_CameraModelD3MultiClipping_SetShapeClipping(self, *args)

    def ShapeClipping(self, *args) -> "opencascade::handle< StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect > const":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect>

        """
        return _StepVisual.StepVisual_CameraModelD3MultiClipping_ShapeClipping(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_CameraModelD3MultiClipping_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_CameraModelD3MultiClipping

# Register StepVisual_CameraModelD3MultiClipping in _StepVisual:
_StepVisual.StepVisual_CameraModelD3MultiClipping_swigregister(StepVisual_CameraModelD3MultiClipping)

class StepVisual_ColourRgb(StepVisual_ColourSpecification):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a colourrgb.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_ColourRgb_swiginit(self, _StepVisual.new_StepVisual_ColourRgb(*args))

    def Blue(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepVisual.StepVisual_ColourRgb_Blue(self, *args)

    def Green(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepVisual.StepVisual_ColourRgb_Green(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aRed: float
        aGreen: float
        aBlue: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ColourRgb_Init(self, *args)

    def Red(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _StepVisual.StepVisual_ColourRgb_Red(self, *args)

    def SetBlue(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aBlue: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ColourRgb_SetBlue(self, *args)

    def SetGreen(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aGreen: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ColourRgb_SetGreen(self, *args)

    def SetRed(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRed: float

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ColourRgb_SetRed(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_ColourRgb_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_ColourRgb

# Register StepVisual_ColourRgb in _StepVisual:
_StepVisual.StepVisual_ColourRgb_swigregister(StepVisual_ColourRgb)

class StepVisual_ContextDependentOverRidingStyledItem(StepVisual_OverRidingStyledItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a contextdependentoverridingstyleditem.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_ContextDependentOverRidingStyledItem_swiginit(self, _StepVisual.new_StepVisual_ContextDependentOverRidingStyledItem(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aStyles: StepVisual_HArray1OfPresentationStyleAssignment
        aItem: Standard_Transient
        aOverRiddenStyle: StepVisual_StyledItem
        aStyleContext: StepVisual_HArray1OfStyleContextSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ContextDependentOverRidingStyledItem_Init(self, *args)

    def NbStyleContext(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepVisual.StepVisual_ContextDependentOverRidingStyledItem_NbStyleContext(self, *args)

    def SetStyleContext(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aStyleContext: StepVisual_HArray1OfStyleContextSelect

        Returns
        -------
        None

        """
        return _StepVisual.StepVisual_ContextDependentOverRidingStyledItem_SetStyleContext(self, *args)

    def StyleContext(self, *args) -> "opencascade::handle< StepVisual_HArray1OfStyleContextSelect >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_HArray1OfStyleContextSelect>

        """
        return _StepVisual.StepVisual_ContextDependentOverRidingStyledItem_StyleContext(self, *args)

    def StyleContextValue(self, *args) -> "StepVisual_StyleContextSelect":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepVisual_StyleContextSelect

        """
        return _StepVisual.StepVisual_ContextDependentOverRidingStyledItem_StyleContextValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_ContextDependentOverRidingStyledItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_ContextDependentOverRidingStyledItem

# Register StepVisual_ContextDependentOverRidingStyledItem in _StepVisual:
_StepVisual.StepVisual_ContextDependentOverRidingStyledItem_swigregister(StepVisual_ContextDependentOverRidingStyledItem)

class StepVisual_DraughtingAnnotationOccurrence(StepVisual_AnnotationOccurrence):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a draughtingannotationoccurrence.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_DraughtingAnnotationOccurrence_swiginit(self, _StepVisual.new_StepVisual_DraughtingAnnotationOccurrence(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_DraughtingAnnotationOccurrence_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_DraughtingAnnotationOccurrence

# Register StepVisual_DraughtingAnnotationOccurrence in _StepVisual:
_StepVisual.StepVisual_DraughtingAnnotationOccurrence_swigregister(StepVisual_DraughtingAnnotationOccurrence)

class StepVisual_DraughtingPreDefinedColour(StepVisual_PreDefinedColour):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a draughtingpredefinedcolour.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_DraughtingPreDefinedColour_swiginit(self, _StepVisual.new_StepVisual_DraughtingPreDefinedColour(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_DraughtingPreDefinedColour_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_DraughtingPreDefinedColour

# Register StepVisual_DraughtingPreDefinedColour in _StepVisual:
_StepVisual.StepVisual_DraughtingPreDefinedColour_swigregister(StepVisual_DraughtingPreDefinedColour)

class StepVisual_DraughtingPreDefinedCurveFont(StepVisual_PreDefinedCurveFont):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a draughtingpredefinedcurvefont.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_DraughtingPreDefinedCurveFont_swiginit(self, _StepVisual.new_StepVisual_DraughtingPreDefinedCurveFont(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_DraughtingPreDefinedCurveFont_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_DraughtingPreDefinedCurveFont

# Register StepVisual_DraughtingPreDefinedCurveFont in _StepVisual:
_StepVisual.StepVisual_DraughtingPreDefinedCurveFont_swigregister(StepVisual_DraughtingPreDefinedCurveFont)

class StepVisual_MechanicalDesignGeometricPresentationArea(StepVisual_PresentationArea):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a mechanicaldesigngeometricpresentationarea.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_MechanicalDesignGeometricPresentationArea_swiginit(self, _StepVisual.new_StepVisual_MechanicalDesignGeometricPresentationArea(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_MechanicalDesignGeometricPresentationArea_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_MechanicalDesignGeometricPresentationArea

# Register StepVisual_MechanicalDesignGeometricPresentationArea in _StepVisual:
_StepVisual.StepVisual_MechanicalDesignGeometricPresentationArea_swigregister(StepVisual_MechanicalDesignGeometricPresentationArea)

class StepVisual_AnnotationCurveOccurrenceAndGeomReprItem(StepVisual_AnnotationCurveOccurrence):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepVisual.StepVisual_AnnotationCurveOccurrenceAndGeomReprItem_swiginit(self, _StepVisual.new_StepVisual_AnnotationCurveOccurrenceAndGeomReprItem(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_AnnotationCurveOccurrenceAndGeomReprItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepVisual.delete_StepVisual_AnnotationCurveOccurrenceAndGeomReprItem

# Register StepVisual_AnnotationCurveOccurrenceAndGeomReprItem in _StepVisual:
_StepVisual.StepVisual_AnnotationCurveOccurrenceAndGeomReprItem_swigregister(StepVisual_AnnotationCurveOccurrenceAndGeomReprItem)

class StepVisual_HArray1OfAnnotationPlaneElement(StepVisual_Array1OfAnnotationPlaneElement, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfAnnotationPlaneElement_swiginit(self, _StepVisual.new_StepVisual_HArray1OfAnnotationPlaneElement(*args))

    def Array1(self) -> "StepVisual_Array1OfAnnotationPlaneElement const &":
        return _StepVisual.StepVisual_HArray1OfAnnotationPlaneElement_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfAnnotationPlaneElement &":
        return _StepVisual.StepVisual_HArray1OfAnnotationPlaneElement_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfAnnotationPlaneElement_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfAnnotationPlaneElement

# Register StepVisual_HArray1OfAnnotationPlaneElement in _StepVisual:
_StepVisual.StepVisual_HArray1OfAnnotationPlaneElement_swigregister(StepVisual_HArray1OfAnnotationPlaneElement)

class StepVisual_HArray1OfDraughtingCalloutElement(StepVisual_Array1OfDraughtingCalloutElement, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfDraughtingCalloutElement_swiginit(self, _StepVisual.new_StepVisual_HArray1OfDraughtingCalloutElement(*args))

    def Array1(self) -> "StepVisual_Array1OfDraughtingCalloutElement const &":
        return _StepVisual.StepVisual_HArray1OfDraughtingCalloutElement_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfDraughtingCalloutElement &":
        return _StepVisual.StepVisual_HArray1OfDraughtingCalloutElement_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfDraughtingCalloutElement_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfDraughtingCalloutElement

# Register StepVisual_HArray1OfDraughtingCalloutElement in _StepVisual:
_StepVisual.StepVisual_HArray1OfDraughtingCalloutElement_swigregister(StepVisual_HArray1OfDraughtingCalloutElement)

class StepVisual_HArray1OfDirectionCountSelect(StepVisual_Array1OfDirectionCountSelect, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfDirectionCountSelect_swiginit(self, _StepVisual.new_StepVisual_HArray1OfDirectionCountSelect(*args))

    def Array1(self) -> "StepVisual_Array1OfDirectionCountSelect const &":
        return _StepVisual.StepVisual_HArray1OfDirectionCountSelect_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfDirectionCountSelect &":
        return _StepVisual.StepVisual_HArray1OfDirectionCountSelect_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfDirectionCountSelect_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfDirectionCountSelect

# Register StepVisual_HArray1OfDirectionCountSelect in _StepVisual:
_StepVisual.StepVisual_HArray1OfDirectionCountSelect_swigregister(StepVisual_HArray1OfDirectionCountSelect)

class StepVisual_HArray1OfStyleContextSelect(StepVisual_Array1OfStyleContextSelect, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfStyleContextSelect_swiginit(self, _StepVisual.new_StepVisual_HArray1OfStyleContextSelect(*args))

    def Array1(self) -> "StepVisual_Array1OfStyleContextSelect const &":
        return _StepVisual.StepVisual_HArray1OfStyleContextSelect_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfStyleContextSelect &":
        return _StepVisual.StepVisual_HArray1OfStyleContextSelect_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfStyleContextSelect_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfStyleContextSelect

# Register StepVisual_HArray1OfStyleContextSelect in _StepVisual:
_StepVisual.StepVisual_HArray1OfStyleContextSelect_swigregister(StepVisual_HArray1OfStyleContextSelect)

class StepVisual_HArray1OfPresentationStyleSelect(StepVisual_Array1OfPresentationStyleSelect, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfPresentationStyleSelect_swiginit(self, _StepVisual.new_StepVisual_HArray1OfPresentationStyleSelect(*args))

    def Array1(self) -> "StepVisual_Array1OfPresentationStyleSelect const &":
        return _StepVisual.StepVisual_HArray1OfPresentationStyleSelect_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfPresentationStyleSelect &":
        return _StepVisual.StepVisual_HArray1OfPresentationStyleSelect_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfPresentationStyleSelect_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfPresentationStyleSelect

# Register StepVisual_HArray1OfPresentationStyleSelect in _StepVisual:
_StepVisual.StepVisual_HArray1OfPresentationStyleSelect_swigregister(StepVisual_HArray1OfPresentationStyleSelect)

class StepVisual_HArray1OfCurveStyleFontPattern(StepVisual_Array1OfCurveStyleFontPattern, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfCurveStyleFontPattern_swiginit(self, _StepVisual.new_StepVisual_HArray1OfCurveStyleFontPattern(*args))

    def Array1(self) -> "StepVisual_Array1OfCurveStyleFontPattern const &":
        return _StepVisual.StepVisual_HArray1OfCurveStyleFontPattern_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfCurveStyleFontPattern &":
        return _StepVisual.StepVisual_HArray1OfCurveStyleFontPattern_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfCurveStyleFontPattern_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfCurveStyleFontPattern

# Register StepVisual_HArray1OfCurveStyleFontPattern in _StepVisual:
_StepVisual.StepVisual_HArray1OfCurveStyleFontPattern_swigregister(StepVisual_HArray1OfCurveStyleFontPattern)

class StepVisual_HArray1OfRenderingPropertiesSelect(StepVisual_Array1OfRenderingPropertiesSelect, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfRenderingPropertiesSelect_swiginit(self, _StepVisual.new_StepVisual_HArray1OfRenderingPropertiesSelect(*args))

    def Array1(self) -> "StepVisual_Array1OfRenderingPropertiesSelect const &":
        return _StepVisual.StepVisual_HArray1OfRenderingPropertiesSelect_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfRenderingPropertiesSelect &":
        return _StepVisual.StepVisual_HArray1OfRenderingPropertiesSelect_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfRenderingPropertiesSelect_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfRenderingPropertiesSelect

# Register StepVisual_HArray1OfRenderingPropertiesSelect in _StepVisual:
_StepVisual.StepVisual_HArray1OfRenderingPropertiesSelect_swigregister(StepVisual_HArray1OfRenderingPropertiesSelect)

class StepVisual_HArray1OfBoxCharacteristicSelect(StepVisual_Array1OfBoxCharacteristicSelect, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfBoxCharacteristicSelect_swiginit(self, _StepVisual.new_StepVisual_HArray1OfBoxCharacteristicSelect(*args))

    def Array1(self) -> "StepVisual_Array1OfBoxCharacteristicSelect const &":
        return _StepVisual.StepVisual_HArray1OfBoxCharacteristicSelect_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfBoxCharacteristicSelect &":
        return _StepVisual.StepVisual_HArray1OfBoxCharacteristicSelect_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfBoxCharacteristicSelect_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfBoxCharacteristicSelect

# Register StepVisual_HArray1OfBoxCharacteristicSelect in _StepVisual:
_StepVisual.StepVisual_HArray1OfBoxCharacteristicSelect_swigregister(StepVisual_HArray1OfBoxCharacteristicSelect)

class StepVisual_HArray1OfPresentationStyleAssignment(StepVisual_Array1OfPresentationStyleAssignment, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfPresentationStyleAssignment_swiginit(self, _StepVisual.new_StepVisual_HArray1OfPresentationStyleAssignment(*args))

    def Array1(self) -> "StepVisual_Array1OfPresentationStyleAssignment const &":
        return _StepVisual.StepVisual_HArray1OfPresentationStyleAssignment_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfPresentationStyleAssignment &":
        return _StepVisual.StepVisual_HArray1OfPresentationStyleAssignment_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfPresentationStyleAssignment_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfPresentationStyleAssignment

# Register StepVisual_HArray1OfPresentationStyleAssignment in _StepVisual:
_StepVisual.StepVisual_HArray1OfPresentationStyleAssignment_swigregister(StepVisual_HArray1OfPresentationStyleAssignment)

class StepVisual_HArray1OfFillStyleSelect(StepVisual_Array1OfFillStyleSelect, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfFillStyleSelect_swiginit(self, _StepVisual.new_StepVisual_HArray1OfFillStyleSelect(*args))

    def Array1(self) -> "StepVisual_Array1OfFillStyleSelect const &":
        return _StepVisual.StepVisual_HArray1OfFillStyleSelect_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfFillStyleSelect &":
        return _StepVisual.StepVisual_HArray1OfFillStyleSelect_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfFillStyleSelect_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfFillStyleSelect

# Register StepVisual_HArray1OfFillStyleSelect in _StepVisual:
_StepVisual.StepVisual_HArray1OfFillStyleSelect_swigregister(StepVisual_HArray1OfFillStyleSelect)

class StepVisual_HArray1OfTextOrCharacter(StepVisual_Array1OfTextOrCharacter, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfTextOrCharacter_swiginit(self, _StepVisual.new_StepVisual_HArray1OfTextOrCharacter(*args))

    def Array1(self) -> "StepVisual_Array1OfTextOrCharacter const &":
        return _StepVisual.StepVisual_HArray1OfTextOrCharacter_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfTextOrCharacter &":
        return _StepVisual.StepVisual_HArray1OfTextOrCharacter_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfTextOrCharacter_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfTextOrCharacter

# Register StepVisual_HArray1OfTextOrCharacter in _StepVisual:
_StepVisual.StepVisual_HArray1OfTextOrCharacter_swigregister(StepVisual_HArray1OfTextOrCharacter)

class StepVisual_HArray1OfSurfaceStyleElementSelect(StepVisual_Array1OfSurfaceStyleElementSelect, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfSurfaceStyleElementSelect_swiginit(self, _StepVisual.new_StepVisual_HArray1OfSurfaceStyleElementSelect(*args))

    def Array1(self) -> "StepVisual_Array1OfSurfaceStyleElementSelect const &":
        return _StepVisual.StepVisual_HArray1OfSurfaceStyleElementSelect_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfSurfaceStyleElementSelect &":
        return _StepVisual.StepVisual_HArray1OfSurfaceStyleElementSelect_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfSurfaceStyleElementSelect_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfSurfaceStyleElementSelect

# Register StepVisual_HArray1OfSurfaceStyleElementSelect in _StepVisual:
_StepVisual.StepVisual_HArray1OfSurfaceStyleElementSelect_swigregister(StepVisual_HArray1OfSurfaceStyleElementSelect)

class StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect(StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect_swiginit(self, _StepVisual.new_StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect(*args))

    def Array1(self) -> "StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect const &":
        return _StepVisual.StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfCameraModelD3MultiClippingUnionSelect &":
        return _StepVisual.StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect

# Register StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect in _StepVisual:
_StepVisual.StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect_swigregister(StepVisual_HArray1OfCameraModelD3MultiClippingUnionSelect)

class StepVisual_HArray1OfLayeredItem(StepVisual_Array1OfLayeredItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfLayeredItem_swiginit(self, _StepVisual.new_StepVisual_HArray1OfLayeredItem(*args))

    def Array1(self) -> "StepVisual_Array1OfLayeredItem const &":
        return _StepVisual.StepVisual_HArray1OfLayeredItem_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfLayeredItem &":
        return _StepVisual.StepVisual_HArray1OfLayeredItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfLayeredItem_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfLayeredItem

# Register StepVisual_HArray1OfLayeredItem in _StepVisual:
_StepVisual.StepVisual_HArray1OfLayeredItem_swigregister(StepVisual_HArray1OfLayeredItem)

class StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect(StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect_swiginit(self, _StepVisual.new_StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect(*args))

    def Array1(self) -> "StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect const &":
        return _StepVisual.StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfCameraModelD3MultiClippingInterectionSelect &":
        return _StepVisual.StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect

# Register StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect in _StepVisual:
_StepVisual.StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect_swigregister(StepVisual_HArray1OfCameraModelD3MultiClippingInterectionSelect)

class StepVisual_HArray1OfInvisibleItem(StepVisual_Array1OfInvisibleItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepVisual.StepVisual_HArray1OfInvisibleItem_swiginit(self, _StepVisual.new_StepVisual_HArray1OfInvisibleItem(*args))

    def Array1(self) -> "StepVisual_Array1OfInvisibleItem const &":
        return _StepVisual.StepVisual_HArray1OfInvisibleItem_Array1(self)

    def ChangeArray1(self) -> "StepVisual_Array1OfInvisibleItem &":
        return _StepVisual.StepVisual_HArray1OfInvisibleItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepVisual_HArray1OfInvisibleItem_DownCast(t)

    __swig_destroy__ = _StepVisual.delete_StepVisual_HArray1OfInvisibleItem

# Register StepVisual_HArray1OfInvisibleItem in _StepVisual:
_StepVisual.StepVisual_HArray1OfInvisibleItem_swigregister(StepVisual_HArray1OfInvisibleItem)





